/*
** ###################################################################
**     Processors:          MCIMX7U5CVM05
**                          MCIMX7U5DVK08
**
**     Compilers:           Keil ARM C/C++ Compiler
**                          GNU C Compiler
**                          GNU C Compiler - CodeSourcery Sourcery G++
**                          IAR ANSI C/C++ Compiler for ARM
**
**     Reference manual:    i.MX7ULPRM, Rev. C, Jun. 2016
**     Version:             rev. 2.0, 2016-07-19
**     Build:               b160722
**
**     Abstract:
**         Provides a system configuration function and a global variable that
**         contains the system frequency. It configures the device and initializes
**         the oscillator (PLL) that is part of the microcontroller device.
**
**     Copyright (c) 2016 Freescale Semiconductor, Inc.
**     All rights reserved.
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of Freescale Semiconductor, Inc. nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**     http:                 www.freescale.com
**     mail:                 support@freescale.com
**
**     Revisions:
**     - rev. 1.0 (2016-04-13)
**         Initial version.
**     - rev. 2.0 (2016-07-19)
**         RevC Header ER
**
** ###################################################################
*/

/*!
 * @file MCIMX7U5_M4
 * @version 2.0
 * @date 2016-07-19
 * @brief Device specific configuration file for MCIMX7U5_M4 (implementation
 *        file)
 *
 * Provides a system configuration function and a global variable that contains
 * the system frequency. It configures the device and initializes the oscillator
 * (PLL) that is part of the microcontroller device.
 */

#include <stdint.h>
#include "MCIMX7U5_M4.h"



/* ----------------------------------------------------------------------------
   -- Core clock
   ---------------------------------------------------------------------------- */

uint32_t SystemCoreClock = DEFAULT_SYSTEM_CLOCK;

/* ----------------------------------------------------------------------------
   -- SystemInit()
   ---------------------------------------------------------------------------- */

void SystemInit (void) {
#if ((__FPU_PRESENT == 1) && (__FPU_USED == 1))
  SCB->CPACR |= ((3UL << 10*2) | (3UL << 11*2));    /* set CP10, CP11 Full Access */
#endif /* ((__FPU_PRESENT == 1) && (__FPU_USED == 1)) */

/* i.MX7ULP systemInit */
#if (DISABLE_WDOG)
  WDOG0->CS = (uint32_t) ((WDOG0->CS) & ~WDOG_CS_EN_MASK) | WDOG_CS_UPDATE_MASK | WDOG_CS_CMD32EN_MASK;
  WDOG0->TOVAL = 0xFFFF;
  WDOG0->CNT = WDOG_REFRESH_KEY;
  WDOG0->CNT = WDOG_REFRESH_KEY>>16;
#endif /* (DISABLE_WDOG) */

  /* Enable Code Bus Cache */
  /* set command to invalidate all ways and write GO bit
     to initiate command */
  LMEM->PCCCR = LMEM_PCCCR_INVW1_MASK | LMEM_PCCCR_INVW0_MASK;
  LMEM->PCCCR |= LMEM_PCCCR_GO_MASK;
  /* Wait until the command completes */
  while (LMEM->PCCCR & LMEM_PCCCR_GO_MASK)
  {}
  /* Enable code bus cache, enable write buffer */
  LMEM->PCCCR = (LMEM_PCCCR_ENWRBUF_MASK | LMEM_PCCCR_ENCACHE_MASK);
  __ISB();
  __DSB();
}

/* ----------------------------------------------------------------------------
   -- SystemCoreClockUpdate()
   ---------------------------------------------------------------------------- */

void SystemCoreClockUpdate (void) {

  /* i.MX7ULP systemCoreClockUpdate */
  uint32_t SCGOUTClock, apllNum, apllDenom;

  /* Identify current system clock source. */
  switch (SCG0->CSR & SCG_CSR_SCS_MASK)
  {
    /* System OSC */
    case SCG_CSR_SCS(1):
      SCGOUTClock = CPU_XTAL_SOSC_CLK_HZ;
      break;

    /* Slow IRC */
    case SCG_CSR_SCS(2):
      SCGOUTClock = ((0 == (SCG0->SIRCCFG & SCG_SIRCCFG_RANGE_MASK)) ? 4000000u : 16000000u);
      break;

    /* Fast IRC */
    case SCG_CSR_SCS(3):
      SCGOUTClock = 48000000u + ((SCG0->FIRCCFG & SCG_FIRCCFG_RANGE_MASK) >> SCG_FIRCCFG_RANGE_SHIFT) * 4000000u;
      break;

    /* RTC OSC */
    case SCG_CSR_SCS(4):
      SCGOUTClock = 32768u;
      break;

    /* System PLL */
    case SCG_CSR_SCS(5):
      /* System clock from SPLL. */
      SCGOUTClock = (0 == (SCG0->SPLLCFG & SCG_SPLLCFG_SOURCE_MASK)) ? CPU_XTAL_SOSC_CLK_HZ :
                    (48000000u + ((SCG0->FIRCCFG & SCG_FIRCCFG_RANGE_MASK) >> SCG_FIRCCFG_RANGE_SHIFT) * 4000000u);
      SCGOUTClock /= ((SCG0->SPLLCFG & SCG_SPLLCFG_PREDIV_MASK) >> SCG_SPLLCFG_PREDIV_SHIFT) + 1;
      SCGOUTClock *= ((SCG0->SPLLCFG & SCG_SPLLCFG_MULT_MASK) >> SCG_SPLLCFG_MULT_SHIFT);

      /* Is Core clock from PLL directly? */
      if (0 == (SCG0->SPLLCFG & SCG_SPLLCFG_PLLS_MASK))
      {
        /* System clock from SPLL directly. */
        SCGOUTClock /= (((SCG0->SPLLCFG & SCG_SPLLCFG_PLLPOSTDIV1_MASK) >> SCG_SPLLCFG_PLLPOSTDIV1_SHIFT) + 1);
        SCGOUTClock /= (((SCG0->SPLLCFG & SCG_SPLLCFG_PLLPOSTDIV2_MASK) >> SCG_SPLLCFG_PLLPOSTDIV2_SHIFT) + 1);
      }
      else
      {
        /* System clock from SPLL PFD. */
        /* Is SPLL PFD bypassed? */
        if (0 == (SCG0->SPLLCFG & SCG_SPLLCFG_BYPASS_MASK))
        {
          /* SPLL PFD output clock. */
          switch (SCG0->SPLLCFG & SCG_SPLLCFG_PFDSEL_MASK)
          {
            case SCG_SPLLCFG_PFDSEL(0):
              SCGOUTClock = (SCGOUTClock * 18) / ((SCG0->SPLLPFD & SCG_SPLLPFD_PFD0_MASK) >> SCG_SPLLPFD_PFD0_SHIFT);
              break;

            case SCG_SPLLCFG_PFDSEL(1):
              SCGOUTClock = (SCGOUTClock * 18) / ((SCG0->SPLLPFD & SCG_SPLLPFD_PFD1_MASK) >> SCG_SPLLPFD_PFD1_SHIFT);
              break;

            case SCG_SPLLCFG_PFDSEL(2):
              SCGOUTClock = (SCGOUTClock * 18) / ((SCG0->SPLLPFD & SCG_SPLLPFD_PFD2_MASK) >> SCG_SPLLPFD_PFD2_SHIFT);
              break;

            case SCG_SPLLCFG_PFDSEL(3):
              SCGOUTClock = (SCGOUTClock * 18) / ((SCG0->SPLLPFD & SCG_SPLLPFD_PFD3_MASK) >> SCG_SPLLPFD_PFD3_SHIFT);
              break;

            default:
              SCGOUTClock = 0;
              break;
          }
        }
        else
        {
          /* SPLL PFD is bypassed. */
          SCGOUTClock = CPU_XTAL_LVDS_CLK_HZ;
        }
      }
      break;

    /* Auxiliary PLL */
    case SCG_CSR_SCS(6):
      /* System clock from APLL. */
      SCGOUTClock = (0 == (SCG0->APLLCFG & SCG_APLLCFG_SOURCE_MASK)) ? CPU_XTAL_SOSC_CLK_HZ :
                    (48000000u + ((SCG0->FIRCCFG & SCG_FIRCCFG_RANGE_MASK) >> SCG_FIRCCFG_RANGE_SHIFT) * 4000000u);
      SCGOUTClock /= ((SCG0->APLLCFG & SCG_APLLCFG_PREDIV_MASK) >> SCG_APLLCFG_PREDIV_SHIFT) + 1;

      apllNum = SCG0->APLLNUM;
      apllDenom = SCG0->APLLDENOM;
      SCGOUTClock *= ((SCG0->APLLCFG & SCG_APLLCFG_MULT_MASK) >> SCG_APLLCFG_MULT_SHIFT) + (apllNum / apllDenom);

      /* Is Core clock from PLL directly? */
      if (0 == (SCG0->APLLCFG & SCG_APLLCFG_PLLS_MASK))
      {
        /* System clock from APLL directly. */
        SCGOUTClock /= (((SCG0->APLLCFG & SCG_APLLCFG_PLLPOSTDIV1_MASK) >> SCG_APLLCFG_PLLPOSTDIV1_SHIFT) + 1);
        SCGOUTClock /= (((SCG0->APLLCFG & SCG_APLLCFG_PLLPOSTDIV2_MASK) >> SCG_APLLCFG_PLLPOSTDIV2_SHIFT) + 1);
      }
      else
      {
        /* System clock from APLL PFD. */
        /* Is APLL PFD bypassed? */
        if (0 == (SCG0->APLLCFG & SCG_APLLCFG_BYPASS_MASK))
        {
          /* APLL PFD output clock. */
          switch (SCG0->APLLCFG & SCG_APLLCFG_PFDSEL_MASK)
          {
            case SCG_APLLCFG_PFDSEL(0):
              SCGOUTClock = (SCGOUTClock * 18) / ((SCG0->APLLPFD & SCG_APLLPFD_PFD0_MASK) >> SCG_APLLPFD_PFD0_SHIFT);
              break;

            case SCG_APLLCFG_PFDSEL(1):
              SCGOUTClock = (SCGOUTClock * 18) / ((SCG0->APLLPFD & SCG_APLLPFD_PFD1_MASK) >> SCG_APLLPFD_PFD1_SHIFT);
              break;

            case SCG_APLLCFG_PFDSEL(2):
              SCGOUTClock = (SCGOUTClock * 18) / ((SCG0->APLLPFD & SCG_APLLPFD_PFD2_MASK) >> SCG_APLLPFD_PFD2_SHIFT);
              break;

            case SCG_APLLCFG_PFDSEL(3):
              SCGOUTClock = (SCGOUTClock * 18) / ((SCG0->APLLPFD & SCG_APLLPFD_PFD3_MASK) >> SCG_APLLPFD_PFD3_SHIFT);
              break;

            default:
              SCGOUTClock = 0;
              break;
          }
        }
        else
        {
          /* APLL PFD is bypassed. */
          SCGOUTClock = CPU_XTAL_LVDS_CLK_HZ;
        }
      }
      break;

    /* Can not identify core clock source. */
    default:
      SCGOUTClock = 0u;
      break;
  }

  /* Divide the SCG output clock to get the M4 Core clock. */
  SCGOUTClock /= ((SCG0->CSR & SCG_CSR_DIVCORE_MASK) >> SCG_CSR_DIVCORE_SHIFT) + 1;

  /* Update System Core Clock. */
  SystemCoreClock = SCGOUTClock;
}
