; * ---------------------------------------------------------------------------------------
; *  @file:    startup_MCIMX7U5_M4.s
; *  @purpose: CMSIS Cortex-M4 Core Device Startup File
; *            MCIMX7U5_M4
; *  @version: 2.0
; *  @date:    2016-7-19
; *  @build:   b160722
; * ---------------------------------------------------------------------------------------
; *
; * Copyright (c) 1997 - 2016 , Freescale Semiconductor, Inc.
; * All rights reserved.
; *
; * Redistribution and use in source and binary forms, with or without modification,
; * are permitted provided that the following conditions are met:
; *
; * o Redistributions of source code must retain the above copyright notice, this list
; *   of conditions and the following disclaimer.
; *
; * o Redistributions in binary form must reproduce the above copyright notice, this
; *   list of conditions and the following disclaimer in the documentation and/or
; *   other materials provided with the distribution.
; *
; * o Neither the name of Freescale Semiconductor, Inc. nor the names of its
; *   contributors may be used to endorse or promote products derived from this
; *   software without specific prior written permission.
; *
; * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
; * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
; * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
; * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
; * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
; * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
; * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
; * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
; * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
; * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
; *
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; *
; *****************************************************************************/


; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000400

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors
                EXPORT  __Vectors_End
                EXPORT  __Vectors_Size

__Vectors       DCD     __initial_sp  ; Top of Stack
                DCD     Reset_Handler  ; Reset Handler
                DCD     NMI_Handler                         ;NMI Handler
                DCD     HardFault_Handler                   ;Hard Fault Handler
                DCD     MemManage_Handler                   ;MPU Fault Handler
                DCD     BusFault_Handler                    ;Bus Fault Handler
                DCD     UsageFault_Handler                  ;Usage Fault Handler
                DCD     0                                   ;Reserved
                DCD     0                                   ;Reserved
                DCD     0                                   ;Reserved
                DCD     0                                   ;Reserved
                DCD     SVC_Handler                         ;SVCall Handler
                DCD     DebugMon_Handler                    ;Debug Monitor Handler
                DCD     0                                   ;Reserved
                DCD     PendSV_Handler                      ;PendSV Handler
                DCD     SysTick_Handler                     ;SysTick Handler

                                                            ;External Interrupts
                DCD     CTI0_IRQHandler                     ;Cross Trigger Interface for CM4
                DCD     DMA0_0_4_IRQHandler                 ;DMA Channel 0, 4 Transfer Complete
                DCD     DMA0_1_5_IRQHandler                 ;DMA Channel 1, 5 Transfer Complete
                DCD     DMA0_2_6_IRQHandler                 ;DMA Channel 2, 6 Transfer Complete
                DCD     DMA0_3_7_IRQHandler                 ;DMA Channel 3, 7 Transfer Complete
                DCD     DMA0_8_12_IRQHandler                ;DMA Channel 8, 12 Transfer Complete
                DCD     DMA0_9_13_IRQHandler                ;DMA Channel 9, 13 Transfer Complete
                DCD     DMA0_10_14_IRQHandler               ;DMA Channel 10, 14 Transfer Complete
                DCD     DMA0_11_15_IRQHandler               ;DMA Channel 11, 15 Transfer Complete
                DCD     DMA0_16_20_IRQHandler               ;DMA Channel 16, 20 Transfer Complete
                DCD     DMA0_17_21_IRQHandler               ;DMA Channel 17, 21 Transfer Complete
                DCD     DMA0_18_22_IRQHandler               ;DMA Channel 18, 22 Transfer Complete
                DCD     DMA0_19_23_IRQHandler               ;DMA Channel 19, 23 Transfer Complete
                DCD     DMA0_24_28_IRQHandler               ;DMA Channel 24, 28 Transfer Complete
                DCD     DMA0_25_29_IRQHandler               ;DMA Channel 25, 29 Transfer Complete
                DCD     DMA0_26_30_IRQHandler               ;DMA Channel 26, 30 Transfer Complete
                DCD     DMA0_27_31_IRQHandler               ;DMA Channel 27, 31 Transfer Complete
                DCD     DMA0_Error_IRQHandler               ;DMA Error Interrupt - All Channels
                DCD     MCM0_IRQHandler                     ;MCM Interrupt
                DCD     EWM_IRQHandler                      ;External Watchdog Monitor Interrupt
                DCD     LLWU0_IRQHandler                    ;Low Leakage Wake Up
                DCD     SIM_IRQHandler                      ;System Integation Module
                DCD     MU_A_IRQHandler                     ;Messaging Unit - Side A
                DCD     Reserved39_IRQHandler               ;Secured JTAG Controller
                DCD     Software1_IRQHandler                ;Software Interrupt
                DCD     Software2_IRQHandler                ;Software Interrupt
                DCD     WDOG0_IRQHandler                    ;Watchdog Interrupt
                DCD     SCG0_IRQHandler                     ;System Clock Generator for M4 domain
                DCD     QSPI_IRQHandler                     ;Quad Serial Peripheral Interface
                DCD     LTC_IRQHandler                      ;Low Power Trusted Cryptography
                DCD     Reserved46_IRQHandler               ;Reserved
                DCD     SNVS_IRQHandler                     ;Secure Non-Volatile Storage Consolidated Interrupt
                DCD     TRNG0_IRQHandler                    ;Random Number Generator
                DCD     LPIT0_IRQHandler                    ;Low Power Periodic Interrupt Timer
                DCD     PMC0_IRQHandler                     ;Power Management  Control interrupts for M4 domain
                DCD     CMC0_IRQHandler                     ;Core Mode Controller interrupts for M4 domain
                DCD     LPTMR0_IRQHandler                   ;Low Power Timer
                DCD     LPTMR1_IRQHandler                   ;Low Power Timer
                DCD     TPM0_IRQHandler                     ;Timer PWM module
                DCD     TPM1_IRQHandler                     ;Timer PWM module
                DCD     TPM2_IRQHandler                     ;Timer PWM module
                DCD     TPM3_IRQHandler                     ;Timer PWM module
                DCD     FLEXIO0_IRQHandler                  ;Flexible IO
                DCD     LPI2C0_IRQHandler                   ;Inter-integrated circuit 0
                DCD     LPI2C1_IRQHandler                   ;Inter-integrated circuit 1
                DCD     LPI2C2_IRQHandler                   ;Inter-integrated circuit 2
                DCD     LPI2C3_IRQHandler                   ;Inter-integrated circuit 3
                DCD     SAI0_IRQHandler                     ;Serial Audio Interface
                DCD     SAI1_IRQHandler                     ;Serial Audio Interface 1
                DCD     LPSPI0_IRQHandler                   ;Low Power Serial Peripheral Interface
                DCD     LPSPI1_IRQHandler                   ;Low Power Serial Peripheral Interface
                DCD     LPUART0_IRQHandler                  ;Low Power UART
                DCD     LPUART1_IRQHandler                  ;Low Power UART
                DCD     LPUART2_IRQHandler                  ;Low Power UART
                DCD     LPUART3_IRQHandler                  ;Low Power UART
                DCD     DPM_IRQHandler                      ;Dynamic Process Monitor
                DCD     PCTLA_IRQHandler                    ;Port A pin interrupt
                DCD     PCTLB_IRQHandler                    ;Port B pin interrupt
                DCD     ADC0_IRQHandler                     ;Analog to Digital Convertor
                DCD     ADC1_IRQHandler                     ;Analog to Digital Convertor
                DCD     CMP0_IRQHandler                     ;Comparator
                DCD     CMP1_IRQHandler                     ;Comparator
                DCD     DAC0_IRQHandler                     ;Digital to Analog Convertor
                DCD     DAC1_IRQHandler                     ;Digital to Analog Convertor
                DCD     WDOG1_IRQHandler                    ;Watchdog Interrupt from A7 subsystem
                DCD     USB0_IRQHandler                     ;USB 0 Interrupt from A7 subsystem
                DCD     USB1_IRQHandler                     ;USB 1 Interrupt from A7 subsystem
                DCD     Reserved83_IRQHandler               ;
                DCD     WDOG2_IRQHandler                    ;Watchdog Interrupt from A7 subsystem
                DCD     USBPHY_IRQHandler                   ;USB PHY (used in conjunction with USBOTG0)
                DCD     CMC1_IRQHandler                     ;A7 resets
                DCD     DefaultISR                          ;87
                DCD     DefaultISR                          ;88
                DCD     DefaultISR                          ;89
                DCD     DefaultISR                          ;90
                DCD     DefaultISR                          ;91
                DCD     DefaultISR                          ;92
                DCD     DefaultISR                          ;93
                DCD     DefaultISR                          ;94
                DCD     DefaultISR                          ;95
                DCD     DefaultISR                          ;96
                DCD     DefaultISR                          ;97
                DCD     DefaultISR                          ;98
                DCD     DefaultISR                          ;99
                DCD     DefaultISR                          ;100
                DCD     DefaultISR                          ;101
                DCD     DefaultISR                          ;102
                DCD     DefaultISR                          ;103
                DCD     DefaultISR                          ;104
                DCD     DefaultISR                          ;105
                DCD     DefaultISR                          ;106
                DCD     DefaultISR                          ;107
                DCD     DefaultISR                          ;108
                DCD     DefaultISR                          ;109
                DCD     DefaultISR                          ;110
                DCD     DefaultISR                          ;111
                DCD     DefaultISR                          ;112
                DCD     DefaultISR                          ;113
                DCD     DefaultISR                          ;114
                DCD     DefaultISR                          ;115
                DCD     DefaultISR                          ;116
                DCD     DefaultISR                          ;117
                DCD     DefaultISR                          ;118
                DCD     DefaultISR                          ;119
                DCD     DefaultISR                          ;120
                DCD     DefaultISR                          ;121
                DCD     DefaultISR                          ;122
                DCD     DefaultISR                          ;123
                DCD     DefaultISR                          ;124
                DCD     DefaultISR                          ;125
                DCD     DefaultISR                          ;126
                DCD     DefaultISR                          ;127
                DCD     DefaultISR                          ;128
                DCD     DefaultISR                          ;129
                DCD     DefaultISR                          ;130
                DCD     DefaultISR                          ;131
                DCD     DefaultISR                          ;132
                DCD     DefaultISR                          ;133
                DCD     DefaultISR                          ;134
                DCD     DefaultISR                          ;135
                DCD     DefaultISR                          ;136
                DCD     DefaultISR                          ;137
                DCD     DefaultISR                          ;138
                DCD     DefaultISR                          ;139
                DCD     DefaultISR                          ;140
                DCD     DefaultISR                          ;141
                DCD     DefaultISR                          ;142
                DCD     DefaultISR                          ;143
__Vectors_End

__Vectors_Size  EQU     __Vectors_End - __Vectors

                AREA    |.text|, CODE, READONLY

; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main

                CPSID   I               ; Mask interrupts
                LDR     R0, =0xE000ED08
                LDR     R1, =__Vectors
                STR     R1, [R0]
                LDR     R0, =SystemInit
                BLX     R0
                CPSIE   i               ; Unmask interrupts
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)
NMI_Handler\
                PROC
                EXPORT  NMI_Handler         [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler         [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler\
                PROC
                EXPORT  SVC_Handler         [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler         [WEAK]
                B       .
                ENDP
PendSV_Handler\
                PROC
                EXPORT  PendSV_Handler         [WEAK]
                B       .
                ENDP
SysTick_Handler\
                PROC
                EXPORT  SysTick_Handler         [WEAK]
                B       .
                ENDP
DMA0_0_4_IRQHandler\
                PROC
                EXPORT  DMA0_0_4_IRQHandler         [WEAK]
                LDR     R0, =DMA0_0_4_DriverIRQHandler
                BX      R0
                ENDP

DMA0_1_5_IRQHandler\
                PROC
                EXPORT  DMA0_1_5_IRQHandler         [WEAK]
                LDR     R0, =DMA0_1_5_DriverIRQHandler
                BX      R0
                ENDP

DMA0_2_6_IRQHandler\
                PROC
                EXPORT  DMA0_2_6_IRQHandler         [WEAK]
                LDR     R0, =DMA0_2_6_DriverIRQHandler
                BX      R0
                ENDP

DMA0_3_7_IRQHandler\
                PROC
                EXPORT  DMA0_3_7_IRQHandler         [WEAK]
                LDR     R0, =DMA0_3_7_DriverIRQHandler
                BX      R0
                ENDP

DMA0_8_12_IRQHandler\
                PROC
                EXPORT  DMA0_8_12_IRQHandler         [WEAK]
                LDR     R0, =DMA0_8_12_DriverIRQHandler
                BX      R0
                ENDP

DMA0_9_13_IRQHandler\
                PROC
                EXPORT  DMA0_9_13_IRQHandler         [WEAK]
                LDR     R0, =DMA0_9_13_DriverIRQHandler
                BX      R0
                ENDP

DMA0_10_14_IRQHandler\
                PROC
                EXPORT  DMA0_10_14_IRQHandler         [WEAK]
                LDR     R0, =DMA0_10_14_DriverIRQHandler
                BX      R0
                ENDP

DMA0_11_15_IRQHandler\
                PROC
                EXPORT  DMA0_11_15_IRQHandler         [WEAK]
                LDR     R0, =DMA0_11_15_DriverIRQHandler
                BX      R0
                ENDP

DMA0_16_20_IRQHandler\
                PROC
                EXPORT  DMA0_16_20_IRQHandler         [WEAK]
                LDR     R0, =DMA0_16_20_DriverIRQHandler
                BX      R0
                ENDP

DMA0_17_21_IRQHandler\
                PROC
                EXPORT  DMA0_17_21_IRQHandler         [WEAK]
                LDR     R0, =DMA0_17_21_DriverIRQHandler
                BX      R0
                ENDP

DMA0_18_22_IRQHandler\
                PROC
                EXPORT  DMA0_18_22_IRQHandler         [WEAK]
                LDR     R0, =DMA0_18_22_DriverIRQHandler
                BX      R0
                ENDP

DMA0_19_23_IRQHandler\
                PROC
                EXPORT  DMA0_19_23_IRQHandler         [WEAK]
                LDR     R0, =DMA0_19_23_DriverIRQHandler
                BX      R0
                ENDP

DMA0_24_28_IRQHandler\
                PROC
                EXPORT  DMA0_24_28_IRQHandler         [WEAK]
                LDR     R0, =DMA0_24_28_DriverIRQHandler
                BX      R0
                ENDP

DMA0_25_29_IRQHandler\
                PROC
                EXPORT  DMA0_25_29_IRQHandler         [WEAK]
                LDR     R0, =DMA0_25_29_DriverIRQHandler
                BX      R0
                ENDP

DMA0_26_30_IRQHandler\
                PROC
                EXPORT  DMA0_26_30_IRQHandler         [WEAK]
                LDR     R0, =DMA0_26_30_DriverIRQHandler
                BX      R0
                ENDP

DMA0_27_31_IRQHandler\
                PROC
                EXPORT  DMA0_27_31_IRQHandler         [WEAK]
                LDR     R0, =DMA0_27_31_DriverIRQHandler
                BX      R0
                ENDP

DMA0_Error_IRQHandler\
                PROC
                EXPORT  DMA0_Error_IRQHandler         [WEAK]
                LDR     R0, =DMA0_Error_DriverIRQHandler
                BX      R0
                ENDP

QSPI_IRQHandler\
                PROC
                EXPORT  QSPI_IRQHandler         [WEAK]
                LDR     R0, =QSPI_DriverIRQHandler
                BX      R0
                ENDP

FLEXIO0_IRQHandler\
                PROC
                EXPORT  FLEXIO0_IRQHandler         [WEAK]
                LDR     R0, =FLEXIO0_DriverIRQHandler
                BX      R0
                ENDP

LPI2C0_IRQHandler\
                PROC
                EXPORT  LPI2C0_IRQHandler         [WEAK]
                LDR     R0, =LPI2C0_DriverIRQHandler
                BX      R0
                ENDP

LPI2C1_IRQHandler\
                PROC
                EXPORT  LPI2C1_IRQHandler         [WEAK]
                LDR     R0, =LPI2C1_DriverIRQHandler
                BX      R0
                ENDP

LPI2C2_IRQHandler\
                PROC
                EXPORT  LPI2C2_IRQHandler         [WEAK]
                LDR     R0, =LPI2C2_DriverIRQHandler
                BX      R0
                ENDP

LPI2C3_IRQHandler\
                PROC
                EXPORT  LPI2C3_IRQHandler         [WEAK]
                LDR     R0, =LPI2C3_DriverIRQHandler
                BX      R0
                ENDP

LPSPI0_IRQHandler\
                PROC
                EXPORT  LPSPI0_IRQHandler         [WEAK]
                LDR     R0, =LPSPI0_DriverIRQHandler
                BX      R0
                ENDP

LPSPI1_IRQHandler\
                PROC
                EXPORT  LPSPI1_IRQHandler         [WEAK]
                LDR     R0, =LPSPI1_DriverIRQHandler
                BX      R0
                ENDP

LPUART0_IRQHandler\
                PROC
                EXPORT  LPUART0_IRQHandler         [WEAK]
                LDR     R0, =LPUART0_DriverIRQHandler
                BX      R0
                ENDP

LPUART1_IRQHandler\
                PROC
                EXPORT  LPUART1_IRQHandler         [WEAK]
                LDR     R0, =LPUART1_DriverIRQHandler
                BX      R0
                ENDP

LPUART2_IRQHandler\
                PROC
                EXPORT  LPUART2_IRQHandler         [WEAK]
                LDR     R0, =LPUART2_DriverIRQHandler
                BX      R0
                ENDP

LPUART3_IRQHandler\
                PROC
                EXPORT  LPUART3_IRQHandler         [WEAK]
                LDR     R0, =LPUART3_DriverIRQHandler
                BX      R0
                ENDP

Default_Handler\
                PROC
                EXPORT  CTI0_IRQHandler         [WEAK]
                EXPORT  DMA0_0_4_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_1_5_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_2_6_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_3_7_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_8_12_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_9_13_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_10_14_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_11_15_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_16_20_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_17_21_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_18_22_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_19_23_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_24_28_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_25_29_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_26_30_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_27_31_DriverIRQHandler         [WEAK]
                EXPORT  DMA0_Error_DriverIRQHandler         [WEAK]
                EXPORT  MCM0_IRQHandler         [WEAK]
                EXPORT  EWM_IRQHandler         [WEAK]
                EXPORT  LLWU0_IRQHandler         [WEAK]
                EXPORT  SIM_IRQHandler         [WEAK]
                EXPORT  MU_A_IRQHandler         [WEAK]
                EXPORT  Reserved39_IRQHandler         [WEAK]
                EXPORT  Software1_IRQHandler         [WEAK]
                EXPORT  Software2_IRQHandler         [WEAK]
                EXPORT  WDOG0_IRQHandler         [WEAK]
                EXPORT  SCG0_IRQHandler         [WEAK]
                EXPORT  QSPI_DriverIRQHandler         [WEAK]
                EXPORT  LTC_IRQHandler         [WEAK]
                EXPORT  Reserved46_IRQHandler         [WEAK]
                EXPORT  SNVS_IRQHandler         [WEAK]
                EXPORT  TRNG0_IRQHandler         [WEAK]
                EXPORT  LPIT0_IRQHandler         [WEAK]
                EXPORT  PMC0_IRQHandler         [WEAK]
                EXPORT  CMC0_IRQHandler         [WEAK]
                EXPORT  LPTMR0_IRQHandler         [WEAK]
                EXPORT  LPTMR1_IRQHandler         [WEAK]
                EXPORT  TPM0_IRQHandler         [WEAK]
                EXPORT  TPM1_IRQHandler         [WEAK]
                EXPORT  TPM2_IRQHandler         [WEAK]
                EXPORT  TPM3_IRQHandler         [WEAK]
                EXPORT  FLEXIO0_DriverIRQHandler         [WEAK]
                EXPORT  LPI2C0_DriverIRQHandler         [WEAK]
                EXPORT  LPI2C1_DriverIRQHandler         [WEAK]
                EXPORT  LPI2C2_DriverIRQHandler         [WEAK]
                EXPORT  LPI2C3_DriverIRQHandler         [WEAK]
                EXPORT  SAI0_IRQHandler         [WEAK]
                EXPORT  SAI1_IRQHandler         [WEAK]
                EXPORT  LPSPI0_DriverIRQHandler         [WEAK]
                EXPORT  LPSPI1_DriverIRQHandler         [WEAK]
                EXPORT  LPUART0_DriverIRQHandler         [WEAK]
                EXPORT  LPUART1_DriverIRQHandler         [WEAK]
                EXPORT  LPUART2_DriverIRQHandler         [WEAK]
                EXPORT  LPUART3_DriverIRQHandler         [WEAK]
                EXPORT  DPM_IRQHandler         [WEAK]
                EXPORT  PCTLA_IRQHandler         [WEAK]
                EXPORT  PCTLB_IRQHandler         [WEAK]
                EXPORT  ADC0_IRQHandler         [WEAK]
                EXPORT  ADC1_IRQHandler         [WEAK]
                EXPORT  CMP0_IRQHandler         [WEAK]
                EXPORT  CMP1_IRQHandler         [WEAK]
                EXPORT  DAC0_IRQHandler         [WEAK]
                EXPORT  DAC1_IRQHandler         [WEAK]
                EXPORT  WDOG1_IRQHandler         [WEAK]
                EXPORT  USB0_IRQHandler         [WEAK]
                EXPORT  USB1_IRQHandler         [WEAK]
                EXPORT  Reserved83_IRQHandler         [WEAK]
                EXPORT  WDOG2_IRQHandler         [WEAK]
                EXPORT  USBPHY_IRQHandler         [WEAK]
                EXPORT  CMC1_IRQHandler         [WEAK]
                EXPORT  DefaultISR         [WEAK]
CTI0_IRQHandler
DMA0_0_4_DriverIRQHandler
DMA0_1_5_DriverIRQHandler
DMA0_2_6_DriverIRQHandler
DMA0_3_7_DriverIRQHandler
DMA0_8_12_DriverIRQHandler
DMA0_9_13_DriverIRQHandler
DMA0_10_14_DriverIRQHandler
DMA0_11_15_DriverIRQHandler
DMA0_16_20_DriverIRQHandler
DMA0_17_21_DriverIRQHandler
DMA0_18_22_DriverIRQHandler
DMA0_19_23_DriverIRQHandler
DMA0_24_28_DriverIRQHandler
DMA0_25_29_DriverIRQHandler
DMA0_26_30_DriverIRQHandler
DMA0_27_31_DriverIRQHandler
DMA0_Error_DriverIRQHandler
MCM0_IRQHandler
EWM_IRQHandler
LLWU0_IRQHandler
SIM_IRQHandler
MU_A_IRQHandler
Reserved39_IRQHandler
Software1_IRQHandler
Software2_IRQHandler
WDOG0_IRQHandler
SCG0_IRQHandler
QSPI_DriverIRQHandler
LTC_IRQHandler
Reserved46_IRQHandler
SNVS_IRQHandler
TRNG0_IRQHandler
LPIT0_IRQHandler
PMC0_IRQHandler
CMC0_IRQHandler
LPTMR0_IRQHandler
LPTMR1_IRQHandler
TPM0_IRQHandler
TPM1_IRQHandler
TPM2_IRQHandler
TPM3_IRQHandler
FLEXIO0_DriverIRQHandler
LPI2C0_DriverIRQHandler
LPI2C1_DriverIRQHandler
LPI2C2_DriverIRQHandler
LPI2C3_DriverIRQHandler
SAI0_IRQHandler
SAI1_IRQHandler
LPSPI0_DriverIRQHandler
LPSPI1_DriverIRQHandler
LPUART0_DriverIRQHandler
LPUART1_DriverIRQHandler
LPUART2_DriverIRQHandler
LPUART3_DriverIRQHandler
DPM_IRQHandler
PCTLA_IRQHandler
PCTLB_IRQHandler
ADC0_IRQHandler
ADC1_IRQHandler
CMP0_IRQHandler
CMP1_IRQHandler
DAC0_IRQHandler
DAC1_IRQHandler
WDOG1_IRQHandler
USB0_IRQHandler
USB1_IRQHandler
Reserved83_IRQHandler
WDOG2_IRQHandler
USBPHY_IRQHandler
CMC1_IRQHandler
DefaultISR
                B      DefaultISR
                ENDP
                  ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END
