/*----------------------------------------------------------------------------
 *      main Template for CMSIS RTE C/C++ Project
 *----------------------------------------------------------------------------
 *      Name:    main.c
 *      Purpose: Generic main program body including main() function
 *      Rev.:    1.0.0
 *----------------------------------------------------------------------------*/
/*******************************************************************************
* Copyright (c) 2015 ARM Ltd. and others
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
* ARM Ltd and ARM Germany GmbH - file template
*******************************************************************************/

#ifdef _RTE_
  #include "RTE_Components.h"             // Component selection
#endif
#ifdef RTE_CMSIS_RTOS                     // when RTE component CMSIS RTOS is used
  #include "cmsis_os.h"                   // CMSIS RTOS header file
#endif
#include "system_iMX7D_M4.h"
#include "Board_LED.h"                    // ::Board Support:LED
#include "board.h"
#include <stdio.h>


/*----------------------------------------------------------------------------
 *      Thread A
 *---------------------------------------------------------------------------*/
void threadA (void  const *argument) {
  int32_t led_num = 0;
  uint32_t led_dir = 0;
  for (;;) {
	osDelay(50);
	LED_On(led_num);                     // Turn specified LED on
	osDelay(50);
	LED_Off(led_num);                    // Turn specified LED off
	if (led_dir == 0) {
	  led_num++;                         // Change LED number
	  if (led_num >= LED_GetCount() - 1) {
		led_dir = 1;                     // Restart with first LED
	  }
	} else {
	  led_num--;                         // Change LED number
	  if (led_num <= 0) {
		led_dir = 0;                     // Restart with first LED
	  }
	}
  }
}

osThreadDef(threadA,  osPriorityNormal, 1, 0);

/* main function */
int main(void)
{
  /* Board specific RDC settings */
  BOARD_RdcInit();

  /* Board specific clock settings */
  BOARD_ClockInit();

  SystemCoreClockUpdate();

  /* Setup IO Pins */
  LED_Initialize();

  /* Initialize CMSIS-RTOS */
  osKernelInitialize(); 
  
  /* Create new thread */  
  osThreadCreate(osThread(threadA), NULL);
   
  /* Start thread execution */ 
  osKernelStart();                    

  /* Infinite loop */
  while(true);
}
