/*
 * Copyright (c) 2015, Freescale Semiconductor, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of Freescale Semiconductor, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * Modifications Copyright (c) 2016 ARM Germany GmbH. All rights reserved.
 */

///////////////////////////////////////////////////////////////////////////////
//  Includes
///////////////////////////////////////////////////////////////////////////////
#include "rpmsg_rtos.h"
#include "board.h"
#include "mu_imx.h"
#include "cmsis_os.h"                   // ARM::CMSIS:RTOS:Keil RTX
#include "retarget_io_user.h"

#define PRINTF printf

////////////////////////////////////////////////////////////////////////////////
// Definitions
////////////////////////////////////////////////////////////////////////////////
void PingPongThread (void const *arg);                           
osThreadDef (PingPongThread, osPriorityNormal, 1, 0);            
 
typedef struct the_message
{
   uint32_t  DATA;
} THE_MESSAGE, * THE_MESSAGE_PTR;

////////////////////////////////////////////////////////////////////////////////
// Code
////////////////////////////////////////////////////////////////////////////////

void PingPongThread (void const *arg)
{
  int result;
  struct remote_device *rdev = NULL;
  struct rpmsg_channel *app_chnl = NULL;
  THE_MESSAGE msg = {0};
  int len;

  /* Print the initial banner */
  PRINTF("\r\nRPMSG PingPong RTX API Demo...\r\n");

  PRINTF("RPMSG Init as Remote\r\n");
  result = rpmsg_rtos_init(0 /*REMOTE_CPU_ID*/, &rdev, RPMSG_MASTER, &app_chnl);
  assert(0 == result);

  /* reinitialize debug uart */
  InitRetargetIOUSART();

  PRINTF("Name service handshake is done, M4 has setup a rpmsg channel [%ld ---> %ld]\r\n", app_chnl->src, app_chnl->dst);

  while (true)
  {      
    /* receive/send data to channel default ept */
    result = rpmsg_rtos_recv(app_chnl->rp_ept, &msg, &len, sizeof(THE_MESSAGE), NULL, 0xFFFFFFFF);
    assert(0 == result);
    PRINTF("Get Data From Master Side : %d\r\n", msg.DATA);
  
    msg.DATA++;
    result = rpmsg_rtos_send(app_chnl->rp_ept, &msg, sizeof(THE_MESSAGE), app_chnl->dst);
    assert(0 == result);
  }
}


/*!
 * @brief Main function
 */
int main (void)
{
  hardware_init();
  
  SystemCoreClockUpdate();

  InitRetargetIOUSART();

  /* Initialize CMSIS-RTOS */
  osKernelInitialize();

  /* Create a demo thread */
  osThreadCreate (osThread (PingPongThread), NULL);                                    

  /* Start thread execution */ 
  osKernelStart();

  /* Infinite loop */
  while(true);
}

/*******************************************************************************
 * EOF
 ******************************************************************************/
