/*
** ###################################################################
**     Processors:          MCIMX7D7DVK10
**                          MCIMX7D7DVM10
**
**     Compilers:           Keil ARM C/C++ Compiler
**                          GNU C Compiler
**                          IAR ANSI C/C++ Compiler for ARM
**
**     Reference manual:    IMX7DRM, Rev.0, 08/2016
**     Version:             rev. 1.0, 2016-04-13
**     Build:               b170406
**
**     Abstract:
**         This header file implements peripheral memory map for MCIMX7D7_A7
**         processor.
**
**     Copyright 1997-2016 Freescale Semiconductor, Inc.
**     Copyright 2016-2017 NXP
**
**     http:                 www.nxp.com
**     mail:                 support@nxp.com
**
**     Revisions:
**     - rev. 1.0 (2016-04-13)
**         Initial version.
**
** ###################################################################
*/

/*!
 * @file iMX7D_A7.h
 * @version 1.0
 * @date 2016-04-13
 * @brief Peripheral memory map for iMX7D_A7
 *
 * This header file implements peripheral memory map for MCIMX7D7_A7 processor.
 */


/* ----------------------------------------------------------------------------
   -- MCU activation
   ---------------------------------------------------------------------------- */

/* Prevention from multiple including the same memory map */
#if !defined(MCU_MCIMX7D7_A7)  /* Check if memory map has not been already included */
#define MCU_MCIMX7D7_A7

/* Check if another memory map has not been also included */
#if (defined(MCU_ACTIVE))
  #error MCIMX7D7_A7 memory map: There is already included another memory map. Only one memory map can be included.
#endif /* (defined(MCU_ACTIVE)) */
#define MCU_ACTIVE

#include <stdint.h>

/** Memory map major version (memory maps with equal major version number are
 * compatible) */
#define MCU_MEM_MAP_VERSION 0x0100U
/** Memory map minor version */
#define MCU_MEM_MAP_VERSION_MINOR 0x0000U


/* ----------------------------------------------------------------------------
   -- Interrupt vector numbers
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Interrupt_vector_numbers Interrupt vector numbers
 * @{
 */

/** Interrupt Number Definitions */
#define NUMBER_OF_INT_VECTORS 160                  /**< Number of interrupts in the Vector table */

typedef enum IRQn {
  INT_Reserved0                = 0,                /**< Reserved */
  INT_Reserved1                = 1,                /**< Reserved */
  INT_Reserved2                = 2,                /**< Reserved */
  INT_Reserved3                = 3,                /**< Reserved */
  INT_Reserved4                = 4,                /**< Reserved */
  INT_Reserved5                = 5,                /**< Reserved */
  INT_Reserved6                = 6,                /**< Reserved */
  INT_Reserved7                = 7,                /**< Reserved */
  INT_Reserved8                = 8,                /**< Reserved */
  INT_Reserved9                = 9,                /**< Reserved */
  INT_Reserved10               = 10,               /**< Reserved */
  INT_Reserved11               = 11,               /**< Reserved */
  INT_Reserved12               = 12,               /**< Reserved */
  INT_Reserved13               = 13,               /**< Reserved */
  INT_Reserved14               = 14,               /**< Reserved */
  INT_Reserved15               = 15,               /**< Reserved */
  INT_Reserved16               = 16,               /**< Reserved */
  INT_Reserved17               = 17,               /**< Reserved */
  INT_Reserved18               = 18,               /**< Reserved */
  INT_Reserved19               = 19,               /**< Reserved */
  INT_Reserved20               = 20,               /**< Reserved */
  INT_Reserved21               = 21,               /**< Reserved */
  INT_Reserved22               = 22,               /**< Reserved */
  INT_Reserved23               = 23,               /**< Reserved */
  INT_Reserved24               = 24,               /**< Reserved */
  INT_Reserved25               = 25,               /**< Reserved */
  INT_Reserved26               = 26,               /**< Reserved */
  INT_Reserved27               = 27,               /**< Reserved */
  INT_Reserved28               = 28,               /**< Reserved */
  SecurePhyTimer_IRQn          = 29,               /**< Cortex-A7 Secure Physical Timer Interrupt */
  INT_Reserved30               = 30,               /**< Reserved */
  INT_Reserved31               = 31,               /**< Reserved */
  INT_GPR_IRQ                  = 32,               /**< GPR Interrupt. Used to notify cores on exception condition while boot. */
  INT_DAP                      = 33,               /**< DAP Interrupt */
  INT_SDMA                     = 34,               /**< AND of all 48 SDMA interrupts (events) from all the channels */
  INT_DBGMON                   = 35,               /**< DBGMON Sync Interrupt */
  INT_SNVS                     = 36,               /**< ON-OFF button press shorter than 5 seconds (pulse event) */
  INT_LCDIF                    = 37,               /**< LCDIF Sync Interrupt */
  INT_SIM2                     = 38,               /**< SIM2 Interrupt */
  INT_CSI                      = 39,               /**< CSI Interrupt */
  INT_PXP0                     = 40,               /**< PXP Interrupt 0 */
  INT_Reserved41               = 41,               /**< Reserved */
  INT_WDOG3                    = 42,               /**< Watchdog Timer reset */
  INT_HS0                      = 43,               /**< HS Interrupt Request 0 */
  INT_APBHDMA                  = 44,               /**< GPMI operation channel 0 description complete interrupt */
  INT_EIM                      = 45,               /**< EIM Interrupt */
  INT_BCH                      = 46,               /**< BCH operation complete interrupt */
  INT_GPMI                     = 47,               /**< GPMI operation TIMEOUT ERROR interrupt */
  INT_UART6                    = 48,               /**< UART-6 ORed interrupt */
  INT_FTM1                     = 49,               /**< Flex Timer1 Fault / Counter / Channel interrupt */
  INT_FTM2                     = 50,               /**< Flex Timer2 Fault / Counter / Channel interrupt */
  INT_SNVS_Consolidated        = 51,               /**< SRTC Consolidated Interrupt. Non TZ. */
  INT_SNVS_Security            = 52,               /**< SRTC Security Interrupt. TZ. */
  INT_CSU                      = 53,               /**< CSU Interrupt Request. Indicates to the processor that one or more alarm inputs were asserted. */
  INT_USDHC1                   = 54,               /**< uSDHC1 Enhanced SDHC Interrupt Request */
  INT_USDHC2                   = 55,               /**< uSDHC2 Enhanced SDHC Interrupt Request */
  INT_USDHC3                   = 56,               /**< uSDHC3 Enhanced SDHC Interrupt Request */
  INT_MIPI_CSI                 = 57,               /**< MIPI CSI interrupt */
  INT_UART1                    = 58,               /**< UART-1 ORed interrupt */
  INT_UART2                    = 59,               /**< UART-2 ORed interrupt */
  INT_UART3                    = 60,               /**< UART-3 ORed interrupt */
  INT_UART4                    = 61,               /**< UART-4 ORed interrupt */
  INT_UART5                    = 62,               /**< UART-5 ORed interrupt */
  INT_eCSPI1                   = 63,               /**< eCSPI1 interrupt request line to the core. */
  INT_eCSPI2                   = 64,               /**< eCSPI2 interrupt request line to the core. */
  INT_eCSPI3                   = 65,               /**< eCSPI3 interrupt request line to the core. */
  INT_eCSPI4                   = 66,               /**< eCSPI4 interrupt request line to the core. */
  INT_I2C1                     = 67,               /**< I2C-1 Interrupt */
  INT_I2C2                     = 68,               /**< I2C-2 Interrupt */
  INT_I2C3                     = 69,               /**< I2C-3 Interrupt */
  INT_I2C4                     = 70,               /**< I2C-4 Interrupt */
  INT_RDC                      = 71,               /**< RDC interrupt */
  INT_USB_HOST                 = 72,               /**< USB HOST Interrupt */
  INT_MIPI_DSI                 = 73,               /**< DSI Interrupt */
  INT_USB_OTG2_CORE            = 74,               /**< USB OTG2 core interrupt */
  INT_USB_OTG1_CORE            = 75,               /**< USB OTG1 core interrupt */
  INT_USB_OTG1_WAKEUP          = 76,               /**< USB OTG1 wake up Interrupt */
  INT_USB_OTG2_WAKEUP          = 77,               /**< USB OTG2 wake up Interrupt */
  INT_PXP1                     = 78,               /**< PXP Interrupt 1 */
  INT_SCTR_IRQ0                = 79,               /**< ISO7816IP Interrupt 0 */
  INT_SCTR_IRQ1                = 80,               /**< ISO7816IP Interrupt 1 */
  INT_TEMPMON_LOW              = 81,               /**< TempSensor (Temperature low alarm). */
  INT_SAI3                     = 82,               /**< SAI3 Receive / Transmit Interrupt */
  INT_PMU                      = 83,               /**< Brown-out event on either analog regulators. */
  INT_GPT4                     = 84,               /**< OR of GPT Rollover interrupt line, Input Capture 1 and 2 lines, Output Compare 1, 2, and 3 Interrupt lines */
  INT_GPT3                     = 85,               /**< OR of GPT Rollover interrupt line, Input Capture 1 and 2 lines, Output Compare 1, 2, and 3 Interrupt lines */
  INT_GPT2                     = 86,               /**< OR of GPT Rollover interrupt line, Input Capture 1 and 2 lines, Output Compare 1, 2, and 3 Interrupt lines */
  INT_GPT1                     = 87,               /**< OR of GPT Rollover interrupt line, Input Capture 1 and 2 lines, Output Compare 1, 2, and 3 Interrupt lines */
  INT_GPIO1_INT7               = 88,               /**< Active HIGH Interrupt from INT7 from GPIO */
  INT_GPIO1_INT6               = 89,               /**< Active HIGH Interrupt from INT6 from GPIO */
  INT_GPIO1_INT5               = 90,               /**< Active HIGH Interrupt from INT5 from GPIO */
  INT_GPIO1_INT4               = 91,               /**< Active HIGH Interrupt from INT4 from GPIO */
  INT_GPIO1_INT3               = 92,               /**< Active HIGH Interrupt from INT3 from GPIO */
  INT_GPIO1_INT2               = 93,               /**< Active HIGH Interrupt from INT2 from GPIO */
  INT_GPIO1_INT1               = 94,               /**< Active HIGH Interrupt from INT1 from GPIO */
  INT_GPIO1_INT0               = 95,               /**< Active HIGH Interrupt from INT0 from GPIO */
  INT_GPIO1_Combined_0_15      = 96,               /**< Combined interrupt indication for GPIO1 signal 0 throughout 15 */
  INT_GPIO1_Combined_16_31     = 97,               /**< Combined interrupt indication for GPIO1 signal 16 throughout 31 */
  INT_GPIO2_Combined_0_15      = 98,               /**< Combined interrupt indication for GPIO2 signal 0 throughout 15 */
  INT_GPIO2_Combined_16_31     = 99,               /**< Combined interrupt indication for GPIO2 signal 16 throughout 31 */
  INT_GPIO3_Combined_0_15      = 100,              /**< Combined interrupt indication for GPIO3 signal 0 throughout 15 */
  INT_GPIO3_Combined_16_31     = 101,              /**< Combined interrupt indication for GPIO3 signal 16 throughout 31 */
  INT_GPIO4_Combined_0_15      = 102,              /**< Combined interrupt indication for GPIO4 signal 0 throughout 15 */
  INT_GPIO4_Combined_16_31     = 103,              /**< Combined interrupt indication for GPIO4 signal 16 throughout 31 */
  INT_GPIO5_Combined_0_15      = 104,              /**< Combined interrupt indication for GPIO5 signal 0 throughout 15 */
  INT_GPIO5_Combined_16_31     = 105,              /**< Combined interrupt indication for GPIO5 signal 16 throughout 31 */
  INT_GPIO6_Combined_0_15      = 106,              /**< Combined interrupt indication for GPIO6 signal 0 throughout 15 */
  INT_GPIO6_Combined_16_31     = 107,              /**< Combined interrupt indication for GPIO6 signal 16 throughout 31 */
  INT_GPIO7_Combined_0_15      = 108,              /**< Combined interrupt indication for GPIO7 signal 0 throughout 15 */
  INT_GPIO7_Combined_16_31     = 109,              /**< Combined interrupt indication for GPIO7 signal 16 throughout 31 */
  INT_WDOG1                    = 110,              /**< Watchdog Timer reset */
  INT_WDOG2                    = 111,              /**< Watchdog Timer reset */
  INT_KPP                      = 112,              /**< Keypad Interrupt */
  INT_PWM1                     = 113,              /**< Cumulative interrupt line. OR of Rollover Interrupt line, Compare Interrupt line and FIFO Waterlevel crossing interrupt line. */
  INT_PWM2                     = 114,              /**< Cumulative interrupt line. OR of Rollover Interrupt line, Compare Interrupt line and FIFO Waterlevel crossing interrupt line. */
  INT_PWM3                     = 115,              /**< Cumulative interrupt line. OR of Rollover Interrupt line, Compare Interrupt line and FIFO Waterlevel crossing interrupt line. */
  INT_PWM4                     = 116,              /**< Cumulative interrupt line. OR of Rollover Interrupt line, Compare Interrupt line and FIFO Waterlevel crossing interrupt line. */
  INT_CCM1                     = 117,              /**< CCM, Interrupt Request 1 */
  INT_CCM2                     = 118,              /**< CCM, Interrupt Request 2 */
  INT_GPC                      = 119,              /**< GPC Interrupt Request 1 */
  INT_MU_A7                    = 120,              /**< Interrupt to A7 */
  INT_SRC                      = 121,              /**< SRC interrupt request */
  INT_SIM1                     = 122,              /**< SIM1 Interrupt */
  INT_RTIC                     = 123,              /**< RTIC Interrupt */
  INT_CPU_PerformanceUnit      = 124,              /**< Performance Unit Interrupts from Cheetah (interrnally: PMUIRQ[n] */
  INT_CPU_CTI_Trigger          = 125,              /**< CTI trigger outputs (internal: nCTIIRQ[n] */
  INT_SRC_Combined             = 126,              /**< Combined CPU wdog interrupts (4x) out of SRC. */
  INT_SAI1                     = 127,              /**< SAI1 Receive / Transmit Interrupt */
  INT_SAI2                     = 128,              /**< SAI2 Receive / Transmit Interrupt */
  INT_MU_M4                    = 129,              /**< Interrupt to M4 */
  INT_ADC1                     = 130,              /**< ADC-1 Interrupt */
  INT_ADC2                     = 131,              /**< ADC-2 Interrupt */
  INT_ENET2_MAC0_Rx_Tx_Done1   = 132,              /**< MAC 0 Receive / Transmit Frame / Buffer Done */
  INT_ENET2_MAC0_Rx_Tx_Done2   = 133,              /**< MAC 0 Receive / Transmit Frame / Buffer Done */
  INT_ENET2                    = 134,              /**< MAC 0 IRQ */
  INT_ENET2_1588               = 135,              /**< MAC 0 1588 Timer Interrupt - synchronous */
  INT_TPR_IRQ                  = 136,              /**< TPR IRQ */
  INT_CAAM_Job_Ring0           = 137,              /**< CAAM interrupt queue for JQ */
  INT_CAAM_Job_Ring1           = 138,              /**< CAAM interrupt queue for JQ */
  INT_QSPI                     = 139,              /**< QSPI Interrupt */
  INT_TZASC1                   = 140,              /**< TZASC (PL380) interrupt */
  INT_WDOG4                    = 141,              /**< Watchdog Timer reset */
  INT_CAN1                     = 142,              /**< FlexCAN1 Interrupt */
  INT_CAN2                     = 143,              /**< FlexCAN2 Interrupt */
  INT_PERFMON1                 = 144,              /**< General Interrupt */
  INT_PERFMON2                 = 145,              /**< General Interrupt */
  INT_CAAM_Job_Ring2           = 146,              /**< CAAM interrupt queue for JQ */
  INT_CAAM_ERROR               = 147,              /**< Recoverable error interrupt */
  INT_HS1                      = 148,              /**< HS Interrupt Request 0 */
  INT_EPDC                     = 149,              /**< EPDC Interrupt */
  INT_ENET1_MAC0_Rx_Tx_Done1   = 150,              /**< MAC 0 Receive / Trasmit Frame / Buffer Done */
  INT_ENET1_MAC0_Rx_Tx_Done2   = 151,              /**< MAC 0 Receive / Trasmit Frame / Buffer Done */
  INT_ENET1                    = 152,              /**< MAC 0 IRQ */
  INT_ENET1_1588               = 153,              /**< MAC 0 1588 Timer Interrupt – synchronous */
  INT_PCIE_CTRL_IRQ0           = 154,              /**< Coming from GLUE logic, of set / reset FF, driven by PCIE signals. */
  INT_PCIE_CTRL_IRQ1           = 155,              /**< Coming from GLUE logic, of set / reset FF, driven by PCIE signals. */
  INT_PCIE_CTRL_IRQ2           = 156,              /**< Coming from GLUE logic, of set / reset FF, driven by PCIE signals. */
  INT_PCIE_CTRL_IRQ3           = 157,              /**< Coming from GLUE logic, of set / reset FF, driven by PCIE signals. */
  INT_UART7                    = 158,              /**< UART-7 ORed interrupt */
  INT_PCIE_CTRL                = 159               /**< Channels [63:32] interrupts requests */
} IRQn_Type;

/*!
 * @}
 */ /* end of group Interrupt_vector_numbers */


/* Peripheral and RAM base address */
#define IMX7D_GIC_DISTRIBUTOR_BASE           (0x00001000UL + 0x31000000UL)         /*!< (GIC DIST  ) Base Address */
#define IMX7D_GIC_INTERFACE_BASE             (0x00002000UL + 0x31000000UL)         /*!< (GIC CPU IF) Base Address */
#define IMX7D_SCTR_BASE                      (0x306C0000UL)                        /*!< (SCTR      ) Base Address */
#define GIC_DISTRIBUTOR_BASE                  IMX7D_GIC_DISTRIBUTOR_BASE
#define GIC_INTERFACE_BASE                    IMX7D_GIC_INTERFACE_BASE
#define SCTR_BASE                            IMX7D_SCTR_BASE

/* --------  Configuration of the Cortex-A7 Processor and Core Peripherals  ------- */
#define __CA_REV        0x0000U    /*!< Core revision r0p0                          */
#define __CORTEX_A           7U    /*!< Cortex-A7 Core                              */
#define __FPU_PRESENT        1U    /* FPU present                                   */
#define __GIC_PRESENT        1U    /* GIC present                                   */
#define __TIM_PRESENT        1U    /* TIM present                                   */
#define __L2C_PRESENT        0U    /* L2C present                                   */

#include "core_ca.h"
#include <system_iMX7D_A7.h>

/* ----------------------------------------------------------------------------
   -- Mapping Information
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Mapping_Information Mapping Information
 * @{
 */

/** Mapping Information */
/*!
 * @addtogroup iomuxc_pads
 * @{ */

/*******************************************************************************
 * Definitions
*******************************************************************************/

/*!
 * @brief Enumeration for the IOMUXC SW_MUX_CTL_PAD
 *
 * Defines the enumeration for the IOMUXC SW_MUX_CTL_PAD collections.
 */
typedef enum _iomuxc_sw_mux_ctl_pad
{
    kIOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 = 0U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 = 1U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 = 2U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 = 3U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 = 4U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 = 5U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14 = 6U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15 = 7U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00 = 8U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01 = 9U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02 = 10U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03 = 11U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04 = 12U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05 = 13U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06 = 14U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07 = 15U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08 = 16U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09 = 17U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10 = 18U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11 = 19U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12 = 20U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13 = 21U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14 = 22U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15 = 23U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK = 24U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE = 25U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE = 26U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR = 27U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0 = 28U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1 = 29U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2 = 30U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3 = 31U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK = 32U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE = 33U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL = 34U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP = 35U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0 = 36U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1 = 37U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM = 38U,     /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT = 39U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_CLK  = 40U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE = 41U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC = 42U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC = 43U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_RESET = 44U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA00 = 45U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA01 = 46U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA02 = 47U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA03 = 48U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA04 = 49U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA05 = 50U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA06 = 51U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA07 = 52U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA08 = 53U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA09 = 54U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA10 = 55U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA11 = 56U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA12 = 57U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA13 = 58U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA14 = 59U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA15 = 60U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA16 = 61U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA17 = 62U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA18 = 63U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA19 = 64U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA20 = 65U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA21 = 66U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA22 = 67U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_LCD_DATA23 = 68U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA = 69U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA = 70U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA = 71U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA = 72U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA = 73U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA = 74U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B = 75U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B = 76U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_I2C1_SCL = 77U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_I2C1_SDA = 78U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_I2C2_SCL = 79U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_I2C2_SDA = 80U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_I2C3_SCL = 81U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_I2C3_SDA = 82U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_I2C4_SCL = 83U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_I2C4_SDA = 84U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK = 85U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI = 86U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO = 87U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0 = 88U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK = 89U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI = 90U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO = 91U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0 = 92U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_CD_B = 93U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_WP   = 94U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B = 95U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_CLK  = 96U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_CMD  = 97U,         /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 = 98U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 = 99U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 = 100U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 = 101U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_CD_B = 102U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_WP   = 103U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B = 104U,     /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_CLK  = 105U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_CMD  = 106U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 = 107U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 = 108U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 = 109U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 = 110U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_CLK  = 111U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_CMD  = 112U,        /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 = 113U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 = 114U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 = 115U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 = 116U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 = 117U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 = 118U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 = 119U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 = 120U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_STROBE = 121U,      /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B = 122U,     /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA = 123U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK = 124U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC = 125U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA = 126U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC = 127U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK = 128U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK = 129U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC = 130U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK = 131U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA = 132U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA = 133U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0 = 134U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1 = 135U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2 = 136U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3 = 137U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL = 138U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC = 139U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0 = 140U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1 = 141U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2 = 142U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3 = 143U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL = 144U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC = 145U, /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK = 146U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK = 147U,    /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_CRS = 148U,       /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_SW_MUX_CTL_PAD_ENET1_COL = 149U,       /**< IOMUXC SW_MUX_CTL_PAD index */
} iomuxc_sw_mux_ctl_pad_t;

/*!
 * @addtogroup iomuxc_pads
 * @{ */

/*******************************************************************************
 * Definitions
*******************************************************************************/

/*!
 * @brief Enumeration for the IOMUXC SW_PAD_CTL_PAD
 *
 * Defines the enumeration for the IOMUXC SW_PAD_CTL_PAD collections.
 */
typedef enum _iomuxc_sw_pad_ctl_pad
{
    kIOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 = 0U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 = 1U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 = 2U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 = 3U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 = 4U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 = 5U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14 = 6U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15 = 7U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_JTAG_MOD = 8U,          /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_JTAG_TCK = 9U,          /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_JTAG_TDI = 10U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_JTAG_TDO = 11U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_JTAG_TMS = 12U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B = 13U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00 = 14U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01 = 15U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02 = 16U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03 = 17U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04 = 18U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05 = 19U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06 = 20U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07 = 21U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08 = 22U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09 = 23U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10 = 24U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11 = 25U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12 = 26U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13 = 27U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14 = 28U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15 = 29U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK = 30U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE = 31U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE = 32U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR = 33U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0 = 34U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1 = 35U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2 = 36U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3 = 37U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK = 38U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE = 39U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL = 40U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP = 41U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0 = 42U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1 = 43U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM = 44U,     /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT = 45U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_CLK  = 46U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE = 47U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC = 48U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC = 49U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_RESET = 50U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA00 = 51U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA01 = 52U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA02 = 53U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA03 = 54U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA04 = 55U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA05 = 56U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA06 = 57U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA07 = 58U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA08 = 59U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA09 = 60U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA10 = 61U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA11 = 62U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA12 = 63U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA13 = 64U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA14 = 65U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA15 = 66U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA16 = 67U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA17 = 68U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA18 = 69U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA19 = 70U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA20 = 71U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA21 = 72U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA22 = 73U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_LCD_DATA23 = 74U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA = 75U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA = 76U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA = 77U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA = 78U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA = 79U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA = 80U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B = 81U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B = 82U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_I2C1_SCL = 83U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_I2C1_SDA = 84U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_I2C2_SCL = 85U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_I2C2_SDA = 86U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_I2C3_SCL = 87U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_I2C3_SDA = 88U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_I2C4_SCL = 89U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_I2C4_SDA = 90U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK = 91U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI = 92U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO = 93U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0 = 94U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK = 95U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI = 96U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO = 97U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0 = 98U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_CD_B = 99U,         /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_WP   = 100U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B = 101U,     /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_CLK  = 102U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_CMD  = 103U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 = 104U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 = 105U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 = 106U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 = 107U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_CD_B = 108U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_WP   = 109U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B = 110U,     /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_CLK  = 111U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_CMD  = 112U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 = 113U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 = 114U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 = 115U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 = 116U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_CLK  = 117U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_CMD  = 118U,        /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 = 119U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 = 120U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 = 121U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 = 122U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 = 123U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 = 124U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 = 125U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 = 126U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_STROBE = 127U,      /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B = 128U,     /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA = 129U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK = 130U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC = 131U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA = 132U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC = 133U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK = 134U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK = 135U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC = 136U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK = 137U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA = 138U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA = 139U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0 = 140U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1 = 141U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2 = 142U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3 = 143U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL = 144U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC = 145U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0 = 146U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1 = 147U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2 = 148U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3 = 149U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL = 150U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC = 151U, /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK = 152U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK = 153U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_CRS = 154U,       /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_SW_PAD_CTL_PAD_ENET1_COL = 155U,       /**< IOMUXC SW_PAD_CTL_PAD index */
} iomuxc_sw_pad_ctl_pad_t;

/*!
 * @brief Enumeration for the IOMUXC select input
 *
 * Defines the enumeration for the IOMUXC select input collections.
 */
typedef enum _iomuxc_select_input
{
    kIOMUXC_FLEXCAN1_RX_SELECT_INPUT = 0U,         /**< IOMUXC select input index */
    kIOMUXC_FLEXCAN2_RX_SELECT_INPUT = 1U,         /**< IOMUXC select input index */
    kIOMUXC_CCM_EXT_CLK_1_SELECT_INPUT = 2U,       /**< IOMUXC select input index */
    kIOMUXC_CCM_EXT_CLK_2_SELECT_INPUT = 3U,       /**< IOMUXC select input index */
    kIOMUXC_CCM_EXT_CLK_3_SELECT_INPUT = 4U,       /**< IOMUXC select input index */
    kIOMUXC_CCM_EXT_CLK_4_SELECT_INPUT = 5U,       /**< IOMUXC select input index */
    kIOMUXC_CCM_PMIC_READY_SELECT_INPUT = 6U,      /**< IOMUXC select input index */
    kIOMUXC_CSI_DATA2_SELECT_INPUT  = 7U,          /**< IOMUXC select input index */
    kIOMUXC_CSI_DATA3_SELECT_INPUT  = 8U,          /**< IOMUXC select input index */
    kIOMUXC_CSI_DATA4_SELECT_INPUT  = 9U,          /**< IOMUXC select input index */
    kIOMUXC_CSI_DATA5_SELECT_INPUT  = 10U,         /**< IOMUXC select input index */
    kIOMUXC_CSI_DATA6_SELECT_INPUT  = 11U,         /**< IOMUXC select input index */
    kIOMUXC_CSI_DATA7_SELECT_INPUT  = 12U,         /**< IOMUXC select input index */
    kIOMUXC_CSI_DATA8_SELECT_INPUT  = 13U,         /**< IOMUXC select input index */
    kIOMUXC_CSI_DATA9_SELECT_INPUT  = 14U,         /**< IOMUXC select input index */
    kIOMUXC_CSI_HSYNC_SELECT_INPUT  = 15U,         /**< IOMUXC select input index */
    kIOMUXC_CSI_PIXCLK_SELECT_INPUT = 16U,         /**< IOMUXC select input index */
    kIOMUXC_CSI_VSYNC_SELECT_INPUT  = 17U,         /**< IOMUXC select input index */
    kIOMUXC_ECSPI1_SCLK_SELECT_INPUT = 18U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI1_MISO_SELECT_INPUT = 19U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI1_MOSI_SELECT_INPUT = 20U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI1_SS0_B_SELECT_INPUT = 21U,       /**< IOMUXC select input index */
    kIOMUXC_ECSPI2_SCLK_SELECT_INPUT = 22U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI2_MISO_SELECT_INPUT = 23U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI2_MOSI_SELECT_INPUT = 24U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI2_SS0_B_SELECT_INPUT = 25U,       /**< IOMUXC select input index */
    kIOMUXC_ECSPI3_SCLK_SELECT_INPUT = 26U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI3_MISO_SELECT_INPUT = 27U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI3_MOSI_SELECT_INPUT = 28U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI3_SS0_B_SELECT_INPUT = 29U,       /**< IOMUXC select input index */
    kIOMUXC_ECSPI4_SCLK_SELECT_INPUT = 30U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI4_MISO_SELECT_INPUT = 31U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI4_MOSI_SELECT_INPUT = 32U,        /**< IOMUXC select input index */
    kIOMUXC_ECSPI4_SS0_B_SELECT_INPUT = 33U,       /**< IOMUXC select input index */
    kIOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT = 34U,  /**< IOMUXC select input index */
    kIOMUXC_ENET1_MDIO_SELECT_INPUT = 35U,         /**< IOMUXC select input index */
    kIOMUXC_ENET1_RX_CLK_SELECT_INPUT = 36U,       /**< IOMUXC select input index */
    kIOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT = 37U,  /**< IOMUXC select input index */
    kIOMUXC_ENET2_MDIO_SELECT_INPUT = 38U,         /**< IOMUXC select input index */
    kIOMUXC_ENET2_RX_CLK_SELECT_INPUT = 39U,       /**< IOMUXC select input index */
    kIOMUXC_EPDC_PWR_IRQ_SELECT_INPUT = 40U,       /**< IOMUXC select input index */
    kIOMUXC_EPDC_PWR_STAT_SELECT_INPUT = 41U,      /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_CH0_SELECT_INPUT = 42U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_CH1_SELECT_INPUT = 43U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_CH2_SELECT_INPUT = 44U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_CH3_SELECT_INPUT = 45U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_CH4_SELECT_INPUT = 46U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_CH5_SELECT_INPUT = 47U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_CH6_SELECT_INPUT = 48U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_CH7_SELECT_INPUT = 49U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_PHA_SELECT_INPUT = 50U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER1_PHB_SELECT_INPUT = 51U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_CH0_SELECT_INPUT = 52U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_CH1_SELECT_INPUT = 53U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_CH2_SELECT_INPUT = 54U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_CH3_SELECT_INPUT = 55U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_CH4_SELECT_INPUT = 56U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_CH5_SELECT_INPUT = 57U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_CH6_SELECT_INPUT = 58U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_CH7_SELECT_INPUT = 59U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_PHA_SELECT_INPUT = 60U,     /**< IOMUXC select input index */
    kIOMUXC_FLEXTIMER2_PHB_SELECT_INPUT = 61U,     /**< IOMUXC select input index */
    kIOMUXC_I2C1_SCL_SELECT_INPUT   = 62U,         /**< IOMUXC select input index */
    kIOMUXC_I2C1_SDA_SELECT_INPUT   = 63U,         /**< IOMUXC select input index */
    kIOMUXC_I2C2_SCL_SELECT_INPUT   = 64U,         /**< IOMUXC select input index */
    kIOMUXC_I2C2_SDA_SELECT_INPUT   = 65U,         /**< IOMUXC select input index */
    kIOMUXC_I2C3_SCL_SELECT_INPUT   = 66U,         /**< IOMUXC select input index */
    kIOMUXC_I2C3_SDA_SELECT_INPUT   = 67U,         /**< IOMUXC select input index */
    kIOMUXC_I2C4_SCL_SELECT_INPUT   = 68U,         /**< IOMUXC select input index */
    kIOMUXC_I2C4_SDA_SELECT_INPUT   = 69U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_COL0_SELECT_INPUT   = 70U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_COL1_SELECT_INPUT   = 71U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_COL2_SELECT_INPUT   = 72U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_COL3_SELECT_INPUT   = 73U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_COL4_SELECT_INPUT   = 74U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_COL5_SELECT_INPUT   = 75U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_COL6_SELECT_INPUT   = 76U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_COL7_SELECT_INPUT   = 77U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_ROW0_SELECT_INPUT   = 78U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_ROW1_SELECT_INPUT   = 79U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_ROW2_SELECT_INPUT   = 80U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_ROW3_SELECT_INPUT   = 81U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_ROW4_SELECT_INPUT   = 82U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_ROW5_SELECT_INPUT   = 83U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_ROW6_SELECT_INPUT   = 84U,         /**< IOMUXC select input index */
    kIOMUXC_KPP_ROW7_SELECT_INPUT   = 85U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_BUSY_SELECT_INPUT   = 86U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA00_SELECT_INPUT = 87U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA01_SELECT_INPUT = 88U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA02_SELECT_INPUT = 89U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA03_SELECT_INPUT = 90U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA04_SELECT_INPUT = 91U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA05_SELECT_INPUT = 92U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA06_SELECT_INPUT = 93U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA07_SELECT_INPUT = 94U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA08_SELECT_INPUT = 95U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA09_SELECT_INPUT = 96U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA10_SELECT_INPUT = 97U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA11_SELECT_INPUT = 98U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA12_SELECT_INPUT = 99U,         /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA13_SELECT_INPUT = 100U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA14_SELECT_INPUT = 101U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA15_SELECT_INPUT = 102U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA16_SELECT_INPUT = 103U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA17_SELECT_INPUT = 104U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA18_SELECT_INPUT = 105U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA19_SELECT_INPUT = 106U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA20_SELECT_INPUT = 107U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA21_SELECT_INPUT = 108U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA22_SELECT_INPUT = 109U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_DATA23_SELECT_INPUT = 110U,        /**< IOMUXC select input index */
    kIOMUXC_LCD_VSYNC_SELECT_INPUT  = 111U,        /**< IOMUXC select input index */
    kIOMUXC_SAI1_RX_BCLK_SELECT_INPUT = 112U,      /**< IOMUXC select input index */
    kIOMUXC_SAI1_RX_DATA_SELECT_INPUT = 113U,      /**< IOMUXC select input index */
    kIOMUXC_SAI1_RX_SYNC_SELECT_INPUT = 114U,      /**< IOMUXC select input index */
    kIOMUXC_SAI1_TX_BCLK_SELECT_INPUT = 115U,      /**< IOMUXC select input index */
    kIOMUXC_SAI1_TX_SYNC_SELECT_INPUT = 116U,      /**< IOMUXC select input index */
    kIOMUXC_SAI2_RX_BCLK_SELECT_INPUT = 117U,      /**< IOMUXC select input index */
    kIOMUXC_SAI2_RX_DATA_SELECT_INPUT = 118U,      /**< IOMUXC select input index */
    kIOMUXC_SAI2_RX_SYNC_SELECT_INPUT = 119U,      /**< IOMUXC select input index */
    kIOMUXC_SAI2_TX_BCLK_SELECT_INPUT = 120U,      /**< IOMUXC select input index */
    kIOMUXC_SAI2_TX_SYNC_SELECT_INPUT = 121U,      /**< IOMUXC select input index */
    kIOMUXC_SAI3_RX_BCLK_SELECT_INPUT = 122U,      /**< IOMUXC select input index */
    kIOMUXC_SAI3_RX_DATA_SELECT_INPUT = 123U,      /**< IOMUXC select input index */
    kIOMUXC_SAI3_RX_SYNC_SELECT_INPUT = 124U,      /**< IOMUXC select input index */
    kIOMUXC_SAI3_TX_BCLK_SELECT_INPUT = 125U,      /**< IOMUXC select input index */
    kIOMUXC_SAI3_TX_SYNC_SELECT_INPUT = 126U,      /**< IOMUXC select input index */
    kIOMUXC_SDMA_EVENTS0_SELECT_INPUT = 127U,      /**< IOMUXC select input index */
    kIOMUXC_SDMA_EVENTS1_SELECT_INPUT = 128U,      /**< IOMUXC select input index */
    kIOMUXC_SIM1_PORT1_PD_SELECT_INPUT = 129U,     /**< IOMUXC select input index */
    kIOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT = 130U,   /**< IOMUXC select input index */
    kIOMUXC_SIM2_PORT1_PD_SELECT_INPUT = 131U,     /**< IOMUXC select input index */
    kIOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT = 132U,   /**< IOMUXC select input index */
    kIOMUXC_UART1_RTS_B_SELECT_INPUT = 133U,       /**< IOMUXC select input index */
    kIOMUXC_UART1_RX_DATA_SELECT_INPUT = 134U,     /**< IOMUXC select input index */
    kIOMUXC_UART2_RTS_B_SELECT_INPUT = 135U,       /**< IOMUXC select input index */
    kIOMUXC_UART2_RX_DATA_SELECT_INPUT = 136U,     /**< IOMUXC select input index */
    kIOMUXC_UART3_RTS_B_SELECT_INPUT = 137U,       /**< IOMUXC select input index */
    kIOMUXC_UART3_RX_DATA_SELECT_INPUT = 138U,     /**< IOMUXC select input index */
    kIOMUXC_UART4_RTS_B_SELECT_INPUT = 139U,       /**< IOMUXC select input index */
    kIOMUXC_UART4_RX_DATA_SELECT_INPUT = 140U,     /**< IOMUXC select input index */
    kIOMUXC_UART5_RTS_B_SELECT_INPUT = 141U,       /**< IOMUXC select input index */
    kIOMUXC_UART5_RX_DATA_SELECT_INPUT = 142U,     /**< IOMUXC select input index */
    kIOMUXC_UART6_RTS_B_SELECT_INPUT = 143U,       /**< IOMUXC select input index */
    kIOMUXC_UART6_RX_DATA_SELECT_INPUT = 144U,     /**< IOMUXC select input index */
    kIOMUXC_UART7_RTS_B_SELECT_INPUT = 145U,       /**< IOMUXC select input index */
    kIOMUXC_UART7_RX_DATA_SELECT_INPUT = 146U,     /**< IOMUXC select input index */
    kIOMUXC_USB_OTG2_OC_SELECT_INPUT = 147U,       /**< IOMUXC select input index */
    kIOMUXC_USB_OTG1_OC_SELECT_INPUT = 148U,       /**< IOMUXC select input index */
    kIOMUXC_USB_OTG2_ID_SELECT_INPUT = 149U,       /**< IOMUXC select input index */
    kIOMUXC_USB_OTG1_ID_SELECT_INPUT = 150U,       /**< IOMUXC select input index */
    kIOMUXC_SD3_CD_B_SELECT_INPUT   = 151U,        /**< IOMUXC select input index */
    kIOMUXC_SD3_WP_SELECT_INPUT     = 152U,        /**< IOMUXC select input index */
} iomuxc_select_input_t;

/* @} */

/*!
 * @addtogroup iomuxc_lpsr_pads
 * @{ */

/*******************************************************************************
 * Definitions
*******************************************************************************/

/*!
 * @brief Enumeration for the IOMUXC_LPSR SW_MUX_CTL_PAD
 *
 * Defines the enumeration for the IOMUXC_LPSR SW_MUX_CTL_PAD collections.
 */
typedef enum _iomuxc_lpsr_sw_mux_ctl_pad
{
    kIOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00 = 0U,   /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01 = 1U,   /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02 = 2U,   /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03 = 3U,   /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04 = 4U,   /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05 = 5U,   /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06 = 6U,   /**< IOMUXC SW_MUX_CTL_PAD index */
    kIOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07 = 7U,   /**< IOMUXC SW_MUX_CTL_PAD index */
} iomuxc_lpsr_sw_mux_ctl_pad_t;

/*!
 * @addtogroup iomuxc_lpsr_pads
 * @{ */

/*******************************************************************************
 * Definitions
*******************************************************************************/

/*!
 * @brief Enumeration for the IOMUXC_LPSR SW_PAD_CTL_PAD
 *
 * Defines the enumeration for the IOMUXC_LPSR SW_PAD_CTL_PAD collections.
 */
typedef enum _iomuxc_lpsr_sw_pad_ctl_pad
{
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE = 0U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B = 1U,    /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0 = 2U,   /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1 = 3U,   /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00 = 4U,   /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01 = 5U,   /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02 = 6U,   /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03 = 7U,   /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04 = 8U,   /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05 = 9U,   /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06 = 10U,  /**< IOMUXC SW_PAD_CTL_PAD index */
    kIOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07 = 11U,  /**< IOMUXC SW_PAD_CTL_PAD index */
} iomuxc_lpsr_sw_pad_ctl_pad_t;


/*!
 * @}
 */ /* end of group Mapping_Information */


/* ----------------------------------------------------------------------------
   -- Peripheral type defines
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Peripheral_defines Peripheral type defines
 * @{
 */


/*
** Start of section using anonymous unions
*/

#if defined (__CC_ARM)
  #pragma push
  #pragma anon_unions
#elif defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
  #pragma clang diagnostic push
  #pragma clang diagnostic ignored "-Wc11-extensions"
  #pragma clang diagnostic ignored "-Wreserved-id-macro"
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=extended
#else
  #error Not supported compiler type
#endif

/* ----------------------------------------------------------------------------
   -- ADC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ADC_Peripheral ADC
 * @{
 */

/** ADC - Peripheral register structure */
typedef struct ADC_MemMap {
  uint32_t CH_A_CFG1;                              /**< Channel A configuration 1, offset: 0x0 */
  uint8_t RESERVED_0[12];
  uint32_t CH_A_CFG2;                              /**< Channel A configuration 2, offset: 0x10 */
  uint8_t RESERVED_1[12];
  uint32_t CH_B_CFG1;                              /**< , offset: 0x20 */
  uint8_t RESERVED_2[12];
  uint32_t CH_B_CFG2;                              /**< Channel B Configuration 2, offset: 0x30 */
  uint8_t RESERVED_3[12];
  uint32_t CH_C_CFG1;                              /**< Channel C Configuration 1, offset: 0x40 */
  uint8_t RESERVED_4[12];
  uint32_t CH_C_CFG2;                              /**< Channel C Configuration 2, offset: 0x50 */
  uint8_t RESERVED_5[12];
  uint32_t CH_D_CFG1;                              /**< Channel D Configuration 1, offset: 0x60 */
  uint8_t RESERVED_6[12];
  uint32_t CH_D_CFG2;                              /**< Channel D Configuration 2, offset: 0x70 */
  uint8_t RESERVED_7[12];
  uint32_t CH_SW_CFG;                              /**< Channel Software Configuration, offset: 0x80 */
  uint8_t RESERVED_8[12];
  uint32_t TIMER_UNIT;                             /**< Timer Unit, offset: 0x90 */
  uint8_t RESERVED_9[12];
  uint32_t DMA_FIFO;                               /**< DMA FIFO, offset: 0xA0 */
  uint8_t RESERVED_10[12];
  uint32_t FIFO_STATUS;                            /**< FIFO Status, offset: 0xB0 */
  uint8_t RESERVED_11[12];
  uint32_t INT_SIG_EN;                             /**< , offset: 0xC0 */
  uint8_t RESERVED_12[12];
  uint32_t INT_EN;                                 /**< Interrupt Enable, offset: 0xD0 */
  uint8_t RESERVED_13[12];
  uint32_t INT_STATUS;                             /**< , offset: 0xE0 */
  uint8_t RESERVED_14[12];
  uint32_t CHA_B_CNV_RSLT;                         /**< Channel A and B Conversion Result, offset: 0xF0 */
  uint8_t RESERVED_15[12];
  uint32_t CHC_D_CNV_RSLT;                         /**< Channel C and D Conversion Result, offset: 0x100 */
  uint8_t RESERVED_16[12];
  uint32_t CH_SW_CNV_RSLT;                         /**< Channel Software Conversion Result, offset: 0x110 */
  uint8_t RESERVED_17[12];
  uint32_t DMA_FIFO_DAT;                           /**< DMA FIFO Data, offset: 0x120 */
  uint8_t RESERVED_18[12];
  uint32_t ADC_CFG;                                /**< ADC Configuration, offset: 0x130 */
} volatile *ADC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- ADC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ADC_Register_Accessor_Macros ADC - Register accessor macros
 * @{
 */


/* ADC - Register accessors */
#define ADC_CH_A_CFG1_REG(base)                  ((base)->CH_A_CFG1)
#define ADC_CH_A_CFG2_REG(base)                  ((base)->CH_A_CFG2)
#define ADC_CH_B_CFG1_REG(base)                  ((base)->CH_B_CFG1)
#define ADC_CH_B_CFG2_REG(base)                  ((base)->CH_B_CFG2)
#define ADC_CH_C_CFG1_REG(base)                  ((base)->CH_C_CFG1)
#define ADC_CH_C_CFG2_REG(base)                  ((base)->CH_C_CFG2)
#define ADC_CH_D_CFG1_REG(base)                  ((base)->CH_D_CFG1)
#define ADC_CH_D_CFG2_REG(base)                  ((base)->CH_D_CFG2)
#define ADC_CH_SW_CFG_REG(base)                  ((base)->CH_SW_CFG)
#define ADC_TIMER_UNIT_REG(base)                 ((base)->TIMER_UNIT)
#define ADC_DMA_FIFO_REG(base)                   ((base)->DMA_FIFO)
#define ADC_FIFO_STATUS_REG(base)                ((base)->FIFO_STATUS)
#define ADC_INT_SIG_EN_REG(base)                 ((base)->INT_SIG_EN)
#define ADC_INT_EN_REG(base)                     ((base)->INT_EN)
#define ADC_INT_STATUS_REG(base)                 ((base)->INT_STATUS)
#define ADC_CHA_B_CNV_RSLT_REG(base)             ((base)->CHA_B_CNV_RSLT)
#define ADC_CHC_D_CNV_RSLT_REG(base)             ((base)->CHC_D_CNV_RSLT)
#define ADC_CH_SW_CNV_RSLT_REG(base)             ((base)->CH_SW_CNV_RSLT)
#define ADC_DMA_FIFO_DAT_REG(base)               ((base)->DMA_FIFO_DAT)
#define ADC_ADC_CFG_REG(base)                    ((base)->ADC_CFG)

/*!
 * @}
 */ /* end of group ADC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- ADC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ADC_Register_Masks ADC Register Masks
 * @{
 */

/*! @name CH_A_CFG1 - Channel A configuration 1 */
#define ADC_CH_A_CFG1_CHA_TIMER_MASK             (0xFFFFFFU)
#define ADC_CH_A_CFG1_CHA_TIMER_SHIFT            (0U)
#define ADC_CH_A_CFG1_CHA_TIMER(x)               (((uint32_t)(((uint32_t)(x)) << ADC_CH_A_CFG1_CHA_TIMER_SHIFT)) & ADC_CH_A_CFG1_CHA_TIMER_MASK)
#define ADC_CH_A_CFG1_CHA_SEL_MASK               (0xF000000U)
#define ADC_CH_A_CFG1_CHA_SEL_SHIFT              (24U)
#define ADC_CH_A_CFG1_CHA_SEL(x)                 (((uint32_t)(((uint32_t)(x)) << ADC_CH_A_CFG1_CHA_SEL_SHIFT)) & ADC_CH_A_CFG1_CHA_SEL_MASK)
#define ADC_CH_A_CFG1_CHA_AVG_EN_MASK            (0x20000000U)
#define ADC_CH_A_CFG1_CHA_AVG_EN_SHIFT           (29U)
#define ADC_CH_A_CFG1_CHA_SINGLE_MASK            (0x40000000U)
#define ADC_CH_A_CFG1_CHA_SINGLE_SHIFT           (30U)
#define ADC_CH_A_CFG1_CHA_EN_MASK                (0x80000000U)
#define ADC_CH_A_CFG1_CHA_EN_SHIFT               (31U)

/*! @name CH_A_CFG2 - Channel A configuration 2 */
#define ADC_CH_A_CFG2_CHA_LOW_THRES_MASK         (0xFFFU)
#define ADC_CH_A_CFG2_CHA_LOW_THRES_SHIFT        (0U)
#define ADC_CH_A_CFG2_CHA_LOW_THRES(x)           (((uint32_t)(((uint32_t)(x)) << ADC_CH_A_CFG2_CHA_LOW_THRES_SHIFT)) & ADC_CH_A_CFG2_CHA_LOW_THRES_MASK)
#define ADC_CH_A_CFG2_CHA_AVG_NUMBER_MASK        (0x3000U)
#define ADC_CH_A_CFG2_CHA_AVG_NUMBER_SHIFT       (12U)
#define ADC_CH_A_CFG2_CHA_AVG_NUMBER(x)          (((uint32_t)(((uint32_t)(x)) << ADC_CH_A_CFG2_CHA_AVG_NUMBER_SHIFT)) & ADC_CH_A_CFG2_CHA_AVG_NUMBER_MASK)
#define ADC_CH_A_CFG2_CHA_AUTO_DIS_MASK          (0x8000U)
#define ADC_CH_A_CFG2_CHA_AUTO_DIS_SHIFT         (15U)
#define ADC_CH_A_CFG2_CHA_HIGH_THRES_MASK        (0xFFF0000U)
#define ADC_CH_A_CFG2_CHA_HIGH_THRES_SHIFT       (16U)
#define ADC_CH_A_CFG2_CHA_HIGH_THRES(x)          (((uint32_t)(((uint32_t)(x)) << ADC_CH_A_CFG2_CHA_HIGH_THRES_SHIFT)) & ADC_CH_A_CFG2_CHA_HIGH_THRES_MASK)
#define ADC_CH_A_CFG2_CHA_CMP_MODE_MASK          (0xE0000000U)
#define ADC_CH_A_CFG2_CHA_CMP_MODE_SHIFT         (29U)
#define ADC_CH_A_CFG2_CHA_CMP_MODE(x)            (((uint32_t)(((uint32_t)(x)) << ADC_CH_A_CFG2_CHA_CMP_MODE_SHIFT)) & ADC_CH_A_CFG2_CHA_CMP_MODE_MASK)

/*! @name CH_B_CFG1 -  */
#define ADC_CH_B_CFG1_CHB_TIMER_MASK             (0xFFFFFFU)
#define ADC_CH_B_CFG1_CHB_TIMER_SHIFT            (0U)
#define ADC_CH_B_CFG1_CHB_TIMER(x)               (((uint32_t)(((uint32_t)(x)) << ADC_CH_B_CFG1_CHB_TIMER_SHIFT)) & ADC_CH_B_CFG1_CHB_TIMER_MASK)
#define ADC_CH_B_CFG1_CHB_SEL_MASK               (0xF000000U)
#define ADC_CH_B_CFG1_CHB_SEL_SHIFT              (24U)
#define ADC_CH_B_CFG1_CHB_SEL(x)                 (((uint32_t)(((uint32_t)(x)) << ADC_CH_B_CFG1_CHB_SEL_SHIFT)) & ADC_CH_B_CFG1_CHB_SEL_MASK)
#define ADC_CH_B_CFG1_CHB_AVG_EN_MASK            (0x20000000U)
#define ADC_CH_B_CFG1_CHB_AVG_EN_SHIFT           (29U)
#define ADC_CH_B_CFG1_CHB_SINGLE_MASK            (0x40000000U)
#define ADC_CH_B_CFG1_CHB_SINGLE_SHIFT           (30U)
#define ADC_CH_B_CFG1_CHB_EN_MASK                (0x80000000U)
#define ADC_CH_B_CFG1_CHB_EN_SHIFT               (31U)

/*! @name CH_B_CFG2 - Channel B Configuration 2 */
#define ADC_CH_B_CFG2_CHB_LOW_THRES_MASK         (0xFFFU)
#define ADC_CH_B_CFG2_CHB_LOW_THRES_SHIFT        (0U)
#define ADC_CH_B_CFG2_CHB_LOW_THRES(x)           (((uint32_t)(((uint32_t)(x)) << ADC_CH_B_CFG2_CHB_LOW_THRES_SHIFT)) & ADC_CH_B_CFG2_CHB_LOW_THRES_MASK)
#define ADC_CH_B_CFG2_CHB_AVG_NUMBER_MASK        (0x3000U)
#define ADC_CH_B_CFG2_CHB_AVG_NUMBER_SHIFT       (12U)
#define ADC_CH_B_CFG2_CHB_AVG_NUMBER(x)          (((uint32_t)(((uint32_t)(x)) << ADC_CH_B_CFG2_CHB_AVG_NUMBER_SHIFT)) & ADC_CH_B_CFG2_CHB_AVG_NUMBER_MASK)
#define ADC_CH_B_CFG2_CHB_AUTO_DIS_MASK          (0x8000U)
#define ADC_CH_B_CFG2_CHB_AUTO_DIS_SHIFT         (15U)
#define ADC_CH_B_CFG2_CHB_HIGH_THRES_MASK        (0xFFF0000U)
#define ADC_CH_B_CFG2_CHB_HIGH_THRES_SHIFT       (16U)
#define ADC_CH_B_CFG2_CHB_HIGH_THRES(x)          (((uint32_t)(((uint32_t)(x)) << ADC_CH_B_CFG2_CHB_HIGH_THRES_SHIFT)) & ADC_CH_B_CFG2_CHB_HIGH_THRES_MASK)
#define ADC_CH_B_CFG2_CHB_CMP_MODE_MASK          (0xE0000000U)
#define ADC_CH_B_CFG2_CHB_CMP_MODE_SHIFT         (29U)
#define ADC_CH_B_CFG2_CHB_CMP_MODE(x)            (((uint32_t)(((uint32_t)(x)) << ADC_CH_B_CFG2_CHB_CMP_MODE_SHIFT)) & ADC_CH_B_CFG2_CHB_CMP_MODE_MASK)

/*! @name CH_C_CFG1 - Channel C Configuration 1 */
#define ADC_CH_C_CFG1_CHC_TIMER_MASK             (0xFFFFFFU)
#define ADC_CH_C_CFG1_CHC_TIMER_SHIFT            (0U)
#define ADC_CH_C_CFG1_CHC_TIMER(x)               (((uint32_t)(((uint32_t)(x)) << ADC_CH_C_CFG1_CHC_TIMER_SHIFT)) & ADC_CH_C_CFG1_CHC_TIMER_MASK)
#define ADC_CH_C_CFG1_CHC_SEL_MASK               (0xF000000U)
#define ADC_CH_C_CFG1_CHC_SEL_SHIFT              (24U)
#define ADC_CH_C_CFG1_CHC_SEL(x)                 (((uint32_t)(((uint32_t)(x)) << ADC_CH_C_CFG1_CHC_SEL_SHIFT)) & ADC_CH_C_CFG1_CHC_SEL_MASK)
#define ADC_CH_C_CFG1_CHC_AVG_EN_MASK            (0x20000000U)
#define ADC_CH_C_CFG1_CHC_AVG_EN_SHIFT           (29U)
#define ADC_CH_C_CFG1_CHC_SINGLE_MASK            (0x40000000U)
#define ADC_CH_C_CFG1_CHC_SINGLE_SHIFT           (30U)
#define ADC_CH_C_CFG1_CHC_EN_MASK                (0x80000000U)
#define ADC_CH_C_CFG1_CHC_EN_SHIFT               (31U)

/*! @name CH_C_CFG2 - Channel C Configuration 2 */
#define ADC_CH_C_CFG2_CHC_LOW_THRES_MASK         (0xFFFU)
#define ADC_CH_C_CFG2_CHC_LOW_THRES_SHIFT        (0U)
#define ADC_CH_C_CFG2_CHC_LOW_THRES(x)           (((uint32_t)(((uint32_t)(x)) << ADC_CH_C_CFG2_CHC_LOW_THRES_SHIFT)) & ADC_CH_C_CFG2_CHC_LOW_THRES_MASK)
#define ADC_CH_C_CFG2_CHC_AVG_NUMBER_MASK        (0x3000U)
#define ADC_CH_C_CFG2_CHC_AVG_NUMBER_SHIFT       (12U)
#define ADC_CH_C_CFG2_CHC_AVG_NUMBER(x)          (((uint32_t)(((uint32_t)(x)) << ADC_CH_C_CFG2_CHC_AVG_NUMBER_SHIFT)) & ADC_CH_C_CFG2_CHC_AVG_NUMBER_MASK)
#define ADC_CH_C_CFG2_CHC_AUTO_DIS_MASK          (0x8000U)
#define ADC_CH_C_CFG2_CHC_AUTO_DIS_SHIFT         (15U)
#define ADC_CH_C_CFG2_CHC_HIGH_THRES_MASK        (0xFFF0000U)
#define ADC_CH_C_CFG2_CHC_HIGH_THRES_SHIFT       (16U)
#define ADC_CH_C_CFG2_CHC_HIGH_THRES(x)          (((uint32_t)(((uint32_t)(x)) << ADC_CH_C_CFG2_CHC_HIGH_THRES_SHIFT)) & ADC_CH_C_CFG2_CHC_HIGH_THRES_MASK)
#define ADC_CH_C_CFG2_CHC_CMP_MODE_MASK          (0xE0000000U)
#define ADC_CH_C_CFG2_CHC_CMP_MODE_SHIFT         (29U)
#define ADC_CH_C_CFG2_CHC_CMP_MODE(x)            (((uint32_t)(((uint32_t)(x)) << ADC_CH_C_CFG2_CHC_CMP_MODE_SHIFT)) & ADC_CH_C_CFG2_CHC_CMP_MODE_MASK)

/*! @name CH_D_CFG1 - Channel D Configuration 1 */
#define ADC_CH_D_CFG1_CHD_TIMER_MASK             (0xFFFFFFU)
#define ADC_CH_D_CFG1_CHD_TIMER_SHIFT            (0U)
#define ADC_CH_D_CFG1_CHD_TIMER(x)               (((uint32_t)(((uint32_t)(x)) << ADC_CH_D_CFG1_CHD_TIMER_SHIFT)) & ADC_CH_D_CFG1_CHD_TIMER_MASK)
#define ADC_CH_D_CFG1_CHD_SEL_MASK               (0xF000000U)
#define ADC_CH_D_CFG1_CHD_SEL_SHIFT              (24U)
#define ADC_CH_D_CFG1_CHD_SEL(x)                 (((uint32_t)(((uint32_t)(x)) << ADC_CH_D_CFG1_CHD_SEL_SHIFT)) & ADC_CH_D_CFG1_CHD_SEL_MASK)
#define ADC_CH_D_CFG1_CHD_AVG_EN_MASK            (0x20000000U)
#define ADC_CH_D_CFG1_CHD_AVG_EN_SHIFT           (29U)
#define ADC_CH_D_CFG1_CHD_SINGLE_MASK            (0x40000000U)
#define ADC_CH_D_CFG1_CHD_SINGLE_SHIFT           (30U)
#define ADC_CH_D_CFG1_CHD_EN_MASK                (0x80000000U)
#define ADC_CH_D_CFG1_CHD_EN_SHIFT               (31U)

/*! @name CH_D_CFG2 - Channel D Configuration 2 */
#define ADC_CH_D_CFG2_CHD_LOW_THRES_MASK         (0xFFFU)
#define ADC_CH_D_CFG2_CHD_LOW_THRES_SHIFT        (0U)
#define ADC_CH_D_CFG2_CHD_LOW_THRES(x)           (((uint32_t)(((uint32_t)(x)) << ADC_CH_D_CFG2_CHD_LOW_THRES_SHIFT)) & ADC_CH_D_CFG2_CHD_LOW_THRES_MASK)
#define ADC_CH_D_CFG2_CHD_AVG_NUMBER_MASK        (0x3000U)
#define ADC_CH_D_CFG2_CHD_AVG_NUMBER_SHIFT       (12U)
#define ADC_CH_D_CFG2_CHD_AVG_NUMBER(x)          (((uint32_t)(((uint32_t)(x)) << ADC_CH_D_CFG2_CHD_AVG_NUMBER_SHIFT)) & ADC_CH_D_CFG2_CHD_AVG_NUMBER_MASK)
#define ADC_CH_D_CFG2_CHD_AUTO_DIS_MASK          (0x8000U)
#define ADC_CH_D_CFG2_CHD_AUTO_DIS_SHIFT         (15U)
#define ADC_CH_D_CFG2_CHD_HIGH_THRES_MASK        (0xFFF0000U)
#define ADC_CH_D_CFG2_CHD_HIGH_THRES_SHIFT       (16U)
#define ADC_CH_D_CFG2_CHD_HIGH_THRES(x)          (((uint32_t)(((uint32_t)(x)) << ADC_CH_D_CFG2_CHD_HIGH_THRES_SHIFT)) & ADC_CH_D_CFG2_CHD_HIGH_THRES_MASK)
#define ADC_CH_D_CFG2_CHD_CMP_MODE_MASK          (0xE0000000U)
#define ADC_CH_D_CFG2_CHD_CMP_MODE_SHIFT         (29U)
#define ADC_CH_D_CFG2_CHD_CMP_MODE(x)            (((uint32_t)(((uint32_t)(x)) << ADC_CH_D_CFG2_CHD_CMP_MODE_SHIFT)) & ADC_CH_D_CFG2_CHD_CMP_MODE_MASK)

/*! @name CH_SW_CFG - Channel Software Configuration */
#define ADC_CH_SW_CFG_CH_SW_AVG_NUMBER_MASK      (0x600000U)
#define ADC_CH_SW_CFG_CH_SW_AVG_NUMBER_SHIFT     (21U)
#define ADC_CH_SW_CFG_CH_SW_AVG_NUMBER(x)        (((uint32_t)(((uint32_t)(x)) << ADC_CH_SW_CFG_CH_SW_AVG_NUMBER_SHIFT)) & ADC_CH_SW_CFG_CH_SW_AVG_NUMBER_MASK)
#define ADC_CH_SW_CFG_CH_SW_AVG_EN_MASK          (0x800000U)
#define ADC_CH_SW_CFG_CH_SW_AVG_EN_SHIFT         (23U)
#define ADC_CH_SW_CFG_CH_SW_SEL_MASK             (0xF000000U)
#define ADC_CH_SW_CFG_CH_SW_SEL_SHIFT            (24U)
#define ADC_CH_SW_CFG_CH_SW_SEL(x)               (((uint32_t)(((uint32_t)(x)) << ADC_CH_SW_CFG_CH_SW_SEL_SHIFT)) & ADC_CH_SW_CFG_CH_SW_SEL_MASK)
#define ADC_CH_SW_CFG_START_CONV_MASK            (0x80000000U)
#define ADC_CH_SW_CFG_START_CONV_SHIFT           (31U)

/*! @name TIMER_UNIT - Timer Unit */
#define ADC_TIMER_UNIT_CORE_TIMER_UNIT_MASK      (0x1FU)
#define ADC_TIMER_UNIT_CORE_TIMER_UNIT_SHIFT     (0U)
#define ADC_TIMER_UNIT_CORE_TIMER_UNIT(x)        (((uint32_t)(((uint32_t)(x)) << ADC_TIMER_UNIT_CORE_TIMER_UNIT_SHIFT)) & ADC_TIMER_UNIT_CORE_TIMER_UNIT_MASK)
#define ADC_TIMER_UNIT_PRE_DIV_MASK              (0xE0000000U)
#define ADC_TIMER_UNIT_PRE_DIV_SHIFT             (29U)
#define ADC_TIMER_UNIT_PRE_DIV(x)                (((uint32_t)(((uint32_t)(x)) << ADC_TIMER_UNIT_PRE_DIV_SHIFT)) & ADC_TIMER_UNIT_PRE_DIV_MASK)

/*! @name DMA_FIFO - DMA FIFO */
#define ADC_DMA_FIFO_DMA_WM_LVL_MASK             (0x1FU)
#define ADC_DMA_FIFO_DMA_WM_LVL_SHIFT            (0U)
#define ADC_DMA_FIFO_DMA_WM_LVL(x)               (((uint32_t)(((uint32_t)(x)) << ADC_DMA_FIFO_DMA_WM_LVL_SHIFT)) & ADC_DMA_FIFO_DMA_WM_LVL_MASK)
#define ADC_DMA_FIFO_DMA_CH_SEL_MASK             (0x60U)
#define ADC_DMA_FIFO_DMA_CH_SEL_SHIFT            (5U)
#define ADC_DMA_FIFO_DMA_CH_SEL(x)               (((uint32_t)(((uint32_t)(x)) << ADC_DMA_FIFO_DMA_CH_SEL_SHIFT)) & ADC_DMA_FIFO_DMA_CH_SEL_MASK)
#define ADC_DMA_FIFO_DMA_EN_MASK                 (0x80U)
#define ADC_DMA_FIFO_DMA_EN_SHIFT                (7U)
#define ADC_DMA_FIFO_DMA_FIFO_EN_MASK            (0x100U)
#define ADC_DMA_FIFO_DMA_FIFO_EN_SHIFT           (8U)
#define ADC_DMA_FIFO_DMA_RST_MASK                (0x200U)
#define ADC_DMA_FIFO_DMA_RST_SHIFT               (9U)

/*! @name FIFO_STATUS - FIFO Status */
#define ADC_FIFO_STATUS_FIFO_ENTRIES_MASK        (0x3FU)
#define ADC_FIFO_STATUS_FIFO_ENTRIES_SHIFT       (0U)
#define ADC_FIFO_STATUS_FIFO_ENTRIES(x)          (((uint32_t)(((uint32_t)(x)) << ADC_FIFO_STATUS_FIFO_ENTRIES_SHIFT)) & ADC_FIFO_STATUS_FIFO_ENTRIES_MASK)
#define ADC_FIFO_STATUS_FIFO_EMPTY_MASK          (0x100U)
#define ADC_FIFO_STATUS_FIFO_EMPTY_SHIFT         (8U)
#define ADC_FIFO_STATUS_FIFO_FULL_MASK           (0x200U)
#define ADC_FIFO_STATUS_FIFO_FULL_SHIFT          (9U)

/*! @name INT_SIG_EN -  */
#define ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN_MASK   (0x1U)
#define ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN_SHIFT  (0U)
#define ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN_MASK   (0x2U)
#define ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN_SHIFT  (1U)
#define ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN_MASK   (0x4U)
#define ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN_SHIFT  (2U)
#define ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN_MASK   (0x8U)
#define ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN_SHIFT  (3U)
#define ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN_MASK (0x20U)
#define ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN_SHIFT (5U)
#define ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN_MASK (0x40U)
#define ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN_SHIFT (6U)
#define ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN_MASK (0x80U)
#define ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN_SHIFT (7U)
#define ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN_MASK   (0x100U)
#define ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN_SHIFT  (8U)
#define ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN_MASK   (0x200U)
#define ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN_SHIFT  (9U)
#define ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN_MASK   (0x400U)
#define ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN_SHIFT  (10U)
#define ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN_MASK   (0x800U)
#define ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN_SHIFT  (11U)
#define ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN_MASK (0x1000U)
#define ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN_SHIFT (12U)
#define ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN_MASK (0x10000U)
#define ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN_SHIFT (16U)
#define ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN_MASK (0x20000U)
#define ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN_SHIFT (17U)
#define ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN_MASK (0x40000U)
#define ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN_SHIFT (18U)
#define ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN_MASK (0x80000U)
#define ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN_SHIFT (19U)
#define ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN_MASK (0x100000U)
#define ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN_SHIFT (20U)
#define ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN_MASK (0x200000U)
#define ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN_SHIFT (21U)

/*! @name INT_EN - Interrupt Enable */
#define ADC_INT_EN_CHA_CMP_INT_EN_MASK           (0x1U)
#define ADC_INT_EN_CHA_CMP_INT_EN_SHIFT          (0U)
#define ADC_INT_EN_CHB_CMP_INT_EN_MASK           (0x2U)
#define ADC_INT_EN_CHB_CMP_INT_EN_SHIFT          (1U)
#define ADC_INT_EN_CHC_CMP_INT_EN_MASK           (0x4U)
#define ADC_INT_EN_CHC_CMP_INT_EN_SHIFT          (2U)
#define ADC_INT_EN_CHD_CMP_INT_EN_MASK           (0x8U)
#define ADC_INT_EN_CHD_CMP_INT_EN_SHIFT          (3U)
#define ADC_INT_EN_DMA_REACH_WM_INT_EN_MASK      (0x20U)
#define ADC_INT_EN_DMA_REACH_WM_INT_EN_SHIFT     (5U)
#define ADC_INT_EN_FIFO_UNDERRUN_INT_EN_MASK     (0x40U)
#define ADC_INT_EN_FIFO_UNDERRUN_INT_EN_SHIFT    (6U)
#define ADC_INT_EN_FIFO_OVERRUN_INT_EN_MASK      (0x80U)
#define ADC_INT_EN_FIFO_OVERRUN_INT_EN_SHIFT     (7U)
#define ADC_INT_EN_CHA_COV_INT_EN_MASK           (0x100U)
#define ADC_INT_EN_CHA_COV_INT_EN_SHIFT          (8U)
#define ADC_INT_EN_CHB_COV_INT_EN_MASK           (0x200U)
#define ADC_INT_EN_CHB_COV_INT_EN_SHIFT          (9U)
#define ADC_INT_EN_CHC_COV_INT_EN_MASK           (0x400U)
#define ADC_INT_EN_CHC_COV_INT_EN_SHIFT          (10U)
#define ADC_INT_EN_CHD_COV_INT_EN_MASK           (0x800U)
#define ADC_INT_EN_CHD_COV_INT_EN_SHIFT          (11U)
#define ADC_INT_EN_SW_CH_COV_INT_EN_MASK         (0x1000U)
#define ADC_INT_EN_SW_CH_COV_INT_EN_SHIFT        (12U)
#define ADC_INT_EN_CHA_COV_TO_INT_EN_MASK        (0x10000U)
#define ADC_INT_EN_CHA_COV_TO_INT_EN_SHIFT       (16U)
#define ADC_INT_EN_CHB_COV_TO_INT_EN_MASK        (0x20000U)
#define ADC_INT_EN_CHB_COV_TO_INT_EN_SHIFT       (17U)
#define ADC_INT_EN_CHC_COV_TO_INT_EN_MASK        (0x40000U)
#define ADC_INT_EN_CHC_COV_TO_INT_EN_SHIFT       (18U)
#define ADC_INT_EN_CHD_COV_TO_INT_EN_MASK        (0x80000U)
#define ADC_INT_EN_CHD_COV_TO_INT_EN_SHIFT       (19U)
#define ADC_INT_EN_SW_CH_COV_TO_INT_EN_MASK      (0x100000U)
#define ADC_INT_EN_SW_CH_COV_TO_INT_EN_SHIFT     (20U)
#define ADC_INT_EN_LAST_FIFO_DATA_READ_EN_MASK   (0x200000U)
#define ADC_INT_EN_LAST_FIFO_DATA_READ_EN_SHIFT  (21U)

/*! @name INT_STATUS -  */
#define ADC_INT_STATUS_CBA_CMP_MASK              (0x1U)
#define ADC_INT_STATUS_CBA_CMP_SHIFT             (0U)
#define ADC_INT_STATUS_CHB_CMP_MASK              (0x2U)
#define ADC_INT_STATUS_CHB_CMP_SHIFT             (1U)
#define ADC_INT_STATUS_CHC_CMP_MASK              (0x4U)
#define ADC_INT_STATUS_CHC_CMP_SHIFT             (2U)
#define ADC_INT_STATUS_CHD_CMP_MASK              (0x8U)
#define ADC_INT_STATUS_CHD_CMP_SHIFT             (3U)
#define ADC_INT_STATUS_DMA_REACH_WM_MASK         (0x20U)
#define ADC_INT_STATUS_DMA_REACH_WM_SHIFT        (5U)
#define ADC_INT_STATUS_FIFO_UNDERRUN_MASK        (0x40U)
#define ADC_INT_STATUS_FIFO_UNDERRUN_SHIFT       (6U)
#define ADC_INT_STATUS_FIFO_OVERRUN_MASK         (0x80U)
#define ADC_INT_STATUS_FIFO_OVERRUN_SHIFT        (7U)
#define ADC_INT_STATUS_CHA_COV_MASK              (0x100U)
#define ADC_INT_STATUS_CHA_COV_SHIFT             (8U)
#define ADC_INT_STATUS_CHB_COV_MASK              (0x200U)
#define ADC_INT_STATUS_CHB_COV_SHIFT             (9U)
#define ADC_INT_STATUS_CHC_COV_MASK              (0x400U)
#define ADC_INT_STATUS_CHC_COV_SHIFT             (10U)
#define ADC_INT_STATUS_CHD_COV_MASK              (0x800U)
#define ADC_INT_STATUS_CHD_COV_SHIFT             (11U)
#define ADC_INT_STATUS_SW_CH_COV_MASK            (0x1000U)
#define ADC_INT_STATUS_SW_CH_COV_SHIFT           (12U)
#define ADC_INT_STATUS_CHA_COV_TO_MASK           (0x10000U)
#define ADC_INT_STATUS_CHA_COV_TO_SHIFT          (16U)
#define ADC_INT_STATUS_CHB_COV_TO_MASK           (0x20000U)
#define ADC_INT_STATUS_CHB_COV_TO_SHIFT          (17U)
#define ADC_INT_STATUS_CHC_COV_TO_MASK           (0x40000U)
#define ADC_INT_STATUS_CHC_COV_TO_SHIFT          (18U)
#define ADC_INT_STATUS_CHD_COV_TO_MASK           (0x80000U)
#define ADC_INT_STATUS_CHD_COV_TO_SHIFT          (19U)
#define ADC_INT_STATUS_SW_CH_COV_TO_MASK         (0x100000U)
#define ADC_INT_STATUS_SW_CH_COV_TO_SHIFT        (20U)
#define ADC_INT_STATUS_LAST_FIFO_DATA_READ_MASK  (0x200000U)
#define ADC_INT_STATUS_LAST_FIFO_DATA_READ_SHIFT (21U)

/*! @name CHA_B_CNV_RSLT - Channel A and B Conversion Result */
#define ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT_MASK     (0xFFFU)
#define ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT_SHIFT    (0U)
#define ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT(x)       (((uint32_t)(((uint32_t)(x)) << ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT_SHIFT)) & ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT_MASK)
#define ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT_MASK     (0xFFF0000U)
#define ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT_SHIFT    (16U)
#define ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT(x)       (((uint32_t)(((uint32_t)(x)) << ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT_SHIFT)) & ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT_MASK)

/*! @name CHC_D_CNV_RSLT - Channel C and D Conversion Result */
#define ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT_MASK     (0xFFFU)
#define ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT_SHIFT    (0U)
#define ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT(x)       (((uint32_t)(((uint32_t)(x)) << ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT_SHIFT)) & ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT_MASK)
#define ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT_MASK     (0xFFF0000U)
#define ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT_SHIFT    (16U)
#define ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT(x)       (((uint32_t)(((uint32_t)(x)) << ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT_SHIFT)) & ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT_MASK)

/*! @name CH_SW_CNV_RSLT - Channel Software Conversion Result */
#define ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT_MASK   (0xFFFU)
#define ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT_SHIFT  (0U)
#define ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT(x)     (((uint32_t)(((uint32_t)(x)) << ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT_SHIFT)) & ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT_MASK)

/*! @name DMA_FIFO_DAT - DMA FIFO Data */
#define ADC_DMA_FIFO_DAT_DMA_FIFO_0_MASK         (0xFFFU)
#define ADC_DMA_FIFO_DAT_DMA_FIFO_0_SHIFT        (0U)
#define ADC_DMA_FIFO_DAT_DMA_FIFO_0(x)           (((uint32_t)(((uint32_t)(x)) << ADC_DMA_FIFO_DAT_DMA_FIFO_0_SHIFT)) & ADC_DMA_FIFO_DAT_DMA_FIFO_0_MASK)
#define ADC_DMA_FIFO_DAT_DAT1_FLAG_MASK          (0xC000U)
#define ADC_DMA_FIFO_DAT_DAT1_FLAG_SHIFT         (14U)
#define ADC_DMA_FIFO_DAT_DAT1_FLAG(x)            (((uint32_t)(((uint32_t)(x)) << ADC_DMA_FIFO_DAT_DAT1_FLAG_SHIFT)) & ADC_DMA_FIFO_DAT_DAT1_FLAG_MASK)
#define ADC_DMA_FIFO_DAT_DMA_FIFO_1_MASK         (0xFFF0000U)
#define ADC_DMA_FIFO_DAT_DMA_FIFO_1_SHIFT        (16U)
#define ADC_DMA_FIFO_DAT_DMA_FIFO_1(x)           (((uint32_t)(((uint32_t)(x)) << ADC_DMA_FIFO_DAT_DMA_FIFO_1_SHIFT)) & ADC_DMA_FIFO_DAT_DMA_FIFO_1_MASK)
#define ADC_DMA_FIFO_DAT_DAT2_FLAG_MASK          (0xC0000000U)
#define ADC_DMA_FIFO_DAT_DAT2_FLAG_SHIFT         (30U)
#define ADC_DMA_FIFO_DAT_DAT2_FLAG(x)            (((uint32_t)(((uint32_t)(x)) << ADC_DMA_FIFO_DAT_DAT2_FLAG_SHIFT)) & ADC_DMA_FIFO_DAT_DAT2_FLAG_MASK)

/*! @name ADC_CFG - ADC Configuration */
#define ADC_ADC_CFG_ADC_EN_MASK                  (0x1U)
#define ADC_ADC_CFG_ADC_EN_SHIFT                 (0U)
#define ADC_ADC_CFG_ADC_PD_MASK                  (0x2U)
#define ADC_ADC_CFG_ADC_PD_SHIFT                 (1U)
#define ADC_ADC_CFG_ADC_PD_OK_MASK               (0x80U)
#define ADC_ADC_CFG_ADC_PD_OK_SHIFT              (7U)
#define ADC_ADC_CFG_ADC_CLK_DOWN_MASK            (0x80000000U)
#define ADC_ADC_CFG_ADC_CLK_DOWN_SHIFT           (31U)


/*!
 * @}
 */ /* end of group ADC_Register_Masks */


/* ADC - Peripheral instance base addresses */
/** Peripheral ADC1 base pointer */
#define ADC1_BASE_PTR                            ((ADC_MemMapPtr)0x30610000u)
/** Peripheral ADC2 base pointer */
#define ADC2_BASE_PTR                            ((ADC_MemMapPtr)0x30620000u)
/** Array initializer of ADC peripheral base pointers */
#define ADC_BASE_PTRS                            { ADC1_BASE_PTR, ADC2_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- ADC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ADC_Register_Accessor_Macros ADC - Register accessor macros
 * @{
 */


/* ADC - Register instance definitions */
/* ADC1 */
#define ADC1_CH_A_CFG1                           ADC_CH_A_CFG1_REG(ADC1_BASE_PTR)
#define ADC1_CH_A_CFG2                           ADC_CH_A_CFG2_REG(ADC1_BASE_PTR)
#define ADC1_CH_B_CFG1                           ADC_CH_B_CFG1_REG(ADC1_BASE_PTR)
#define ADC1_CH_B_CFG2                           ADC_CH_B_CFG2_REG(ADC1_BASE_PTR)
#define ADC1_CH_C_CFG1                           ADC_CH_C_CFG1_REG(ADC1_BASE_PTR)
#define ADC1_CH_C_CFG2                           ADC_CH_C_CFG2_REG(ADC1_BASE_PTR)
#define ADC1_CH_D_CFG1                           ADC_CH_D_CFG1_REG(ADC1_BASE_PTR)
#define ADC1_CH_D_CFG2                           ADC_CH_D_CFG2_REG(ADC1_BASE_PTR)
#define ADC1_CH_SW_CFG                           ADC_CH_SW_CFG_REG(ADC1_BASE_PTR)
#define ADC1_TIMER_UNIT                          ADC_TIMER_UNIT_REG(ADC1_BASE_PTR)
#define ADC1_DMA_FIFO                            ADC_DMA_FIFO_REG(ADC1_BASE_PTR)
#define ADC1_FIFO_STATUS                         ADC_FIFO_STATUS_REG(ADC1_BASE_PTR)
#define ADC1_INT_SIG_EN                          ADC_INT_SIG_EN_REG(ADC1_BASE_PTR)
#define ADC1_INT_EN                              ADC_INT_EN_REG(ADC1_BASE_PTR)
#define ADC1_INT_STATUS                          ADC_INT_STATUS_REG(ADC1_BASE_PTR)
#define ADC1_CHA_B_CNV_RSLT                      ADC_CHA_B_CNV_RSLT_REG(ADC1_BASE_PTR)
#define ADC1_CHC_D_CNV_RSLT                      ADC_CHC_D_CNV_RSLT_REG(ADC1_BASE_PTR)
#define ADC1_CH_SW_CNV_RSLT                      ADC_CH_SW_CNV_RSLT_REG(ADC1_BASE_PTR)
#define ADC1_DMA_FIFO_DAT                        ADC_DMA_FIFO_DAT_REG(ADC1_BASE_PTR)
#define ADC1_ADC_CFG                             ADC_ADC_CFG_REG(ADC1_BASE_PTR)
/* ADC2 */
#define ADC2_CH_A_CFG1                           ADC_CH_A_CFG1_REG(ADC2_BASE_PTR)
#define ADC2_CH_A_CFG2                           ADC_CH_A_CFG2_REG(ADC2_BASE_PTR)
#define ADC2_CH_B_CFG1                           ADC_CH_B_CFG1_REG(ADC2_BASE_PTR)
#define ADC2_CH_B_CFG2                           ADC_CH_B_CFG2_REG(ADC2_BASE_PTR)
#define ADC2_CH_C_CFG1                           ADC_CH_C_CFG1_REG(ADC2_BASE_PTR)
#define ADC2_CH_C_CFG2                           ADC_CH_C_CFG2_REG(ADC2_BASE_PTR)
#define ADC2_CH_D_CFG1                           ADC_CH_D_CFG1_REG(ADC2_BASE_PTR)
#define ADC2_CH_D_CFG2                           ADC_CH_D_CFG2_REG(ADC2_BASE_PTR)
#define ADC2_CH_SW_CFG                           ADC_CH_SW_CFG_REG(ADC2_BASE_PTR)
#define ADC2_TIMER_UNIT                          ADC_TIMER_UNIT_REG(ADC2_BASE_PTR)
#define ADC2_DMA_FIFO                            ADC_DMA_FIFO_REG(ADC2_BASE_PTR)
#define ADC2_FIFO_STATUS                         ADC_FIFO_STATUS_REG(ADC2_BASE_PTR)
#define ADC2_INT_SIG_EN                          ADC_INT_SIG_EN_REG(ADC2_BASE_PTR)
#define ADC2_INT_EN                              ADC_INT_EN_REG(ADC2_BASE_PTR)
#define ADC2_INT_STATUS                          ADC_INT_STATUS_REG(ADC2_BASE_PTR)
#define ADC2_CHA_B_CNV_RSLT                      ADC_CHA_B_CNV_RSLT_REG(ADC2_BASE_PTR)
#define ADC2_CHC_D_CNV_RSLT                      ADC_CHC_D_CNV_RSLT_REG(ADC2_BASE_PTR)
#define ADC2_CH_SW_CNV_RSLT                      ADC_CH_SW_CNV_RSLT_REG(ADC2_BASE_PTR)
#define ADC2_DMA_FIFO_DAT                        ADC_DMA_FIFO_DAT_REG(ADC2_BASE_PTR)
#define ADC2_ADC_CFG                             ADC_ADC_CFG_REG(ADC2_BASE_PTR)

/*!
 * @}
 */ /* end of group ADC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group ADC_Peripheral */


/* ----------------------------------------------------------------------------
   -- APBH
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup APBH_Peripheral APBH
 * @{
 */

/** APBH - Peripheral register structure */
typedef struct APBH_MemMap {
  uint32_t CTRL0;                                  /**< AHB to APBH Bridge Control and Status Register 0, offset: 0x0 */
  uint32_t CTRL0_SET;                              /**< AHB to APBH Bridge Control and Status Register 0, offset: 0x4 */
  uint32_t CTRL0_CLR;                              /**< AHB to APBH Bridge Control and Status Register 0, offset: 0x8 */
  uint32_t CTRL0_TOG;                              /**< AHB to APBH Bridge Control and Status Register 0, offset: 0xC */
  uint32_t CTRL1;                                  /**< AHB to APBH Bridge Control and Status Register 1, offset: 0x10 */
  uint32_t CTRL1_SET;                              /**< AHB to APBH Bridge Control and Status Register 1, offset: 0x14 */
  uint32_t CTRL1_CLR;                              /**< AHB to APBH Bridge Control and Status Register 1, offset: 0x18 */
  uint32_t CTRL1_TOG;                              /**< AHB to APBH Bridge Control and Status Register 1, offset: 0x1C */
  uint32_t CTRL2;                                  /**< AHB to APBH Bridge Control and Status Register 2, offset: 0x20 */
  uint32_t CTRL2_SET;                              /**< AHB to APBH Bridge Control and Status Register 2, offset: 0x24 */
  uint32_t CTRL2_CLR;                              /**< AHB to APBH Bridge Control and Status Register 2, offset: 0x28 */
  uint32_t CTRL2_TOG;                              /**< AHB to APBH Bridge Control and Status Register 2, offset: 0x2C */
  uint32_t CHANNEL_CTRL;                           /**< AHB to APBH Bridge Channel Register, offset: 0x30 */
  uint32_t CHANNEL_CTRL_SET;                       /**< AHB to APBH Bridge Channel Register, offset: 0x34 */
  uint32_t CHANNEL_CTRL_CLR;                       /**< AHB to APBH Bridge Channel Register, offset: 0x38 */
  uint32_t CHANNEL_CTRL_TOG;                       /**< AHB to APBH Bridge Channel Register, offset: 0x3C */
  uint32_t DEVSEL;                                 /**< AHB to APBH DMA Device Assignment Register, offset: 0x40 */
  uint8_t RESERVED_0[12];
  uint32_t DMA_BURST_SIZE;                         /**< AHB to APBH DMA burst size, offset: 0x50 */
  uint8_t RESERVED_1[12];
  uint32_t DEBUG;                                  /**< AHB to APBH DMA Debug Register, offset: 0x60 */
  uint8_t RESERVED_2[156];
  uint32_t CH0_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x100 */
  uint8_t RESERVED_3[12];
  uint32_t CH0_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x110 */
  uint8_t RESERVED_4[12];
  uint32_t CH0_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x120 */
  uint8_t RESERVED_5[12];
  uint32_t CH0_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x130 */
  uint8_t RESERVED_6[12];
  uint32_t CH0_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x140 */
  uint8_t RESERVED_7[12];
  uint32_t CH0_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x150 */
  uint8_t RESERVED_8[12];
  uint32_t CH0_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x160 */
  uint8_t RESERVED_9[12];
  uint32_t CH1_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x170 */
  uint8_t RESERVED_10[12];
  uint32_t CH1_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x180 */
  uint8_t RESERVED_11[12];
  uint32_t CH1_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x190 */
  uint8_t RESERVED_12[12];
  uint32_t CH1_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x1A0 */
  uint8_t RESERVED_13[12];
  uint32_t CH1_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x1B0 */
  uint8_t RESERVED_14[12];
  uint32_t CH1_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x1C0 */
  uint8_t RESERVED_15[12];
  uint32_t CH1_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x1D0 */
  uint8_t RESERVED_16[12];
  uint32_t CH2_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x1E0 */
  uint8_t RESERVED_17[12];
  uint32_t CH2_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x1F0 */
  uint8_t RESERVED_18[12];
  uint32_t CH2_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x200 */
  uint8_t RESERVED_19[12];
  uint32_t CH2_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x210 */
  uint8_t RESERVED_20[12];
  uint32_t CH2_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x220 */
  uint8_t RESERVED_21[12];
  uint32_t CH2_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x230 */
  uint8_t RESERVED_22[12];
  uint32_t CH2_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x240 */
  uint8_t RESERVED_23[12];
  uint32_t CH3_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x250 */
  uint8_t RESERVED_24[12];
  uint32_t CH3_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x260 */
  uint8_t RESERVED_25[12];
  uint32_t CH3_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x270 */
  uint8_t RESERVED_26[12];
  uint32_t CH3_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x280 */
  uint8_t RESERVED_27[12];
  uint32_t CH3_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x290 */
  uint8_t RESERVED_28[12];
  uint32_t CH3_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x2A0 */
  uint8_t RESERVED_29[12];
  uint32_t CH3_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x2B0 */
  uint8_t RESERVED_30[12];
  uint32_t CH4_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x2C0 */
  uint8_t RESERVED_31[12];
  uint32_t CH4_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x2D0 */
  uint8_t RESERVED_32[12];
  uint32_t CH4_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x2E0 */
  uint8_t RESERVED_33[12];
  uint32_t CH4_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x2F0 */
  uint8_t RESERVED_34[12];
  uint32_t CH4_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x300 */
  uint8_t RESERVED_35[12];
  uint32_t CH4_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x310 */
  uint8_t RESERVED_36[12];
  uint32_t CH4_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x320 */
  uint8_t RESERVED_37[12];
  uint32_t CH5_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x330 */
  uint8_t RESERVED_38[12];
  uint32_t CH5_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x340 */
  uint8_t RESERVED_39[12];
  uint32_t CH5_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x350 */
  uint8_t RESERVED_40[12];
  uint32_t CH5_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x360 */
  uint8_t RESERVED_41[12];
  uint32_t CH5_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x370 */
  uint8_t RESERVED_42[12];
  uint32_t CH5_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x380 */
  uint8_t RESERVED_43[12];
  uint32_t CH5_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x390 */
  uint8_t RESERVED_44[12];
  uint32_t CH6_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x3A0 */
  uint8_t RESERVED_45[12];
  uint32_t CH6_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x3B0 */
  uint8_t RESERVED_46[12];
  uint32_t CH6_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x3C0 */
  uint8_t RESERVED_47[12];
  uint32_t CH6_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x3D0 */
  uint8_t RESERVED_48[12];
  uint32_t CH6_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x3E0 */
  uint8_t RESERVED_49[12];
  uint32_t CH6_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x3F0 */
  uint8_t RESERVED_50[12];
  uint32_t CH6_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x400 */
  uint8_t RESERVED_51[12];
  uint32_t CH7_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x410 */
  uint8_t RESERVED_52[12];
  uint32_t CH7_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x420 */
  uint8_t RESERVED_53[12];
  uint32_t CH7_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x430 */
  uint8_t RESERVED_54[12];
  uint32_t CH7_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x440 */
  uint8_t RESERVED_55[12];
  uint32_t CH7_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x450 */
  uint8_t RESERVED_56[12];
  uint32_t CH7_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x460 */
  uint8_t RESERVED_57[12];
  uint32_t CH7_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x470 */
  uint8_t RESERVED_58[12];
  uint32_t CH8_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x480 */
  uint8_t RESERVED_59[12];
  uint32_t CH8_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x490 */
  uint8_t RESERVED_60[12];
  uint32_t CH8_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x4A0 */
  uint8_t RESERVED_61[12];
  uint32_t CH8_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x4B0 */
  uint8_t RESERVED_62[12];
  uint32_t CH8_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x4C0 */
  uint8_t RESERVED_63[12];
  uint32_t CH8_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x4D0 */
  uint8_t RESERVED_64[12];
  uint32_t CH8_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x4E0 */
  uint8_t RESERVED_65[12];
  uint32_t CH9_CURCMDAR;                           /**< APBH DMA Channel n Current Command Address Register, offset: 0x4F0 */
  uint8_t RESERVED_66[12];
  uint32_t CH9_NXTCMDAR;                           /**< APBH DMA Channel n Next Command Address Register, offset: 0x500 */
  uint8_t RESERVED_67[12];
  uint32_t CH9_CMD;                                /**< APBH DMA Channel n Command Register, offset: 0x510 */
  uint8_t RESERVED_68[12];
  uint32_t CH9_BAR;                                /**< APBH DMA Channel n Buffer Address Register, offset: 0x520 */
  uint8_t RESERVED_69[12];
  uint32_t CH9_SEMA;                               /**< APBH DMA Channel n Semaphore Register, offset: 0x530 */
  uint8_t RESERVED_70[12];
  uint32_t CH9_DEBUG1;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x540 */
  uint8_t RESERVED_71[12];
  uint32_t CH9_DEBUG2;                             /**< AHB to APBH DMA Channel n Debug Information, offset: 0x550 */
  uint8_t RESERVED_72[12];
  uint32_t CH10_CURCMDAR;                          /**< APBH DMA Channel n Current Command Address Register, offset: 0x560 */
  uint8_t RESERVED_73[12];
  uint32_t CH10_NXTCMDAR;                          /**< APBH DMA Channel n Next Command Address Register, offset: 0x570 */
  uint8_t RESERVED_74[12];
  uint32_t CH10_CMD;                               /**< APBH DMA Channel n Command Register, offset: 0x580 */
  uint8_t RESERVED_75[12];
  uint32_t CH10_BAR;                               /**< APBH DMA Channel n Buffer Address Register, offset: 0x590 */
  uint8_t RESERVED_76[12];
  uint32_t CH10_SEMA;                              /**< APBH DMA Channel n Semaphore Register, offset: 0x5A0 */
  uint8_t RESERVED_77[12];
  uint32_t CH10_DEBUG1;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x5B0 */
  uint8_t RESERVED_78[12];
  uint32_t CH10_DEBUG2;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x5C0 */
  uint8_t RESERVED_79[12];
  uint32_t CH11_CURCMDAR;                          /**< APBH DMA Channel n Current Command Address Register, offset: 0x5D0 */
  uint8_t RESERVED_80[12];
  uint32_t CH11_NXTCMDAR;                          /**< APBH DMA Channel n Next Command Address Register, offset: 0x5E0 */
  uint8_t RESERVED_81[12];
  uint32_t CH11_CMD;                               /**< APBH DMA Channel n Command Register, offset: 0x5F0 */
  uint8_t RESERVED_82[12];
  uint32_t CH11_BAR;                               /**< APBH DMA Channel n Buffer Address Register, offset: 0x600 */
  uint8_t RESERVED_83[12];
  uint32_t CH11_SEMA;                              /**< APBH DMA Channel n Semaphore Register, offset: 0x610 */
  uint8_t RESERVED_84[12];
  uint32_t CH11_DEBUG1;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x620 */
  uint8_t RESERVED_85[12];
  uint32_t CH11_DEBUG2;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x630 */
  uint8_t RESERVED_86[12];
  uint32_t CH12_CURCMDAR;                          /**< APBH DMA Channel n Current Command Address Register, offset: 0x640 */
  uint8_t RESERVED_87[12];
  uint32_t CH12_NXTCMDAR;                          /**< APBH DMA Channel n Next Command Address Register, offset: 0x650 */
  uint8_t RESERVED_88[12];
  uint32_t CH12_CMD;                               /**< APBH DMA Channel n Command Register, offset: 0x660 */
  uint8_t RESERVED_89[12];
  uint32_t CH12_BAR;                               /**< APBH DMA Channel n Buffer Address Register, offset: 0x670 */
  uint8_t RESERVED_90[12];
  uint32_t CH12_SEMA;                              /**< APBH DMA Channel n Semaphore Register, offset: 0x680 */
  uint8_t RESERVED_91[12];
  uint32_t CH12_DEBUG1;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x690 */
  uint8_t RESERVED_92[12];
  uint32_t CH12_DEBUG2;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x6A0 */
  uint8_t RESERVED_93[12];
  uint32_t CH13_CURCMDAR;                          /**< APBH DMA Channel n Current Command Address Register, offset: 0x6B0 */
  uint8_t RESERVED_94[12];
  uint32_t CH13_NXTCMDAR;                          /**< APBH DMA Channel n Next Command Address Register, offset: 0x6C0 */
  uint8_t RESERVED_95[12];
  uint32_t CH13_CMD;                               /**< APBH DMA Channel n Command Register, offset: 0x6D0 */
  uint8_t RESERVED_96[12];
  uint32_t CH13_BAR;                               /**< APBH DMA Channel n Buffer Address Register, offset: 0x6E0 */
  uint8_t RESERVED_97[12];
  uint32_t CH13_SEMA;                              /**< APBH DMA Channel n Semaphore Register, offset: 0x6F0 */
  uint8_t RESERVED_98[12];
  uint32_t CH13_DEBUG1;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x700 */
  uint8_t RESERVED_99[12];
  uint32_t CH13_DEBUG2;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x710 */
  uint8_t RESERVED_100[12];
  uint32_t CH14_CURCMDAR;                          /**< APBH DMA Channel n Current Command Address Register, offset: 0x720 */
  uint8_t RESERVED_101[12];
  uint32_t CH14_NXTCMDAR;                          /**< APBH DMA Channel n Next Command Address Register, offset: 0x730 */
  uint8_t RESERVED_102[12];
  uint32_t CH14_CMD;                               /**< APBH DMA Channel n Command Register, offset: 0x740 */
  uint8_t RESERVED_103[12];
  uint32_t CH14_BAR;                               /**< APBH DMA Channel n Buffer Address Register, offset: 0x750 */
  uint8_t RESERVED_104[12];
  uint32_t CH14_SEMA;                              /**< APBH DMA Channel n Semaphore Register, offset: 0x760 */
  uint8_t RESERVED_105[12];
  uint32_t CH14_DEBUG1;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x770 */
  uint8_t RESERVED_106[12];
  uint32_t CH14_DEBUG2;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x780 */
  uint8_t RESERVED_107[12];
  uint32_t CH15_CURCMDAR;                          /**< APBH DMA Channel n Current Command Address Register, offset: 0x790 */
  uint8_t RESERVED_108[12];
  uint32_t CH15_NXTCMDAR;                          /**< APBH DMA Channel n Next Command Address Register, offset: 0x7A0 */
  uint8_t RESERVED_109[12];
  uint32_t CH15_CMD;                               /**< APBH DMA Channel n Command Register, offset: 0x7B0 */
  uint8_t RESERVED_110[12];
  uint32_t CH15_BAR;                               /**< APBH DMA Channel n Buffer Address Register, offset: 0x7C0 */
  uint8_t RESERVED_111[12];
  uint32_t CH15_SEMA;                              /**< APBH DMA Channel n Semaphore Register, offset: 0x7D0 */
  uint8_t RESERVED_112[12];
  uint32_t CH15_DEBUG1;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x7E0 */
  uint8_t RESERVED_113[12];
  uint32_t CH15_DEBUG2;                            /**< AHB to APBH DMA Channel n Debug Information, offset: 0x7F0 */
  uint8_t RESERVED_114[12];
  uint32_t VERSION;                                /**< APBH Bridge Version Register, offset: 0x800 */
} volatile *APBH_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- APBH - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup APBH_Register_Accessor_Macros APBH - Register accessor macros
 * @{
 */


/* APBH - Register accessors */
#define APBH_CTRL0_REG(base)                     ((base)->CTRL0)
#define APBH_CTRL0_SET_REG(base)                 ((base)->CTRL0_SET)
#define APBH_CTRL0_CLR_REG(base)                 ((base)->CTRL0_CLR)
#define APBH_CTRL0_TOG_REG(base)                 ((base)->CTRL0_TOG)
#define APBH_CTRL1_REG(base)                     ((base)->CTRL1)
#define APBH_CTRL1_SET_REG(base)                 ((base)->CTRL1_SET)
#define APBH_CTRL1_CLR_REG(base)                 ((base)->CTRL1_CLR)
#define APBH_CTRL1_TOG_REG(base)                 ((base)->CTRL1_TOG)
#define APBH_CTRL2_REG(base)                     ((base)->CTRL2)
#define APBH_CTRL2_SET_REG(base)                 ((base)->CTRL2_SET)
#define APBH_CTRL2_CLR_REG(base)                 ((base)->CTRL2_CLR)
#define APBH_CTRL2_TOG_REG(base)                 ((base)->CTRL2_TOG)
#define APBH_CHANNEL_CTRL_REG(base)              ((base)->CHANNEL_CTRL)
#define APBH_CHANNEL_CTRL_SET_REG(base)          ((base)->CHANNEL_CTRL_SET)
#define APBH_CHANNEL_CTRL_CLR_REG(base)          ((base)->CHANNEL_CTRL_CLR)
#define APBH_CHANNEL_CTRL_TOG_REG(base)          ((base)->CHANNEL_CTRL_TOG)
#define APBH_DEVSEL_REG(base)                    ((base)->DEVSEL)
#define APBH_DMA_BURST_SIZE_REG(base)            ((base)->DMA_BURST_SIZE)
#define APBH_DEBUG_REG(base)                     ((base)->DEBUG)
#define APBH_CH0_CURCMDAR_REG(base)              ((base)->CH0_CURCMDAR)
#define APBH_CH0_NXTCMDAR_REG(base)              ((base)->CH0_NXTCMDAR)
#define APBH_CH0_CMD_REG(base)                   ((base)->CH0_CMD)
#define APBH_CH0_BAR_REG(base)                   ((base)->CH0_BAR)
#define APBH_CH0_SEMA_REG(base)                  ((base)->CH0_SEMA)
#define APBH_CH0_DEBUG1_REG(base)                ((base)->CH0_DEBUG1)
#define APBH_CH0_DEBUG2_REG(base)                ((base)->CH0_DEBUG2)
#define APBH_CH1_CURCMDAR_REG(base)              ((base)->CH1_CURCMDAR)
#define APBH_CH1_NXTCMDAR_REG(base)              ((base)->CH1_NXTCMDAR)
#define APBH_CH1_CMD_REG(base)                   ((base)->CH1_CMD)
#define APBH_CH1_BAR_REG(base)                   ((base)->CH1_BAR)
#define APBH_CH1_SEMA_REG(base)                  ((base)->CH1_SEMA)
#define APBH_CH1_DEBUG1_REG(base)                ((base)->CH1_DEBUG1)
#define APBH_CH1_DEBUG2_REG(base)                ((base)->CH1_DEBUG2)
#define APBH_CH2_CURCMDAR_REG(base)              ((base)->CH2_CURCMDAR)
#define APBH_CH2_NXTCMDAR_REG(base)              ((base)->CH2_NXTCMDAR)
#define APBH_CH2_CMD_REG(base)                   ((base)->CH2_CMD)
#define APBH_CH2_BAR_REG(base)                   ((base)->CH2_BAR)
#define APBH_CH2_SEMA_REG(base)                  ((base)->CH2_SEMA)
#define APBH_CH2_DEBUG1_REG(base)                ((base)->CH2_DEBUG1)
#define APBH_CH2_DEBUG2_REG(base)                ((base)->CH2_DEBUG2)
#define APBH_CH3_CURCMDAR_REG(base)              ((base)->CH3_CURCMDAR)
#define APBH_CH3_NXTCMDAR_REG(base)              ((base)->CH3_NXTCMDAR)
#define APBH_CH3_CMD_REG(base)                   ((base)->CH3_CMD)
#define APBH_CH3_BAR_REG(base)                   ((base)->CH3_BAR)
#define APBH_CH3_SEMA_REG(base)                  ((base)->CH3_SEMA)
#define APBH_CH3_DEBUG1_REG(base)                ((base)->CH3_DEBUG1)
#define APBH_CH3_DEBUG2_REG(base)                ((base)->CH3_DEBUG2)
#define APBH_CH4_CURCMDAR_REG(base)              ((base)->CH4_CURCMDAR)
#define APBH_CH4_NXTCMDAR_REG(base)              ((base)->CH4_NXTCMDAR)
#define APBH_CH4_CMD_REG(base)                   ((base)->CH4_CMD)
#define APBH_CH4_BAR_REG(base)                   ((base)->CH4_BAR)
#define APBH_CH4_SEMA_REG(base)                  ((base)->CH4_SEMA)
#define APBH_CH4_DEBUG1_REG(base)                ((base)->CH4_DEBUG1)
#define APBH_CH4_DEBUG2_REG(base)                ((base)->CH4_DEBUG2)
#define APBH_CH5_CURCMDAR_REG(base)              ((base)->CH5_CURCMDAR)
#define APBH_CH5_NXTCMDAR_REG(base)              ((base)->CH5_NXTCMDAR)
#define APBH_CH5_CMD_REG(base)                   ((base)->CH5_CMD)
#define APBH_CH5_BAR_REG(base)                   ((base)->CH5_BAR)
#define APBH_CH5_SEMA_REG(base)                  ((base)->CH5_SEMA)
#define APBH_CH5_DEBUG1_REG(base)                ((base)->CH5_DEBUG1)
#define APBH_CH5_DEBUG2_REG(base)                ((base)->CH5_DEBUG2)
#define APBH_CH6_CURCMDAR_REG(base)              ((base)->CH6_CURCMDAR)
#define APBH_CH6_NXTCMDAR_REG(base)              ((base)->CH6_NXTCMDAR)
#define APBH_CH6_CMD_REG(base)                   ((base)->CH6_CMD)
#define APBH_CH6_BAR_REG(base)                   ((base)->CH6_BAR)
#define APBH_CH6_SEMA_REG(base)                  ((base)->CH6_SEMA)
#define APBH_CH6_DEBUG1_REG(base)                ((base)->CH6_DEBUG1)
#define APBH_CH6_DEBUG2_REG(base)                ((base)->CH6_DEBUG2)
#define APBH_CH7_CURCMDAR_REG(base)              ((base)->CH7_CURCMDAR)
#define APBH_CH7_NXTCMDAR_REG(base)              ((base)->CH7_NXTCMDAR)
#define APBH_CH7_CMD_REG(base)                   ((base)->CH7_CMD)
#define APBH_CH7_BAR_REG(base)                   ((base)->CH7_BAR)
#define APBH_CH7_SEMA_REG(base)                  ((base)->CH7_SEMA)
#define APBH_CH7_DEBUG1_REG(base)                ((base)->CH7_DEBUG1)
#define APBH_CH7_DEBUG2_REG(base)                ((base)->CH7_DEBUG2)
#define APBH_CH8_CURCMDAR_REG(base)              ((base)->CH8_CURCMDAR)
#define APBH_CH8_NXTCMDAR_REG(base)              ((base)->CH8_NXTCMDAR)
#define APBH_CH8_CMD_REG(base)                   ((base)->CH8_CMD)
#define APBH_CH8_BAR_REG(base)                   ((base)->CH8_BAR)
#define APBH_CH8_SEMA_REG(base)                  ((base)->CH8_SEMA)
#define APBH_CH8_DEBUG1_REG(base)                ((base)->CH8_DEBUG1)
#define APBH_CH8_DEBUG2_REG(base)                ((base)->CH8_DEBUG2)
#define APBH_CH9_CURCMDAR_REG(base)              ((base)->CH9_CURCMDAR)
#define APBH_CH9_NXTCMDAR_REG(base)              ((base)->CH9_NXTCMDAR)
#define APBH_CH9_CMD_REG(base)                   ((base)->CH9_CMD)
#define APBH_CH9_BAR_REG(base)                   ((base)->CH9_BAR)
#define APBH_CH9_SEMA_REG(base)                  ((base)->CH9_SEMA)
#define APBH_CH9_DEBUG1_REG(base)                ((base)->CH9_DEBUG1)
#define APBH_CH9_DEBUG2_REG(base)                ((base)->CH9_DEBUG2)
#define APBH_CH10_CURCMDAR_REG(base)             ((base)->CH10_CURCMDAR)
#define APBH_CH10_NXTCMDAR_REG(base)             ((base)->CH10_NXTCMDAR)
#define APBH_CH10_CMD_REG(base)                  ((base)->CH10_CMD)
#define APBH_CH10_BAR_REG(base)                  ((base)->CH10_BAR)
#define APBH_CH10_SEMA_REG(base)                 ((base)->CH10_SEMA)
#define APBH_CH10_DEBUG1_REG(base)               ((base)->CH10_DEBUG1)
#define APBH_CH10_DEBUG2_REG(base)               ((base)->CH10_DEBUG2)
#define APBH_CH11_CURCMDAR_REG(base)             ((base)->CH11_CURCMDAR)
#define APBH_CH11_NXTCMDAR_REG(base)             ((base)->CH11_NXTCMDAR)
#define APBH_CH11_CMD_REG(base)                  ((base)->CH11_CMD)
#define APBH_CH11_BAR_REG(base)                  ((base)->CH11_BAR)
#define APBH_CH11_SEMA_REG(base)                 ((base)->CH11_SEMA)
#define APBH_CH11_DEBUG1_REG(base)               ((base)->CH11_DEBUG1)
#define APBH_CH11_DEBUG2_REG(base)               ((base)->CH11_DEBUG2)
#define APBH_CH12_CURCMDAR_REG(base)             ((base)->CH12_CURCMDAR)
#define APBH_CH12_NXTCMDAR_REG(base)             ((base)->CH12_NXTCMDAR)
#define APBH_CH12_CMD_REG(base)                  ((base)->CH12_CMD)
#define APBH_CH12_BAR_REG(base)                  ((base)->CH12_BAR)
#define APBH_CH12_SEMA_REG(base)                 ((base)->CH12_SEMA)
#define APBH_CH12_DEBUG1_REG(base)               ((base)->CH12_DEBUG1)
#define APBH_CH12_DEBUG2_REG(base)               ((base)->CH12_DEBUG2)
#define APBH_CH13_CURCMDAR_REG(base)             ((base)->CH13_CURCMDAR)
#define APBH_CH13_NXTCMDAR_REG(base)             ((base)->CH13_NXTCMDAR)
#define APBH_CH13_CMD_REG(base)                  ((base)->CH13_CMD)
#define APBH_CH13_BAR_REG(base)                  ((base)->CH13_BAR)
#define APBH_CH13_SEMA_REG(base)                 ((base)->CH13_SEMA)
#define APBH_CH13_DEBUG1_REG(base)               ((base)->CH13_DEBUG1)
#define APBH_CH13_DEBUG2_REG(base)               ((base)->CH13_DEBUG2)
#define APBH_CH14_CURCMDAR_REG(base)             ((base)->CH14_CURCMDAR)
#define APBH_CH14_NXTCMDAR_REG(base)             ((base)->CH14_NXTCMDAR)
#define APBH_CH14_CMD_REG(base)                  ((base)->CH14_CMD)
#define APBH_CH14_BAR_REG(base)                  ((base)->CH14_BAR)
#define APBH_CH14_SEMA_REG(base)                 ((base)->CH14_SEMA)
#define APBH_CH14_DEBUG1_REG(base)               ((base)->CH14_DEBUG1)
#define APBH_CH14_DEBUG2_REG(base)               ((base)->CH14_DEBUG2)
#define APBH_CH15_CURCMDAR_REG(base)             ((base)->CH15_CURCMDAR)
#define APBH_CH15_NXTCMDAR_REG(base)             ((base)->CH15_NXTCMDAR)
#define APBH_CH15_CMD_REG(base)                  ((base)->CH15_CMD)
#define APBH_CH15_BAR_REG(base)                  ((base)->CH15_BAR)
#define APBH_CH15_SEMA_REG(base)                 ((base)->CH15_SEMA)
#define APBH_CH15_DEBUG1_REG(base)               ((base)->CH15_DEBUG1)
#define APBH_CH15_DEBUG2_REG(base)               ((base)->CH15_DEBUG2)
#define APBH_VERSION_REG(base)                   ((base)->VERSION)

/*!
 * @}
 */ /* end of group APBH_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- APBH Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup APBH_Register_Masks APBH Register Masks
 * @{
 */

/*! @name CTRL0 - AHB to APBH Bridge Control and Status Register 0 */
#define APBH_CTRL0_CLKGATE_CHANNEL_MASK          (0xFFFFU)
#define APBH_CTRL0_CLKGATE_CHANNEL_SHIFT         (0U)
#define APBH_CTRL0_CLKGATE_CHANNEL(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CTRL0_CLKGATE_CHANNEL_SHIFT)) & APBH_CTRL0_CLKGATE_CHANNEL_MASK)
#define APBH_CTRL0_RSVD0_MASK                    (0xFFF0000U)
#define APBH_CTRL0_RSVD0_SHIFT                   (16U)
#define APBH_CTRL0_RSVD0(x)                      (((uint32_t)(((uint32_t)(x)) << APBH_CTRL0_RSVD0_SHIFT)) & APBH_CTRL0_RSVD0_MASK)
#define APBH_CTRL0_APB_BURST_EN_MASK             (0x10000000U)
#define APBH_CTRL0_APB_BURST_EN_SHIFT            (28U)
#define APBH_CTRL0_AHB_BURST8_EN_MASK            (0x20000000U)
#define APBH_CTRL0_AHB_BURST8_EN_SHIFT           (29U)
#define APBH_CTRL0_CLKGATE_MASK                  (0x40000000U)
#define APBH_CTRL0_CLKGATE_SHIFT                 (30U)
#define APBH_CTRL0_SFTRST_MASK                   (0x80000000U)
#define APBH_CTRL0_SFTRST_SHIFT                  (31U)

/*! @name CTRL0_SET - AHB to APBH Bridge Control and Status Register 0 */
#define APBH_CTRL0_SET_CLKGATE_CHANNEL_MASK      (0xFFFFU)
#define APBH_CTRL0_SET_CLKGATE_CHANNEL_SHIFT     (0U)
#define APBH_CTRL0_SET_CLKGATE_CHANNEL(x)        (((uint32_t)(((uint32_t)(x)) << APBH_CTRL0_SET_CLKGATE_CHANNEL_SHIFT)) & APBH_CTRL0_SET_CLKGATE_CHANNEL_MASK)
#define APBH_CTRL0_SET_RSVD0_MASK                (0xFFF0000U)
#define APBH_CTRL0_SET_RSVD0_SHIFT               (16U)
#define APBH_CTRL0_SET_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CTRL0_SET_RSVD0_SHIFT)) & APBH_CTRL0_SET_RSVD0_MASK)
#define APBH_CTRL0_SET_APB_BURST_EN_MASK         (0x10000000U)
#define APBH_CTRL0_SET_APB_BURST_EN_SHIFT        (28U)
#define APBH_CTRL0_SET_AHB_BURST8_EN_MASK        (0x20000000U)
#define APBH_CTRL0_SET_AHB_BURST8_EN_SHIFT       (29U)
#define APBH_CTRL0_SET_CLKGATE_MASK              (0x40000000U)
#define APBH_CTRL0_SET_CLKGATE_SHIFT             (30U)
#define APBH_CTRL0_SET_SFTRST_MASK               (0x80000000U)
#define APBH_CTRL0_SET_SFTRST_SHIFT              (31U)

/*! @name CTRL0_CLR - AHB to APBH Bridge Control and Status Register 0 */
#define APBH_CTRL0_CLR_CLKGATE_CHANNEL_MASK      (0xFFFFU)
#define APBH_CTRL0_CLR_CLKGATE_CHANNEL_SHIFT     (0U)
#define APBH_CTRL0_CLR_CLKGATE_CHANNEL(x)        (((uint32_t)(((uint32_t)(x)) << APBH_CTRL0_CLR_CLKGATE_CHANNEL_SHIFT)) & APBH_CTRL0_CLR_CLKGATE_CHANNEL_MASK)
#define APBH_CTRL0_CLR_RSVD0_MASK                (0xFFF0000U)
#define APBH_CTRL0_CLR_RSVD0_SHIFT               (16U)
#define APBH_CTRL0_CLR_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CTRL0_CLR_RSVD0_SHIFT)) & APBH_CTRL0_CLR_RSVD0_MASK)
#define APBH_CTRL0_CLR_APB_BURST_EN_MASK         (0x10000000U)
#define APBH_CTRL0_CLR_APB_BURST_EN_SHIFT        (28U)
#define APBH_CTRL0_CLR_AHB_BURST8_EN_MASK        (0x20000000U)
#define APBH_CTRL0_CLR_AHB_BURST8_EN_SHIFT       (29U)
#define APBH_CTRL0_CLR_CLKGATE_MASK              (0x40000000U)
#define APBH_CTRL0_CLR_CLKGATE_SHIFT             (30U)
#define APBH_CTRL0_CLR_SFTRST_MASK               (0x80000000U)
#define APBH_CTRL0_CLR_SFTRST_SHIFT              (31U)

/*! @name CTRL0_TOG - AHB to APBH Bridge Control and Status Register 0 */
#define APBH_CTRL0_TOG_CLKGATE_CHANNEL_MASK      (0xFFFFU)
#define APBH_CTRL0_TOG_CLKGATE_CHANNEL_SHIFT     (0U)
#define APBH_CTRL0_TOG_CLKGATE_CHANNEL(x)        (((uint32_t)(((uint32_t)(x)) << APBH_CTRL0_TOG_CLKGATE_CHANNEL_SHIFT)) & APBH_CTRL0_TOG_CLKGATE_CHANNEL_MASK)
#define APBH_CTRL0_TOG_RSVD0_MASK                (0xFFF0000U)
#define APBH_CTRL0_TOG_RSVD0_SHIFT               (16U)
#define APBH_CTRL0_TOG_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CTRL0_TOG_RSVD0_SHIFT)) & APBH_CTRL0_TOG_RSVD0_MASK)
#define APBH_CTRL0_TOG_APB_BURST_EN_MASK         (0x10000000U)
#define APBH_CTRL0_TOG_APB_BURST_EN_SHIFT        (28U)
#define APBH_CTRL0_TOG_AHB_BURST8_EN_MASK        (0x20000000U)
#define APBH_CTRL0_TOG_AHB_BURST8_EN_SHIFT       (29U)
#define APBH_CTRL0_TOG_CLKGATE_MASK              (0x40000000U)
#define APBH_CTRL0_TOG_CLKGATE_SHIFT             (30U)
#define APBH_CTRL0_TOG_SFTRST_MASK               (0x80000000U)
#define APBH_CTRL0_TOG_SFTRST_SHIFT              (31U)

/*! @name CTRL1 - AHB to APBH Bridge Control and Status Register 1 */
#define APBH_CTRL1_CH0_CMDCMPLT_IRQ_MASK         (0x1U)
#define APBH_CTRL1_CH0_CMDCMPLT_IRQ_SHIFT        (0U)
#define APBH_CTRL1_CH1_CMDCMPLT_IRQ_MASK         (0x2U)
#define APBH_CTRL1_CH1_CMDCMPLT_IRQ_SHIFT        (1U)
#define APBH_CTRL1_CH2_CMDCMPLT_IRQ_MASK         (0x4U)
#define APBH_CTRL1_CH2_CMDCMPLT_IRQ_SHIFT        (2U)
#define APBH_CTRL1_CH3_CMDCMPLT_IRQ_MASK         (0x8U)
#define APBH_CTRL1_CH3_CMDCMPLT_IRQ_SHIFT        (3U)
#define APBH_CTRL1_CH4_CMDCMPLT_IRQ_MASK         (0x10U)
#define APBH_CTRL1_CH4_CMDCMPLT_IRQ_SHIFT        (4U)
#define APBH_CTRL1_CH5_CMDCMPLT_IRQ_MASK         (0x20U)
#define APBH_CTRL1_CH5_CMDCMPLT_IRQ_SHIFT        (5U)
#define APBH_CTRL1_CH6_CMDCMPLT_IRQ_MASK         (0x40U)
#define APBH_CTRL1_CH6_CMDCMPLT_IRQ_SHIFT        (6U)
#define APBH_CTRL1_CH7_CMDCMPLT_IRQ_MASK         (0x80U)
#define APBH_CTRL1_CH7_CMDCMPLT_IRQ_SHIFT        (7U)
#define APBH_CTRL1_CH8_CMDCMPLT_IRQ_MASK         (0x100U)
#define APBH_CTRL1_CH8_CMDCMPLT_IRQ_SHIFT        (8U)
#define APBH_CTRL1_CH9_CMDCMPLT_IRQ_MASK         (0x200U)
#define APBH_CTRL1_CH9_CMDCMPLT_IRQ_SHIFT        (9U)
#define APBH_CTRL1_CH10_CMDCMPLT_IRQ_MASK        (0x400U)
#define APBH_CTRL1_CH10_CMDCMPLT_IRQ_SHIFT       (10U)
#define APBH_CTRL1_CH11_CMDCMPLT_IRQ_MASK        (0x800U)
#define APBH_CTRL1_CH11_CMDCMPLT_IRQ_SHIFT       (11U)
#define APBH_CTRL1_CH12_CMDCMPLT_IRQ_MASK        (0x1000U)
#define APBH_CTRL1_CH12_CMDCMPLT_IRQ_SHIFT       (12U)
#define APBH_CTRL1_CH13_CMDCMPLT_IRQ_MASK        (0x2000U)
#define APBH_CTRL1_CH13_CMDCMPLT_IRQ_SHIFT       (13U)
#define APBH_CTRL1_CH14_CMDCMPLT_IRQ_MASK        (0x4000U)
#define APBH_CTRL1_CH14_CMDCMPLT_IRQ_SHIFT       (14U)
#define APBH_CTRL1_CH15_CMDCMPLT_IRQ_MASK        (0x8000U)
#define APBH_CTRL1_CH15_CMDCMPLT_IRQ_SHIFT       (15U)
#define APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN_MASK      (0x10000U)
#define APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN_SHIFT     (16U)
#define APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN_MASK      (0x20000U)
#define APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN_SHIFT     (17U)
#define APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN_MASK      (0x40000U)
#define APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN_SHIFT     (18U)
#define APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN_MASK      (0x80000U)
#define APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN_SHIFT     (19U)
#define APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN_MASK      (0x100000U)
#define APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN_SHIFT     (20U)
#define APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN_MASK      (0x200000U)
#define APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN_SHIFT     (21U)
#define APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN_MASK      (0x400000U)
#define APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN_SHIFT     (22U)
#define APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN_MASK      (0x800000U)
#define APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN_SHIFT     (23U)
#define APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN_MASK      (0x1000000U)
#define APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN_SHIFT     (24U)
#define APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN_MASK      (0x2000000U)
#define APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN_SHIFT     (25U)
#define APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN_MASK     (0x4000000U)
#define APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN_SHIFT    (26U)
#define APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN_MASK     (0x8000000U)
#define APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN_SHIFT    (27U)
#define APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN_MASK     (0x10000000U)
#define APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN_SHIFT    (28U)
#define APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN_MASK     (0x20000000U)
#define APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN_SHIFT    (29U)
#define APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN_MASK     (0x40000000U)
#define APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN_SHIFT    (30U)
#define APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN_MASK     (0x80000000U)
#define APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN_SHIFT    (31U)

/*! @name CTRL1_SET - AHB to APBH Bridge Control and Status Register 1 */
#define APBH_CTRL1_SET_CH0_CMDCMPLT_IRQ_MASK     (0x1U)
#define APBH_CTRL1_SET_CH0_CMDCMPLT_IRQ_SHIFT    (0U)
#define APBH_CTRL1_SET_CH1_CMDCMPLT_IRQ_MASK     (0x2U)
#define APBH_CTRL1_SET_CH1_CMDCMPLT_IRQ_SHIFT    (1U)
#define APBH_CTRL1_SET_CH2_CMDCMPLT_IRQ_MASK     (0x4U)
#define APBH_CTRL1_SET_CH2_CMDCMPLT_IRQ_SHIFT    (2U)
#define APBH_CTRL1_SET_CH3_CMDCMPLT_IRQ_MASK     (0x8U)
#define APBH_CTRL1_SET_CH3_CMDCMPLT_IRQ_SHIFT    (3U)
#define APBH_CTRL1_SET_CH4_CMDCMPLT_IRQ_MASK     (0x10U)
#define APBH_CTRL1_SET_CH4_CMDCMPLT_IRQ_SHIFT    (4U)
#define APBH_CTRL1_SET_CH5_CMDCMPLT_IRQ_MASK     (0x20U)
#define APBH_CTRL1_SET_CH5_CMDCMPLT_IRQ_SHIFT    (5U)
#define APBH_CTRL1_SET_CH6_CMDCMPLT_IRQ_MASK     (0x40U)
#define APBH_CTRL1_SET_CH6_CMDCMPLT_IRQ_SHIFT    (6U)
#define APBH_CTRL1_SET_CH7_CMDCMPLT_IRQ_MASK     (0x80U)
#define APBH_CTRL1_SET_CH7_CMDCMPLT_IRQ_SHIFT    (7U)
#define APBH_CTRL1_SET_CH8_CMDCMPLT_IRQ_MASK     (0x100U)
#define APBH_CTRL1_SET_CH8_CMDCMPLT_IRQ_SHIFT    (8U)
#define APBH_CTRL1_SET_CH9_CMDCMPLT_IRQ_MASK     (0x200U)
#define APBH_CTRL1_SET_CH9_CMDCMPLT_IRQ_SHIFT    (9U)
#define APBH_CTRL1_SET_CH10_CMDCMPLT_IRQ_MASK    (0x400U)
#define APBH_CTRL1_SET_CH10_CMDCMPLT_IRQ_SHIFT   (10U)
#define APBH_CTRL1_SET_CH11_CMDCMPLT_IRQ_MASK    (0x800U)
#define APBH_CTRL1_SET_CH11_CMDCMPLT_IRQ_SHIFT   (11U)
#define APBH_CTRL1_SET_CH12_CMDCMPLT_IRQ_MASK    (0x1000U)
#define APBH_CTRL1_SET_CH12_CMDCMPLT_IRQ_SHIFT   (12U)
#define APBH_CTRL1_SET_CH13_CMDCMPLT_IRQ_MASK    (0x2000U)
#define APBH_CTRL1_SET_CH13_CMDCMPLT_IRQ_SHIFT   (13U)
#define APBH_CTRL1_SET_CH14_CMDCMPLT_IRQ_MASK    (0x4000U)
#define APBH_CTRL1_SET_CH14_CMDCMPLT_IRQ_SHIFT   (14U)
#define APBH_CTRL1_SET_CH15_CMDCMPLT_IRQ_MASK    (0x8000U)
#define APBH_CTRL1_SET_CH15_CMDCMPLT_IRQ_SHIFT   (15U)
#define APBH_CTRL1_SET_CH0_CMDCMPLT_IRQ_EN_MASK  (0x10000U)
#define APBH_CTRL1_SET_CH0_CMDCMPLT_IRQ_EN_SHIFT (16U)
#define APBH_CTRL1_SET_CH1_CMDCMPLT_IRQ_EN_MASK  (0x20000U)
#define APBH_CTRL1_SET_CH1_CMDCMPLT_IRQ_EN_SHIFT (17U)
#define APBH_CTRL1_SET_CH2_CMDCMPLT_IRQ_EN_MASK  (0x40000U)
#define APBH_CTRL1_SET_CH2_CMDCMPLT_IRQ_EN_SHIFT (18U)
#define APBH_CTRL1_SET_CH3_CMDCMPLT_IRQ_EN_MASK  (0x80000U)
#define APBH_CTRL1_SET_CH3_CMDCMPLT_IRQ_EN_SHIFT (19U)
#define APBH_CTRL1_SET_CH4_CMDCMPLT_IRQ_EN_MASK  (0x100000U)
#define APBH_CTRL1_SET_CH4_CMDCMPLT_IRQ_EN_SHIFT (20U)
#define APBH_CTRL1_SET_CH5_CMDCMPLT_IRQ_EN_MASK  (0x200000U)
#define APBH_CTRL1_SET_CH5_CMDCMPLT_IRQ_EN_SHIFT (21U)
#define APBH_CTRL1_SET_CH6_CMDCMPLT_IRQ_EN_MASK  (0x400000U)
#define APBH_CTRL1_SET_CH6_CMDCMPLT_IRQ_EN_SHIFT (22U)
#define APBH_CTRL1_SET_CH7_CMDCMPLT_IRQ_EN_MASK  (0x800000U)
#define APBH_CTRL1_SET_CH7_CMDCMPLT_IRQ_EN_SHIFT (23U)
#define APBH_CTRL1_SET_CH8_CMDCMPLT_IRQ_EN_MASK  (0x1000000U)
#define APBH_CTRL1_SET_CH8_CMDCMPLT_IRQ_EN_SHIFT (24U)
#define APBH_CTRL1_SET_CH9_CMDCMPLT_IRQ_EN_MASK  (0x2000000U)
#define APBH_CTRL1_SET_CH9_CMDCMPLT_IRQ_EN_SHIFT (25U)
#define APBH_CTRL1_SET_CH10_CMDCMPLT_IRQ_EN_MASK (0x4000000U)
#define APBH_CTRL1_SET_CH10_CMDCMPLT_IRQ_EN_SHIFT (26U)
#define APBH_CTRL1_SET_CH11_CMDCMPLT_IRQ_EN_MASK (0x8000000U)
#define APBH_CTRL1_SET_CH11_CMDCMPLT_IRQ_EN_SHIFT (27U)
#define APBH_CTRL1_SET_CH12_CMDCMPLT_IRQ_EN_MASK (0x10000000U)
#define APBH_CTRL1_SET_CH12_CMDCMPLT_IRQ_EN_SHIFT (28U)
#define APBH_CTRL1_SET_CH13_CMDCMPLT_IRQ_EN_MASK (0x20000000U)
#define APBH_CTRL1_SET_CH13_CMDCMPLT_IRQ_EN_SHIFT (29U)
#define APBH_CTRL1_SET_CH14_CMDCMPLT_IRQ_EN_MASK (0x40000000U)
#define APBH_CTRL1_SET_CH14_CMDCMPLT_IRQ_EN_SHIFT (30U)
#define APBH_CTRL1_SET_CH15_CMDCMPLT_IRQ_EN_MASK (0x80000000U)
#define APBH_CTRL1_SET_CH15_CMDCMPLT_IRQ_EN_SHIFT (31U)

/*! @name CTRL1_CLR - AHB to APBH Bridge Control and Status Register 1 */
#define APBH_CTRL1_CLR_CH0_CMDCMPLT_IRQ_MASK     (0x1U)
#define APBH_CTRL1_CLR_CH0_CMDCMPLT_IRQ_SHIFT    (0U)
#define APBH_CTRL1_CLR_CH1_CMDCMPLT_IRQ_MASK     (0x2U)
#define APBH_CTRL1_CLR_CH1_CMDCMPLT_IRQ_SHIFT    (1U)
#define APBH_CTRL1_CLR_CH2_CMDCMPLT_IRQ_MASK     (0x4U)
#define APBH_CTRL1_CLR_CH2_CMDCMPLT_IRQ_SHIFT    (2U)
#define APBH_CTRL1_CLR_CH3_CMDCMPLT_IRQ_MASK     (0x8U)
#define APBH_CTRL1_CLR_CH3_CMDCMPLT_IRQ_SHIFT    (3U)
#define APBH_CTRL1_CLR_CH4_CMDCMPLT_IRQ_MASK     (0x10U)
#define APBH_CTRL1_CLR_CH4_CMDCMPLT_IRQ_SHIFT    (4U)
#define APBH_CTRL1_CLR_CH5_CMDCMPLT_IRQ_MASK     (0x20U)
#define APBH_CTRL1_CLR_CH5_CMDCMPLT_IRQ_SHIFT    (5U)
#define APBH_CTRL1_CLR_CH6_CMDCMPLT_IRQ_MASK     (0x40U)
#define APBH_CTRL1_CLR_CH6_CMDCMPLT_IRQ_SHIFT    (6U)
#define APBH_CTRL1_CLR_CH7_CMDCMPLT_IRQ_MASK     (0x80U)
#define APBH_CTRL1_CLR_CH7_CMDCMPLT_IRQ_SHIFT    (7U)
#define APBH_CTRL1_CLR_CH8_CMDCMPLT_IRQ_MASK     (0x100U)
#define APBH_CTRL1_CLR_CH8_CMDCMPLT_IRQ_SHIFT    (8U)
#define APBH_CTRL1_CLR_CH9_CMDCMPLT_IRQ_MASK     (0x200U)
#define APBH_CTRL1_CLR_CH9_CMDCMPLT_IRQ_SHIFT    (9U)
#define APBH_CTRL1_CLR_CH10_CMDCMPLT_IRQ_MASK    (0x400U)
#define APBH_CTRL1_CLR_CH10_CMDCMPLT_IRQ_SHIFT   (10U)
#define APBH_CTRL1_CLR_CH11_CMDCMPLT_IRQ_MASK    (0x800U)
#define APBH_CTRL1_CLR_CH11_CMDCMPLT_IRQ_SHIFT   (11U)
#define APBH_CTRL1_CLR_CH12_CMDCMPLT_IRQ_MASK    (0x1000U)
#define APBH_CTRL1_CLR_CH12_CMDCMPLT_IRQ_SHIFT   (12U)
#define APBH_CTRL1_CLR_CH13_CMDCMPLT_IRQ_MASK    (0x2000U)
#define APBH_CTRL1_CLR_CH13_CMDCMPLT_IRQ_SHIFT   (13U)
#define APBH_CTRL1_CLR_CH14_CMDCMPLT_IRQ_MASK    (0x4000U)
#define APBH_CTRL1_CLR_CH14_CMDCMPLT_IRQ_SHIFT   (14U)
#define APBH_CTRL1_CLR_CH15_CMDCMPLT_IRQ_MASK    (0x8000U)
#define APBH_CTRL1_CLR_CH15_CMDCMPLT_IRQ_SHIFT   (15U)
#define APBH_CTRL1_CLR_CH0_CMDCMPLT_IRQ_EN_MASK  (0x10000U)
#define APBH_CTRL1_CLR_CH0_CMDCMPLT_IRQ_EN_SHIFT (16U)
#define APBH_CTRL1_CLR_CH1_CMDCMPLT_IRQ_EN_MASK  (0x20000U)
#define APBH_CTRL1_CLR_CH1_CMDCMPLT_IRQ_EN_SHIFT (17U)
#define APBH_CTRL1_CLR_CH2_CMDCMPLT_IRQ_EN_MASK  (0x40000U)
#define APBH_CTRL1_CLR_CH2_CMDCMPLT_IRQ_EN_SHIFT (18U)
#define APBH_CTRL1_CLR_CH3_CMDCMPLT_IRQ_EN_MASK  (0x80000U)
#define APBH_CTRL1_CLR_CH3_CMDCMPLT_IRQ_EN_SHIFT (19U)
#define APBH_CTRL1_CLR_CH4_CMDCMPLT_IRQ_EN_MASK  (0x100000U)
#define APBH_CTRL1_CLR_CH4_CMDCMPLT_IRQ_EN_SHIFT (20U)
#define APBH_CTRL1_CLR_CH5_CMDCMPLT_IRQ_EN_MASK  (0x200000U)
#define APBH_CTRL1_CLR_CH5_CMDCMPLT_IRQ_EN_SHIFT (21U)
#define APBH_CTRL1_CLR_CH6_CMDCMPLT_IRQ_EN_MASK  (0x400000U)
#define APBH_CTRL1_CLR_CH6_CMDCMPLT_IRQ_EN_SHIFT (22U)
#define APBH_CTRL1_CLR_CH7_CMDCMPLT_IRQ_EN_MASK  (0x800000U)
#define APBH_CTRL1_CLR_CH7_CMDCMPLT_IRQ_EN_SHIFT (23U)
#define APBH_CTRL1_CLR_CH8_CMDCMPLT_IRQ_EN_MASK  (0x1000000U)
#define APBH_CTRL1_CLR_CH8_CMDCMPLT_IRQ_EN_SHIFT (24U)
#define APBH_CTRL1_CLR_CH9_CMDCMPLT_IRQ_EN_MASK  (0x2000000U)
#define APBH_CTRL1_CLR_CH9_CMDCMPLT_IRQ_EN_SHIFT (25U)
#define APBH_CTRL1_CLR_CH10_CMDCMPLT_IRQ_EN_MASK (0x4000000U)
#define APBH_CTRL1_CLR_CH10_CMDCMPLT_IRQ_EN_SHIFT (26U)
#define APBH_CTRL1_CLR_CH11_CMDCMPLT_IRQ_EN_MASK (0x8000000U)
#define APBH_CTRL1_CLR_CH11_CMDCMPLT_IRQ_EN_SHIFT (27U)
#define APBH_CTRL1_CLR_CH12_CMDCMPLT_IRQ_EN_MASK (0x10000000U)
#define APBH_CTRL1_CLR_CH12_CMDCMPLT_IRQ_EN_SHIFT (28U)
#define APBH_CTRL1_CLR_CH13_CMDCMPLT_IRQ_EN_MASK (0x20000000U)
#define APBH_CTRL1_CLR_CH13_CMDCMPLT_IRQ_EN_SHIFT (29U)
#define APBH_CTRL1_CLR_CH14_CMDCMPLT_IRQ_EN_MASK (0x40000000U)
#define APBH_CTRL1_CLR_CH14_CMDCMPLT_IRQ_EN_SHIFT (30U)
#define APBH_CTRL1_CLR_CH15_CMDCMPLT_IRQ_EN_MASK (0x80000000U)
#define APBH_CTRL1_CLR_CH15_CMDCMPLT_IRQ_EN_SHIFT (31U)

/*! @name CTRL1_TOG - AHB to APBH Bridge Control and Status Register 1 */
#define APBH_CTRL1_TOG_CH0_CMDCMPLT_IRQ_MASK     (0x1U)
#define APBH_CTRL1_TOG_CH0_CMDCMPLT_IRQ_SHIFT    (0U)
#define APBH_CTRL1_TOG_CH1_CMDCMPLT_IRQ_MASK     (0x2U)
#define APBH_CTRL1_TOG_CH1_CMDCMPLT_IRQ_SHIFT    (1U)
#define APBH_CTRL1_TOG_CH2_CMDCMPLT_IRQ_MASK     (0x4U)
#define APBH_CTRL1_TOG_CH2_CMDCMPLT_IRQ_SHIFT    (2U)
#define APBH_CTRL1_TOG_CH3_CMDCMPLT_IRQ_MASK     (0x8U)
#define APBH_CTRL1_TOG_CH3_CMDCMPLT_IRQ_SHIFT    (3U)
#define APBH_CTRL1_TOG_CH4_CMDCMPLT_IRQ_MASK     (0x10U)
#define APBH_CTRL1_TOG_CH4_CMDCMPLT_IRQ_SHIFT    (4U)
#define APBH_CTRL1_TOG_CH5_CMDCMPLT_IRQ_MASK     (0x20U)
#define APBH_CTRL1_TOG_CH5_CMDCMPLT_IRQ_SHIFT    (5U)
#define APBH_CTRL1_TOG_CH6_CMDCMPLT_IRQ_MASK     (0x40U)
#define APBH_CTRL1_TOG_CH6_CMDCMPLT_IRQ_SHIFT    (6U)
#define APBH_CTRL1_TOG_CH7_CMDCMPLT_IRQ_MASK     (0x80U)
#define APBH_CTRL1_TOG_CH7_CMDCMPLT_IRQ_SHIFT    (7U)
#define APBH_CTRL1_TOG_CH8_CMDCMPLT_IRQ_MASK     (0x100U)
#define APBH_CTRL1_TOG_CH8_CMDCMPLT_IRQ_SHIFT    (8U)
#define APBH_CTRL1_TOG_CH9_CMDCMPLT_IRQ_MASK     (0x200U)
#define APBH_CTRL1_TOG_CH9_CMDCMPLT_IRQ_SHIFT    (9U)
#define APBH_CTRL1_TOG_CH10_CMDCMPLT_IRQ_MASK    (0x400U)
#define APBH_CTRL1_TOG_CH10_CMDCMPLT_IRQ_SHIFT   (10U)
#define APBH_CTRL1_TOG_CH11_CMDCMPLT_IRQ_MASK    (0x800U)
#define APBH_CTRL1_TOG_CH11_CMDCMPLT_IRQ_SHIFT   (11U)
#define APBH_CTRL1_TOG_CH12_CMDCMPLT_IRQ_MASK    (0x1000U)
#define APBH_CTRL1_TOG_CH12_CMDCMPLT_IRQ_SHIFT   (12U)
#define APBH_CTRL1_TOG_CH13_CMDCMPLT_IRQ_MASK    (0x2000U)
#define APBH_CTRL1_TOG_CH13_CMDCMPLT_IRQ_SHIFT   (13U)
#define APBH_CTRL1_TOG_CH14_CMDCMPLT_IRQ_MASK    (0x4000U)
#define APBH_CTRL1_TOG_CH14_CMDCMPLT_IRQ_SHIFT   (14U)
#define APBH_CTRL1_TOG_CH15_CMDCMPLT_IRQ_MASK    (0x8000U)
#define APBH_CTRL1_TOG_CH15_CMDCMPLT_IRQ_SHIFT   (15U)
#define APBH_CTRL1_TOG_CH0_CMDCMPLT_IRQ_EN_MASK  (0x10000U)
#define APBH_CTRL1_TOG_CH0_CMDCMPLT_IRQ_EN_SHIFT (16U)
#define APBH_CTRL1_TOG_CH1_CMDCMPLT_IRQ_EN_MASK  (0x20000U)
#define APBH_CTRL1_TOG_CH1_CMDCMPLT_IRQ_EN_SHIFT (17U)
#define APBH_CTRL1_TOG_CH2_CMDCMPLT_IRQ_EN_MASK  (0x40000U)
#define APBH_CTRL1_TOG_CH2_CMDCMPLT_IRQ_EN_SHIFT (18U)
#define APBH_CTRL1_TOG_CH3_CMDCMPLT_IRQ_EN_MASK  (0x80000U)
#define APBH_CTRL1_TOG_CH3_CMDCMPLT_IRQ_EN_SHIFT (19U)
#define APBH_CTRL1_TOG_CH4_CMDCMPLT_IRQ_EN_MASK  (0x100000U)
#define APBH_CTRL1_TOG_CH4_CMDCMPLT_IRQ_EN_SHIFT (20U)
#define APBH_CTRL1_TOG_CH5_CMDCMPLT_IRQ_EN_MASK  (0x200000U)
#define APBH_CTRL1_TOG_CH5_CMDCMPLT_IRQ_EN_SHIFT (21U)
#define APBH_CTRL1_TOG_CH6_CMDCMPLT_IRQ_EN_MASK  (0x400000U)
#define APBH_CTRL1_TOG_CH6_CMDCMPLT_IRQ_EN_SHIFT (22U)
#define APBH_CTRL1_TOG_CH7_CMDCMPLT_IRQ_EN_MASK  (0x800000U)
#define APBH_CTRL1_TOG_CH7_CMDCMPLT_IRQ_EN_SHIFT (23U)
#define APBH_CTRL1_TOG_CH8_CMDCMPLT_IRQ_EN_MASK  (0x1000000U)
#define APBH_CTRL1_TOG_CH8_CMDCMPLT_IRQ_EN_SHIFT (24U)
#define APBH_CTRL1_TOG_CH9_CMDCMPLT_IRQ_EN_MASK  (0x2000000U)
#define APBH_CTRL1_TOG_CH9_CMDCMPLT_IRQ_EN_SHIFT (25U)
#define APBH_CTRL1_TOG_CH10_CMDCMPLT_IRQ_EN_MASK (0x4000000U)
#define APBH_CTRL1_TOG_CH10_CMDCMPLT_IRQ_EN_SHIFT (26U)
#define APBH_CTRL1_TOG_CH11_CMDCMPLT_IRQ_EN_MASK (0x8000000U)
#define APBH_CTRL1_TOG_CH11_CMDCMPLT_IRQ_EN_SHIFT (27U)
#define APBH_CTRL1_TOG_CH12_CMDCMPLT_IRQ_EN_MASK (0x10000000U)
#define APBH_CTRL1_TOG_CH12_CMDCMPLT_IRQ_EN_SHIFT (28U)
#define APBH_CTRL1_TOG_CH13_CMDCMPLT_IRQ_EN_MASK (0x20000000U)
#define APBH_CTRL1_TOG_CH13_CMDCMPLT_IRQ_EN_SHIFT (29U)
#define APBH_CTRL1_TOG_CH14_CMDCMPLT_IRQ_EN_MASK (0x40000000U)
#define APBH_CTRL1_TOG_CH14_CMDCMPLT_IRQ_EN_SHIFT (30U)
#define APBH_CTRL1_TOG_CH15_CMDCMPLT_IRQ_EN_MASK (0x80000000U)
#define APBH_CTRL1_TOG_CH15_CMDCMPLT_IRQ_EN_SHIFT (31U)

/*! @name CTRL2 - AHB to APBH Bridge Control and Status Register 2 */
#define APBH_CTRL2_CH0_ERROR_IRQ_MASK            (0x1U)
#define APBH_CTRL2_CH0_ERROR_IRQ_SHIFT           (0U)
#define APBH_CTRL2_CH1_ERROR_IRQ_MASK            (0x2U)
#define APBH_CTRL2_CH1_ERROR_IRQ_SHIFT           (1U)
#define APBH_CTRL2_CH2_ERROR_IRQ_MASK            (0x4U)
#define APBH_CTRL2_CH2_ERROR_IRQ_SHIFT           (2U)
#define APBH_CTRL2_CH3_ERROR_IRQ_MASK            (0x8U)
#define APBH_CTRL2_CH3_ERROR_IRQ_SHIFT           (3U)
#define APBH_CTRL2_CH4_ERROR_IRQ_MASK            (0x10U)
#define APBH_CTRL2_CH4_ERROR_IRQ_SHIFT           (4U)
#define APBH_CTRL2_CH5_ERROR_IRQ_MASK            (0x20U)
#define APBH_CTRL2_CH5_ERROR_IRQ_SHIFT           (5U)
#define APBH_CTRL2_CH6_ERROR_IRQ_MASK            (0x40U)
#define APBH_CTRL2_CH6_ERROR_IRQ_SHIFT           (6U)
#define APBH_CTRL2_CH7_ERROR_IRQ_MASK            (0x80U)
#define APBH_CTRL2_CH7_ERROR_IRQ_SHIFT           (7U)
#define APBH_CTRL2_CH8_ERROR_IRQ_MASK            (0x100U)
#define APBH_CTRL2_CH8_ERROR_IRQ_SHIFT           (8U)
#define APBH_CTRL2_CH9_ERROR_IRQ_MASK            (0x200U)
#define APBH_CTRL2_CH9_ERROR_IRQ_SHIFT           (9U)
#define APBH_CTRL2_CH10_ERROR_IRQ_MASK           (0x400U)
#define APBH_CTRL2_CH10_ERROR_IRQ_SHIFT          (10U)
#define APBH_CTRL2_CH11_ERROR_IRQ_MASK           (0x800U)
#define APBH_CTRL2_CH11_ERROR_IRQ_SHIFT          (11U)
#define APBH_CTRL2_CH12_ERROR_IRQ_MASK           (0x1000U)
#define APBH_CTRL2_CH12_ERROR_IRQ_SHIFT          (12U)
#define APBH_CTRL2_CH13_ERROR_IRQ_MASK           (0x2000U)
#define APBH_CTRL2_CH13_ERROR_IRQ_SHIFT          (13U)
#define APBH_CTRL2_CH14_ERROR_IRQ_MASK           (0x4000U)
#define APBH_CTRL2_CH14_ERROR_IRQ_SHIFT          (14U)
#define APBH_CTRL2_CH15_ERROR_IRQ_MASK           (0x8000U)
#define APBH_CTRL2_CH15_ERROR_IRQ_SHIFT          (15U)
#define APBH_CTRL2_CH0_ERROR_STATUS_MASK         (0x10000U)
#define APBH_CTRL2_CH0_ERROR_STATUS_SHIFT        (16U)
#define APBH_CTRL2_CH1_ERROR_STATUS_MASK         (0x20000U)
#define APBH_CTRL2_CH1_ERROR_STATUS_SHIFT        (17U)
#define APBH_CTRL2_CH2_ERROR_STATUS_MASK         (0x40000U)
#define APBH_CTRL2_CH2_ERROR_STATUS_SHIFT        (18U)
#define APBH_CTRL2_CH3_ERROR_STATUS_MASK         (0x80000U)
#define APBH_CTRL2_CH3_ERROR_STATUS_SHIFT        (19U)
#define APBH_CTRL2_CH4_ERROR_STATUS_MASK         (0x100000U)
#define APBH_CTRL2_CH4_ERROR_STATUS_SHIFT        (20U)
#define APBH_CTRL2_CH5_ERROR_STATUS_MASK         (0x200000U)
#define APBH_CTRL2_CH5_ERROR_STATUS_SHIFT        (21U)
#define APBH_CTRL2_CH6_ERROR_STATUS_MASK         (0x400000U)
#define APBH_CTRL2_CH6_ERROR_STATUS_SHIFT        (22U)
#define APBH_CTRL2_CH7_ERROR_STATUS_MASK         (0x800000U)
#define APBH_CTRL2_CH7_ERROR_STATUS_SHIFT        (23U)
#define APBH_CTRL2_CH8_ERROR_STATUS_MASK         (0x1000000U)
#define APBH_CTRL2_CH8_ERROR_STATUS_SHIFT        (24U)
#define APBH_CTRL2_CH9_ERROR_STATUS_MASK         (0x2000000U)
#define APBH_CTRL2_CH9_ERROR_STATUS_SHIFT        (25U)
#define APBH_CTRL2_CH10_ERROR_STATUS_MASK        (0x4000000U)
#define APBH_CTRL2_CH10_ERROR_STATUS_SHIFT       (26U)
#define APBH_CTRL2_CH11_ERROR_STATUS_MASK        (0x8000000U)
#define APBH_CTRL2_CH11_ERROR_STATUS_SHIFT       (27U)
#define APBH_CTRL2_CH12_ERROR_STATUS_MASK        (0x10000000U)
#define APBH_CTRL2_CH12_ERROR_STATUS_SHIFT       (28U)
#define APBH_CTRL2_CH13_ERROR_STATUS_MASK        (0x20000000U)
#define APBH_CTRL2_CH13_ERROR_STATUS_SHIFT       (29U)
#define APBH_CTRL2_CH14_ERROR_STATUS_MASK        (0x40000000U)
#define APBH_CTRL2_CH14_ERROR_STATUS_SHIFT       (30U)
#define APBH_CTRL2_CH15_ERROR_STATUS_MASK        (0x80000000U)
#define APBH_CTRL2_CH15_ERROR_STATUS_SHIFT       (31U)

/*! @name CTRL2_SET - AHB to APBH Bridge Control and Status Register 2 */
#define APBH_CTRL2_SET_CH0_ERROR_IRQ_MASK        (0x1U)
#define APBH_CTRL2_SET_CH0_ERROR_IRQ_SHIFT       (0U)
#define APBH_CTRL2_SET_CH1_ERROR_IRQ_MASK        (0x2U)
#define APBH_CTRL2_SET_CH1_ERROR_IRQ_SHIFT       (1U)
#define APBH_CTRL2_SET_CH2_ERROR_IRQ_MASK        (0x4U)
#define APBH_CTRL2_SET_CH2_ERROR_IRQ_SHIFT       (2U)
#define APBH_CTRL2_SET_CH3_ERROR_IRQ_MASK        (0x8U)
#define APBH_CTRL2_SET_CH3_ERROR_IRQ_SHIFT       (3U)
#define APBH_CTRL2_SET_CH4_ERROR_IRQ_MASK        (0x10U)
#define APBH_CTRL2_SET_CH4_ERROR_IRQ_SHIFT       (4U)
#define APBH_CTRL2_SET_CH5_ERROR_IRQ_MASK        (0x20U)
#define APBH_CTRL2_SET_CH5_ERROR_IRQ_SHIFT       (5U)
#define APBH_CTRL2_SET_CH6_ERROR_IRQ_MASK        (0x40U)
#define APBH_CTRL2_SET_CH6_ERROR_IRQ_SHIFT       (6U)
#define APBH_CTRL2_SET_CH7_ERROR_IRQ_MASK        (0x80U)
#define APBH_CTRL2_SET_CH7_ERROR_IRQ_SHIFT       (7U)
#define APBH_CTRL2_SET_CH8_ERROR_IRQ_MASK        (0x100U)
#define APBH_CTRL2_SET_CH8_ERROR_IRQ_SHIFT       (8U)
#define APBH_CTRL2_SET_CH9_ERROR_IRQ_MASK        (0x200U)
#define APBH_CTRL2_SET_CH9_ERROR_IRQ_SHIFT       (9U)
#define APBH_CTRL2_SET_CH10_ERROR_IRQ_MASK       (0x400U)
#define APBH_CTRL2_SET_CH10_ERROR_IRQ_SHIFT      (10U)
#define APBH_CTRL2_SET_CH11_ERROR_IRQ_MASK       (0x800U)
#define APBH_CTRL2_SET_CH11_ERROR_IRQ_SHIFT      (11U)
#define APBH_CTRL2_SET_CH12_ERROR_IRQ_MASK       (0x1000U)
#define APBH_CTRL2_SET_CH12_ERROR_IRQ_SHIFT      (12U)
#define APBH_CTRL2_SET_CH13_ERROR_IRQ_MASK       (0x2000U)
#define APBH_CTRL2_SET_CH13_ERROR_IRQ_SHIFT      (13U)
#define APBH_CTRL2_SET_CH14_ERROR_IRQ_MASK       (0x4000U)
#define APBH_CTRL2_SET_CH14_ERROR_IRQ_SHIFT      (14U)
#define APBH_CTRL2_SET_CH15_ERROR_IRQ_MASK       (0x8000U)
#define APBH_CTRL2_SET_CH15_ERROR_IRQ_SHIFT      (15U)
#define APBH_CTRL2_SET_CH0_ERROR_STATUS_MASK     (0x10000U)
#define APBH_CTRL2_SET_CH0_ERROR_STATUS_SHIFT    (16U)
#define APBH_CTRL2_SET_CH1_ERROR_STATUS_MASK     (0x20000U)
#define APBH_CTRL2_SET_CH1_ERROR_STATUS_SHIFT    (17U)
#define APBH_CTRL2_SET_CH2_ERROR_STATUS_MASK     (0x40000U)
#define APBH_CTRL2_SET_CH2_ERROR_STATUS_SHIFT    (18U)
#define APBH_CTRL2_SET_CH3_ERROR_STATUS_MASK     (0x80000U)
#define APBH_CTRL2_SET_CH3_ERROR_STATUS_SHIFT    (19U)
#define APBH_CTRL2_SET_CH4_ERROR_STATUS_MASK     (0x100000U)
#define APBH_CTRL2_SET_CH4_ERROR_STATUS_SHIFT    (20U)
#define APBH_CTRL2_SET_CH5_ERROR_STATUS_MASK     (0x200000U)
#define APBH_CTRL2_SET_CH5_ERROR_STATUS_SHIFT    (21U)
#define APBH_CTRL2_SET_CH6_ERROR_STATUS_MASK     (0x400000U)
#define APBH_CTRL2_SET_CH6_ERROR_STATUS_SHIFT    (22U)
#define APBH_CTRL2_SET_CH7_ERROR_STATUS_MASK     (0x800000U)
#define APBH_CTRL2_SET_CH7_ERROR_STATUS_SHIFT    (23U)
#define APBH_CTRL2_SET_CH8_ERROR_STATUS_MASK     (0x1000000U)
#define APBH_CTRL2_SET_CH8_ERROR_STATUS_SHIFT    (24U)
#define APBH_CTRL2_SET_CH9_ERROR_STATUS_MASK     (0x2000000U)
#define APBH_CTRL2_SET_CH9_ERROR_STATUS_SHIFT    (25U)
#define APBH_CTRL2_SET_CH10_ERROR_STATUS_MASK    (0x4000000U)
#define APBH_CTRL2_SET_CH10_ERROR_STATUS_SHIFT   (26U)
#define APBH_CTRL2_SET_CH11_ERROR_STATUS_MASK    (0x8000000U)
#define APBH_CTRL2_SET_CH11_ERROR_STATUS_SHIFT   (27U)
#define APBH_CTRL2_SET_CH12_ERROR_STATUS_MASK    (0x10000000U)
#define APBH_CTRL2_SET_CH12_ERROR_STATUS_SHIFT   (28U)
#define APBH_CTRL2_SET_CH13_ERROR_STATUS_MASK    (0x20000000U)
#define APBH_CTRL2_SET_CH13_ERROR_STATUS_SHIFT   (29U)
#define APBH_CTRL2_SET_CH14_ERROR_STATUS_MASK    (0x40000000U)
#define APBH_CTRL2_SET_CH14_ERROR_STATUS_SHIFT   (30U)
#define APBH_CTRL2_SET_CH15_ERROR_STATUS_MASK    (0x80000000U)
#define APBH_CTRL2_SET_CH15_ERROR_STATUS_SHIFT   (31U)

/*! @name CTRL2_CLR - AHB to APBH Bridge Control and Status Register 2 */
#define APBH_CTRL2_CLR_CH0_ERROR_IRQ_MASK        (0x1U)
#define APBH_CTRL2_CLR_CH0_ERROR_IRQ_SHIFT       (0U)
#define APBH_CTRL2_CLR_CH1_ERROR_IRQ_MASK        (0x2U)
#define APBH_CTRL2_CLR_CH1_ERROR_IRQ_SHIFT       (1U)
#define APBH_CTRL2_CLR_CH2_ERROR_IRQ_MASK        (0x4U)
#define APBH_CTRL2_CLR_CH2_ERROR_IRQ_SHIFT       (2U)
#define APBH_CTRL2_CLR_CH3_ERROR_IRQ_MASK        (0x8U)
#define APBH_CTRL2_CLR_CH3_ERROR_IRQ_SHIFT       (3U)
#define APBH_CTRL2_CLR_CH4_ERROR_IRQ_MASK        (0x10U)
#define APBH_CTRL2_CLR_CH4_ERROR_IRQ_SHIFT       (4U)
#define APBH_CTRL2_CLR_CH5_ERROR_IRQ_MASK        (0x20U)
#define APBH_CTRL2_CLR_CH5_ERROR_IRQ_SHIFT       (5U)
#define APBH_CTRL2_CLR_CH6_ERROR_IRQ_MASK        (0x40U)
#define APBH_CTRL2_CLR_CH6_ERROR_IRQ_SHIFT       (6U)
#define APBH_CTRL2_CLR_CH7_ERROR_IRQ_MASK        (0x80U)
#define APBH_CTRL2_CLR_CH7_ERROR_IRQ_SHIFT       (7U)
#define APBH_CTRL2_CLR_CH8_ERROR_IRQ_MASK        (0x100U)
#define APBH_CTRL2_CLR_CH8_ERROR_IRQ_SHIFT       (8U)
#define APBH_CTRL2_CLR_CH9_ERROR_IRQ_MASK        (0x200U)
#define APBH_CTRL2_CLR_CH9_ERROR_IRQ_SHIFT       (9U)
#define APBH_CTRL2_CLR_CH10_ERROR_IRQ_MASK       (0x400U)
#define APBH_CTRL2_CLR_CH10_ERROR_IRQ_SHIFT      (10U)
#define APBH_CTRL2_CLR_CH11_ERROR_IRQ_MASK       (0x800U)
#define APBH_CTRL2_CLR_CH11_ERROR_IRQ_SHIFT      (11U)
#define APBH_CTRL2_CLR_CH12_ERROR_IRQ_MASK       (0x1000U)
#define APBH_CTRL2_CLR_CH12_ERROR_IRQ_SHIFT      (12U)
#define APBH_CTRL2_CLR_CH13_ERROR_IRQ_MASK       (0x2000U)
#define APBH_CTRL2_CLR_CH13_ERROR_IRQ_SHIFT      (13U)
#define APBH_CTRL2_CLR_CH14_ERROR_IRQ_MASK       (0x4000U)
#define APBH_CTRL2_CLR_CH14_ERROR_IRQ_SHIFT      (14U)
#define APBH_CTRL2_CLR_CH15_ERROR_IRQ_MASK       (0x8000U)
#define APBH_CTRL2_CLR_CH15_ERROR_IRQ_SHIFT      (15U)
#define APBH_CTRL2_CLR_CH0_ERROR_STATUS_MASK     (0x10000U)
#define APBH_CTRL2_CLR_CH0_ERROR_STATUS_SHIFT    (16U)
#define APBH_CTRL2_CLR_CH1_ERROR_STATUS_MASK     (0x20000U)
#define APBH_CTRL2_CLR_CH1_ERROR_STATUS_SHIFT    (17U)
#define APBH_CTRL2_CLR_CH2_ERROR_STATUS_MASK     (0x40000U)
#define APBH_CTRL2_CLR_CH2_ERROR_STATUS_SHIFT    (18U)
#define APBH_CTRL2_CLR_CH3_ERROR_STATUS_MASK     (0x80000U)
#define APBH_CTRL2_CLR_CH3_ERROR_STATUS_SHIFT    (19U)
#define APBH_CTRL2_CLR_CH4_ERROR_STATUS_MASK     (0x100000U)
#define APBH_CTRL2_CLR_CH4_ERROR_STATUS_SHIFT    (20U)
#define APBH_CTRL2_CLR_CH5_ERROR_STATUS_MASK     (0x200000U)
#define APBH_CTRL2_CLR_CH5_ERROR_STATUS_SHIFT    (21U)
#define APBH_CTRL2_CLR_CH6_ERROR_STATUS_MASK     (0x400000U)
#define APBH_CTRL2_CLR_CH6_ERROR_STATUS_SHIFT    (22U)
#define APBH_CTRL2_CLR_CH7_ERROR_STATUS_MASK     (0x800000U)
#define APBH_CTRL2_CLR_CH7_ERROR_STATUS_SHIFT    (23U)
#define APBH_CTRL2_CLR_CH8_ERROR_STATUS_MASK     (0x1000000U)
#define APBH_CTRL2_CLR_CH8_ERROR_STATUS_SHIFT    (24U)
#define APBH_CTRL2_CLR_CH9_ERROR_STATUS_MASK     (0x2000000U)
#define APBH_CTRL2_CLR_CH9_ERROR_STATUS_SHIFT    (25U)
#define APBH_CTRL2_CLR_CH10_ERROR_STATUS_MASK    (0x4000000U)
#define APBH_CTRL2_CLR_CH10_ERROR_STATUS_SHIFT   (26U)
#define APBH_CTRL2_CLR_CH11_ERROR_STATUS_MASK    (0x8000000U)
#define APBH_CTRL2_CLR_CH11_ERROR_STATUS_SHIFT   (27U)
#define APBH_CTRL2_CLR_CH12_ERROR_STATUS_MASK    (0x10000000U)
#define APBH_CTRL2_CLR_CH12_ERROR_STATUS_SHIFT   (28U)
#define APBH_CTRL2_CLR_CH13_ERROR_STATUS_MASK    (0x20000000U)
#define APBH_CTRL2_CLR_CH13_ERROR_STATUS_SHIFT   (29U)
#define APBH_CTRL2_CLR_CH14_ERROR_STATUS_MASK    (0x40000000U)
#define APBH_CTRL2_CLR_CH14_ERROR_STATUS_SHIFT   (30U)
#define APBH_CTRL2_CLR_CH15_ERROR_STATUS_MASK    (0x80000000U)
#define APBH_CTRL2_CLR_CH15_ERROR_STATUS_SHIFT   (31U)

/*! @name CTRL2_TOG - AHB to APBH Bridge Control and Status Register 2 */
#define APBH_CTRL2_TOG_CH0_ERROR_IRQ_MASK        (0x1U)
#define APBH_CTRL2_TOG_CH0_ERROR_IRQ_SHIFT       (0U)
#define APBH_CTRL2_TOG_CH1_ERROR_IRQ_MASK        (0x2U)
#define APBH_CTRL2_TOG_CH1_ERROR_IRQ_SHIFT       (1U)
#define APBH_CTRL2_TOG_CH2_ERROR_IRQ_MASK        (0x4U)
#define APBH_CTRL2_TOG_CH2_ERROR_IRQ_SHIFT       (2U)
#define APBH_CTRL2_TOG_CH3_ERROR_IRQ_MASK        (0x8U)
#define APBH_CTRL2_TOG_CH3_ERROR_IRQ_SHIFT       (3U)
#define APBH_CTRL2_TOG_CH4_ERROR_IRQ_MASK        (0x10U)
#define APBH_CTRL2_TOG_CH4_ERROR_IRQ_SHIFT       (4U)
#define APBH_CTRL2_TOG_CH5_ERROR_IRQ_MASK        (0x20U)
#define APBH_CTRL2_TOG_CH5_ERROR_IRQ_SHIFT       (5U)
#define APBH_CTRL2_TOG_CH6_ERROR_IRQ_MASK        (0x40U)
#define APBH_CTRL2_TOG_CH6_ERROR_IRQ_SHIFT       (6U)
#define APBH_CTRL2_TOG_CH7_ERROR_IRQ_MASK        (0x80U)
#define APBH_CTRL2_TOG_CH7_ERROR_IRQ_SHIFT       (7U)
#define APBH_CTRL2_TOG_CH8_ERROR_IRQ_MASK        (0x100U)
#define APBH_CTRL2_TOG_CH8_ERROR_IRQ_SHIFT       (8U)
#define APBH_CTRL2_TOG_CH9_ERROR_IRQ_MASK        (0x200U)
#define APBH_CTRL2_TOG_CH9_ERROR_IRQ_SHIFT       (9U)
#define APBH_CTRL2_TOG_CH10_ERROR_IRQ_MASK       (0x400U)
#define APBH_CTRL2_TOG_CH10_ERROR_IRQ_SHIFT      (10U)
#define APBH_CTRL2_TOG_CH11_ERROR_IRQ_MASK       (0x800U)
#define APBH_CTRL2_TOG_CH11_ERROR_IRQ_SHIFT      (11U)
#define APBH_CTRL2_TOG_CH12_ERROR_IRQ_MASK       (0x1000U)
#define APBH_CTRL2_TOG_CH12_ERROR_IRQ_SHIFT      (12U)
#define APBH_CTRL2_TOG_CH13_ERROR_IRQ_MASK       (0x2000U)
#define APBH_CTRL2_TOG_CH13_ERROR_IRQ_SHIFT      (13U)
#define APBH_CTRL2_TOG_CH14_ERROR_IRQ_MASK       (0x4000U)
#define APBH_CTRL2_TOG_CH14_ERROR_IRQ_SHIFT      (14U)
#define APBH_CTRL2_TOG_CH15_ERROR_IRQ_MASK       (0x8000U)
#define APBH_CTRL2_TOG_CH15_ERROR_IRQ_SHIFT      (15U)
#define APBH_CTRL2_TOG_CH0_ERROR_STATUS_MASK     (0x10000U)
#define APBH_CTRL2_TOG_CH0_ERROR_STATUS_SHIFT    (16U)
#define APBH_CTRL2_TOG_CH1_ERROR_STATUS_MASK     (0x20000U)
#define APBH_CTRL2_TOG_CH1_ERROR_STATUS_SHIFT    (17U)
#define APBH_CTRL2_TOG_CH2_ERROR_STATUS_MASK     (0x40000U)
#define APBH_CTRL2_TOG_CH2_ERROR_STATUS_SHIFT    (18U)
#define APBH_CTRL2_TOG_CH3_ERROR_STATUS_MASK     (0x80000U)
#define APBH_CTRL2_TOG_CH3_ERROR_STATUS_SHIFT    (19U)
#define APBH_CTRL2_TOG_CH4_ERROR_STATUS_MASK     (0x100000U)
#define APBH_CTRL2_TOG_CH4_ERROR_STATUS_SHIFT    (20U)
#define APBH_CTRL2_TOG_CH5_ERROR_STATUS_MASK     (0x200000U)
#define APBH_CTRL2_TOG_CH5_ERROR_STATUS_SHIFT    (21U)
#define APBH_CTRL2_TOG_CH6_ERROR_STATUS_MASK     (0x400000U)
#define APBH_CTRL2_TOG_CH6_ERROR_STATUS_SHIFT    (22U)
#define APBH_CTRL2_TOG_CH7_ERROR_STATUS_MASK     (0x800000U)
#define APBH_CTRL2_TOG_CH7_ERROR_STATUS_SHIFT    (23U)
#define APBH_CTRL2_TOG_CH8_ERROR_STATUS_MASK     (0x1000000U)
#define APBH_CTRL2_TOG_CH8_ERROR_STATUS_SHIFT    (24U)
#define APBH_CTRL2_TOG_CH9_ERROR_STATUS_MASK     (0x2000000U)
#define APBH_CTRL2_TOG_CH9_ERROR_STATUS_SHIFT    (25U)
#define APBH_CTRL2_TOG_CH10_ERROR_STATUS_MASK    (0x4000000U)
#define APBH_CTRL2_TOG_CH10_ERROR_STATUS_SHIFT   (26U)
#define APBH_CTRL2_TOG_CH11_ERROR_STATUS_MASK    (0x8000000U)
#define APBH_CTRL2_TOG_CH11_ERROR_STATUS_SHIFT   (27U)
#define APBH_CTRL2_TOG_CH12_ERROR_STATUS_MASK    (0x10000000U)
#define APBH_CTRL2_TOG_CH12_ERROR_STATUS_SHIFT   (28U)
#define APBH_CTRL2_TOG_CH13_ERROR_STATUS_MASK    (0x20000000U)
#define APBH_CTRL2_TOG_CH13_ERROR_STATUS_SHIFT   (29U)
#define APBH_CTRL2_TOG_CH14_ERROR_STATUS_MASK    (0x40000000U)
#define APBH_CTRL2_TOG_CH14_ERROR_STATUS_SHIFT   (30U)
#define APBH_CTRL2_TOG_CH15_ERROR_STATUS_MASK    (0x80000000U)
#define APBH_CTRL2_TOG_CH15_ERROR_STATUS_SHIFT   (31U)

/*! @name CHANNEL_CTRL - AHB to APBH Bridge Channel Register */
#define APBH_CHANNEL_CTRL_FREEZE_CHANNEL_MASK    (0xFFFFU)
#define APBH_CHANNEL_CTRL_FREEZE_CHANNEL_SHIFT   (0U)
#define APBH_CHANNEL_CTRL_FREEZE_CHANNEL(x)      (((uint32_t)(((uint32_t)(x)) << APBH_CHANNEL_CTRL_FREEZE_CHANNEL_SHIFT)) & APBH_CHANNEL_CTRL_FREEZE_CHANNEL_MASK)
#define APBH_CHANNEL_CTRL_RESET_CHANNEL_MASK     (0xFFFF0000U)
#define APBH_CHANNEL_CTRL_RESET_CHANNEL_SHIFT    (16U)
#define APBH_CHANNEL_CTRL_RESET_CHANNEL(x)       (((uint32_t)(((uint32_t)(x)) << APBH_CHANNEL_CTRL_RESET_CHANNEL_SHIFT)) & APBH_CHANNEL_CTRL_RESET_CHANNEL_MASK)

/*! @name CHANNEL_CTRL_SET - AHB to APBH Bridge Channel Register */
#define APBH_CHANNEL_CTRL_SET_FREEZE_CHANNEL_MASK (0xFFFFU)
#define APBH_CHANNEL_CTRL_SET_FREEZE_CHANNEL_SHIFT (0U)
#define APBH_CHANNEL_CTRL_SET_FREEZE_CHANNEL(x)  (((uint32_t)(((uint32_t)(x)) << APBH_CHANNEL_CTRL_SET_FREEZE_CHANNEL_SHIFT)) & APBH_CHANNEL_CTRL_SET_FREEZE_CHANNEL_MASK)
#define APBH_CHANNEL_CTRL_SET_RESET_CHANNEL_MASK (0xFFFF0000U)
#define APBH_CHANNEL_CTRL_SET_RESET_CHANNEL_SHIFT (16U)
#define APBH_CHANNEL_CTRL_SET_RESET_CHANNEL(x)   (((uint32_t)(((uint32_t)(x)) << APBH_CHANNEL_CTRL_SET_RESET_CHANNEL_SHIFT)) & APBH_CHANNEL_CTRL_SET_RESET_CHANNEL_MASK)

/*! @name CHANNEL_CTRL_CLR - AHB to APBH Bridge Channel Register */
#define APBH_CHANNEL_CTRL_CLR_FREEZE_CHANNEL_MASK (0xFFFFU)
#define APBH_CHANNEL_CTRL_CLR_FREEZE_CHANNEL_SHIFT (0U)
#define APBH_CHANNEL_CTRL_CLR_FREEZE_CHANNEL(x)  (((uint32_t)(((uint32_t)(x)) << APBH_CHANNEL_CTRL_CLR_FREEZE_CHANNEL_SHIFT)) & APBH_CHANNEL_CTRL_CLR_FREEZE_CHANNEL_MASK)
#define APBH_CHANNEL_CTRL_CLR_RESET_CHANNEL_MASK (0xFFFF0000U)
#define APBH_CHANNEL_CTRL_CLR_RESET_CHANNEL_SHIFT (16U)
#define APBH_CHANNEL_CTRL_CLR_RESET_CHANNEL(x)   (((uint32_t)(((uint32_t)(x)) << APBH_CHANNEL_CTRL_CLR_RESET_CHANNEL_SHIFT)) & APBH_CHANNEL_CTRL_CLR_RESET_CHANNEL_MASK)

/*! @name CHANNEL_CTRL_TOG - AHB to APBH Bridge Channel Register */
#define APBH_CHANNEL_CTRL_TOG_FREEZE_CHANNEL_MASK (0xFFFFU)
#define APBH_CHANNEL_CTRL_TOG_FREEZE_CHANNEL_SHIFT (0U)
#define APBH_CHANNEL_CTRL_TOG_FREEZE_CHANNEL(x)  (((uint32_t)(((uint32_t)(x)) << APBH_CHANNEL_CTRL_TOG_FREEZE_CHANNEL_SHIFT)) & APBH_CHANNEL_CTRL_TOG_FREEZE_CHANNEL_MASK)
#define APBH_CHANNEL_CTRL_TOG_RESET_CHANNEL_MASK (0xFFFF0000U)
#define APBH_CHANNEL_CTRL_TOG_RESET_CHANNEL_SHIFT (16U)
#define APBH_CHANNEL_CTRL_TOG_RESET_CHANNEL(x)   (((uint32_t)(((uint32_t)(x)) << APBH_CHANNEL_CTRL_TOG_RESET_CHANNEL_SHIFT)) & APBH_CHANNEL_CTRL_TOG_RESET_CHANNEL_MASK)

/*! @name DEVSEL - AHB to APBH DMA Device Assignment Register */
#define APBH_DEVSEL_CH0_MASK                     (0x3U)
#define APBH_DEVSEL_CH0_SHIFT                    (0U)
#define APBH_DEVSEL_CH0(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH0_SHIFT)) & APBH_DEVSEL_CH0_MASK)
#define APBH_DEVSEL_CH1_MASK                     (0xCU)
#define APBH_DEVSEL_CH1_SHIFT                    (2U)
#define APBH_DEVSEL_CH1(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH1_SHIFT)) & APBH_DEVSEL_CH1_MASK)
#define APBH_DEVSEL_CH2_MASK                     (0x30U)
#define APBH_DEVSEL_CH2_SHIFT                    (4U)
#define APBH_DEVSEL_CH2(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH2_SHIFT)) & APBH_DEVSEL_CH2_MASK)
#define APBH_DEVSEL_CH3_MASK                     (0xC0U)
#define APBH_DEVSEL_CH3_SHIFT                    (6U)
#define APBH_DEVSEL_CH3(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH3_SHIFT)) & APBH_DEVSEL_CH3_MASK)
#define APBH_DEVSEL_CH4_MASK                     (0x300U)
#define APBH_DEVSEL_CH4_SHIFT                    (8U)
#define APBH_DEVSEL_CH4(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH4_SHIFT)) & APBH_DEVSEL_CH4_MASK)
#define APBH_DEVSEL_CH5_MASK                     (0xC00U)
#define APBH_DEVSEL_CH5_SHIFT                    (10U)
#define APBH_DEVSEL_CH5(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH5_SHIFT)) & APBH_DEVSEL_CH5_MASK)
#define APBH_DEVSEL_CH6_MASK                     (0x3000U)
#define APBH_DEVSEL_CH6_SHIFT                    (12U)
#define APBH_DEVSEL_CH6(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH6_SHIFT)) & APBH_DEVSEL_CH6_MASK)
#define APBH_DEVSEL_CH7_MASK                     (0xC000U)
#define APBH_DEVSEL_CH7_SHIFT                    (14U)
#define APBH_DEVSEL_CH7(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH7_SHIFT)) & APBH_DEVSEL_CH7_MASK)
#define APBH_DEVSEL_CH8_MASK                     (0x30000U)
#define APBH_DEVSEL_CH8_SHIFT                    (16U)
#define APBH_DEVSEL_CH8(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH8_SHIFT)) & APBH_DEVSEL_CH8_MASK)
#define APBH_DEVSEL_CH9_MASK                     (0xC0000U)
#define APBH_DEVSEL_CH9_SHIFT                    (18U)
#define APBH_DEVSEL_CH9(x)                       (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH9_SHIFT)) & APBH_DEVSEL_CH9_MASK)
#define APBH_DEVSEL_CH10_MASK                    (0x300000U)
#define APBH_DEVSEL_CH10_SHIFT                   (20U)
#define APBH_DEVSEL_CH10(x)                      (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH10_SHIFT)) & APBH_DEVSEL_CH10_MASK)
#define APBH_DEVSEL_CH11_MASK                    (0xC00000U)
#define APBH_DEVSEL_CH11_SHIFT                   (22U)
#define APBH_DEVSEL_CH11(x)                      (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH11_SHIFT)) & APBH_DEVSEL_CH11_MASK)
#define APBH_DEVSEL_CH12_MASK                    (0x3000000U)
#define APBH_DEVSEL_CH12_SHIFT                   (24U)
#define APBH_DEVSEL_CH12(x)                      (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH12_SHIFT)) & APBH_DEVSEL_CH12_MASK)
#define APBH_DEVSEL_CH13_MASK                    (0xC000000U)
#define APBH_DEVSEL_CH13_SHIFT                   (26U)
#define APBH_DEVSEL_CH13(x)                      (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH13_SHIFT)) & APBH_DEVSEL_CH13_MASK)
#define APBH_DEVSEL_CH14_MASK                    (0x30000000U)
#define APBH_DEVSEL_CH14_SHIFT                   (28U)
#define APBH_DEVSEL_CH14(x)                      (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH14_SHIFT)) & APBH_DEVSEL_CH14_MASK)
#define APBH_DEVSEL_CH15_MASK                    (0xC0000000U)
#define APBH_DEVSEL_CH15_SHIFT                   (30U)
#define APBH_DEVSEL_CH15(x)                      (((uint32_t)(((uint32_t)(x)) << APBH_DEVSEL_CH15_SHIFT)) & APBH_DEVSEL_CH15_MASK)

/*! @name DMA_BURST_SIZE - AHB to APBH DMA burst size */
#define APBH_DMA_BURST_SIZE_CH0_MASK             (0x3U)
#define APBH_DMA_BURST_SIZE_CH0_SHIFT            (0U)
#define APBH_DMA_BURST_SIZE_CH0(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH0_SHIFT)) & APBH_DMA_BURST_SIZE_CH0_MASK)
#define APBH_DMA_BURST_SIZE_CH1_MASK             (0xCU)
#define APBH_DMA_BURST_SIZE_CH1_SHIFT            (2U)
#define APBH_DMA_BURST_SIZE_CH1(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH1_SHIFT)) & APBH_DMA_BURST_SIZE_CH1_MASK)
#define APBH_DMA_BURST_SIZE_CH2_MASK             (0x30U)
#define APBH_DMA_BURST_SIZE_CH2_SHIFT            (4U)
#define APBH_DMA_BURST_SIZE_CH2(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH2_SHIFT)) & APBH_DMA_BURST_SIZE_CH2_MASK)
#define APBH_DMA_BURST_SIZE_CH3_MASK             (0xC0U)
#define APBH_DMA_BURST_SIZE_CH3_SHIFT            (6U)
#define APBH_DMA_BURST_SIZE_CH3(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH3_SHIFT)) & APBH_DMA_BURST_SIZE_CH3_MASK)
#define APBH_DMA_BURST_SIZE_CH4_MASK             (0x300U)
#define APBH_DMA_BURST_SIZE_CH4_SHIFT            (8U)
#define APBH_DMA_BURST_SIZE_CH4(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH4_SHIFT)) & APBH_DMA_BURST_SIZE_CH4_MASK)
#define APBH_DMA_BURST_SIZE_CH5_MASK             (0xC00U)
#define APBH_DMA_BURST_SIZE_CH5_SHIFT            (10U)
#define APBH_DMA_BURST_SIZE_CH5(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH5_SHIFT)) & APBH_DMA_BURST_SIZE_CH5_MASK)
#define APBH_DMA_BURST_SIZE_CH6_MASK             (0x3000U)
#define APBH_DMA_BURST_SIZE_CH6_SHIFT            (12U)
#define APBH_DMA_BURST_SIZE_CH6(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH6_SHIFT)) & APBH_DMA_BURST_SIZE_CH6_MASK)
#define APBH_DMA_BURST_SIZE_CH7_MASK             (0xC000U)
#define APBH_DMA_BURST_SIZE_CH7_SHIFT            (14U)
#define APBH_DMA_BURST_SIZE_CH7(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH7_SHIFT)) & APBH_DMA_BURST_SIZE_CH7_MASK)
#define APBH_DMA_BURST_SIZE_CH8_MASK             (0x30000U)
#define APBH_DMA_BURST_SIZE_CH8_SHIFT            (16U)
#define APBH_DMA_BURST_SIZE_CH8(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH8_SHIFT)) & APBH_DMA_BURST_SIZE_CH8_MASK)
#define APBH_DMA_BURST_SIZE_CH9_MASK             (0xC0000U)
#define APBH_DMA_BURST_SIZE_CH9_SHIFT            (18U)
#define APBH_DMA_BURST_SIZE_CH9(x)               (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH9_SHIFT)) & APBH_DMA_BURST_SIZE_CH9_MASK)
#define APBH_DMA_BURST_SIZE_CH10_MASK            (0x300000U)
#define APBH_DMA_BURST_SIZE_CH10_SHIFT           (20U)
#define APBH_DMA_BURST_SIZE_CH10(x)              (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH10_SHIFT)) & APBH_DMA_BURST_SIZE_CH10_MASK)
#define APBH_DMA_BURST_SIZE_CH11_MASK            (0xC00000U)
#define APBH_DMA_BURST_SIZE_CH11_SHIFT           (22U)
#define APBH_DMA_BURST_SIZE_CH11(x)              (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH11_SHIFT)) & APBH_DMA_BURST_SIZE_CH11_MASK)
#define APBH_DMA_BURST_SIZE_CH12_MASK            (0x3000000U)
#define APBH_DMA_BURST_SIZE_CH12_SHIFT           (24U)
#define APBH_DMA_BURST_SIZE_CH12(x)              (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH12_SHIFT)) & APBH_DMA_BURST_SIZE_CH12_MASK)
#define APBH_DMA_BURST_SIZE_CH13_MASK            (0xC000000U)
#define APBH_DMA_BURST_SIZE_CH13_SHIFT           (26U)
#define APBH_DMA_BURST_SIZE_CH13(x)              (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH13_SHIFT)) & APBH_DMA_BURST_SIZE_CH13_MASK)
#define APBH_DMA_BURST_SIZE_CH14_MASK            (0x30000000U)
#define APBH_DMA_BURST_SIZE_CH14_SHIFT           (28U)
#define APBH_DMA_BURST_SIZE_CH14(x)              (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH14_SHIFT)) & APBH_DMA_BURST_SIZE_CH14_MASK)
#define APBH_DMA_BURST_SIZE_CH15_MASK            (0xC0000000U)
#define APBH_DMA_BURST_SIZE_CH15_SHIFT           (30U)
#define APBH_DMA_BURST_SIZE_CH15(x)              (((uint32_t)(((uint32_t)(x)) << APBH_DMA_BURST_SIZE_CH15_SHIFT)) & APBH_DMA_BURST_SIZE_CH15_MASK)

/*! @name DEBUG - AHB to APBH DMA Debug Register */
#define APBH_DEBUG_GPMI_ONE_FIFO_MASK            (0x1U)
#define APBH_DEBUG_GPMI_ONE_FIFO_SHIFT           (0U)

/*! @name CH0_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH0_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH0_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH0_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH0_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH0_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH0_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH0_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH0_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH0_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH0_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH0_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH0_CMD - APBH DMA Channel n Command Register */
#define APBH_CH0_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH0_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH0_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH0_CMD_COMMAND_SHIFT)) & APBH_CH0_CMD_COMMAND_MASK)
#define APBH_CH0_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH0_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH0_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH0_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH0_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH0_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH0_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH0_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH0_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH0_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH0_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH0_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH0_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH0_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH0_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH0_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH0_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH0_CMD_CMDWORDS_SHIFT)) & APBH_CH0_CMD_CMDWORDS_MASK)
#define APBH_CH0_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH0_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH0_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH0_CMD_XFER_COUNT_SHIFT)) & APBH_CH0_CMD_XFER_COUNT_MASK)

/*! @name CH0_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH0_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH0_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH0_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH0_BAR_ADDRESS_SHIFT)) & APBH_CH0_BAR_ADDRESS_MASK)

/*! @name CH0_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH0_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH0_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH0_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH0_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH0_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH0_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH0_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH0_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH0_SEMA_PHORE_SHIFT)) & APBH_CH0_SEMA_PHORE_MASK)

/*! @name CH0_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH0_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH0_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH0_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH0_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH0_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH0_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH0_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH0_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH0_DEBUG1_RSVD1_SHIFT)) & APBH_CH0_DEBUG1_RSVD1_MASK)
#define APBH_CH0_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH0_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH0_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH0_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH0_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH0_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH0_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH0_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH0_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH0_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH0_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH0_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH0_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH0_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH0_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH0_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH0_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH0_DEBUG1_END_SHIFT                (28U)
#define APBH_CH0_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH0_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH0_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH0_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH0_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH0_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH0_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH0_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH0_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH0_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH0_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH0_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH0_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH0_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH0_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH0_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH0_DEBUG2_APB_BYTES_MASK)

/*! @name CH1_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH1_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH1_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH1_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH1_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH1_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH1_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH1_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH1_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH1_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH1_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH1_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH1_CMD - APBH DMA Channel n Command Register */
#define APBH_CH1_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH1_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH1_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH1_CMD_COMMAND_SHIFT)) & APBH_CH1_CMD_COMMAND_MASK)
#define APBH_CH1_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH1_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH1_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH1_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH1_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH1_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH1_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH1_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH1_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH1_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH1_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH1_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH1_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH1_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH1_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH1_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH1_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH1_CMD_CMDWORDS_SHIFT)) & APBH_CH1_CMD_CMDWORDS_MASK)
#define APBH_CH1_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH1_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH1_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH1_CMD_XFER_COUNT_SHIFT)) & APBH_CH1_CMD_XFER_COUNT_MASK)

/*! @name CH1_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH1_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH1_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH1_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH1_BAR_ADDRESS_SHIFT)) & APBH_CH1_BAR_ADDRESS_MASK)

/*! @name CH1_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH1_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH1_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH1_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH1_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH1_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH1_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH1_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH1_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH1_SEMA_PHORE_SHIFT)) & APBH_CH1_SEMA_PHORE_MASK)

/*! @name CH1_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH1_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH1_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH1_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH1_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH1_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH1_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH1_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH1_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH1_DEBUG1_RSVD1_SHIFT)) & APBH_CH1_DEBUG1_RSVD1_MASK)
#define APBH_CH1_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH1_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH1_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH1_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH1_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH1_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH1_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH1_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH1_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH1_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH1_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH1_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH1_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH1_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH1_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH1_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH1_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH1_DEBUG1_END_SHIFT                (28U)
#define APBH_CH1_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH1_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH1_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH1_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH1_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH1_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH1_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH1_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH1_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH1_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH1_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH1_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH1_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH1_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH1_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH1_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH1_DEBUG2_APB_BYTES_MASK)

/*! @name CH2_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH2_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH2_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH2_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH2_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH2_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH2_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH2_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH2_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH2_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH2_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH2_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH2_CMD - APBH DMA Channel n Command Register */
#define APBH_CH2_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH2_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH2_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH2_CMD_COMMAND_SHIFT)) & APBH_CH2_CMD_COMMAND_MASK)
#define APBH_CH2_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH2_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH2_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH2_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH2_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH2_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH2_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH2_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH2_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH2_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH2_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH2_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH2_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH2_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH2_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH2_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH2_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH2_CMD_CMDWORDS_SHIFT)) & APBH_CH2_CMD_CMDWORDS_MASK)
#define APBH_CH2_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH2_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH2_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH2_CMD_XFER_COUNT_SHIFT)) & APBH_CH2_CMD_XFER_COUNT_MASK)

/*! @name CH2_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH2_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH2_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH2_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH2_BAR_ADDRESS_SHIFT)) & APBH_CH2_BAR_ADDRESS_MASK)

/*! @name CH2_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH2_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH2_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH2_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH2_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH2_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH2_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH2_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH2_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH2_SEMA_PHORE_SHIFT)) & APBH_CH2_SEMA_PHORE_MASK)

/*! @name CH2_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH2_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH2_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH2_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH2_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH2_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH2_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH2_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH2_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH2_DEBUG1_RSVD1_SHIFT)) & APBH_CH2_DEBUG1_RSVD1_MASK)
#define APBH_CH2_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH2_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH2_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH2_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH2_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH2_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH2_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH2_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH2_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH2_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH2_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH2_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH2_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH2_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH2_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH2_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH2_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH2_DEBUG1_END_SHIFT                (28U)
#define APBH_CH2_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH2_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH2_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH2_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH2_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH2_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH2_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH2_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH2_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH2_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH2_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH2_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH2_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH2_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH2_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH2_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH2_DEBUG2_APB_BYTES_MASK)

/*! @name CH3_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH3_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH3_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH3_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH3_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH3_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH3_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH3_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH3_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH3_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH3_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH3_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH3_CMD - APBH DMA Channel n Command Register */
#define APBH_CH3_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH3_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH3_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH3_CMD_COMMAND_SHIFT)) & APBH_CH3_CMD_COMMAND_MASK)
#define APBH_CH3_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH3_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH3_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH3_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH3_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH3_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH3_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH3_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH3_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH3_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH3_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH3_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH3_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH3_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH3_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH3_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH3_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH3_CMD_CMDWORDS_SHIFT)) & APBH_CH3_CMD_CMDWORDS_MASK)
#define APBH_CH3_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH3_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH3_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH3_CMD_XFER_COUNT_SHIFT)) & APBH_CH3_CMD_XFER_COUNT_MASK)

/*! @name CH3_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH3_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH3_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH3_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH3_BAR_ADDRESS_SHIFT)) & APBH_CH3_BAR_ADDRESS_MASK)

/*! @name CH3_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH3_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH3_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH3_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH3_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH3_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH3_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH3_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH3_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH3_SEMA_PHORE_SHIFT)) & APBH_CH3_SEMA_PHORE_MASK)

/*! @name CH3_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH3_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH3_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH3_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH3_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH3_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH3_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH3_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH3_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH3_DEBUG1_RSVD1_SHIFT)) & APBH_CH3_DEBUG1_RSVD1_MASK)
#define APBH_CH3_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH3_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH3_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH3_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH3_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH3_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH3_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH3_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH3_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH3_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH3_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH3_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH3_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH3_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH3_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH3_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH3_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH3_DEBUG1_END_SHIFT                (28U)
#define APBH_CH3_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH3_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH3_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH3_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH3_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH3_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH3_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH3_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH3_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH3_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH3_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH3_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH3_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH3_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH3_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH3_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH3_DEBUG2_APB_BYTES_MASK)

/*! @name CH4_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH4_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH4_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH4_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH4_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH4_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH4_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH4_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH4_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH4_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH4_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH4_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH4_CMD - APBH DMA Channel n Command Register */
#define APBH_CH4_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH4_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH4_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH4_CMD_COMMAND_SHIFT)) & APBH_CH4_CMD_COMMAND_MASK)
#define APBH_CH4_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH4_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH4_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH4_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH4_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH4_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH4_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH4_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH4_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH4_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH4_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH4_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH4_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH4_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH4_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH4_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH4_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH4_CMD_CMDWORDS_SHIFT)) & APBH_CH4_CMD_CMDWORDS_MASK)
#define APBH_CH4_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH4_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH4_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH4_CMD_XFER_COUNT_SHIFT)) & APBH_CH4_CMD_XFER_COUNT_MASK)

/*! @name CH4_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH4_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH4_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH4_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH4_BAR_ADDRESS_SHIFT)) & APBH_CH4_BAR_ADDRESS_MASK)

/*! @name CH4_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH4_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH4_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH4_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH4_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH4_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH4_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH4_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH4_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH4_SEMA_PHORE_SHIFT)) & APBH_CH4_SEMA_PHORE_MASK)

/*! @name CH4_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH4_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH4_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH4_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH4_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH4_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH4_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH4_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH4_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH4_DEBUG1_RSVD1_SHIFT)) & APBH_CH4_DEBUG1_RSVD1_MASK)
#define APBH_CH4_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH4_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH4_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH4_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH4_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH4_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH4_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH4_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH4_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH4_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH4_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH4_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH4_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH4_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH4_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH4_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH4_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH4_DEBUG1_END_SHIFT                (28U)
#define APBH_CH4_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH4_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH4_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH4_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH4_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH4_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH4_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH4_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH4_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH4_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH4_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH4_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH4_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH4_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH4_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH4_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH4_DEBUG2_APB_BYTES_MASK)

/*! @name CH5_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH5_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH5_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH5_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH5_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH5_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH5_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH5_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH5_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH5_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH5_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH5_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH5_CMD - APBH DMA Channel n Command Register */
#define APBH_CH5_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH5_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH5_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH5_CMD_COMMAND_SHIFT)) & APBH_CH5_CMD_COMMAND_MASK)
#define APBH_CH5_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH5_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH5_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH5_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH5_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH5_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH5_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH5_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH5_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH5_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH5_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH5_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH5_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH5_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH5_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH5_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH5_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH5_CMD_CMDWORDS_SHIFT)) & APBH_CH5_CMD_CMDWORDS_MASK)
#define APBH_CH5_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH5_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH5_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH5_CMD_XFER_COUNT_SHIFT)) & APBH_CH5_CMD_XFER_COUNT_MASK)

/*! @name CH5_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH5_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH5_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH5_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH5_BAR_ADDRESS_SHIFT)) & APBH_CH5_BAR_ADDRESS_MASK)

/*! @name CH5_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH5_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH5_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH5_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH5_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH5_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH5_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH5_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH5_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH5_SEMA_PHORE_SHIFT)) & APBH_CH5_SEMA_PHORE_MASK)

/*! @name CH5_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH5_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH5_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH5_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH5_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH5_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH5_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH5_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH5_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH5_DEBUG1_RSVD1_SHIFT)) & APBH_CH5_DEBUG1_RSVD1_MASK)
#define APBH_CH5_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH5_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH5_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH5_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH5_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH5_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH5_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH5_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH5_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH5_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH5_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH5_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH5_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH5_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH5_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH5_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH5_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH5_DEBUG1_END_SHIFT                (28U)
#define APBH_CH5_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH5_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH5_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH5_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH5_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH5_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH5_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH5_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH5_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH5_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH5_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH5_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH5_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH5_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH5_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH5_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH5_DEBUG2_APB_BYTES_MASK)

/*! @name CH6_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH6_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH6_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH6_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH6_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH6_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH6_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH6_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH6_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH6_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH6_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH6_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH6_CMD - APBH DMA Channel n Command Register */
#define APBH_CH6_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH6_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH6_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH6_CMD_COMMAND_SHIFT)) & APBH_CH6_CMD_COMMAND_MASK)
#define APBH_CH6_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH6_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH6_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH6_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH6_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH6_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH6_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH6_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH6_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH6_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH6_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH6_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH6_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH6_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH6_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH6_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH6_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH6_CMD_CMDWORDS_SHIFT)) & APBH_CH6_CMD_CMDWORDS_MASK)
#define APBH_CH6_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH6_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH6_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH6_CMD_XFER_COUNT_SHIFT)) & APBH_CH6_CMD_XFER_COUNT_MASK)

/*! @name CH6_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH6_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH6_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH6_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH6_BAR_ADDRESS_SHIFT)) & APBH_CH6_BAR_ADDRESS_MASK)

/*! @name CH6_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH6_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH6_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH6_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH6_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH6_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH6_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH6_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH6_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH6_SEMA_PHORE_SHIFT)) & APBH_CH6_SEMA_PHORE_MASK)

/*! @name CH6_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH6_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH6_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH6_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH6_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH6_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH6_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH6_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH6_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH6_DEBUG1_RSVD1_SHIFT)) & APBH_CH6_DEBUG1_RSVD1_MASK)
#define APBH_CH6_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH6_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH6_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH6_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH6_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH6_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH6_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH6_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH6_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH6_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH6_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH6_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH6_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH6_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH6_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH6_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH6_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH6_DEBUG1_END_SHIFT                (28U)
#define APBH_CH6_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH6_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH6_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH6_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH6_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH6_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH6_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH6_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH6_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH6_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH6_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH6_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH6_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH6_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH6_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH6_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH6_DEBUG2_APB_BYTES_MASK)

/*! @name CH7_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH7_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH7_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH7_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH7_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH7_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH7_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH7_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH7_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH7_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH7_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH7_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH7_CMD - APBH DMA Channel n Command Register */
#define APBH_CH7_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH7_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH7_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH7_CMD_COMMAND_SHIFT)) & APBH_CH7_CMD_COMMAND_MASK)
#define APBH_CH7_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH7_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH7_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH7_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH7_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH7_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH7_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH7_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH7_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH7_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH7_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH7_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH7_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH7_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH7_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH7_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH7_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH7_CMD_CMDWORDS_SHIFT)) & APBH_CH7_CMD_CMDWORDS_MASK)
#define APBH_CH7_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH7_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH7_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH7_CMD_XFER_COUNT_SHIFT)) & APBH_CH7_CMD_XFER_COUNT_MASK)

/*! @name CH7_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH7_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH7_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH7_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH7_BAR_ADDRESS_SHIFT)) & APBH_CH7_BAR_ADDRESS_MASK)

/*! @name CH7_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH7_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH7_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH7_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH7_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH7_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH7_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH7_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH7_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH7_SEMA_PHORE_SHIFT)) & APBH_CH7_SEMA_PHORE_MASK)

/*! @name CH7_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH7_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH7_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH7_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH7_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH7_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH7_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH7_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH7_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH7_DEBUG1_RSVD1_SHIFT)) & APBH_CH7_DEBUG1_RSVD1_MASK)
#define APBH_CH7_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH7_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH7_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH7_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH7_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH7_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH7_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH7_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH7_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH7_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH7_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH7_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH7_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH7_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH7_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH7_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH7_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH7_DEBUG1_END_SHIFT                (28U)
#define APBH_CH7_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH7_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH7_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH7_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH7_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH7_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH7_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH7_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH7_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH7_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH7_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH7_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH7_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH7_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH7_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH7_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH7_DEBUG2_APB_BYTES_MASK)

/*! @name CH8_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH8_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH8_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH8_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH8_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH8_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH8_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH8_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH8_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH8_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH8_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH8_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH8_CMD - APBH DMA Channel n Command Register */
#define APBH_CH8_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH8_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH8_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH8_CMD_COMMAND_SHIFT)) & APBH_CH8_CMD_COMMAND_MASK)
#define APBH_CH8_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH8_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH8_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH8_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH8_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH8_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH8_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH8_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH8_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH8_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH8_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH8_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH8_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH8_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH8_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH8_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH8_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH8_CMD_CMDWORDS_SHIFT)) & APBH_CH8_CMD_CMDWORDS_MASK)
#define APBH_CH8_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH8_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH8_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH8_CMD_XFER_COUNT_SHIFT)) & APBH_CH8_CMD_XFER_COUNT_MASK)

/*! @name CH8_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH8_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH8_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH8_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH8_BAR_ADDRESS_SHIFT)) & APBH_CH8_BAR_ADDRESS_MASK)

/*! @name CH8_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH8_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH8_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH8_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH8_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH8_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH8_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH8_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH8_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH8_SEMA_PHORE_SHIFT)) & APBH_CH8_SEMA_PHORE_MASK)

/*! @name CH8_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH8_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH8_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH8_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH8_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH8_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH8_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH8_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH8_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH8_DEBUG1_RSVD1_SHIFT)) & APBH_CH8_DEBUG1_RSVD1_MASK)
#define APBH_CH8_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH8_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH8_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH8_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH8_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH8_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH8_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH8_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH8_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH8_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH8_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH8_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH8_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH8_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH8_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH8_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH8_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH8_DEBUG1_END_SHIFT                (28U)
#define APBH_CH8_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH8_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH8_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH8_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH8_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH8_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH8_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH8_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH8_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH8_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH8_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH8_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH8_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH8_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH8_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH8_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH8_DEBUG2_APB_BYTES_MASK)

/*! @name CH9_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH9_CURCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH9_CURCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH9_CURCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH9_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH9_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH9_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH9_NXTCMDAR_CMD_ADDR_MASK          (0xFFFFFFFFU)
#define APBH_CH9_NXTCMDAR_CMD_ADDR_SHIFT         (0U)
#define APBH_CH9_NXTCMDAR_CMD_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH9_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH9_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH9_CMD - APBH DMA Channel n Command Register */
#define APBH_CH9_CMD_COMMAND_MASK                (0x3U)
#define APBH_CH9_CMD_COMMAND_SHIFT               (0U)
#define APBH_CH9_CMD_COMMAND(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH9_CMD_COMMAND_SHIFT)) & APBH_CH9_CMD_COMMAND_MASK)
#define APBH_CH9_CMD_CHAIN_MASK                  (0x4U)
#define APBH_CH9_CMD_CHAIN_SHIFT                 (2U)
#define APBH_CH9_CMD_IRQONCMPLT_MASK             (0x8U)
#define APBH_CH9_CMD_IRQONCMPLT_SHIFT            (3U)
#define APBH_CH9_CMD_NANDLOCK_MASK               (0x10U)
#define APBH_CH9_CMD_NANDLOCK_SHIFT              (4U)
#define APBH_CH9_CMD_NANDWAIT4READY_MASK         (0x20U)
#define APBH_CH9_CMD_NANDWAIT4READY_SHIFT        (5U)
#define APBH_CH9_CMD_SEMAPHORE_MASK              (0x40U)
#define APBH_CH9_CMD_SEMAPHORE_SHIFT             (6U)
#define APBH_CH9_CMD_WAIT4ENDCMD_MASK            (0x80U)
#define APBH_CH9_CMD_WAIT4ENDCMD_SHIFT           (7U)
#define APBH_CH9_CMD_HALTONTERMINATE_MASK        (0x100U)
#define APBH_CH9_CMD_HALTONTERMINATE_SHIFT       (8U)
#define APBH_CH9_CMD_CMDWORDS_MASK               (0xF000U)
#define APBH_CH9_CMD_CMDWORDS_SHIFT              (12U)
#define APBH_CH9_CMD_CMDWORDS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH9_CMD_CMDWORDS_SHIFT)) & APBH_CH9_CMD_CMDWORDS_MASK)
#define APBH_CH9_CMD_XFER_COUNT_MASK             (0xFFFF0000U)
#define APBH_CH9_CMD_XFER_COUNT_SHIFT            (16U)
#define APBH_CH9_CMD_XFER_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << APBH_CH9_CMD_XFER_COUNT_SHIFT)) & APBH_CH9_CMD_XFER_COUNT_MASK)

/*! @name CH9_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH9_BAR_ADDRESS_MASK                (0xFFFFFFFFU)
#define APBH_CH9_BAR_ADDRESS_SHIFT               (0U)
#define APBH_CH9_BAR_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH9_BAR_ADDRESS_SHIFT)) & APBH_CH9_BAR_ADDRESS_MASK)

/*! @name CH9_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH9_SEMA_INCREMENT_SEMA_MASK        (0xFFU)
#define APBH_CH9_SEMA_INCREMENT_SEMA_SHIFT       (0U)
#define APBH_CH9_SEMA_INCREMENT_SEMA(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH9_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH9_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH9_SEMA_PHORE_MASK                 (0xFF0000U)
#define APBH_CH9_SEMA_PHORE_SHIFT                (16U)
#define APBH_CH9_SEMA_PHORE(x)                   (((uint32_t)(((uint32_t)(x)) << APBH_CH9_SEMA_PHORE_SHIFT)) & APBH_CH9_SEMA_PHORE_MASK)

/*! @name CH9_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH9_DEBUG1_STATEMACHINE_MASK        (0x1FU)
#define APBH_CH9_DEBUG1_STATEMACHINE_SHIFT       (0U)
#define APBH_CH9_DEBUG1_STATEMACHINE(x)          (((uint32_t)(((uint32_t)(x)) << APBH_CH9_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH9_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH9_DEBUG1_RSVD1_MASK               (0xFFFE0U)
#define APBH_CH9_DEBUG1_RSVD1_SHIFT              (5U)
#define APBH_CH9_DEBUG1_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH9_DEBUG1_RSVD1_SHIFT)) & APBH_CH9_DEBUG1_RSVD1_MASK)
#define APBH_CH9_DEBUG1_WR_FIFO_FULL_MASK        (0x100000U)
#define APBH_CH9_DEBUG1_WR_FIFO_FULL_SHIFT       (20U)
#define APBH_CH9_DEBUG1_WR_FIFO_EMPTY_MASK       (0x200000U)
#define APBH_CH9_DEBUG1_WR_FIFO_EMPTY_SHIFT      (21U)
#define APBH_CH9_DEBUG1_RD_FIFO_FULL_MASK        (0x400000U)
#define APBH_CH9_DEBUG1_RD_FIFO_FULL_SHIFT       (22U)
#define APBH_CH9_DEBUG1_RD_FIFO_EMPTY_MASK       (0x800000U)
#define APBH_CH9_DEBUG1_RD_FIFO_EMPTY_SHIFT      (23U)
#define APBH_CH9_DEBUG1_NEXTCMDADDRVALID_MASK    (0x1000000U)
#define APBH_CH9_DEBUG1_NEXTCMDADDRVALID_SHIFT   (24U)
#define APBH_CH9_DEBUG1_LOCK_MASK                (0x2000000U)
#define APBH_CH9_DEBUG1_LOCK_SHIFT               (25U)
#define APBH_CH9_DEBUG1_READY_MASK               (0x4000000U)
#define APBH_CH9_DEBUG1_READY_SHIFT              (26U)
#define APBH_CH9_DEBUG1_SENSE_MASK               (0x8000000U)
#define APBH_CH9_DEBUG1_SENSE_SHIFT              (27U)
#define APBH_CH9_DEBUG1_END_MASK                 (0x10000000U)
#define APBH_CH9_DEBUG1_END_SHIFT                (28U)
#define APBH_CH9_DEBUG1_KICK_MASK                (0x20000000U)
#define APBH_CH9_DEBUG1_KICK_SHIFT               (29U)
#define APBH_CH9_DEBUG1_BURST_MASK               (0x40000000U)
#define APBH_CH9_DEBUG1_BURST_SHIFT              (30U)
#define APBH_CH9_DEBUG1_REQ_MASK                 (0x80000000U)
#define APBH_CH9_DEBUG1_REQ_SHIFT                (31U)

/*! @name CH9_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH9_DEBUG2_AHB_BYTES_MASK           (0xFFFFU)
#define APBH_CH9_DEBUG2_AHB_BYTES_SHIFT          (0U)
#define APBH_CH9_DEBUG2_AHB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH9_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH9_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH9_DEBUG2_APB_BYTES_MASK           (0xFFFF0000U)
#define APBH_CH9_DEBUG2_APB_BYTES_SHIFT          (16U)
#define APBH_CH9_DEBUG2_APB_BYTES(x)             (((uint32_t)(((uint32_t)(x)) << APBH_CH9_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH9_DEBUG2_APB_BYTES_MASK)

/*! @name CH10_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH10_CURCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH10_CURCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH10_CURCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH10_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH10_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH10_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH10_NXTCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH10_NXTCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH10_NXTCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH10_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH10_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH10_CMD - APBH DMA Channel n Command Register */
#define APBH_CH10_CMD_COMMAND_MASK               (0x3U)
#define APBH_CH10_CMD_COMMAND_SHIFT              (0U)
#define APBH_CH10_CMD_COMMAND(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH10_CMD_COMMAND_SHIFT)) & APBH_CH10_CMD_COMMAND_MASK)
#define APBH_CH10_CMD_CHAIN_MASK                 (0x4U)
#define APBH_CH10_CMD_CHAIN_SHIFT                (2U)
#define APBH_CH10_CMD_IRQONCMPLT_MASK            (0x8U)
#define APBH_CH10_CMD_IRQONCMPLT_SHIFT           (3U)
#define APBH_CH10_CMD_NANDLOCK_MASK              (0x10U)
#define APBH_CH10_CMD_NANDLOCK_SHIFT             (4U)
#define APBH_CH10_CMD_NANDWAIT4READY_MASK        (0x20U)
#define APBH_CH10_CMD_NANDWAIT4READY_SHIFT       (5U)
#define APBH_CH10_CMD_SEMAPHORE_MASK             (0x40U)
#define APBH_CH10_CMD_SEMAPHORE_SHIFT            (6U)
#define APBH_CH10_CMD_WAIT4ENDCMD_MASK           (0x80U)
#define APBH_CH10_CMD_WAIT4ENDCMD_SHIFT          (7U)
#define APBH_CH10_CMD_HALTONTERMINATE_MASK       (0x100U)
#define APBH_CH10_CMD_HALTONTERMINATE_SHIFT      (8U)
#define APBH_CH10_CMD_CMDWORDS_MASK              (0xF000U)
#define APBH_CH10_CMD_CMDWORDS_SHIFT             (12U)
#define APBH_CH10_CMD_CMDWORDS(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH10_CMD_CMDWORDS_SHIFT)) & APBH_CH10_CMD_CMDWORDS_MASK)
#define APBH_CH10_CMD_XFER_COUNT_MASK            (0xFFFF0000U)
#define APBH_CH10_CMD_XFER_COUNT_SHIFT           (16U)
#define APBH_CH10_CMD_XFER_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << APBH_CH10_CMD_XFER_COUNT_SHIFT)) & APBH_CH10_CMD_XFER_COUNT_MASK)

/*! @name CH10_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH10_BAR_ADDRESS_MASK               (0xFFFFFFFFU)
#define APBH_CH10_BAR_ADDRESS_SHIFT              (0U)
#define APBH_CH10_BAR_ADDRESS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH10_BAR_ADDRESS_SHIFT)) & APBH_CH10_BAR_ADDRESS_MASK)

/*! @name CH10_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH10_SEMA_INCREMENT_SEMA_MASK       (0xFFU)
#define APBH_CH10_SEMA_INCREMENT_SEMA_SHIFT      (0U)
#define APBH_CH10_SEMA_INCREMENT_SEMA(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH10_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH10_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH10_SEMA_PHORE_MASK                (0xFF0000U)
#define APBH_CH10_SEMA_PHORE_SHIFT               (16U)
#define APBH_CH10_SEMA_PHORE(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH10_SEMA_PHORE_SHIFT)) & APBH_CH10_SEMA_PHORE_MASK)

/*! @name CH10_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH10_DEBUG1_STATEMACHINE_MASK       (0x1FU)
#define APBH_CH10_DEBUG1_STATEMACHINE_SHIFT      (0U)
#define APBH_CH10_DEBUG1_STATEMACHINE(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH10_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH10_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH10_DEBUG1_RSVD1_MASK              (0xFFFE0U)
#define APBH_CH10_DEBUG1_RSVD1_SHIFT             (5U)
#define APBH_CH10_DEBUG1_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH10_DEBUG1_RSVD1_SHIFT)) & APBH_CH10_DEBUG1_RSVD1_MASK)
#define APBH_CH10_DEBUG1_WR_FIFO_FULL_MASK       (0x100000U)
#define APBH_CH10_DEBUG1_WR_FIFO_FULL_SHIFT      (20U)
#define APBH_CH10_DEBUG1_WR_FIFO_EMPTY_MASK      (0x200000U)
#define APBH_CH10_DEBUG1_WR_FIFO_EMPTY_SHIFT     (21U)
#define APBH_CH10_DEBUG1_RD_FIFO_FULL_MASK       (0x400000U)
#define APBH_CH10_DEBUG1_RD_FIFO_FULL_SHIFT      (22U)
#define APBH_CH10_DEBUG1_RD_FIFO_EMPTY_MASK      (0x800000U)
#define APBH_CH10_DEBUG1_RD_FIFO_EMPTY_SHIFT     (23U)
#define APBH_CH10_DEBUG1_NEXTCMDADDRVALID_MASK   (0x1000000U)
#define APBH_CH10_DEBUG1_NEXTCMDADDRVALID_SHIFT  (24U)
#define APBH_CH10_DEBUG1_LOCK_MASK               (0x2000000U)
#define APBH_CH10_DEBUG1_LOCK_SHIFT              (25U)
#define APBH_CH10_DEBUG1_READY_MASK              (0x4000000U)
#define APBH_CH10_DEBUG1_READY_SHIFT             (26U)
#define APBH_CH10_DEBUG1_SENSE_MASK              (0x8000000U)
#define APBH_CH10_DEBUG1_SENSE_SHIFT             (27U)
#define APBH_CH10_DEBUG1_END_MASK                (0x10000000U)
#define APBH_CH10_DEBUG1_END_SHIFT               (28U)
#define APBH_CH10_DEBUG1_KICK_MASK               (0x20000000U)
#define APBH_CH10_DEBUG1_KICK_SHIFT              (29U)
#define APBH_CH10_DEBUG1_BURST_MASK              (0x40000000U)
#define APBH_CH10_DEBUG1_BURST_SHIFT             (30U)
#define APBH_CH10_DEBUG1_REQ_MASK                (0x80000000U)
#define APBH_CH10_DEBUG1_REQ_SHIFT               (31U)

/*! @name CH10_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH10_DEBUG2_AHB_BYTES_MASK          (0xFFFFU)
#define APBH_CH10_DEBUG2_AHB_BYTES_SHIFT         (0U)
#define APBH_CH10_DEBUG2_AHB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH10_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH10_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH10_DEBUG2_APB_BYTES_MASK          (0xFFFF0000U)
#define APBH_CH10_DEBUG2_APB_BYTES_SHIFT         (16U)
#define APBH_CH10_DEBUG2_APB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH10_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH10_DEBUG2_APB_BYTES_MASK)

/*! @name CH11_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH11_CURCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH11_CURCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH11_CURCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH11_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH11_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH11_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH11_NXTCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH11_NXTCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH11_NXTCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH11_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH11_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH11_CMD - APBH DMA Channel n Command Register */
#define APBH_CH11_CMD_COMMAND_MASK               (0x3U)
#define APBH_CH11_CMD_COMMAND_SHIFT              (0U)
#define APBH_CH11_CMD_COMMAND(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH11_CMD_COMMAND_SHIFT)) & APBH_CH11_CMD_COMMAND_MASK)
#define APBH_CH11_CMD_CHAIN_MASK                 (0x4U)
#define APBH_CH11_CMD_CHAIN_SHIFT                (2U)
#define APBH_CH11_CMD_IRQONCMPLT_MASK            (0x8U)
#define APBH_CH11_CMD_IRQONCMPLT_SHIFT           (3U)
#define APBH_CH11_CMD_NANDLOCK_MASK              (0x10U)
#define APBH_CH11_CMD_NANDLOCK_SHIFT             (4U)
#define APBH_CH11_CMD_NANDWAIT4READY_MASK        (0x20U)
#define APBH_CH11_CMD_NANDWAIT4READY_SHIFT       (5U)
#define APBH_CH11_CMD_SEMAPHORE_MASK             (0x40U)
#define APBH_CH11_CMD_SEMAPHORE_SHIFT            (6U)
#define APBH_CH11_CMD_WAIT4ENDCMD_MASK           (0x80U)
#define APBH_CH11_CMD_WAIT4ENDCMD_SHIFT          (7U)
#define APBH_CH11_CMD_HALTONTERMINATE_MASK       (0x100U)
#define APBH_CH11_CMD_HALTONTERMINATE_SHIFT      (8U)
#define APBH_CH11_CMD_CMDWORDS_MASK              (0xF000U)
#define APBH_CH11_CMD_CMDWORDS_SHIFT             (12U)
#define APBH_CH11_CMD_CMDWORDS(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH11_CMD_CMDWORDS_SHIFT)) & APBH_CH11_CMD_CMDWORDS_MASK)
#define APBH_CH11_CMD_XFER_COUNT_MASK            (0xFFFF0000U)
#define APBH_CH11_CMD_XFER_COUNT_SHIFT           (16U)
#define APBH_CH11_CMD_XFER_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << APBH_CH11_CMD_XFER_COUNT_SHIFT)) & APBH_CH11_CMD_XFER_COUNT_MASK)

/*! @name CH11_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH11_BAR_ADDRESS_MASK               (0xFFFFFFFFU)
#define APBH_CH11_BAR_ADDRESS_SHIFT              (0U)
#define APBH_CH11_BAR_ADDRESS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH11_BAR_ADDRESS_SHIFT)) & APBH_CH11_BAR_ADDRESS_MASK)

/*! @name CH11_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH11_SEMA_INCREMENT_SEMA_MASK       (0xFFU)
#define APBH_CH11_SEMA_INCREMENT_SEMA_SHIFT      (0U)
#define APBH_CH11_SEMA_INCREMENT_SEMA(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH11_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH11_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH11_SEMA_PHORE_MASK                (0xFF0000U)
#define APBH_CH11_SEMA_PHORE_SHIFT               (16U)
#define APBH_CH11_SEMA_PHORE(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH11_SEMA_PHORE_SHIFT)) & APBH_CH11_SEMA_PHORE_MASK)

/*! @name CH11_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH11_DEBUG1_STATEMACHINE_MASK       (0x1FU)
#define APBH_CH11_DEBUG1_STATEMACHINE_SHIFT      (0U)
#define APBH_CH11_DEBUG1_STATEMACHINE(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH11_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH11_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH11_DEBUG1_RSVD1_MASK              (0xFFFE0U)
#define APBH_CH11_DEBUG1_RSVD1_SHIFT             (5U)
#define APBH_CH11_DEBUG1_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH11_DEBUG1_RSVD1_SHIFT)) & APBH_CH11_DEBUG1_RSVD1_MASK)
#define APBH_CH11_DEBUG1_WR_FIFO_FULL_MASK       (0x100000U)
#define APBH_CH11_DEBUG1_WR_FIFO_FULL_SHIFT      (20U)
#define APBH_CH11_DEBUG1_WR_FIFO_EMPTY_MASK      (0x200000U)
#define APBH_CH11_DEBUG1_WR_FIFO_EMPTY_SHIFT     (21U)
#define APBH_CH11_DEBUG1_RD_FIFO_FULL_MASK       (0x400000U)
#define APBH_CH11_DEBUG1_RD_FIFO_FULL_SHIFT      (22U)
#define APBH_CH11_DEBUG1_RD_FIFO_EMPTY_MASK      (0x800000U)
#define APBH_CH11_DEBUG1_RD_FIFO_EMPTY_SHIFT     (23U)
#define APBH_CH11_DEBUG1_NEXTCMDADDRVALID_MASK   (0x1000000U)
#define APBH_CH11_DEBUG1_NEXTCMDADDRVALID_SHIFT  (24U)
#define APBH_CH11_DEBUG1_LOCK_MASK               (0x2000000U)
#define APBH_CH11_DEBUG1_LOCK_SHIFT              (25U)
#define APBH_CH11_DEBUG1_READY_MASK              (0x4000000U)
#define APBH_CH11_DEBUG1_READY_SHIFT             (26U)
#define APBH_CH11_DEBUG1_SENSE_MASK              (0x8000000U)
#define APBH_CH11_DEBUG1_SENSE_SHIFT             (27U)
#define APBH_CH11_DEBUG1_END_MASK                (0x10000000U)
#define APBH_CH11_DEBUG1_END_SHIFT               (28U)
#define APBH_CH11_DEBUG1_KICK_MASK               (0x20000000U)
#define APBH_CH11_DEBUG1_KICK_SHIFT              (29U)
#define APBH_CH11_DEBUG1_BURST_MASK              (0x40000000U)
#define APBH_CH11_DEBUG1_BURST_SHIFT             (30U)
#define APBH_CH11_DEBUG1_REQ_MASK                (0x80000000U)
#define APBH_CH11_DEBUG1_REQ_SHIFT               (31U)

/*! @name CH11_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH11_DEBUG2_AHB_BYTES_MASK          (0xFFFFU)
#define APBH_CH11_DEBUG2_AHB_BYTES_SHIFT         (0U)
#define APBH_CH11_DEBUG2_AHB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH11_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH11_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH11_DEBUG2_APB_BYTES_MASK          (0xFFFF0000U)
#define APBH_CH11_DEBUG2_APB_BYTES_SHIFT         (16U)
#define APBH_CH11_DEBUG2_APB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH11_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH11_DEBUG2_APB_BYTES_MASK)

/*! @name CH12_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH12_CURCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH12_CURCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH12_CURCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH12_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH12_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH12_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH12_NXTCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH12_NXTCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH12_NXTCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH12_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH12_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH12_CMD - APBH DMA Channel n Command Register */
#define APBH_CH12_CMD_COMMAND_MASK               (0x3U)
#define APBH_CH12_CMD_COMMAND_SHIFT              (0U)
#define APBH_CH12_CMD_COMMAND(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH12_CMD_COMMAND_SHIFT)) & APBH_CH12_CMD_COMMAND_MASK)
#define APBH_CH12_CMD_CHAIN_MASK                 (0x4U)
#define APBH_CH12_CMD_CHAIN_SHIFT                (2U)
#define APBH_CH12_CMD_IRQONCMPLT_MASK            (0x8U)
#define APBH_CH12_CMD_IRQONCMPLT_SHIFT           (3U)
#define APBH_CH12_CMD_NANDLOCK_MASK              (0x10U)
#define APBH_CH12_CMD_NANDLOCK_SHIFT             (4U)
#define APBH_CH12_CMD_NANDWAIT4READY_MASK        (0x20U)
#define APBH_CH12_CMD_NANDWAIT4READY_SHIFT       (5U)
#define APBH_CH12_CMD_SEMAPHORE_MASK             (0x40U)
#define APBH_CH12_CMD_SEMAPHORE_SHIFT            (6U)
#define APBH_CH12_CMD_WAIT4ENDCMD_MASK           (0x80U)
#define APBH_CH12_CMD_WAIT4ENDCMD_SHIFT          (7U)
#define APBH_CH12_CMD_HALTONTERMINATE_MASK       (0x100U)
#define APBH_CH12_CMD_HALTONTERMINATE_SHIFT      (8U)
#define APBH_CH12_CMD_CMDWORDS_MASK              (0xF000U)
#define APBH_CH12_CMD_CMDWORDS_SHIFT             (12U)
#define APBH_CH12_CMD_CMDWORDS(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH12_CMD_CMDWORDS_SHIFT)) & APBH_CH12_CMD_CMDWORDS_MASK)
#define APBH_CH12_CMD_XFER_COUNT_MASK            (0xFFFF0000U)
#define APBH_CH12_CMD_XFER_COUNT_SHIFT           (16U)
#define APBH_CH12_CMD_XFER_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << APBH_CH12_CMD_XFER_COUNT_SHIFT)) & APBH_CH12_CMD_XFER_COUNT_MASK)

/*! @name CH12_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH12_BAR_ADDRESS_MASK               (0xFFFFFFFFU)
#define APBH_CH12_BAR_ADDRESS_SHIFT              (0U)
#define APBH_CH12_BAR_ADDRESS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH12_BAR_ADDRESS_SHIFT)) & APBH_CH12_BAR_ADDRESS_MASK)

/*! @name CH12_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH12_SEMA_INCREMENT_SEMA_MASK       (0xFFU)
#define APBH_CH12_SEMA_INCREMENT_SEMA_SHIFT      (0U)
#define APBH_CH12_SEMA_INCREMENT_SEMA(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH12_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH12_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH12_SEMA_PHORE_MASK                (0xFF0000U)
#define APBH_CH12_SEMA_PHORE_SHIFT               (16U)
#define APBH_CH12_SEMA_PHORE(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH12_SEMA_PHORE_SHIFT)) & APBH_CH12_SEMA_PHORE_MASK)

/*! @name CH12_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH12_DEBUG1_STATEMACHINE_MASK       (0x1FU)
#define APBH_CH12_DEBUG1_STATEMACHINE_SHIFT      (0U)
#define APBH_CH12_DEBUG1_STATEMACHINE(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH12_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH12_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH12_DEBUG1_RSVD1_MASK              (0xFFFE0U)
#define APBH_CH12_DEBUG1_RSVD1_SHIFT             (5U)
#define APBH_CH12_DEBUG1_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH12_DEBUG1_RSVD1_SHIFT)) & APBH_CH12_DEBUG1_RSVD1_MASK)
#define APBH_CH12_DEBUG1_WR_FIFO_FULL_MASK       (0x100000U)
#define APBH_CH12_DEBUG1_WR_FIFO_FULL_SHIFT      (20U)
#define APBH_CH12_DEBUG1_WR_FIFO_EMPTY_MASK      (0x200000U)
#define APBH_CH12_DEBUG1_WR_FIFO_EMPTY_SHIFT     (21U)
#define APBH_CH12_DEBUG1_RD_FIFO_FULL_MASK       (0x400000U)
#define APBH_CH12_DEBUG1_RD_FIFO_FULL_SHIFT      (22U)
#define APBH_CH12_DEBUG1_RD_FIFO_EMPTY_MASK      (0x800000U)
#define APBH_CH12_DEBUG1_RD_FIFO_EMPTY_SHIFT     (23U)
#define APBH_CH12_DEBUG1_NEXTCMDADDRVALID_MASK   (0x1000000U)
#define APBH_CH12_DEBUG1_NEXTCMDADDRVALID_SHIFT  (24U)
#define APBH_CH12_DEBUG1_LOCK_MASK               (0x2000000U)
#define APBH_CH12_DEBUG1_LOCK_SHIFT              (25U)
#define APBH_CH12_DEBUG1_READY_MASK              (0x4000000U)
#define APBH_CH12_DEBUG1_READY_SHIFT             (26U)
#define APBH_CH12_DEBUG1_SENSE_MASK              (0x8000000U)
#define APBH_CH12_DEBUG1_SENSE_SHIFT             (27U)
#define APBH_CH12_DEBUG1_END_MASK                (0x10000000U)
#define APBH_CH12_DEBUG1_END_SHIFT               (28U)
#define APBH_CH12_DEBUG1_KICK_MASK               (0x20000000U)
#define APBH_CH12_DEBUG1_KICK_SHIFT              (29U)
#define APBH_CH12_DEBUG1_BURST_MASK              (0x40000000U)
#define APBH_CH12_DEBUG1_BURST_SHIFT             (30U)
#define APBH_CH12_DEBUG1_REQ_MASK                (0x80000000U)
#define APBH_CH12_DEBUG1_REQ_SHIFT               (31U)

/*! @name CH12_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH12_DEBUG2_AHB_BYTES_MASK          (0xFFFFU)
#define APBH_CH12_DEBUG2_AHB_BYTES_SHIFT         (0U)
#define APBH_CH12_DEBUG2_AHB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH12_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH12_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH12_DEBUG2_APB_BYTES_MASK          (0xFFFF0000U)
#define APBH_CH12_DEBUG2_APB_BYTES_SHIFT         (16U)
#define APBH_CH12_DEBUG2_APB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH12_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH12_DEBUG2_APB_BYTES_MASK)

/*! @name CH13_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH13_CURCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH13_CURCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH13_CURCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH13_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH13_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH13_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH13_NXTCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH13_NXTCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH13_NXTCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH13_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH13_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH13_CMD - APBH DMA Channel n Command Register */
#define APBH_CH13_CMD_COMMAND_MASK               (0x3U)
#define APBH_CH13_CMD_COMMAND_SHIFT              (0U)
#define APBH_CH13_CMD_COMMAND(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH13_CMD_COMMAND_SHIFT)) & APBH_CH13_CMD_COMMAND_MASK)
#define APBH_CH13_CMD_CHAIN_MASK                 (0x4U)
#define APBH_CH13_CMD_CHAIN_SHIFT                (2U)
#define APBH_CH13_CMD_IRQONCMPLT_MASK            (0x8U)
#define APBH_CH13_CMD_IRQONCMPLT_SHIFT           (3U)
#define APBH_CH13_CMD_NANDLOCK_MASK              (0x10U)
#define APBH_CH13_CMD_NANDLOCK_SHIFT             (4U)
#define APBH_CH13_CMD_NANDWAIT4READY_MASK        (0x20U)
#define APBH_CH13_CMD_NANDWAIT4READY_SHIFT       (5U)
#define APBH_CH13_CMD_SEMAPHORE_MASK             (0x40U)
#define APBH_CH13_CMD_SEMAPHORE_SHIFT            (6U)
#define APBH_CH13_CMD_WAIT4ENDCMD_MASK           (0x80U)
#define APBH_CH13_CMD_WAIT4ENDCMD_SHIFT          (7U)
#define APBH_CH13_CMD_HALTONTERMINATE_MASK       (0x100U)
#define APBH_CH13_CMD_HALTONTERMINATE_SHIFT      (8U)
#define APBH_CH13_CMD_CMDWORDS_MASK              (0xF000U)
#define APBH_CH13_CMD_CMDWORDS_SHIFT             (12U)
#define APBH_CH13_CMD_CMDWORDS(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH13_CMD_CMDWORDS_SHIFT)) & APBH_CH13_CMD_CMDWORDS_MASK)
#define APBH_CH13_CMD_XFER_COUNT_MASK            (0xFFFF0000U)
#define APBH_CH13_CMD_XFER_COUNT_SHIFT           (16U)
#define APBH_CH13_CMD_XFER_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << APBH_CH13_CMD_XFER_COUNT_SHIFT)) & APBH_CH13_CMD_XFER_COUNT_MASK)

/*! @name CH13_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH13_BAR_ADDRESS_MASK               (0xFFFFFFFFU)
#define APBH_CH13_BAR_ADDRESS_SHIFT              (0U)
#define APBH_CH13_BAR_ADDRESS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH13_BAR_ADDRESS_SHIFT)) & APBH_CH13_BAR_ADDRESS_MASK)

/*! @name CH13_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH13_SEMA_INCREMENT_SEMA_MASK       (0xFFU)
#define APBH_CH13_SEMA_INCREMENT_SEMA_SHIFT      (0U)
#define APBH_CH13_SEMA_INCREMENT_SEMA(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH13_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH13_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH13_SEMA_PHORE_MASK                (0xFF0000U)
#define APBH_CH13_SEMA_PHORE_SHIFT               (16U)
#define APBH_CH13_SEMA_PHORE(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH13_SEMA_PHORE_SHIFT)) & APBH_CH13_SEMA_PHORE_MASK)

/*! @name CH13_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH13_DEBUG1_STATEMACHINE_MASK       (0x1FU)
#define APBH_CH13_DEBUG1_STATEMACHINE_SHIFT      (0U)
#define APBH_CH13_DEBUG1_STATEMACHINE(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH13_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH13_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH13_DEBUG1_RSVD1_MASK              (0xFFFE0U)
#define APBH_CH13_DEBUG1_RSVD1_SHIFT             (5U)
#define APBH_CH13_DEBUG1_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH13_DEBUG1_RSVD1_SHIFT)) & APBH_CH13_DEBUG1_RSVD1_MASK)
#define APBH_CH13_DEBUG1_WR_FIFO_FULL_MASK       (0x100000U)
#define APBH_CH13_DEBUG1_WR_FIFO_FULL_SHIFT      (20U)
#define APBH_CH13_DEBUG1_WR_FIFO_EMPTY_MASK      (0x200000U)
#define APBH_CH13_DEBUG1_WR_FIFO_EMPTY_SHIFT     (21U)
#define APBH_CH13_DEBUG1_RD_FIFO_FULL_MASK       (0x400000U)
#define APBH_CH13_DEBUG1_RD_FIFO_FULL_SHIFT      (22U)
#define APBH_CH13_DEBUG1_RD_FIFO_EMPTY_MASK      (0x800000U)
#define APBH_CH13_DEBUG1_RD_FIFO_EMPTY_SHIFT     (23U)
#define APBH_CH13_DEBUG1_NEXTCMDADDRVALID_MASK   (0x1000000U)
#define APBH_CH13_DEBUG1_NEXTCMDADDRVALID_SHIFT  (24U)
#define APBH_CH13_DEBUG1_LOCK_MASK               (0x2000000U)
#define APBH_CH13_DEBUG1_LOCK_SHIFT              (25U)
#define APBH_CH13_DEBUG1_READY_MASK              (0x4000000U)
#define APBH_CH13_DEBUG1_READY_SHIFT             (26U)
#define APBH_CH13_DEBUG1_SENSE_MASK              (0x8000000U)
#define APBH_CH13_DEBUG1_SENSE_SHIFT             (27U)
#define APBH_CH13_DEBUG1_END_MASK                (0x10000000U)
#define APBH_CH13_DEBUG1_END_SHIFT               (28U)
#define APBH_CH13_DEBUG1_KICK_MASK               (0x20000000U)
#define APBH_CH13_DEBUG1_KICK_SHIFT              (29U)
#define APBH_CH13_DEBUG1_BURST_MASK              (0x40000000U)
#define APBH_CH13_DEBUG1_BURST_SHIFT             (30U)
#define APBH_CH13_DEBUG1_REQ_MASK                (0x80000000U)
#define APBH_CH13_DEBUG1_REQ_SHIFT               (31U)

/*! @name CH13_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH13_DEBUG2_AHB_BYTES_MASK          (0xFFFFU)
#define APBH_CH13_DEBUG2_AHB_BYTES_SHIFT         (0U)
#define APBH_CH13_DEBUG2_AHB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH13_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH13_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH13_DEBUG2_APB_BYTES_MASK          (0xFFFF0000U)
#define APBH_CH13_DEBUG2_APB_BYTES_SHIFT         (16U)
#define APBH_CH13_DEBUG2_APB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH13_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH13_DEBUG2_APB_BYTES_MASK)

/*! @name CH14_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH14_CURCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH14_CURCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH14_CURCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH14_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH14_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH14_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH14_NXTCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH14_NXTCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH14_NXTCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH14_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH14_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH14_CMD - APBH DMA Channel n Command Register */
#define APBH_CH14_CMD_COMMAND_MASK               (0x3U)
#define APBH_CH14_CMD_COMMAND_SHIFT              (0U)
#define APBH_CH14_CMD_COMMAND(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH14_CMD_COMMAND_SHIFT)) & APBH_CH14_CMD_COMMAND_MASK)
#define APBH_CH14_CMD_CHAIN_MASK                 (0x4U)
#define APBH_CH14_CMD_CHAIN_SHIFT                (2U)
#define APBH_CH14_CMD_IRQONCMPLT_MASK            (0x8U)
#define APBH_CH14_CMD_IRQONCMPLT_SHIFT           (3U)
#define APBH_CH14_CMD_NANDLOCK_MASK              (0x10U)
#define APBH_CH14_CMD_NANDLOCK_SHIFT             (4U)
#define APBH_CH14_CMD_NANDWAIT4READY_MASK        (0x20U)
#define APBH_CH14_CMD_NANDWAIT4READY_SHIFT       (5U)
#define APBH_CH14_CMD_SEMAPHORE_MASK             (0x40U)
#define APBH_CH14_CMD_SEMAPHORE_SHIFT            (6U)
#define APBH_CH14_CMD_WAIT4ENDCMD_MASK           (0x80U)
#define APBH_CH14_CMD_WAIT4ENDCMD_SHIFT          (7U)
#define APBH_CH14_CMD_HALTONTERMINATE_MASK       (0x100U)
#define APBH_CH14_CMD_HALTONTERMINATE_SHIFT      (8U)
#define APBH_CH14_CMD_CMDWORDS_MASK              (0xF000U)
#define APBH_CH14_CMD_CMDWORDS_SHIFT             (12U)
#define APBH_CH14_CMD_CMDWORDS(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH14_CMD_CMDWORDS_SHIFT)) & APBH_CH14_CMD_CMDWORDS_MASK)
#define APBH_CH14_CMD_XFER_COUNT_MASK            (0xFFFF0000U)
#define APBH_CH14_CMD_XFER_COUNT_SHIFT           (16U)
#define APBH_CH14_CMD_XFER_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << APBH_CH14_CMD_XFER_COUNT_SHIFT)) & APBH_CH14_CMD_XFER_COUNT_MASK)

/*! @name CH14_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH14_BAR_ADDRESS_MASK               (0xFFFFFFFFU)
#define APBH_CH14_BAR_ADDRESS_SHIFT              (0U)
#define APBH_CH14_BAR_ADDRESS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH14_BAR_ADDRESS_SHIFT)) & APBH_CH14_BAR_ADDRESS_MASK)

/*! @name CH14_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH14_SEMA_INCREMENT_SEMA_MASK       (0xFFU)
#define APBH_CH14_SEMA_INCREMENT_SEMA_SHIFT      (0U)
#define APBH_CH14_SEMA_INCREMENT_SEMA(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH14_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH14_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH14_SEMA_PHORE_MASK                (0xFF0000U)
#define APBH_CH14_SEMA_PHORE_SHIFT               (16U)
#define APBH_CH14_SEMA_PHORE(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH14_SEMA_PHORE_SHIFT)) & APBH_CH14_SEMA_PHORE_MASK)

/*! @name CH14_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH14_DEBUG1_STATEMACHINE_MASK       (0x1FU)
#define APBH_CH14_DEBUG1_STATEMACHINE_SHIFT      (0U)
#define APBH_CH14_DEBUG1_STATEMACHINE(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH14_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH14_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH14_DEBUG1_RSVD1_MASK              (0xFFFE0U)
#define APBH_CH14_DEBUG1_RSVD1_SHIFT             (5U)
#define APBH_CH14_DEBUG1_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH14_DEBUG1_RSVD1_SHIFT)) & APBH_CH14_DEBUG1_RSVD1_MASK)
#define APBH_CH14_DEBUG1_WR_FIFO_FULL_MASK       (0x100000U)
#define APBH_CH14_DEBUG1_WR_FIFO_FULL_SHIFT      (20U)
#define APBH_CH14_DEBUG1_WR_FIFO_EMPTY_MASK      (0x200000U)
#define APBH_CH14_DEBUG1_WR_FIFO_EMPTY_SHIFT     (21U)
#define APBH_CH14_DEBUG1_RD_FIFO_FULL_MASK       (0x400000U)
#define APBH_CH14_DEBUG1_RD_FIFO_FULL_SHIFT      (22U)
#define APBH_CH14_DEBUG1_RD_FIFO_EMPTY_MASK      (0x800000U)
#define APBH_CH14_DEBUG1_RD_FIFO_EMPTY_SHIFT     (23U)
#define APBH_CH14_DEBUG1_NEXTCMDADDRVALID_MASK   (0x1000000U)
#define APBH_CH14_DEBUG1_NEXTCMDADDRVALID_SHIFT  (24U)
#define APBH_CH14_DEBUG1_LOCK_MASK               (0x2000000U)
#define APBH_CH14_DEBUG1_LOCK_SHIFT              (25U)
#define APBH_CH14_DEBUG1_READY_MASK              (0x4000000U)
#define APBH_CH14_DEBUG1_READY_SHIFT             (26U)
#define APBH_CH14_DEBUG1_SENSE_MASK              (0x8000000U)
#define APBH_CH14_DEBUG1_SENSE_SHIFT             (27U)
#define APBH_CH14_DEBUG1_END_MASK                (0x10000000U)
#define APBH_CH14_DEBUG1_END_SHIFT               (28U)
#define APBH_CH14_DEBUG1_KICK_MASK               (0x20000000U)
#define APBH_CH14_DEBUG1_KICK_SHIFT              (29U)
#define APBH_CH14_DEBUG1_BURST_MASK              (0x40000000U)
#define APBH_CH14_DEBUG1_BURST_SHIFT             (30U)
#define APBH_CH14_DEBUG1_REQ_MASK                (0x80000000U)
#define APBH_CH14_DEBUG1_REQ_SHIFT               (31U)

/*! @name CH14_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH14_DEBUG2_AHB_BYTES_MASK          (0xFFFFU)
#define APBH_CH14_DEBUG2_AHB_BYTES_SHIFT         (0U)
#define APBH_CH14_DEBUG2_AHB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH14_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH14_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH14_DEBUG2_APB_BYTES_MASK          (0xFFFF0000U)
#define APBH_CH14_DEBUG2_APB_BYTES_SHIFT         (16U)
#define APBH_CH14_DEBUG2_APB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH14_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH14_DEBUG2_APB_BYTES_MASK)

/*! @name CH15_CURCMDAR - APBH DMA Channel n Current Command Address Register */
#define APBH_CH15_CURCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH15_CURCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH15_CURCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH15_CURCMDAR_CMD_ADDR_SHIFT)) & APBH_CH15_CURCMDAR_CMD_ADDR_MASK)

/*! @name CH15_NXTCMDAR - APBH DMA Channel n Next Command Address Register */
#define APBH_CH15_NXTCMDAR_CMD_ADDR_MASK         (0xFFFFFFFFU)
#define APBH_CH15_NXTCMDAR_CMD_ADDR_SHIFT        (0U)
#define APBH_CH15_NXTCMDAR_CMD_ADDR(x)           (((uint32_t)(((uint32_t)(x)) << APBH_CH15_NXTCMDAR_CMD_ADDR_SHIFT)) & APBH_CH15_NXTCMDAR_CMD_ADDR_MASK)

/*! @name CH15_CMD - APBH DMA Channel n Command Register */
#define APBH_CH15_CMD_COMMAND_MASK               (0x3U)
#define APBH_CH15_CMD_COMMAND_SHIFT              (0U)
#define APBH_CH15_CMD_COMMAND(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH15_CMD_COMMAND_SHIFT)) & APBH_CH15_CMD_COMMAND_MASK)
#define APBH_CH15_CMD_CHAIN_MASK                 (0x4U)
#define APBH_CH15_CMD_CHAIN_SHIFT                (2U)
#define APBH_CH15_CMD_IRQONCMPLT_MASK            (0x8U)
#define APBH_CH15_CMD_IRQONCMPLT_SHIFT           (3U)
#define APBH_CH15_CMD_NANDLOCK_MASK              (0x10U)
#define APBH_CH15_CMD_NANDLOCK_SHIFT             (4U)
#define APBH_CH15_CMD_NANDWAIT4READY_MASK        (0x20U)
#define APBH_CH15_CMD_NANDWAIT4READY_SHIFT       (5U)
#define APBH_CH15_CMD_SEMAPHORE_MASK             (0x40U)
#define APBH_CH15_CMD_SEMAPHORE_SHIFT            (6U)
#define APBH_CH15_CMD_WAIT4ENDCMD_MASK           (0x80U)
#define APBH_CH15_CMD_WAIT4ENDCMD_SHIFT          (7U)
#define APBH_CH15_CMD_HALTONTERMINATE_MASK       (0x100U)
#define APBH_CH15_CMD_HALTONTERMINATE_SHIFT      (8U)
#define APBH_CH15_CMD_CMDWORDS_MASK              (0xF000U)
#define APBH_CH15_CMD_CMDWORDS_SHIFT             (12U)
#define APBH_CH15_CMD_CMDWORDS(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH15_CMD_CMDWORDS_SHIFT)) & APBH_CH15_CMD_CMDWORDS_MASK)
#define APBH_CH15_CMD_XFER_COUNT_MASK            (0xFFFF0000U)
#define APBH_CH15_CMD_XFER_COUNT_SHIFT           (16U)
#define APBH_CH15_CMD_XFER_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << APBH_CH15_CMD_XFER_COUNT_SHIFT)) & APBH_CH15_CMD_XFER_COUNT_MASK)

/*! @name CH15_BAR - APBH DMA Channel n Buffer Address Register */
#define APBH_CH15_BAR_ADDRESS_MASK               (0xFFFFFFFFU)
#define APBH_CH15_BAR_ADDRESS_SHIFT              (0U)
#define APBH_CH15_BAR_ADDRESS(x)                 (((uint32_t)(((uint32_t)(x)) << APBH_CH15_BAR_ADDRESS_SHIFT)) & APBH_CH15_BAR_ADDRESS_MASK)

/*! @name CH15_SEMA - APBH DMA Channel n Semaphore Register */
#define APBH_CH15_SEMA_INCREMENT_SEMA_MASK       (0xFFU)
#define APBH_CH15_SEMA_INCREMENT_SEMA_SHIFT      (0U)
#define APBH_CH15_SEMA_INCREMENT_SEMA(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH15_SEMA_INCREMENT_SEMA_SHIFT)) & APBH_CH15_SEMA_INCREMENT_SEMA_MASK)
#define APBH_CH15_SEMA_PHORE_MASK                (0xFF0000U)
#define APBH_CH15_SEMA_PHORE_SHIFT               (16U)
#define APBH_CH15_SEMA_PHORE(x)                  (((uint32_t)(((uint32_t)(x)) << APBH_CH15_SEMA_PHORE_SHIFT)) & APBH_CH15_SEMA_PHORE_MASK)

/*! @name CH15_DEBUG1 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH15_DEBUG1_STATEMACHINE_MASK       (0x1FU)
#define APBH_CH15_DEBUG1_STATEMACHINE_SHIFT      (0U)
#define APBH_CH15_DEBUG1_STATEMACHINE(x)         (((uint32_t)(((uint32_t)(x)) << APBH_CH15_DEBUG1_STATEMACHINE_SHIFT)) & APBH_CH15_DEBUG1_STATEMACHINE_MASK)
#define APBH_CH15_DEBUG1_RSVD1_MASK              (0xFFFE0U)
#define APBH_CH15_DEBUG1_RSVD1_SHIFT             (5U)
#define APBH_CH15_DEBUG1_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << APBH_CH15_DEBUG1_RSVD1_SHIFT)) & APBH_CH15_DEBUG1_RSVD1_MASK)
#define APBH_CH15_DEBUG1_WR_FIFO_FULL_MASK       (0x100000U)
#define APBH_CH15_DEBUG1_WR_FIFO_FULL_SHIFT      (20U)
#define APBH_CH15_DEBUG1_WR_FIFO_EMPTY_MASK      (0x200000U)
#define APBH_CH15_DEBUG1_WR_FIFO_EMPTY_SHIFT     (21U)
#define APBH_CH15_DEBUG1_RD_FIFO_FULL_MASK       (0x400000U)
#define APBH_CH15_DEBUG1_RD_FIFO_FULL_SHIFT      (22U)
#define APBH_CH15_DEBUG1_RD_FIFO_EMPTY_MASK      (0x800000U)
#define APBH_CH15_DEBUG1_RD_FIFO_EMPTY_SHIFT     (23U)
#define APBH_CH15_DEBUG1_NEXTCMDADDRVALID_MASK   (0x1000000U)
#define APBH_CH15_DEBUG1_NEXTCMDADDRVALID_SHIFT  (24U)
#define APBH_CH15_DEBUG1_LOCK_MASK               (0x2000000U)
#define APBH_CH15_DEBUG1_LOCK_SHIFT              (25U)
#define APBH_CH15_DEBUG1_READY_MASK              (0x4000000U)
#define APBH_CH15_DEBUG1_READY_SHIFT             (26U)
#define APBH_CH15_DEBUG1_SENSE_MASK              (0x8000000U)
#define APBH_CH15_DEBUG1_SENSE_SHIFT             (27U)
#define APBH_CH15_DEBUG1_END_MASK                (0x10000000U)
#define APBH_CH15_DEBUG1_END_SHIFT               (28U)
#define APBH_CH15_DEBUG1_KICK_MASK               (0x20000000U)
#define APBH_CH15_DEBUG1_KICK_SHIFT              (29U)
#define APBH_CH15_DEBUG1_BURST_MASK              (0x40000000U)
#define APBH_CH15_DEBUG1_BURST_SHIFT             (30U)
#define APBH_CH15_DEBUG1_REQ_MASK                (0x80000000U)
#define APBH_CH15_DEBUG1_REQ_SHIFT               (31U)

/*! @name CH15_DEBUG2 - AHB to APBH DMA Channel n Debug Information */
#define APBH_CH15_DEBUG2_AHB_BYTES_MASK          (0xFFFFU)
#define APBH_CH15_DEBUG2_AHB_BYTES_SHIFT         (0U)
#define APBH_CH15_DEBUG2_AHB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH15_DEBUG2_AHB_BYTES_SHIFT)) & APBH_CH15_DEBUG2_AHB_BYTES_MASK)
#define APBH_CH15_DEBUG2_APB_BYTES_MASK          (0xFFFF0000U)
#define APBH_CH15_DEBUG2_APB_BYTES_SHIFT         (16U)
#define APBH_CH15_DEBUG2_APB_BYTES(x)            (((uint32_t)(((uint32_t)(x)) << APBH_CH15_DEBUG2_APB_BYTES_SHIFT)) & APBH_CH15_DEBUG2_APB_BYTES_MASK)

/*! @name VERSION - APBH Bridge Version Register */
#define APBH_VERSION_STEP_MASK                   (0xFFFFU)
#define APBH_VERSION_STEP_SHIFT                  (0U)
#define APBH_VERSION_STEP(x)                     (((uint32_t)(((uint32_t)(x)) << APBH_VERSION_STEP_SHIFT)) & APBH_VERSION_STEP_MASK)
#define APBH_VERSION_MINOR_MASK                  (0xFF0000U)
#define APBH_VERSION_MINOR_SHIFT                 (16U)
#define APBH_VERSION_MINOR(x)                    (((uint32_t)(((uint32_t)(x)) << APBH_VERSION_MINOR_SHIFT)) & APBH_VERSION_MINOR_MASK)
#define APBH_VERSION_MAJOR_MASK                  (0xFF000000U)
#define APBH_VERSION_MAJOR_SHIFT                 (24U)
#define APBH_VERSION_MAJOR(x)                    (((uint32_t)(((uint32_t)(x)) << APBH_VERSION_MAJOR_SHIFT)) & APBH_VERSION_MAJOR_MASK)


/*!
 * @}
 */ /* end of group APBH_Register_Masks */


/* APBH - Peripheral instance base addresses */
/** Peripheral APBH base pointer */
#define APBH_BASE_PTR                            ((APBH_MemMapPtr)0x33000000u)
/** Array initializer of APBH peripheral base pointers */
#define APBH_BASE_PTRS                           { APBH_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- APBH - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup APBH_Register_Accessor_Macros APBH - Register accessor macros
 * @{
 */


/* APBH - Register instance definitions */
/* APBH */
#define APBH_CTRL0                               APBH_CTRL0_REG(APBH_BASE_PTR)
#define APBH_CTRL0_SET                           APBH_CTRL0_SET_REG(APBH_BASE_PTR)
#define APBH_CTRL0_CLR                           APBH_CTRL0_CLR_REG(APBH_BASE_PTR)
#define APBH_CTRL0_TOG                           APBH_CTRL0_TOG_REG(APBH_BASE_PTR)
#define APBH_CTRL1                               APBH_CTRL1_REG(APBH_BASE_PTR)
#define APBH_CTRL1_SET                           APBH_CTRL1_SET_REG(APBH_BASE_PTR)
#define APBH_CTRL1_CLR                           APBH_CTRL1_CLR_REG(APBH_BASE_PTR)
#define APBH_CTRL1_TOG                           APBH_CTRL1_TOG_REG(APBH_BASE_PTR)
#define APBH_CTRL2                               APBH_CTRL2_REG(APBH_BASE_PTR)
#define APBH_CTRL2_SET                           APBH_CTRL2_SET_REG(APBH_BASE_PTR)
#define APBH_CTRL2_CLR                           APBH_CTRL2_CLR_REG(APBH_BASE_PTR)
#define APBH_CTRL2_TOG                           APBH_CTRL2_TOG_REG(APBH_BASE_PTR)
#define APBH_CHANNEL_CTRL                        APBH_CHANNEL_CTRL_REG(APBH_BASE_PTR)
#define APBH_CHANNEL_CTRL_SET                    APBH_CHANNEL_CTRL_SET_REG(APBH_BASE_PTR)
#define APBH_CHANNEL_CTRL_CLR                    APBH_CHANNEL_CTRL_CLR_REG(APBH_BASE_PTR)
#define APBH_CHANNEL_CTRL_TOG                    APBH_CHANNEL_CTRL_TOG_REG(APBH_BASE_PTR)
#define APBH_DEVSEL                              APBH_DEVSEL_REG(APBH_BASE_PTR)
#define APBH_DMA_BURST_SIZE                      APBH_DMA_BURST_SIZE_REG(APBH_BASE_PTR)
#define APBH_DEBUG                               APBH_DEBUG_REG(APBH_BASE_PTR)
#define APBH_CH0_CURCMDAR                        APBH_CH0_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH0_NXTCMDAR                        APBH_CH0_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH0_CMD                             APBH_CH0_CMD_REG(APBH_BASE_PTR)
#define APBH_CH0_BAR                             APBH_CH0_BAR_REG(APBH_BASE_PTR)
#define APBH_CH0_SEMA                            APBH_CH0_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH0_DEBUG1                          APBH_CH0_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH0_DEBUG2                          APBH_CH0_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH1_CURCMDAR                        APBH_CH1_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH1_NXTCMDAR                        APBH_CH1_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH1_CMD                             APBH_CH1_CMD_REG(APBH_BASE_PTR)
#define APBH_CH1_BAR                             APBH_CH1_BAR_REG(APBH_BASE_PTR)
#define APBH_CH1_SEMA                            APBH_CH1_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH1_DEBUG1                          APBH_CH1_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH1_DEBUG2                          APBH_CH1_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH2_CURCMDAR                        APBH_CH2_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH2_NXTCMDAR                        APBH_CH2_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH2_CMD                             APBH_CH2_CMD_REG(APBH_BASE_PTR)
#define APBH_CH2_BAR                             APBH_CH2_BAR_REG(APBH_BASE_PTR)
#define APBH_CH2_SEMA                            APBH_CH2_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH2_DEBUG1                          APBH_CH2_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH2_DEBUG2                          APBH_CH2_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH3_CURCMDAR                        APBH_CH3_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH3_NXTCMDAR                        APBH_CH3_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH3_CMD                             APBH_CH3_CMD_REG(APBH_BASE_PTR)
#define APBH_CH3_BAR                             APBH_CH3_BAR_REG(APBH_BASE_PTR)
#define APBH_CH3_SEMA                            APBH_CH3_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH3_DEBUG1                          APBH_CH3_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH3_DEBUG2                          APBH_CH3_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH4_CURCMDAR                        APBH_CH4_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH4_NXTCMDAR                        APBH_CH4_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH4_CMD                             APBH_CH4_CMD_REG(APBH_BASE_PTR)
#define APBH_CH4_BAR                             APBH_CH4_BAR_REG(APBH_BASE_PTR)
#define APBH_CH4_SEMA                            APBH_CH4_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH4_DEBUG1                          APBH_CH4_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH4_DEBUG2                          APBH_CH4_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH5_CURCMDAR                        APBH_CH5_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH5_NXTCMDAR                        APBH_CH5_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH5_CMD                             APBH_CH5_CMD_REG(APBH_BASE_PTR)
#define APBH_CH5_BAR                             APBH_CH5_BAR_REG(APBH_BASE_PTR)
#define APBH_CH5_SEMA                            APBH_CH5_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH5_DEBUG1                          APBH_CH5_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH5_DEBUG2                          APBH_CH5_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH6_CURCMDAR                        APBH_CH6_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH6_NXTCMDAR                        APBH_CH6_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH6_CMD                             APBH_CH6_CMD_REG(APBH_BASE_PTR)
#define APBH_CH6_BAR                             APBH_CH6_BAR_REG(APBH_BASE_PTR)
#define APBH_CH6_SEMA                            APBH_CH6_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH6_DEBUG1                          APBH_CH6_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH6_DEBUG2                          APBH_CH6_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH7_CURCMDAR                        APBH_CH7_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH7_NXTCMDAR                        APBH_CH7_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH7_CMD                             APBH_CH7_CMD_REG(APBH_BASE_PTR)
#define APBH_CH7_BAR                             APBH_CH7_BAR_REG(APBH_BASE_PTR)
#define APBH_CH7_SEMA                            APBH_CH7_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH7_DEBUG1                          APBH_CH7_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH7_DEBUG2                          APBH_CH7_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH8_CURCMDAR                        APBH_CH8_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH8_NXTCMDAR                        APBH_CH8_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH8_CMD                             APBH_CH8_CMD_REG(APBH_BASE_PTR)
#define APBH_CH8_BAR                             APBH_CH8_BAR_REG(APBH_BASE_PTR)
#define APBH_CH8_SEMA                            APBH_CH8_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH8_DEBUG1                          APBH_CH8_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH8_DEBUG2                          APBH_CH8_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH9_CURCMDAR                        APBH_CH9_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH9_NXTCMDAR                        APBH_CH9_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH9_CMD                             APBH_CH9_CMD_REG(APBH_BASE_PTR)
#define APBH_CH9_BAR                             APBH_CH9_BAR_REG(APBH_BASE_PTR)
#define APBH_CH9_SEMA                            APBH_CH9_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH9_DEBUG1                          APBH_CH9_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH9_DEBUG2                          APBH_CH9_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH10_CURCMDAR                       APBH_CH10_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH10_NXTCMDAR                       APBH_CH10_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH10_CMD                            APBH_CH10_CMD_REG(APBH_BASE_PTR)
#define APBH_CH10_BAR                            APBH_CH10_BAR_REG(APBH_BASE_PTR)
#define APBH_CH10_SEMA                           APBH_CH10_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH10_DEBUG1                         APBH_CH10_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH10_DEBUG2                         APBH_CH10_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH11_CURCMDAR                       APBH_CH11_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH11_NXTCMDAR                       APBH_CH11_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH11_CMD                            APBH_CH11_CMD_REG(APBH_BASE_PTR)
#define APBH_CH11_BAR                            APBH_CH11_BAR_REG(APBH_BASE_PTR)
#define APBH_CH11_SEMA                           APBH_CH11_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH11_DEBUG1                         APBH_CH11_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH11_DEBUG2                         APBH_CH11_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH12_CURCMDAR                       APBH_CH12_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH12_NXTCMDAR                       APBH_CH12_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH12_CMD                            APBH_CH12_CMD_REG(APBH_BASE_PTR)
#define APBH_CH12_BAR                            APBH_CH12_BAR_REG(APBH_BASE_PTR)
#define APBH_CH12_SEMA                           APBH_CH12_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH12_DEBUG1                         APBH_CH12_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH12_DEBUG2                         APBH_CH12_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH13_CURCMDAR                       APBH_CH13_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH13_NXTCMDAR                       APBH_CH13_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH13_CMD                            APBH_CH13_CMD_REG(APBH_BASE_PTR)
#define APBH_CH13_BAR                            APBH_CH13_BAR_REG(APBH_BASE_PTR)
#define APBH_CH13_SEMA                           APBH_CH13_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH13_DEBUG1                         APBH_CH13_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH13_DEBUG2                         APBH_CH13_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH14_CURCMDAR                       APBH_CH14_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH14_NXTCMDAR                       APBH_CH14_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH14_CMD                            APBH_CH14_CMD_REG(APBH_BASE_PTR)
#define APBH_CH14_BAR                            APBH_CH14_BAR_REG(APBH_BASE_PTR)
#define APBH_CH14_SEMA                           APBH_CH14_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH14_DEBUG1                         APBH_CH14_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH14_DEBUG2                         APBH_CH14_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_CH15_CURCMDAR                       APBH_CH15_CURCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH15_NXTCMDAR                       APBH_CH15_NXTCMDAR_REG(APBH_BASE_PTR)
#define APBH_CH15_CMD                            APBH_CH15_CMD_REG(APBH_BASE_PTR)
#define APBH_CH15_BAR                            APBH_CH15_BAR_REG(APBH_BASE_PTR)
#define APBH_CH15_SEMA                           APBH_CH15_SEMA_REG(APBH_BASE_PTR)
#define APBH_CH15_DEBUG1                         APBH_CH15_DEBUG1_REG(APBH_BASE_PTR)
#define APBH_CH15_DEBUG2                         APBH_CH15_DEBUG2_REG(APBH_BASE_PTR)
#define APBH_VERSION                             APBH_VERSION_REG(APBH_BASE_PTR)

/*!
 * @}
 */ /* end of group APBH_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group APBH_Peripheral */


/* ----------------------------------------------------------------------------
   -- BCH
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup BCH_Peripheral BCH
 * @{
 */

/** BCH - Peripheral register structure */
typedef struct BCH_MemMap {
  uint32_t CTRL;                                   /**< Hardware BCH ECC Accelerator Control Register, offset: 0x0 */
  uint32_t CTRL_SET;                               /**< Hardware BCH ECC Accelerator Control Register, offset: 0x4 */
  uint32_t CTRL_CLR;                               /**< Hardware BCH ECC Accelerator Control Register, offset: 0x8 */
  uint32_t CTRL_TOG;                               /**< Hardware BCH ECC Accelerator Control Register, offset: 0xC */
  uint32_t STATUS0;                                /**< Hardware ECC Accelerator Status Register 0, offset: 0x10 */
  uint32_t STATUS0_SET;                            /**< Hardware ECC Accelerator Status Register 0, offset: 0x14 */
  uint32_t STATUS0_CLR;                            /**< Hardware ECC Accelerator Status Register 0, offset: 0x18 */
  uint32_t STATUS0_TOG;                            /**< Hardware ECC Accelerator Status Register 0, offset: 0x1C */
  uint32_t MODE;                                   /**< Hardware ECC Accelerator Mode Register, offset: 0x20 */
  uint32_t MODE_SET;                               /**< Hardware ECC Accelerator Mode Register, offset: 0x24 */
  uint32_t MODE_CLR;                               /**< Hardware ECC Accelerator Mode Register, offset: 0x28 */
  uint32_t MODE_TOG;                               /**< Hardware ECC Accelerator Mode Register, offset: 0x2C */
  uint32_t ENCODEPTR;                              /**< Hardware BCH ECC Loopback Encode Buffer Register, offset: 0x30 */
  uint32_t ENCODEPTR_SET;                          /**< Hardware BCH ECC Loopback Encode Buffer Register, offset: 0x34 */
  uint32_t ENCODEPTR_CLR;                          /**< Hardware BCH ECC Loopback Encode Buffer Register, offset: 0x38 */
  uint32_t ENCODEPTR_TOG;                          /**< Hardware BCH ECC Loopback Encode Buffer Register, offset: 0x3C */
  uint32_t DATAPTR;                                /**< Hardware BCH ECC Loopback Data Buffer Register, offset: 0x40 */
  uint32_t DATAPTR_SET;                            /**< Hardware BCH ECC Loopback Data Buffer Register, offset: 0x44 */
  uint32_t DATAPTR_CLR;                            /**< Hardware BCH ECC Loopback Data Buffer Register, offset: 0x48 */
  uint32_t DATAPTR_TOG;                            /**< Hardware BCH ECC Loopback Data Buffer Register, offset: 0x4C */
  uint32_t METAPTR;                                /**< Hardware BCH ECC Loopback Metadata Buffer Register, offset: 0x50 */
  uint32_t METAPTR_SET;                            /**< Hardware BCH ECC Loopback Metadata Buffer Register, offset: 0x54 */
  uint32_t METAPTR_CLR;                            /**< Hardware BCH ECC Loopback Metadata Buffer Register, offset: 0x58 */
  uint32_t METAPTR_TOG;                            /**< Hardware BCH ECC Loopback Metadata Buffer Register, offset: 0x5C */
  uint8_t RESERVED_0[16];
  uint32_t LAYOUTSELECT;                           /**< Hardware ECC Accelerator Layout Select Register, offset: 0x70 */
  uint32_t LAYOUTSELECT_SET;                       /**< Hardware ECC Accelerator Layout Select Register, offset: 0x74 */
  uint32_t LAYOUTSELECT_CLR;                       /**< Hardware ECC Accelerator Layout Select Register, offset: 0x78 */
  uint32_t LAYOUTSELECT_TOG;                       /**< Hardware ECC Accelerator Layout Select Register, offset: 0x7C */
  uint32_t FLASH0LAYOUT0;                          /**< Hardware BCH ECC Flash 0 Layout 0 Register, offset: 0x80 */
  uint32_t FLASH0LAYOUT0_SET;                      /**< Hardware BCH ECC Flash 0 Layout 0 Register, offset: 0x84 */
  uint32_t FLASH0LAYOUT0_CLR;                      /**< Hardware BCH ECC Flash 0 Layout 0 Register, offset: 0x88 */
  uint32_t FLASH0LAYOUT0_TOG;                      /**< Hardware BCH ECC Flash 0 Layout 0 Register, offset: 0x8C */
  uint32_t FLASH0LAYOUT1;                          /**< Hardware BCH ECC Flash 0 Layout 1 Register, offset: 0x90 */
  uint32_t FLASH0LAYOUT1_SET;                      /**< Hardware BCH ECC Flash 0 Layout 1 Register, offset: 0x94 */
  uint32_t FLASH0LAYOUT1_CLR;                      /**< Hardware BCH ECC Flash 0 Layout 1 Register, offset: 0x98 */
  uint32_t FLASH0LAYOUT1_TOG;                      /**< Hardware BCH ECC Flash 0 Layout 1 Register, offset: 0x9C */
  uint32_t FLASH1LAYOUT0;                          /**< Hardware BCH ECC Flash 1 Layout 0 Register, offset: 0xA0 */
  uint32_t FLASH1LAYOUT0_SET;                      /**< Hardware BCH ECC Flash 1 Layout 0 Register, offset: 0xA4 */
  uint32_t FLASH1LAYOUT0_CLR;                      /**< Hardware BCH ECC Flash 1 Layout 0 Register, offset: 0xA8 */
  uint32_t FLASH1LAYOUT0_TOG;                      /**< Hardware BCH ECC Flash 1 Layout 0 Register, offset: 0xAC */
  uint32_t FLASH1LAYOUT1;                          /**< Hardware BCH ECC Flash 1 Layout 1 Register, offset: 0xB0 */
  uint32_t FLASH1LAYOUT1_SET;                      /**< Hardware BCH ECC Flash 1 Layout 1 Register, offset: 0xB4 */
  uint32_t FLASH1LAYOUT1_CLR;                      /**< Hardware BCH ECC Flash 1 Layout 1 Register, offset: 0xB8 */
  uint32_t FLASH1LAYOUT1_TOG;                      /**< Hardware BCH ECC Flash 1 Layout 1 Register, offset: 0xBC */
  uint32_t FLASH2LAYOUT0;                          /**< Hardware BCH ECC Flash 2 Layout 0 Register, offset: 0xC0 */
  uint32_t FLASH2LAYOUT0_SET;                      /**< Hardware BCH ECC Flash 2 Layout 0 Register, offset: 0xC4 */
  uint32_t FLASH2LAYOUT0_CLR;                      /**< Hardware BCH ECC Flash 2 Layout 0 Register, offset: 0xC8 */
  uint32_t FLASH2LAYOUT0_TOG;                      /**< Hardware BCH ECC Flash 2 Layout 0 Register, offset: 0xCC */
  uint32_t FLASH2LAYOUT1;                          /**< Hardware BCH ECC Flash 2 Layout 1 Register, offset: 0xD0 */
  uint32_t FLASH2LAYOUT1_SET;                      /**< Hardware BCH ECC Flash 2 Layout 1 Register, offset: 0xD4 */
  uint32_t FLASH2LAYOUT1_CLR;                      /**< Hardware BCH ECC Flash 2 Layout 1 Register, offset: 0xD8 */
  uint32_t FLASH2LAYOUT1_TOG;                      /**< Hardware BCH ECC Flash 2 Layout 1 Register, offset: 0xDC */
  uint32_t FLASH3LAYOUT0;                          /**< Hardware BCH ECC Flash 3 Layout 0 Register, offset: 0xE0 */
  uint32_t FLASH3LAYOUT0_SET;                      /**< Hardware BCH ECC Flash 3 Layout 0 Register, offset: 0xE4 */
  uint32_t FLASH3LAYOUT0_CLR;                      /**< Hardware BCH ECC Flash 3 Layout 0 Register, offset: 0xE8 */
  uint32_t FLASH3LAYOUT0_TOG;                      /**< Hardware BCH ECC Flash 3 Layout 0 Register, offset: 0xEC */
  uint32_t FLASH3LAYOUT1;                          /**< Hardware BCH ECC Flash 3 Layout 1 Register, offset: 0xF0 */
  uint32_t FLASH3LAYOUT1_SET;                      /**< Hardware BCH ECC Flash 3 Layout 1 Register, offset: 0xF4 */
  uint32_t FLASH3LAYOUT1_CLR;                      /**< Hardware BCH ECC Flash 3 Layout 1 Register, offset: 0xF8 */
  uint32_t FLASH3LAYOUT1_TOG;                      /**< Hardware BCH ECC Flash 3 Layout 1 Register, offset: 0xFC */
  uint32_t DEBUG0;                                 /**< Hardware BCH ECC Debug Register0, offset: 0x100 */
  uint32_t DEBUG0_SET;                             /**< Hardware BCH ECC Debug Register0, offset: 0x104 */
  uint32_t DEBUG0_CLR;                             /**< Hardware BCH ECC Debug Register0, offset: 0x108 */
  uint32_t DEBUG0_TOG;                             /**< Hardware BCH ECC Debug Register0, offset: 0x10C */
  uint32_t DBGKESREAD;                             /**< KES Debug Read Register, offset: 0x110 */
  uint32_t DBGKESREAD_SET;                         /**< KES Debug Read Register, offset: 0x114 */
  uint32_t DBGKESREAD_CLR;                         /**< KES Debug Read Register, offset: 0x118 */
  uint32_t DBGKESREAD_TOG;                         /**< KES Debug Read Register, offset: 0x11C */
  uint32_t DBGCSFEREAD;                            /**< Chien Search Debug Read Register, offset: 0x120 */
  uint32_t DBGCSFEREAD_SET;                        /**< Chien Search Debug Read Register, offset: 0x124 */
  uint32_t DBGCSFEREAD_CLR;                        /**< Chien Search Debug Read Register, offset: 0x128 */
  uint32_t DBGCSFEREAD_TOG;                        /**< Chien Search Debug Read Register, offset: 0x12C */
  uint32_t DBGSYNDGENREAD;                         /**< Syndrome Generator Debug Read Register, offset: 0x130 */
  uint32_t DBGSYNDGENREAD_SET;                     /**< Syndrome Generator Debug Read Register, offset: 0x134 */
  uint32_t DBGSYNDGENREAD_CLR;                     /**< Syndrome Generator Debug Read Register, offset: 0x138 */
  uint32_t DBGSYNDGENREAD_TOG;                     /**< Syndrome Generator Debug Read Register, offset: 0x13C */
  uint32_t DBGAHBMREAD;                            /**< Bus Master and ECC Controller Debug Read Register, offset: 0x140 */
  uint32_t DBGAHBMREAD_SET;                        /**< Bus Master and ECC Controller Debug Read Register, offset: 0x144 */
  uint32_t DBGAHBMREAD_CLR;                        /**< Bus Master and ECC Controller Debug Read Register, offset: 0x148 */
  uint32_t DBGAHBMREAD_TOG;                        /**< Bus Master and ECC Controller Debug Read Register, offset: 0x14C */
  uint32_t BLOCKNAME;                              /**< Block Name Register, offset: 0x150 */
  uint32_t BLOCKNAME_SET;                          /**< Block Name Register, offset: 0x154 */
  uint32_t BLOCKNAME_CLR;                          /**< Block Name Register, offset: 0x158 */
  uint32_t BLOCKNAME_TOG;                          /**< Block Name Register, offset: 0x15C */
  uint32_t VERSION;                                /**< BCH Version Register, offset: 0x160 */
  uint32_t VERSION_SET;                            /**< BCH Version Register, offset: 0x164 */
  uint32_t VERSION_CLR;                            /**< BCH Version Register, offset: 0x168 */
  uint32_t VERSION_TOG;                            /**< BCH Version Register, offset: 0x16C */
  uint32_t DEBUG1;                                 /**< Hardware BCH ECC Debug Register 1, offset: 0x170 */
  uint32_t DEBUG1_SET;                             /**< Hardware BCH ECC Debug Register 1, offset: 0x174 */
  uint32_t DEBUG1_CLR;                             /**< Hardware BCH ECC Debug Register 1, offset: 0x178 */
  uint32_t DEBUG1_TOG;                             /**< Hardware BCH ECC Debug Register 1, offset: 0x17C */
} volatile *BCH_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- BCH - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup BCH_Register_Accessor_Macros BCH - Register accessor macros
 * @{
 */


/* BCH - Register accessors */
#define BCH_CTRL_REG(base)                       ((base)->CTRL)
#define BCH_CTRL_SET_REG(base)                   ((base)->CTRL_SET)
#define BCH_CTRL_CLR_REG(base)                   ((base)->CTRL_CLR)
#define BCH_CTRL_TOG_REG(base)                   ((base)->CTRL_TOG)
#define BCH_STATUS0_REG(base)                    ((base)->STATUS0)
#define BCH_STATUS0_SET_REG(base)                ((base)->STATUS0_SET)
#define BCH_STATUS0_CLR_REG(base)                ((base)->STATUS0_CLR)
#define BCH_STATUS0_TOG_REG(base)                ((base)->STATUS0_TOG)
#define BCH_MODE_REG(base)                       ((base)->MODE)
#define BCH_MODE_SET_REG(base)                   ((base)->MODE_SET)
#define BCH_MODE_CLR_REG(base)                   ((base)->MODE_CLR)
#define BCH_MODE_TOG_REG(base)                   ((base)->MODE_TOG)
#define BCH_ENCODEPTR_REG(base)                  ((base)->ENCODEPTR)
#define BCH_ENCODEPTR_SET_REG(base)              ((base)->ENCODEPTR_SET)
#define BCH_ENCODEPTR_CLR_REG(base)              ((base)->ENCODEPTR_CLR)
#define BCH_ENCODEPTR_TOG_REG(base)              ((base)->ENCODEPTR_TOG)
#define BCH_DATAPTR_REG(base)                    ((base)->DATAPTR)
#define BCH_DATAPTR_SET_REG(base)                ((base)->DATAPTR_SET)
#define BCH_DATAPTR_CLR_REG(base)                ((base)->DATAPTR_CLR)
#define BCH_DATAPTR_TOG_REG(base)                ((base)->DATAPTR_TOG)
#define BCH_METAPTR_REG(base)                    ((base)->METAPTR)
#define BCH_METAPTR_SET_REG(base)                ((base)->METAPTR_SET)
#define BCH_METAPTR_CLR_REG(base)                ((base)->METAPTR_CLR)
#define BCH_METAPTR_TOG_REG(base)                ((base)->METAPTR_TOG)
#define BCH_LAYOUTSELECT_REG(base)               ((base)->LAYOUTSELECT)
#define BCH_LAYOUTSELECT_SET_REG(base)           ((base)->LAYOUTSELECT_SET)
#define BCH_LAYOUTSELECT_CLR_REG(base)           ((base)->LAYOUTSELECT_CLR)
#define BCH_LAYOUTSELECT_TOG_REG(base)           ((base)->LAYOUTSELECT_TOG)
#define BCH_FLASH0LAYOUT0_REG(base)              ((base)->FLASH0LAYOUT0)
#define BCH_FLASH0LAYOUT0_SET_REG(base)          ((base)->FLASH0LAYOUT0_SET)
#define BCH_FLASH0LAYOUT0_CLR_REG(base)          ((base)->FLASH0LAYOUT0_CLR)
#define BCH_FLASH0LAYOUT0_TOG_REG(base)          ((base)->FLASH0LAYOUT0_TOG)
#define BCH_FLASH0LAYOUT1_REG(base)              ((base)->FLASH0LAYOUT1)
#define BCH_FLASH0LAYOUT1_SET_REG(base)          ((base)->FLASH0LAYOUT1_SET)
#define BCH_FLASH0LAYOUT1_CLR_REG(base)          ((base)->FLASH0LAYOUT1_CLR)
#define BCH_FLASH0LAYOUT1_TOG_REG(base)          ((base)->FLASH0LAYOUT1_TOG)
#define BCH_FLASH1LAYOUT0_REG(base)              ((base)->FLASH1LAYOUT0)
#define BCH_FLASH1LAYOUT0_SET_REG(base)          ((base)->FLASH1LAYOUT0_SET)
#define BCH_FLASH1LAYOUT0_CLR_REG(base)          ((base)->FLASH1LAYOUT0_CLR)
#define BCH_FLASH1LAYOUT0_TOG_REG(base)          ((base)->FLASH1LAYOUT0_TOG)
#define BCH_FLASH1LAYOUT1_REG(base)              ((base)->FLASH1LAYOUT1)
#define BCH_FLASH1LAYOUT1_SET_REG(base)          ((base)->FLASH1LAYOUT1_SET)
#define BCH_FLASH1LAYOUT1_CLR_REG(base)          ((base)->FLASH1LAYOUT1_CLR)
#define BCH_FLASH1LAYOUT1_TOG_REG(base)          ((base)->FLASH1LAYOUT1_TOG)
#define BCH_FLASH2LAYOUT0_REG(base)              ((base)->FLASH2LAYOUT0)
#define BCH_FLASH2LAYOUT0_SET_REG(base)          ((base)->FLASH2LAYOUT0_SET)
#define BCH_FLASH2LAYOUT0_CLR_REG(base)          ((base)->FLASH2LAYOUT0_CLR)
#define BCH_FLASH2LAYOUT0_TOG_REG(base)          ((base)->FLASH2LAYOUT0_TOG)
#define BCH_FLASH2LAYOUT1_REG(base)              ((base)->FLASH2LAYOUT1)
#define BCH_FLASH2LAYOUT1_SET_REG(base)          ((base)->FLASH2LAYOUT1_SET)
#define BCH_FLASH2LAYOUT1_CLR_REG(base)          ((base)->FLASH2LAYOUT1_CLR)
#define BCH_FLASH2LAYOUT1_TOG_REG(base)          ((base)->FLASH2LAYOUT1_TOG)
#define BCH_FLASH3LAYOUT0_REG(base)              ((base)->FLASH3LAYOUT0)
#define BCH_FLASH3LAYOUT0_SET_REG(base)          ((base)->FLASH3LAYOUT0_SET)
#define BCH_FLASH3LAYOUT0_CLR_REG(base)          ((base)->FLASH3LAYOUT0_CLR)
#define BCH_FLASH3LAYOUT0_TOG_REG(base)          ((base)->FLASH3LAYOUT0_TOG)
#define BCH_FLASH3LAYOUT1_REG(base)              ((base)->FLASH3LAYOUT1)
#define BCH_FLASH3LAYOUT1_SET_REG(base)          ((base)->FLASH3LAYOUT1_SET)
#define BCH_FLASH3LAYOUT1_CLR_REG(base)          ((base)->FLASH3LAYOUT1_CLR)
#define BCH_FLASH3LAYOUT1_TOG_REG(base)          ((base)->FLASH3LAYOUT1_TOG)
#define BCH_DEBUG0_REG(base)                     ((base)->DEBUG0)
#define BCH_DEBUG0_SET_REG(base)                 ((base)->DEBUG0_SET)
#define BCH_DEBUG0_CLR_REG(base)                 ((base)->DEBUG0_CLR)
#define BCH_DEBUG0_TOG_REG(base)                 ((base)->DEBUG0_TOG)
#define BCH_DBGKESREAD_REG(base)                 ((base)->DBGKESREAD)
#define BCH_DBGKESREAD_SET_REG(base)             ((base)->DBGKESREAD_SET)
#define BCH_DBGKESREAD_CLR_REG(base)             ((base)->DBGKESREAD_CLR)
#define BCH_DBGKESREAD_TOG_REG(base)             ((base)->DBGKESREAD_TOG)
#define BCH_DBGCSFEREAD_REG(base)                ((base)->DBGCSFEREAD)
#define BCH_DBGCSFEREAD_SET_REG(base)            ((base)->DBGCSFEREAD_SET)
#define BCH_DBGCSFEREAD_CLR_REG(base)            ((base)->DBGCSFEREAD_CLR)
#define BCH_DBGCSFEREAD_TOG_REG(base)            ((base)->DBGCSFEREAD_TOG)
#define BCH_DBGSYNDGENREAD_REG(base)             ((base)->DBGSYNDGENREAD)
#define BCH_DBGSYNDGENREAD_SET_REG(base)         ((base)->DBGSYNDGENREAD_SET)
#define BCH_DBGSYNDGENREAD_CLR_REG(base)         ((base)->DBGSYNDGENREAD_CLR)
#define BCH_DBGSYNDGENREAD_TOG_REG(base)         ((base)->DBGSYNDGENREAD_TOG)
#define BCH_DBGAHBMREAD_REG(base)                ((base)->DBGAHBMREAD)
#define BCH_DBGAHBMREAD_SET_REG(base)            ((base)->DBGAHBMREAD_SET)
#define BCH_DBGAHBMREAD_CLR_REG(base)            ((base)->DBGAHBMREAD_CLR)
#define BCH_DBGAHBMREAD_TOG_REG(base)            ((base)->DBGAHBMREAD_TOG)
#define BCH_BLOCKNAME_REG(base)                  ((base)->BLOCKNAME)
#define BCH_BLOCKNAME_SET_REG(base)              ((base)->BLOCKNAME_SET)
#define BCH_BLOCKNAME_CLR_REG(base)              ((base)->BLOCKNAME_CLR)
#define BCH_BLOCKNAME_TOG_REG(base)              ((base)->BLOCKNAME_TOG)
#define BCH_VERSION_REG(base)                    ((base)->VERSION)
#define BCH_VERSION_SET_REG(base)                ((base)->VERSION_SET)
#define BCH_VERSION_CLR_REG(base)                ((base)->VERSION_CLR)
#define BCH_VERSION_TOG_REG(base)                ((base)->VERSION_TOG)
#define BCH_DEBUG1_REG(base)                     ((base)->DEBUG1)
#define BCH_DEBUG1_SET_REG(base)                 ((base)->DEBUG1_SET)
#define BCH_DEBUG1_CLR_REG(base)                 ((base)->DEBUG1_CLR)
#define BCH_DEBUG1_TOG_REG(base)                 ((base)->DEBUG1_TOG)

/*!
 * @}
 */ /* end of group BCH_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- BCH Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup BCH_Register_Masks BCH Register Masks
 * @{
 */

/*! @name CTRL - Hardware BCH ECC Accelerator Control Register */
#define BCH_CTRL_COMPLETE_IRQ_MASK               (0x1U)
#define BCH_CTRL_COMPLETE_IRQ_SHIFT              (0U)
#define BCH_CTRL_RSVD0_MASK                      (0x2U)
#define BCH_CTRL_RSVD0_SHIFT                     (1U)
#define BCH_CTRL_DEBUG_STALL_IRQ_MASK            (0x4U)
#define BCH_CTRL_DEBUG_STALL_IRQ_SHIFT           (2U)
#define BCH_CTRL_BM_ERROR_IRQ_MASK               (0x8U)
#define BCH_CTRL_BM_ERROR_IRQ_SHIFT              (3U)
#define BCH_CTRL_RSVD1_MASK                      (0xF0U)
#define BCH_CTRL_RSVD1_SHIFT                     (4U)
#define BCH_CTRL_RSVD1(x)                        (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_RSVD1_SHIFT)) & BCH_CTRL_RSVD1_MASK)
#define BCH_CTRL_COMPLETE_IRQ_EN_MASK            (0x100U)
#define BCH_CTRL_COMPLETE_IRQ_EN_SHIFT           (8U)
#define BCH_CTRL_RSVD2_MASK                      (0x200U)
#define BCH_CTRL_RSVD2_SHIFT                     (9U)
#define BCH_CTRL_DEBUG_STALL_IRQ_EN_MASK         (0x400U)
#define BCH_CTRL_DEBUG_STALL_IRQ_EN_SHIFT        (10U)
#define BCH_CTRL_RSVD3_MASK                      (0xF800U)
#define BCH_CTRL_RSVD3_SHIFT                     (11U)
#define BCH_CTRL_RSVD3(x)                        (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_RSVD3_SHIFT)) & BCH_CTRL_RSVD3_MASK)
#define BCH_CTRL_M2M_ENABLE_MASK                 (0x10000U)
#define BCH_CTRL_M2M_ENABLE_SHIFT                (16U)
#define BCH_CTRL_M2M_ENCODE_MASK                 (0x20000U)
#define BCH_CTRL_M2M_ENCODE_SHIFT                (17U)
#define BCH_CTRL_M2M_LAYOUT_MASK                 (0xC0000U)
#define BCH_CTRL_M2M_LAYOUT_SHIFT                (18U)
#define BCH_CTRL_M2M_LAYOUT(x)                   (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_M2M_LAYOUT_SHIFT)) & BCH_CTRL_M2M_LAYOUT_MASK)
#define BCH_CTRL_RSVD4_MASK                      (0x300000U)
#define BCH_CTRL_RSVD4_SHIFT                     (20U)
#define BCH_CTRL_RSVD4(x)                        (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_RSVD4_SHIFT)) & BCH_CTRL_RSVD4_MASK)
#define BCH_CTRL_DEBUGSYNDROME_MASK              (0x400000U)
#define BCH_CTRL_DEBUGSYNDROME_SHIFT             (22U)
#define BCH_CTRL_RSVD5_MASK                      (0x3F800000U)
#define BCH_CTRL_RSVD5_SHIFT                     (23U)
#define BCH_CTRL_RSVD5(x)                        (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_RSVD5_SHIFT)) & BCH_CTRL_RSVD5_MASK)
#define BCH_CTRL_CLKGATE_MASK                    (0x40000000U)
#define BCH_CTRL_CLKGATE_SHIFT                   (30U)
#define BCH_CTRL_SFTRST_MASK                     (0x80000000U)
#define BCH_CTRL_SFTRST_SHIFT                    (31U)

/*! @name CTRL_SET - Hardware BCH ECC Accelerator Control Register */
#define BCH_CTRL_SET_COMPLETE_IRQ_MASK           (0x1U)
#define BCH_CTRL_SET_COMPLETE_IRQ_SHIFT          (0U)
#define BCH_CTRL_SET_RSVD0_MASK                  (0x2U)
#define BCH_CTRL_SET_RSVD0_SHIFT                 (1U)
#define BCH_CTRL_SET_DEBUG_STALL_IRQ_MASK        (0x4U)
#define BCH_CTRL_SET_DEBUG_STALL_IRQ_SHIFT       (2U)
#define BCH_CTRL_SET_BM_ERROR_IRQ_MASK           (0x8U)
#define BCH_CTRL_SET_BM_ERROR_IRQ_SHIFT          (3U)
#define BCH_CTRL_SET_RSVD1_MASK                  (0xF0U)
#define BCH_CTRL_SET_RSVD1_SHIFT                 (4U)
#define BCH_CTRL_SET_RSVD1(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_SET_RSVD1_SHIFT)) & BCH_CTRL_SET_RSVD1_MASK)
#define BCH_CTRL_SET_COMPLETE_IRQ_EN_MASK        (0x100U)
#define BCH_CTRL_SET_COMPLETE_IRQ_EN_SHIFT       (8U)
#define BCH_CTRL_SET_RSVD2_MASK                  (0x200U)
#define BCH_CTRL_SET_RSVD2_SHIFT                 (9U)
#define BCH_CTRL_SET_DEBUG_STALL_IRQ_EN_MASK     (0x400U)
#define BCH_CTRL_SET_DEBUG_STALL_IRQ_EN_SHIFT    (10U)
#define BCH_CTRL_SET_RSVD3_MASK                  (0xF800U)
#define BCH_CTRL_SET_RSVD3_SHIFT                 (11U)
#define BCH_CTRL_SET_RSVD3(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_SET_RSVD3_SHIFT)) & BCH_CTRL_SET_RSVD3_MASK)
#define BCH_CTRL_SET_M2M_ENABLE_MASK             (0x10000U)
#define BCH_CTRL_SET_M2M_ENABLE_SHIFT            (16U)
#define BCH_CTRL_SET_M2M_ENCODE_MASK             (0x20000U)
#define BCH_CTRL_SET_M2M_ENCODE_SHIFT            (17U)
#define BCH_CTRL_SET_M2M_LAYOUT_MASK             (0xC0000U)
#define BCH_CTRL_SET_M2M_LAYOUT_SHIFT            (18U)
#define BCH_CTRL_SET_M2M_LAYOUT(x)               (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_SET_M2M_LAYOUT_SHIFT)) & BCH_CTRL_SET_M2M_LAYOUT_MASK)
#define BCH_CTRL_SET_RSVD4_MASK                  (0x300000U)
#define BCH_CTRL_SET_RSVD4_SHIFT                 (20U)
#define BCH_CTRL_SET_RSVD4(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_SET_RSVD4_SHIFT)) & BCH_CTRL_SET_RSVD4_MASK)
#define BCH_CTRL_SET_DEBUGSYNDROME_MASK          (0x400000U)
#define BCH_CTRL_SET_DEBUGSYNDROME_SHIFT         (22U)
#define BCH_CTRL_SET_RSVD5_MASK                  (0x3F800000U)
#define BCH_CTRL_SET_RSVD5_SHIFT                 (23U)
#define BCH_CTRL_SET_RSVD5(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_SET_RSVD5_SHIFT)) & BCH_CTRL_SET_RSVD5_MASK)
#define BCH_CTRL_SET_CLKGATE_MASK                (0x40000000U)
#define BCH_CTRL_SET_CLKGATE_SHIFT               (30U)
#define BCH_CTRL_SET_SFTRST_MASK                 (0x80000000U)
#define BCH_CTRL_SET_SFTRST_SHIFT                (31U)

/*! @name CTRL_CLR - Hardware BCH ECC Accelerator Control Register */
#define BCH_CTRL_CLR_COMPLETE_IRQ_MASK           (0x1U)
#define BCH_CTRL_CLR_COMPLETE_IRQ_SHIFT          (0U)
#define BCH_CTRL_CLR_RSVD0_MASK                  (0x2U)
#define BCH_CTRL_CLR_RSVD0_SHIFT                 (1U)
#define BCH_CTRL_CLR_DEBUG_STALL_IRQ_MASK        (0x4U)
#define BCH_CTRL_CLR_DEBUG_STALL_IRQ_SHIFT       (2U)
#define BCH_CTRL_CLR_BM_ERROR_IRQ_MASK           (0x8U)
#define BCH_CTRL_CLR_BM_ERROR_IRQ_SHIFT          (3U)
#define BCH_CTRL_CLR_RSVD1_MASK                  (0xF0U)
#define BCH_CTRL_CLR_RSVD1_SHIFT                 (4U)
#define BCH_CTRL_CLR_RSVD1(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_CLR_RSVD1_SHIFT)) & BCH_CTRL_CLR_RSVD1_MASK)
#define BCH_CTRL_CLR_COMPLETE_IRQ_EN_MASK        (0x100U)
#define BCH_CTRL_CLR_COMPLETE_IRQ_EN_SHIFT       (8U)
#define BCH_CTRL_CLR_RSVD2_MASK                  (0x200U)
#define BCH_CTRL_CLR_RSVD2_SHIFT                 (9U)
#define BCH_CTRL_CLR_DEBUG_STALL_IRQ_EN_MASK     (0x400U)
#define BCH_CTRL_CLR_DEBUG_STALL_IRQ_EN_SHIFT    (10U)
#define BCH_CTRL_CLR_RSVD3_MASK                  (0xF800U)
#define BCH_CTRL_CLR_RSVD3_SHIFT                 (11U)
#define BCH_CTRL_CLR_RSVD3(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_CLR_RSVD3_SHIFT)) & BCH_CTRL_CLR_RSVD3_MASK)
#define BCH_CTRL_CLR_M2M_ENABLE_MASK             (0x10000U)
#define BCH_CTRL_CLR_M2M_ENABLE_SHIFT            (16U)
#define BCH_CTRL_CLR_M2M_ENCODE_MASK             (0x20000U)
#define BCH_CTRL_CLR_M2M_ENCODE_SHIFT            (17U)
#define BCH_CTRL_CLR_M2M_LAYOUT_MASK             (0xC0000U)
#define BCH_CTRL_CLR_M2M_LAYOUT_SHIFT            (18U)
#define BCH_CTRL_CLR_M2M_LAYOUT(x)               (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_CLR_M2M_LAYOUT_SHIFT)) & BCH_CTRL_CLR_M2M_LAYOUT_MASK)
#define BCH_CTRL_CLR_RSVD4_MASK                  (0x300000U)
#define BCH_CTRL_CLR_RSVD4_SHIFT                 (20U)
#define BCH_CTRL_CLR_RSVD4(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_CLR_RSVD4_SHIFT)) & BCH_CTRL_CLR_RSVD4_MASK)
#define BCH_CTRL_CLR_DEBUGSYNDROME_MASK          (0x400000U)
#define BCH_CTRL_CLR_DEBUGSYNDROME_SHIFT         (22U)
#define BCH_CTRL_CLR_RSVD5_MASK                  (0x3F800000U)
#define BCH_CTRL_CLR_RSVD5_SHIFT                 (23U)
#define BCH_CTRL_CLR_RSVD5(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_CLR_RSVD5_SHIFT)) & BCH_CTRL_CLR_RSVD5_MASK)
#define BCH_CTRL_CLR_CLKGATE_MASK                (0x40000000U)
#define BCH_CTRL_CLR_CLKGATE_SHIFT               (30U)
#define BCH_CTRL_CLR_SFTRST_MASK                 (0x80000000U)
#define BCH_CTRL_CLR_SFTRST_SHIFT                (31U)

/*! @name CTRL_TOG - Hardware BCH ECC Accelerator Control Register */
#define BCH_CTRL_TOG_COMPLETE_IRQ_MASK           (0x1U)
#define BCH_CTRL_TOG_COMPLETE_IRQ_SHIFT          (0U)
#define BCH_CTRL_TOG_RSVD0_MASK                  (0x2U)
#define BCH_CTRL_TOG_RSVD0_SHIFT                 (1U)
#define BCH_CTRL_TOG_DEBUG_STALL_IRQ_MASK        (0x4U)
#define BCH_CTRL_TOG_DEBUG_STALL_IRQ_SHIFT       (2U)
#define BCH_CTRL_TOG_BM_ERROR_IRQ_MASK           (0x8U)
#define BCH_CTRL_TOG_BM_ERROR_IRQ_SHIFT          (3U)
#define BCH_CTRL_TOG_RSVD1_MASK                  (0xF0U)
#define BCH_CTRL_TOG_RSVD1_SHIFT                 (4U)
#define BCH_CTRL_TOG_RSVD1(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_TOG_RSVD1_SHIFT)) & BCH_CTRL_TOG_RSVD1_MASK)
#define BCH_CTRL_TOG_COMPLETE_IRQ_EN_MASK        (0x100U)
#define BCH_CTRL_TOG_COMPLETE_IRQ_EN_SHIFT       (8U)
#define BCH_CTRL_TOG_RSVD2_MASK                  (0x200U)
#define BCH_CTRL_TOG_RSVD2_SHIFT                 (9U)
#define BCH_CTRL_TOG_DEBUG_STALL_IRQ_EN_MASK     (0x400U)
#define BCH_CTRL_TOG_DEBUG_STALL_IRQ_EN_SHIFT    (10U)
#define BCH_CTRL_TOG_RSVD3_MASK                  (0xF800U)
#define BCH_CTRL_TOG_RSVD3_SHIFT                 (11U)
#define BCH_CTRL_TOG_RSVD3(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_TOG_RSVD3_SHIFT)) & BCH_CTRL_TOG_RSVD3_MASK)
#define BCH_CTRL_TOG_M2M_ENABLE_MASK             (0x10000U)
#define BCH_CTRL_TOG_M2M_ENABLE_SHIFT            (16U)
#define BCH_CTRL_TOG_M2M_ENCODE_MASK             (0x20000U)
#define BCH_CTRL_TOG_M2M_ENCODE_SHIFT            (17U)
#define BCH_CTRL_TOG_M2M_LAYOUT_MASK             (0xC0000U)
#define BCH_CTRL_TOG_M2M_LAYOUT_SHIFT            (18U)
#define BCH_CTRL_TOG_M2M_LAYOUT(x)               (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_TOG_M2M_LAYOUT_SHIFT)) & BCH_CTRL_TOG_M2M_LAYOUT_MASK)
#define BCH_CTRL_TOG_RSVD4_MASK                  (0x300000U)
#define BCH_CTRL_TOG_RSVD4_SHIFT                 (20U)
#define BCH_CTRL_TOG_RSVD4(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_TOG_RSVD4_SHIFT)) & BCH_CTRL_TOG_RSVD4_MASK)
#define BCH_CTRL_TOG_DEBUGSYNDROME_MASK          (0x400000U)
#define BCH_CTRL_TOG_DEBUGSYNDROME_SHIFT         (22U)
#define BCH_CTRL_TOG_RSVD5_MASK                  (0x3F800000U)
#define BCH_CTRL_TOG_RSVD5_SHIFT                 (23U)
#define BCH_CTRL_TOG_RSVD5(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_CTRL_TOG_RSVD5_SHIFT)) & BCH_CTRL_TOG_RSVD5_MASK)
#define BCH_CTRL_TOG_CLKGATE_MASK                (0x40000000U)
#define BCH_CTRL_TOG_CLKGATE_SHIFT               (30U)
#define BCH_CTRL_TOG_SFTRST_MASK                 (0x80000000U)
#define BCH_CTRL_TOG_SFTRST_SHIFT                (31U)

/*! @name STATUS0 - Hardware ECC Accelerator Status Register 0 */
#define BCH_STATUS0_RSVD0_MASK                   (0x3U)
#define BCH_STATUS0_RSVD0_SHIFT                  (0U)
#define BCH_STATUS0_RSVD0(x)                     (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_RSVD0_SHIFT)) & BCH_STATUS0_RSVD0_MASK)
#define BCH_STATUS0_UNCORRECTABLE_MASK           (0x4U)
#define BCH_STATUS0_UNCORRECTABLE_SHIFT          (2U)
#define BCH_STATUS0_CORRECTED_MASK               (0x8U)
#define BCH_STATUS0_CORRECTED_SHIFT              (3U)
#define BCH_STATUS0_ALLONES_MASK                 (0x10U)
#define BCH_STATUS0_ALLONES_SHIFT                (4U)
#define BCH_STATUS0_RSVD1_MASK                   (0xE0U)
#define BCH_STATUS0_RSVD1_SHIFT                  (5U)
#define BCH_STATUS0_RSVD1(x)                     (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_RSVD1_SHIFT)) & BCH_STATUS0_RSVD1_MASK)
#define BCH_STATUS0_STATUS_BLK0_MASK             (0xFF00U)
#define BCH_STATUS0_STATUS_BLK0_SHIFT            (8U)
#define BCH_STATUS0_STATUS_BLK0(x)               (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_STATUS_BLK0_SHIFT)) & BCH_STATUS0_STATUS_BLK0_MASK)
#define BCH_STATUS0_COMPLETED_CE_MASK            (0xF0000U)
#define BCH_STATUS0_COMPLETED_CE_SHIFT           (16U)
#define BCH_STATUS0_COMPLETED_CE(x)              (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_COMPLETED_CE_SHIFT)) & BCH_STATUS0_COMPLETED_CE_MASK)
#define BCH_STATUS0_HANDLE_MASK                  (0xFFF00000U)
#define BCH_STATUS0_HANDLE_SHIFT                 (20U)
#define BCH_STATUS0_HANDLE(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_HANDLE_SHIFT)) & BCH_STATUS0_HANDLE_MASK)

/*! @name STATUS0_SET - Hardware ECC Accelerator Status Register 0 */
#define BCH_STATUS0_SET_RSVD0_MASK               (0x3U)
#define BCH_STATUS0_SET_RSVD0_SHIFT              (0U)
#define BCH_STATUS0_SET_RSVD0(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_SET_RSVD0_SHIFT)) & BCH_STATUS0_SET_RSVD0_MASK)
#define BCH_STATUS0_SET_UNCORRECTABLE_MASK       (0x4U)
#define BCH_STATUS0_SET_UNCORRECTABLE_SHIFT      (2U)
#define BCH_STATUS0_SET_CORRECTED_MASK           (0x8U)
#define BCH_STATUS0_SET_CORRECTED_SHIFT          (3U)
#define BCH_STATUS0_SET_ALLONES_MASK             (0x10U)
#define BCH_STATUS0_SET_ALLONES_SHIFT            (4U)
#define BCH_STATUS0_SET_RSVD1_MASK               (0xE0U)
#define BCH_STATUS0_SET_RSVD1_SHIFT              (5U)
#define BCH_STATUS0_SET_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_SET_RSVD1_SHIFT)) & BCH_STATUS0_SET_RSVD1_MASK)
#define BCH_STATUS0_SET_STATUS_BLK0_MASK         (0xFF00U)
#define BCH_STATUS0_SET_STATUS_BLK0_SHIFT        (8U)
#define BCH_STATUS0_SET_STATUS_BLK0(x)           (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_SET_STATUS_BLK0_SHIFT)) & BCH_STATUS0_SET_STATUS_BLK0_MASK)
#define BCH_STATUS0_SET_COMPLETED_CE_MASK        (0xF0000U)
#define BCH_STATUS0_SET_COMPLETED_CE_SHIFT       (16U)
#define BCH_STATUS0_SET_COMPLETED_CE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_SET_COMPLETED_CE_SHIFT)) & BCH_STATUS0_SET_COMPLETED_CE_MASK)
#define BCH_STATUS0_SET_HANDLE_MASK              (0xFFF00000U)
#define BCH_STATUS0_SET_HANDLE_SHIFT             (20U)
#define BCH_STATUS0_SET_HANDLE(x)                (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_SET_HANDLE_SHIFT)) & BCH_STATUS0_SET_HANDLE_MASK)

/*! @name STATUS0_CLR - Hardware ECC Accelerator Status Register 0 */
#define BCH_STATUS0_CLR_RSVD0_MASK               (0x3U)
#define BCH_STATUS0_CLR_RSVD0_SHIFT              (0U)
#define BCH_STATUS0_CLR_RSVD0(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_CLR_RSVD0_SHIFT)) & BCH_STATUS0_CLR_RSVD0_MASK)
#define BCH_STATUS0_CLR_UNCORRECTABLE_MASK       (0x4U)
#define BCH_STATUS0_CLR_UNCORRECTABLE_SHIFT      (2U)
#define BCH_STATUS0_CLR_CORRECTED_MASK           (0x8U)
#define BCH_STATUS0_CLR_CORRECTED_SHIFT          (3U)
#define BCH_STATUS0_CLR_ALLONES_MASK             (0x10U)
#define BCH_STATUS0_CLR_ALLONES_SHIFT            (4U)
#define BCH_STATUS0_CLR_RSVD1_MASK               (0xE0U)
#define BCH_STATUS0_CLR_RSVD1_SHIFT              (5U)
#define BCH_STATUS0_CLR_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_CLR_RSVD1_SHIFT)) & BCH_STATUS0_CLR_RSVD1_MASK)
#define BCH_STATUS0_CLR_STATUS_BLK0_MASK         (0xFF00U)
#define BCH_STATUS0_CLR_STATUS_BLK0_SHIFT        (8U)
#define BCH_STATUS0_CLR_STATUS_BLK0(x)           (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_CLR_STATUS_BLK0_SHIFT)) & BCH_STATUS0_CLR_STATUS_BLK0_MASK)
#define BCH_STATUS0_CLR_COMPLETED_CE_MASK        (0xF0000U)
#define BCH_STATUS0_CLR_COMPLETED_CE_SHIFT       (16U)
#define BCH_STATUS0_CLR_COMPLETED_CE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_CLR_COMPLETED_CE_SHIFT)) & BCH_STATUS0_CLR_COMPLETED_CE_MASK)
#define BCH_STATUS0_CLR_HANDLE_MASK              (0xFFF00000U)
#define BCH_STATUS0_CLR_HANDLE_SHIFT             (20U)
#define BCH_STATUS0_CLR_HANDLE(x)                (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_CLR_HANDLE_SHIFT)) & BCH_STATUS0_CLR_HANDLE_MASK)

/*! @name STATUS0_TOG - Hardware ECC Accelerator Status Register 0 */
#define BCH_STATUS0_TOG_RSVD0_MASK               (0x3U)
#define BCH_STATUS0_TOG_RSVD0_SHIFT              (0U)
#define BCH_STATUS0_TOG_RSVD0(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_TOG_RSVD0_SHIFT)) & BCH_STATUS0_TOG_RSVD0_MASK)
#define BCH_STATUS0_TOG_UNCORRECTABLE_MASK       (0x4U)
#define BCH_STATUS0_TOG_UNCORRECTABLE_SHIFT      (2U)
#define BCH_STATUS0_TOG_CORRECTED_MASK           (0x8U)
#define BCH_STATUS0_TOG_CORRECTED_SHIFT          (3U)
#define BCH_STATUS0_TOG_ALLONES_MASK             (0x10U)
#define BCH_STATUS0_TOG_ALLONES_SHIFT            (4U)
#define BCH_STATUS0_TOG_RSVD1_MASK               (0xE0U)
#define BCH_STATUS0_TOG_RSVD1_SHIFT              (5U)
#define BCH_STATUS0_TOG_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_TOG_RSVD1_SHIFT)) & BCH_STATUS0_TOG_RSVD1_MASK)
#define BCH_STATUS0_TOG_STATUS_BLK0_MASK         (0xFF00U)
#define BCH_STATUS0_TOG_STATUS_BLK0_SHIFT        (8U)
#define BCH_STATUS0_TOG_STATUS_BLK0(x)           (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_TOG_STATUS_BLK0_SHIFT)) & BCH_STATUS0_TOG_STATUS_BLK0_MASK)
#define BCH_STATUS0_TOG_COMPLETED_CE_MASK        (0xF0000U)
#define BCH_STATUS0_TOG_COMPLETED_CE_SHIFT       (16U)
#define BCH_STATUS0_TOG_COMPLETED_CE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_TOG_COMPLETED_CE_SHIFT)) & BCH_STATUS0_TOG_COMPLETED_CE_MASK)
#define BCH_STATUS0_TOG_HANDLE_MASK              (0xFFF00000U)
#define BCH_STATUS0_TOG_HANDLE_SHIFT             (20U)
#define BCH_STATUS0_TOG_HANDLE(x)                (((uint32_t)(((uint32_t)(x)) << BCH_STATUS0_TOG_HANDLE_SHIFT)) & BCH_STATUS0_TOG_HANDLE_MASK)

/*! @name MODE - Hardware ECC Accelerator Mode Register */
#define BCH_MODE_ERASE_THRESHOLD_MASK            (0xFFU)
#define BCH_MODE_ERASE_THRESHOLD_SHIFT           (0U)
#define BCH_MODE_ERASE_THRESHOLD(x)              (((uint32_t)(((uint32_t)(x)) << BCH_MODE_ERASE_THRESHOLD_SHIFT)) & BCH_MODE_ERASE_THRESHOLD_MASK)
#define BCH_MODE_RSVD_MASK                       (0xFFFFFF00U)
#define BCH_MODE_RSVD_SHIFT                      (8U)
#define BCH_MODE_RSVD(x)                         (((uint32_t)(((uint32_t)(x)) << BCH_MODE_RSVD_SHIFT)) & BCH_MODE_RSVD_MASK)

/*! @name MODE_SET - Hardware ECC Accelerator Mode Register */
#define BCH_MODE_SET_ERASE_THRESHOLD_MASK        (0xFFU)
#define BCH_MODE_SET_ERASE_THRESHOLD_SHIFT       (0U)
#define BCH_MODE_SET_ERASE_THRESHOLD(x)          (((uint32_t)(((uint32_t)(x)) << BCH_MODE_SET_ERASE_THRESHOLD_SHIFT)) & BCH_MODE_SET_ERASE_THRESHOLD_MASK)
#define BCH_MODE_SET_RSVD_MASK                   (0xFFFFFF00U)
#define BCH_MODE_SET_RSVD_SHIFT                  (8U)
#define BCH_MODE_SET_RSVD(x)                     (((uint32_t)(((uint32_t)(x)) << BCH_MODE_SET_RSVD_SHIFT)) & BCH_MODE_SET_RSVD_MASK)

/*! @name MODE_CLR - Hardware ECC Accelerator Mode Register */
#define BCH_MODE_CLR_ERASE_THRESHOLD_MASK        (0xFFU)
#define BCH_MODE_CLR_ERASE_THRESHOLD_SHIFT       (0U)
#define BCH_MODE_CLR_ERASE_THRESHOLD(x)          (((uint32_t)(((uint32_t)(x)) << BCH_MODE_CLR_ERASE_THRESHOLD_SHIFT)) & BCH_MODE_CLR_ERASE_THRESHOLD_MASK)
#define BCH_MODE_CLR_RSVD_MASK                   (0xFFFFFF00U)
#define BCH_MODE_CLR_RSVD_SHIFT                  (8U)
#define BCH_MODE_CLR_RSVD(x)                     (((uint32_t)(((uint32_t)(x)) << BCH_MODE_CLR_RSVD_SHIFT)) & BCH_MODE_CLR_RSVD_MASK)

/*! @name MODE_TOG - Hardware ECC Accelerator Mode Register */
#define BCH_MODE_TOG_ERASE_THRESHOLD_MASK        (0xFFU)
#define BCH_MODE_TOG_ERASE_THRESHOLD_SHIFT       (0U)
#define BCH_MODE_TOG_ERASE_THRESHOLD(x)          (((uint32_t)(((uint32_t)(x)) << BCH_MODE_TOG_ERASE_THRESHOLD_SHIFT)) & BCH_MODE_TOG_ERASE_THRESHOLD_MASK)
#define BCH_MODE_TOG_RSVD_MASK                   (0xFFFFFF00U)
#define BCH_MODE_TOG_RSVD_SHIFT                  (8U)
#define BCH_MODE_TOG_RSVD(x)                     (((uint32_t)(((uint32_t)(x)) << BCH_MODE_TOG_RSVD_SHIFT)) & BCH_MODE_TOG_RSVD_MASK)

/*! @name ENCODEPTR - Hardware BCH ECC Loopback Encode Buffer Register */
#define BCH_ENCODEPTR_ADDR_MASK                  (0xFFFFFFFFU)
#define BCH_ENCODEPTR_ADDR_SHIFT                 (0U)
#define BCH_ENCODEPTR_ADDR(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_ENCODEPTR_ADDR_SHIFT)) & BCH_ENCODEPTR_ADDR_MASK)

/*! @name ENCODEPTR_SET - Hardware BCH ECC Loopback Encode Buffer Register */
#define BCH_ENCODEPTR_SET_ADDR_MASK              (0xFFFFFFFFU)
#define BCH_ENCODEPTR_SET_ADDR_SHIFT             (0U)
#define BCH_ENCODEPTR_SET_ADDR(x)                (((uint32_t)(((uint32_t)(x)) << BCH_ENCODEPTR_SET_ADDR_SHIFT)) & BCH_ENCODEPTR_SET_ADDR_MASK)

/*! @name ENCODEPTR_CLR - Hardware BCH ECC Loopback Encode Buffer Register */
#define BCH_ENCODEPTR_CLR_ADDR_MASK              (0xFFFFFFFFU)
#define BCH_ENCODEPTR_CLR_ADDR_SHIFT             (0U)
#define BCH_ENCODEPTR_CLR_ADDR(x)                (((uint32_t)(((uint32_t)(x)) << BCH_ENCODEPTR_CLR_ADDR_SHIFT)) & BCH_ENCODEPTR_CLR_ADDR_MASK)

/*! @name ENCODEPTR_TOG - Hardware BCH ECC Loopback Encode Buffer Register */
#define BCH_ENCODEPTR_TOG_ADDR_MASK              (0xFFFFFFFFU)
#define BCH_ENCODEPTR_TOG_ADDR_SHIFT             (0U)
#define BCH_ENCODEPTR_TOG_ADDR(x)                (((uint32_t)(((uint32_t)(x)) << BCH_ENCODEPTR_TOG_ADDR_SHIFT)) & BCH_ENCODEPTR_TOG_ADDR_MASK)

/*! @name DATAPTR - Hardware BCH ECC Loopback Data Buffer Register */
#define BCH_DATAPTR_ADDR_MASK                    (0xFFFFFFFFU)
#define BCH_DATAPTR_ADDR_SHIFT                   (0U)
#define BCH_DATAPTR_ADDR(x)                      (((uint32_t)(((uint32_t)(x)) << BCH_DATAPTR_ADDR_SHIFT)) & BCH_DATAPTR_ADDR_MASK)

/*! @name DATAPTR_SET - Hardware BCH ECC Loopback Data Buffer Register */
#define BCH_DATAPTR_SET_ADDR_MASK                (0xFFFFFFFFU)
#define BCH_DATAPTR_SET_ADDR_SHIFT               (0U)
#define BCH_DATAPTR_SET_ADDR(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DATAPTR_SET_ADDR_SHIFT)) & BCH_DATAPTR_SET_ADDR_MASK)

/*! @name DATAPTR_CLR - Hardware BCH ECC Loopback Data Buffer Register */
#define BCH_DATAPTR_CLR_ADDR_MASK                (0xFFFFFFFFU)
#define BCH_DATAPTR_CLR_ADDR_SHIFT               (0U)
#define BCH_DATAPTR_CLR_ADDR(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DATAPTR_CLR_ADDR_SHIFT)) & BCH_DATAPTR_CLR_ADDR_MASK)

/*! @name DATAPTR_TOG - Hardware BCH ECC Loopback Data Buffer Register */
#define BCH_DATAPTR_TOG_ADDR_MASK                (0xFFFFFFFFU)
#define BCH_DATAPTR_TOG_ADDR_SHIFT               (0U)
#define BCH_DATAPTR_TOG_ADDR(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DATAPTR_TOG_ADDR_SHIFT)) & BCH_DATAPTR_TOG_ADDR_MASK)

/*! @name METAPTR - Hardware BCH ECC Loopback Metadata Buffer Register */
#define BCH_METAPTR_ADDR_MASK                    (0xFFFFFFFFU)
#define BCH_METAPTR_ADDR_SHIFT                   (0U)
#define BCH_METAPTR_ADDR(x)                      (((uint32_t)(((uint32_t)(x)) << BCH_METAPTR_ADDR_SHIFT)) & BCH_METAPTR_ADDR_MASK)

/*! @name METAPTR_SET - Hardware BCH ECC Loopback Metadata Buffer Register */
#define BCH_METAPTR_SET_ADDR_MASK                (0xFFFFFFFFU)
#define BCH_METAPTR_SET_ADDR_SHIFT               (0U)
#define BCH_METAPTR_SET_ADDR(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_METAPTR_SET_ADDR_SHIFT)) & BCH_METAPTR_SET_ADDR_MASK)

/*! @name METAPTR_CLR - Hardware BCH ECC Loopback Metadata Buffer Register */
#define BCH_METAPTR_CLR_ADDR_MASK                (0xFFFFFFFFU)
#define BCH_METAPTR_CLR_ADDR_SHIFT               (0U)
#define BCH_METAPTR_CLR_ADDR(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_METAPTR_CLR_ADDR_SHIFT)) & BCH_METAPTR_CLR_ADDR_MASK)

/*! @name METAPTR_TOG - Hardware BCH ECC Loopback Metadata Buffer Register */
#define BCH_METAPTR_TOG_ADDR_MASK                (0xFFFFFFFFU)
#define BCH_METAPTR_TOG_ADDR_SHIFT               (0U)
#define BCH_METAPTR_TOG_ADDR(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_METAPTR_TOG_ADDR_SHIFT)) & BCH_METAPTR_TOG_ADDR_MASK)

/*! @name LAYOUTSELECT - Hardware ECC Accelerator Layout Select Register */
#define BCH_LAYOUTSELECT_CS0_SELECT_MASK         (0x3U)
#define BCH_LAYOUTSELECT_CS0_SELECT_SHIFT        (0U)
#define BCH_LAYOUTSELECT_CS0_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS0_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS0_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS1_SELECT_MASK         (0xCU)
#define BCH_LAYOUTSELECT_CS1_SELECT_SHIFT        (2U)
#define BCH_LAYOUTSELECT_CS1_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS1_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS1_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS2_SELECT_MASK         (0x30U)
#define BCH_LAYOUTSELECT_CS2_SELECT_SHIFT        (4U)
#define BCH_LAYOUTSELECT_CS2_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS2_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS2_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS3_SELECT_MASK         (0xC0U)
#define BCH_LAYOUTSELECT_CS3_SELECT_SHIFT        (6U)
#define BCH_LAYOUTSELECT_CS3_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS3_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS3_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS4_SELECT_MASK         (0x300U)
#define BCH_LAYOUTSELECT_CS4_SELECT_SHIFT        (8U)
#define BCH_LAYOUTSELECT_CS4_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS4_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS4_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS5_SELECT_MASK         (0xC00U)
#define BCH_LAYOUTSELECT_CS5_SELECT_SHIFT        (10U)
#define BCH_LAYOUTSELECT_CS5_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS5_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS5_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS6_SELECT_MASK         (0x3000U)
#define BCH_LAYOUTSELECT_CS6_SELECT_SHIFT        (12U)
#define BCH_LAYOUTSELECT_CS6_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS6_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS6_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS7_SELECT_MASK         (0xC000U)
#define BCH_LAYOUTSELECT_CS7_SELECT_SHIFT        (14U)
#define BCH_LAYOUTSELECT_CS7_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS7_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS7_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS8_SELECT_MASK         (0x30000U)
#define BCH_LAYOUTSELECT_CS8_SELECT_SHIFT        (16U)
#define BCH_LAYOUTSELECT_CS8_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS8_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS8_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS9_SELECT_MASK         (0xC0000U)
#define BCH_LAYOUTSELECT_CS9_SELECT_SHIFT        (18U)
#define BCH_LAYOUTSELECT_CS9_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS9_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS9_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS10_SELECT_MASK        (0x300000U)
#define BCH_LAYOUTSELECT_CS10_SELECT_SHIFT       (20U)
#define BCH_LAYOUTSELECT_CS10_SELECT(x)          (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS10_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS10_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS11_SELECT_MASK        (0xC00000U)
#define BCH_LAYOUTSELECT_CS11_SELECT_SHIFT       (22U)
#define BCH_LAYOUTSELECT_CS11_SELECT(x)          (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS11_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS11_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS12_SELECT_MASK        (0x3000000U)
#define BCH_LAYOUTSELECT_CS12_SELECT_SHIFT       (24U)
#define BCH_LAYOUTSELECT_CS12_SELECT(x)          (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS12_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS12_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS13_SELECT_MASK        (0xC000000U)
#define BCH_LAYOUTSELECT_CS13_SELECT_SHIFT       (26U)
#define BCH_LAYOUTSELECT_CS13_SELECT(x)          (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS13_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS13_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS14_SELECT_MASK        (0x30000000U)
#define BCH_LAYOUTSELECT_CS14_SELECT_SHIFT       (28U)
#define BCH_LAYOUTSELECT_CS14_SELECT(x)          (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS14_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS14_SELECT_MASK)
#define BCH_LAYOUTSELECT_CS15_SELECT_MASK        (0xC0000000U)
#define BCH_LAYOUTSELECT_CS15_SELECT_SHIFT       (30U)
#define BCH_LAYOUTSELECT_CS15_SELECT(x)          (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CS15_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CS15_SELECT_MASK)

/*! @name LAYOUTSELECT_SET - Hardware ECC Accelerator Layout Select Register */
#define BCH_LAYOUTSELECT_SET_CS0_SELECT_MASK     (0x3U)
#define BCH_LAYOUTSELECT_SET_CS0_SELECT_SHIFT    (0U)
#define BCH_LAYOUTSELECT_SET_CS0_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS0_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS0_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS1_SELECT_MASK     (0xCU)
#define BCH_LAYOUTSELECT_SET_CS1_SELECT_SHIFT    (2U)
#define BCH_LAYOUTSELECT_SET_CS1_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS1_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS1_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS2_SELECT_MASK     (0x30U)
#define BCH_LAYOUTSELECT_SET_CS2_SELECT_SHIFT    (4U)
#define BCH_LAYOUTSELECT_SET_CS2_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS2_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS2_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS3_SELECT_MASK     (0xC0U)
#define BCH_LAYOUTSELECT_SET_CS3_SELECT_SHIFT    (6U)
#define BCH_LAYOUTSELECT_SET_CS3_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS3_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS3_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS4_SELECT_MASK     (0x300U)
#define BCH_LAYOUTSELECT_SET_CS4_SELECT_SHIFT    (8U)
#define BCH_LAYOUTSELECT_SET_CS4_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS4_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS4_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS5_SELECT_MASK     (0xC00U)
#define BCH_LAYOUTSELECT_SET_CS5_SELECT_SHIFT    (10U)
#define BCH_LAYOUTSELECT_SET_CS5_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS5_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS5_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS6_SELECT_MASK     (0x3000U)
#define BCH_LAYOUTSELECT_SET_CS6_SELECT_SHIFT    (12U)
#define BCH_LAYOUTSELECT_SET_CS6_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS6_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS6_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS7_SELECT_MASK     (0xC000U)
#define BCH_LAYOUTSELECT_SET_CS7_SELECT_SHIFT    (14U)
#define BCH_LAYOUTSELECT_SET_CS7_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS7_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS7_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS8_SELECT_MASK     (0x30000U)
#define BCH_LAYOUTSELECT_SET_CS8_SELECT_SHIFT    (16U)
#define BCH_LAYOUTSELECT_SET_CS8_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS8_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS8_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS9_SELECT_MASK     (0xC0000U)
#define BCH_LAYOUTSELECT_SET_CS9_SELECT_SHIFT    (18U)
#define BCH_LAYOUTSELECT_SET_CS9_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS9_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS9_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS10_SELECT_MASK    (0x300000U)
#define BCH_LAYOUTSELECT_SET_CS10_SELECT_SHIFT   (20U)
#define BCH_LAYOUTSELECT_SET_CS10_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS10_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS10_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS11_SELECT_MASK    (0xC00000U)
#define BCH_LAYOUTSELECT_SET_CS11_SELECT_SHIFT   (22U)
#define BCH_LAYOUTSELECT_SET_CS11_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS11_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS11_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS12_SELECT_MASK    (0x3000000U)
#define BCH_LAYOUTSELECT_SET_CS12_SELECT_SHIFT   (24U)
#define BCH_LAYOUTSELECT_SET_CS12_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS12_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS12_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS13_SELECT_MASK    (0xC000000U)
#define BCH_LAYOUTSELECT_SET_CS13_SELECT_SHIFT   (26U)
#define BCH_LAYOUTSELECT_SET_CS13_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS13_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS13_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS14_SELECT_MASK    (0x30000000U)
#define BCH_LAYOUTSELECT_SET_CS14_SELECT_SHIFT   (28U)
#define BCH_LAYOUTSELECT_SET_CS14_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS14_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS14_SELECT_MASK)
#define BCH_LAYOUTSELECT_SET_CS15_SELECT_MASK    (0xC0000000U)
#define BCH_LAYOUTSELECT_SET_CS15_SELECT_SHIFT   (30U)
#define BCH_LAYOUTSELECT_SET_CS15_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_SET_CS15_SELECT_SHIFT)) & BCH_LAYOUTSELECT_SET_CS15_SELECT_MASK)

/*! @name LAYOUTSELECT_CLR - Hardware ECC Accelerator Layout Select Register */
#define BCH_LAYOUTSELECT_CLR_CS0_SELECT_MASK     (0x3U)
#define BCH_LAYOUTSELECT_CLR_CS0_SELECT_SHIFT    (0U)
#define BCH_LAYOUTSELECT_CLR_CS0_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS0_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS0_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS1_SELECT_MASK     (0xCU)
#define BCH_LAYOUTSELECT_CLR_CS1_SELECT_SHIFT    (2U)
#define BCH_LAYOUTSELECT_CLR_CS1_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS1_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS1_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS2_SELECT_MASK     (0x30U)
#define BCH_LAYOUTSELECT_CLR_CS2_SELECT_SHIFT    (4U)
#define BCH_LAYOUTSELECT_CLR_CS2_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS2_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS2_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS3_SELECT_MASK     (0xC0U)
#define BCH_LAYOUTSELECT_CLR_CS3_SELECT_SHIFT    (6U)
#define BCH_LAYOUTSELECT_CLR_CS3_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS3_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS3_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS4_SELECT_MASK     (0x300U)
#define BCH_LAYOUTSELECT_CLR_CS4_SELECT_SHIFT    (8U)
#define BCH_LAYOUTSELECT_CLR_CS4_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS4_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS4_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS5_SELECT_MASK     (0xC00U)
#define BCH_LAYOUTSELECT_CLR_CS5_SELECT_SHIFT    (10U)
#define BCH_LAYOUTSELECT_CLR_CS5_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS5_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS5_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS6_SELECT_MASK     (0x3000U)
#define BCH_LAYOUTSELECT_CLR_CS6_SELECT_SHIFT    (12U)
#define BCH_LAYOUTSELECT_CLR_CS6_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS6_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS6_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS7_SELECT_MASK     (0xC000U)
#define BCH_LAYOUTSELECT_CLR_CS7_SELECT_SHIFT    (14U)
#define BCH_LAYOUTSELECT_CLR_CS7_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS7_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS7_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS8_SELECT_MASK     (0x30000U)
#define BCH_LAYOUTSELECT_CLR_CS8_SELECT_SHIFT    (16U)
#define BCH_LAYOUTSELECT_CLR_CS8_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS8_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS8_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS9_SELECT_MASK     (0xC0000U)
#define BCH_LAYOUTSELECT_CLR_CS9_SELECT_SHIFT    (18U)
#define BCH_LAYOUTSELECT_CLR_CS9_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS9_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS9_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS10_SELECT_MASK    (0x300000U)
#define BCH_LAYOUTSELECT_CLR_CS10_SELECT_SHIFT   (20U)
#define BCH_LAYOUTSELECT_CLR_CS10_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS10_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS10_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS11_SELECT_MASK    (0xC00000U)
#define BCH_LAYOUTSELECT_CLR_CS11_SELECT_SHIFT   (22U)
#define BCH_LAYOUTSELECT_CLR_CS11_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS11_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS11_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS12_SELECT_MASK    (0x3000000U)
#define BCH_LAYOUTSELECT_CLR_CS12_SELECT_SHIFT   (24U)
#define BCH_LAYOUTSELECT_CLR_CS12_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS12_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS12_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS13_SELECT_MASK    (0xC000000U)
#define BCH_LAYOUTSELECT_CLR_CS13_SELECT_SHIFT   (26U)
#define BCH_LAYOUTSELECT_CLR_CS13_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS13_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS13_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS14_SELECT_MASK    (0x30000000U)
#define BCH_LAYOUTSELECT_CLR_CS14_SELECT_SHIFT   (28U)
#define BCH_LAYOUTSELECT_CLR_CS14_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS14_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS14_SELECT_MASK)
#define BCH_LAYOUTSELECT_CLR_CS15_SELECT_MASK    (0xC0000000U)
#define BCH_LAYOUTSELECT_CLR_CS15_SELECT_SHIFT   (30U)
#define BCH_LAYOUTSELECT_CLR_CS15_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_CLR_CS15_SELECT_SHIFT)) & BCH_LAYOUTSELECT_CLR_CS15_SELECT_MASK)

/*! @name LAYOUTSELECT_TOG - Hardware ECC Accelerator Layout Select Register */
#define BCH_LAYOUTSELECT_TOG_CS0_SELECT_MASK     (0x3U)
#define BCH_LAYOUTSELECT_TOG_CS0_SELECT_SHIFT    (0U)
#define BCH_LAYOUTSELECT_TOG_CS0_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS0_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS0_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS1_SELECT_MASK     (0xCU)
#define BCH_LAYOUTSELECT_TOG_CS1_SELECT_SHIFT    (2U)
#define BCH_LAYOUTSELECT_TOG_CS1_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS1_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS1_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS2_SELECT_MASK     (0x30U)
#define BCH_LAYOUTSELECT_TOG_CS2_SELECT_SHIFT    (4U)
#define BCH_LAYOUTSELECT_TOG_CS2_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS2_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS2_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS3_SELECT_MASK     (0xC0U)
#define BCH_LAYOUTSELECT_TOG_CS3_SELECT_SHIFT    (6U)
#define BCH_LAYOUTSELECT_TOG_CS3_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS3_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS3_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS4_SELECT_MASK     (0x300U)
#define BCH_LAYOUTSELECT_TOG_CS4_SELECT_SHIFT    (8U)
#define BCH_LAYOUTSELECT_TOG_CS4_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS4_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS4_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS5_SELECT_MASK     (0xC00U)
#define BCH_LAYOUTSELECT_TOG_CS5_SELECT_SHIFT    (10U)
#define BCH_LAYOUTSELECT_TOG_CS5_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS5_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS5_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS6_SELECT_MASK     (0x3000U)
#define BCH_LAYOUTSELECT_TOG_CS6_SELECT_SHIFT    (12U)
#define BCH_LAYOUTSELECT_TOG_CS6_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS6_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS6_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS7_SELECT_MASK     (0xC000U)
#define BCH_LAYOUTSELECT_TOG_CS7_SELECT_SHIFT    (14U)
#define BCH_LAYOUTSELECT_TOG_CS7_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS7_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS7_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS8_SELECT_MASK     (0x30000U)
#define BCH_LAYOUTSELECT_TOG_CS8_SELECT_SHIFT    (16U)
#define BCH_LAYOUTSELECT_TOG_CS8_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS8_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS8_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS9_SELECT_MASK     (0xC0000U)
#define BCH_LAYOUTSELECT_TOG_CS9_SELECT_SHIFT    (18U)
#define BCH_LAYOUTSELECT_TOG_CS9_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS9_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS9_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS10_SELECT_MASK    (0x300000U)
#define BCH_LAYOUTSELECT_TOG_CS10_SELECT_SHIFT   (20U)
#define BCH_LAYOUTSELECT_TOG_CS10_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS10_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS10_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS11_SELECT_MASK    (0xC00000U)
#define BCH_LAYOUTSELECT_TOG_CS11_SELECT_SHIFT   (22U)
#define BCH_LAYOUTSELECT_TOG_CS11_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS11_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS11_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS12_SELECT_MASK    (0x3000000U)
#define BCH_LAYOUTSELECT_TOG_CS12_SELECT_SHIFT   (24U)
#define BCH_LAYOUTSELECT_TOG_CS12_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS12_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS12_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS13_SELECT_MASK    (0xC000000U)
#define BCH_LAYOUTSELECT_TOG_CS13_SELECT_SHIFT   (26U)
#define BCH_LAYOUTSELECT_TOG_CS13_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS13_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS13_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS14_SELECT_MASK    (0x30000000U)
#define BCH_LAYOUTSELECT_TOG_CS14_SELECT_SHIFT   (28U)
#define BCH_LAYOUTSELECT_TOG_CS14_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS14_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS14_SELECT_MASK)
#define BCH_LAYOUTSELECT_TOG_CS15_SELECT_MASK    (0xC0000000U)
#define BCH_LAYOUTSELECT_TOG_CS15_SELECT_SHIFT   (30U)
#define BCH_LAYOUTSELECT_TOG_CS15_SELECT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_LAYOUTSELECT_TOG_CS15_SELECT_SHIFT)) & BCH_LAYOUTSELECT_TOG_CS15_SELECT_MASK)

/*! @name FLASH0LAYOUT0 - Hardware BCH ECC Flash 0 Layout 0 Register */
#define BCH_FLASH0LAYOUT0_DATA0_SIZE_MASK        (0x3FFU)
#define BCH_FLASH0LAYOUT0_DATA0_SIZE_SHIFT       (0U)
#define BCH_FLASH0LAYOUT0_DATA0_SIZE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_DATA0_SIZE_SHIFT)) & BCH_FLASH0LAYOUT0_DATA0_SIZE_MASK)
#define BCH_FLASH0LAYOUT0_GF13_0_GF14_1_MASK     (0x400U)
#define BCH_FLASH0LAYOUT0_GF13_0_GF14_1_SHIFT    (10U)
#define BCH_FLASH0LAYOUT0_ECC0_MASK              (0xF800U)
#define BCH_FLASH0LAYOUT0_ECC0_SHIFT             (11U)
#define BCH_FLASH0LAYOUT0_ECC0(x)                (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_ECC0_SHIFT)) & BCH_FLASH0LAYOUT0_ECC0_MASK)
#define BCH_FLASH0LAYOUT0_META_SIZE_MASK         (0xFF0000U)
#define BCH_FLASH0LAYOUT0_META_SIZE_SHIFT        (16U)
#define BCH_FLASH0LAYOUT0_META_SIZE(x)           (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_META_SIZE_SHIFT)) & BCH_FLASH0LAYOUT0_META_SIZE_MASK)
#define BCH_FLASH0LAYOUT0_NBLOCKS_MASK           (0xFF000000U)
#define BCH_FLASH0LAYOUT0_NBLOCKS_SHIFT          (24U)
#define BCH_FLASH0LAYOUT0_NBLOCKS(x)             (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_NBLOCKS_SHIFT)) & BCH_FLASH0LAYOUT0_NBLOCKS_MASK)

/*! @name FLASH0LAYOUT0_SET - Hardware BCH ECC Flash 0 Layout 0 Register */
#define BCH_FLASH0LAYOUT0_SET_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH0LAYOUT0_SET_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH0LAYOUT0_SET_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_SET_DATA0_SIZE_SHIFT)) & BCH_FLASH0LAYOUT0_SET_DATA0_SIZE_MASK)
#define BCH_FLASH0LAYOUT0_SET_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH0LAYOUT0_SET_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH0LAYOUT0_SET_ECC0_MASK          (0xF800U)
#define BCH_FLASH0LAYOUT0_SET_ECC0_SHIFT         (11U)
#define BCH_FLASH0LAYOUT0_SET_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_SET_ECC0_SHIFT)) & BCH_FLASH0LAYOUT0_SET_ECC0_MASK)
#define BCH_FLASH0LAYOUT0_SET_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH0LAYOUT0_SET_META_SIZE_SHIFT    (16U)
#define BCH_FLASH0LAYOUT0_SET_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_SET_META_SIZE_SHIFT)) & BCH_FLASH0LAYOUT0_SET_META_SIZE_MASK)
#define BCH_FLASH0LAYOUT0_SET_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH0LAYOUT0_SET_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH0LAYOUT0_SET_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_SET_NBLOCKS_SHIFT)) & BCH_FLASH0LAYOUT0_SET_NBLOCKS_MASK)

/*! @name FLASH0LAYOUT0_CLR - Hardware BCH ECC Flash 0 Layout 0 Register */
#define BCH_FLASH0LAYOUT0_CLR_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH0LAYOUT0_CLR_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH0LAYOUT0_CLR_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_CLR_DATA0_SIZE_SHIFT)) & BCH_FLASH0LAYOUT0_CLR_DATA0_SIZE_MASK)
#define BCH_FLASH0LAYOUT0_CLR_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH0LAYOUT0_CLR_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH0LAYOUT0_CLR_ECC0_MASK          (0xF800U)
#define BCH_FLASH0LAYOUT0_CLR_ECC0_SHIFT         (11U)
#define BCH_FLASH0LAYOUT0_CLR_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_CLR_ECC0_SHIFT)) & BCH_FLASH0LAYOUT0_CLR_ECC0_MASK)
#define BCH_FLASH0LAYOUT0_CLR_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH0LAYOUT0_CLR_META_SIZE_SHIFT    (16U)
#define BCH_FLASH0LAYOUT0_CLR_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_CLR_META_SIZE_SHIFT)) & BCH_FLASH0LAYOUT0_CLR_META_SIZE_MASK)
#define BCH_FLASH0LAYOUT0_CLR_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH0LAYOUT0_CLR_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH0LAYOUT0_CLR_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_CLR_NBLOCKS_SHIFT)) & BCH_FLASH0LAYOUT0_CLR_NBLOCKS_MASK)

/*! @name FLASH0LAYOUT0_TOG - Hardware BCH ECC Flash 0 Layout 0 Register */
#define BCH_FLASH0LAYOUT0_TOG_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH0LAYOUT0_TOG_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH0LAYOUT0_TOG_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_TOG_DATA0_SIZE_SHIFT)) & BCH_FLASH0LAYOUT0_TOG_DATA0_SIZE_MASK)
#define BCH_FLASH0LAYOUT0_TOG_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH0LAYOUT0_TOG_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH0LAYOUT0_TOG_ECC0_MASK          (0xF800U)
#define BCH_FLASH0LAYOUT0_TOG_ECC0_SHIFT         (11U)
#define BCH_FLASH0LAYOUT0_TOG_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_TOG_ECC0_SHIFT)) & BCH_FLASH0LAYOUT0_TOG_ECC0_MASK)
#define BCH_FLASH0LAYOUT0_TOG_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH0LAYOUT0_TOG_META_SIZE_SHIFT    (16U)
#define BCH_FLASH0LAYOUT0_TOG_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_TOG_META_SIZE_SHIFT)) & BCH_FLASH0LAYOUT0_TOG_META_SIZE_MASK)
#define BCH_FLASH0LAYOUT0_TOG_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH0LAYOUT0_TOG_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH0LAYOUT0_TOG_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT0_TOG_NBLOCKS_SHIFT)) & BCH_FLASH0LAYOUT0_TOG_NBLOCKS_MASK)

/*! @name FLASH0LAYOUT1 - Hardware BCH ECC Flash 0 Layout 1 Register */
#define BCH_FLASH0LAYOUT1_DATAN_SIZE_MASK        (0x3FFU)
#define BCH_FLASH0LAYOUT1_DATAN_SIZE_SHIFT       (0U)
#define BCH_FLASH0LAYOUT1_DATAN_SIZE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_DATAN_SIZE_SHIFT)) & BCH_FLASH0LAYOUT1_DATAN_SIZE_MASK)
#define BCH_FLASH0LAYOUT1_GF13_0_GF14_1_MASK     (0x400U)
#define BCH_FLASH0LAYOUT1_GF13_0_GF14_1_SHIFT    (10U)
#define BCH_FLASH0LAYOUT1_ECCN_MASK              (0xF800U)
#define BCH_FLASH0LAYOUT1_ECCN_SHIFT             (11U)
#define BCH_FLASH0LAYOUT1_ECCN(x)                (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_ECCN_SHIFT)) & BCH_FLASH0LAYOUT1_ECCN_MASK)
#define BCH_FLASH0LAYOUT1_PAGE_SIZE_MASK         (0xFFFF0000U)
#define BCH_FLASH0LAYOUT1_PAGE_SIZE_SHIFT        (16U)
#define BCH_FLASH0LAYOUT1_PAGE_SIZE(x)           (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_PAGE_SIZE_SHIFT)) & BCH_FLASH0LAYOUT1_PAGE_SIZE_MASK)

/*! @name FLASH0LAYOUT1_SET - Hardware BCH ECC Flash 0 Layout 1 Register */
#define BCH_FLASH0LAYOUT1_SET_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH0LAYOUT1_SET_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH0LAYOUT1_SET_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_SET_DATAN_SIZE_SHIFT)) & BCH_FLASH0LAYOUT1_SET_DATAN_SIZE_MASK)
#define BCH_FLASH0LAYOUT1_SET_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH0LAYOUT1_SET_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH0LAYOUT1_SET_ECCN_MASK          (0xF800U)
#define BCH_FLASH0LAYOUT1_SET_ECCN_SHIFT         (11U)
#define BCH_FLASH0LAYOUT1_SET_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_SET_ECCN_SHIFT)) & BCH_FLASH0LAYOUT1_SET_ECCN_MASK)
#define BCH_FLASH0LAYOUT1_SET_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH0LAYOUT1_SET_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH0LAYOUT1_SET_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_SET_PAGE_SIZE_SHIFT)) & BCH_FLASH0LAYOUT1_SET_PAGE_SIZE_MASK)

/*! @name FLASH0LAYOUT1_CLR - Hardware BCH ECC Flash 0 Layout 1 Register */
#define BCH_FLASH0LAYOUT1_CLR_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH0LAYOUT1_CLR_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH0LAYOUT1_CLR_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_CLR_DATAN_SIZE_SHIFT)) & BCH_FLASH0LAYOUT1_CLR_DATAN_SIZE_MASK)
#define BCH_FLASH0LAYOUT1_CLR_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH0LAYOUT1_CLR_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH0LAYOUT1_CLR_ECCN_MASK          (0xF800U)
#define BCH_FLASH0LAYOUT1_CLR_ECCN_SHIFT         (11U)
#define BCH_FLASH0LAYOUT1_CLR_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_CLR_ECCN_SHIFT)) & BCH_FLASH0LAYOUT1_CLR_ECCN_MASK)
#define BCH_FLASH0LAYOUT1_CLR_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH0LAYOUT1_CLR_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH0LAYOUT1_CLR_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_CLR_PAGE_SIZE_SHIFT)) & BCH_FLASH0LAYOUT1_CLR_PAGE_SIZE_MASK)

/*! @name FLASH0LAYOUT1_TOG - Hardware BCH ECC Flash 0 Layout 1 Register */
#define BCH_FLASH0LAYOUT1_TOG_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH0LAYOUT1_TOG_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH0LAYOUT1_TOG_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_TOG_DATAN_SIZE_SHIFT)) & BCH_FLASH0LAYOUT1_TOG_DATAN_SIZE_MASK)
#define BCH_FLASH0LAYOUT1_TOG_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH0LAYOUT1_TOG_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH0LAYOUT1_TOG_ECCN_MASK          (0xF800U)
#define BCH_FLASH0LAYOUT1_TOG_ECCN_SHIFT         (11U)
#define BCH_FLASH0LAYOUT1_TOG_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_TOG_ECCN_SHIFT)) & BCH_FLASH0LAYOUT1_TOG_ECCN_MASK)
#define BCH_FLASH0LAYOUT1_TOG_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH0LAYOUT1_TOG_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH0LAYOUT1_TOG_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH0LAYOUT1_TOG_PAGE_SIZE_SHIFT)) & BCH_FLASH0LAYOUT1_TOG_PAGE_SIZE_MASK)

/*! @name FLASH1LAYOUT0 - Hardware BCH ECC Flash 1 Layout 0 Register */
#define BCH_FLASH1LAYOUT0_DATA0_SIZE_MASK        (0x3FFU)
#define BCH_FLASH1LAYOUT0_DATA0_SIZE_SHIFT       (0U)
#define BCH_FLASH1LAYOUT0_DATA0_SIZE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_DATA0_SIZE_SHIFT)) & BCH_FLASH1LAYOUT0_DATA0_SIZE_MASK)
#define BCH_FLASH1LAYOUT0_GF13_0_GF14_1_MASK     (0x400U)
#define BCH_FLASH1LAYOUT0_GF13_0_GF14_1_SHIFT    (10U)
#define BCH_FLASH1LAYOUT0_ECC0_MASK              (0xF800U)
#define BCH_FLASH1LAYOUT0_ECC0_SHIFT             (11U)
#define BCH_FLASH1LAYOUT0_ECC0(x)                (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_ECC0_SHIFT)) & BCH_FLASH1LAYOUT0_ECC0_MASK)
#define BCH_FLASH1LAYOUT0_META_SIZE_MASK         (0xFF0000U)
#define BCH_FLASH1LAYOUT0_META_SIZE_SHIFT        (16U)
#define BCH_FLASH1LAYOUT0_META_SIZE(x)           (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_META_SIZE_SHIFT)) & BCH_FLASH1LAYOUT0_META_SIZE_MASK)
#define BCH_FLASH1LAYOUT0_NBLOCKS_MASK           (0xFF000000U)
#define BCH_FLASH1LAYOUT0_NBLOCKS_SHIFT          (24U)
#define BCH_FLASH1LAYOUT0_NBLOCKS(x)             (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_NBLOCKS_SHIFT)) & BCH_FLASH1LAYOUT0_NBLOCKS_MASK)

/*! @name FLASH1LAYOUT0_SET - Hardware BCH ECC Flash 1 Layout 0 Register */
#define BCH_FLASH1LAYOUT0_SET_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH1LAYOUT0_SET_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH1LAYOUT0_SET_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_SET_DATA0_SIZE_SHIFT)) & BCH_FLASH1LAYOUT0_SET_DATA0_SIZE_MASK)
#define BCH_FLASH1LAYOUT0_SET_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH1LAYOUT0_SET_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH1LAYOUT0_SET_ECC0_MASK          (0xF800U)
#define BCH_FLASH1LAYOUT0_SET_ECC0_SHIFT         (11U)
#define BCH_FLASH1LAYOUT0_SET_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_SET_ECC0_SHIFT)) & BCH_FLASH1LAYOUT0_SET_ECC0_MASK)
#define BCH_FLASH1LAYOUT0_SET_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH1LAYOUT0_SET_META_SIZE_SHIFT    (16U)
#define BCH_FLASH1LAYOUT0_SET_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_SET_META_SIZE_SHIFT)) & BCH_FLASH1LAYOUT0_SET_META_SIZE_MASK)
#define BCH_FLASH1LAYOUT0_SET_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH1LAYOUT0_SET_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH1LAYOUT0_SET_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_SET_NBLOCKS_SHIFT)) & BCH_FLASH1LAYOUT0_SET_NBLOCKS_MASK)

/*! @name FLASH1LAYOUT0_CLR - Hardware BCH ECC Flash 1 Layout 0 Register */
#define BCH_FLASH1LAYOUT0_CLR_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH1LAYOUT0_CLR_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH1LAYOUT0_CLR_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_CLR_DATA0_SIZE_SHIFT)) & BCH_FLASH1LAYOUT0_CLR_DATA0_SIZE_MASK)
#define BCH_FLASH1LAYOUT0_CLR_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH1LAYOUT0_CLR_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH1LAYOUT0_CLR_ECC0_MASK          (0xF800U)
#define BCH_FLASH1LAYOUT0_CLR_ECC0_SHIFT         (11U)
#define BCH_FLASH1LAYOUT0_CLR_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_CLR_ECC0_SHIFT)) & BCH_FLASH1LAYOUT0_CLR_ECC0_MASK)
#define BCH_FLASH1LAYOUT0_CLR_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH1LAYOUT0_CLR_META_SIZE_SHIFT    (16U)
#define BCH_FLASH1LAYOUT0_CLR_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_CLR_META_SIZE_SHIFT)) & BCH_FLASH1LAYOUT0_CLR_META_SIZE_MASK)
#define BCH_FLASH1LAYOUT0_CLR_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH1LAYOUT0_CLR_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH1LAYOUT0_CLR_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_CLR_NBLOCKS_SHIFT)) & BCH_FLASH1LAYOUT0_CLR_NBLOCKS_MASK)

/*! @name FLASH1LAYOUT0_TOG - Hardware BCH ECC Flash 1 Layout 0 Register */
#define BCH_FLASH1LAYOUT0_TOG_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH1LAYOUT0_TOG_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH1LAYOUT0_TOG_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_TOG_DATA0_SIZE_SHIFT)) & BCH_FLASH1LAYOUT0_TOG_DATA0_SIZE_MASK)
#define BCH_FLASH1LAYOUT0_TOG_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH1LAYOUT0_TOG_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH1LAYOUT0_TOG_ECC0_MASK          (0xF800U)
#define BCH_FLASH1LAYOUT0_TOG_ECC0_SHIFT         (11U)
#define BCH_FLASH1LAYOUT0_TOG_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_TOG_ECC0_SHIFT)) & BCH_FLASH1LAYOUT0_TOG_ECC0_MASK)
#define BCH_FLASH1LAYOUT0_TOG_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH1LAYOUT0_TOG_META_SIZE_SHIFT    (16U)
#define BCH_FLASH1LAYOUT0_TOG_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_TOG_META_SIZE_SHIFT)) & BCH_FLASH1LAYOUT0_TOG_META_SIZE_MASK)
#define BCH_FLASH1LAYOUT0_TOG_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH1LAYOUT0_TOG_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH1LAYOUT0_TOG_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT0_TOG_NBLOCKS_SHIFT)) & BCH_FLASH1LAYOUT0_TOG_NBLOCKS_MASK)

/*! @name FLASH1LAYOUT1 - Hardware BCH ECC Flash 1 Layout 1 Register */
#define BCH_FLASH1LAYOUT1_DATAN_SIZE_MASK        (0x3FFU)
#define BCH_FLASH1LAYOUT1_DATAN_SIZE_SHIFT       (0U)
#define BCH_FLASH1LAYOUT1_DATAN_SIZE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_DATAN_SIZE_SHIFT)) & BCH_FLASH1LAYOUT1_DATAN_SIZE_MASK)
#define BCH_FLASH1LAYOUT1_GF13_0_GF14_1_MASK     (0x400U)
#define BCH_FLASH1LAYOUT1_GF13_0_GF14_1_SHIFT    (10U)
#define BCH_FLASH1LAYOUT1_ECCN_MASK              (0xF800U)
#define BCH_FLASH1LAYOUT1_ECCN_SHIFT             (11U)
#define BCH_FLASH1LAYOUT1_ECCN(x)                (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_ECCN_SHIFT)) & BCH_FLASH1LAYOUT1_ECCN_MASK)
#define BCH_FLASH1LAYOUT1_PAGE_SIZE_MASK         (0xFFFF0000U)
#define BCH_FLASH1LAYOUT1_PAGE_SIZE_SHIFT        (16U)
#define BCH_FLASH1LAYOUT1_PAGE_SIZE(x)           (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_PAGE_SIZE_SHIFT)) & BCH_FLASH1LAYOUT1_PAGE_SIZE_MASK)

/*! @name FLASH1LAYOUT1_SET - Hardware BCH ECC Flash 1 Layout 1 Register */
#define BCH_FLASH1LAYOUT1_SET_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH1LAYOUT1_SET_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH1LAYOUT1_SET_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_SET_DATAN_SIZE_SHIFT)) & BCH_FLASH1LAYOUT1_SET_DATAN_SIZE_MASK)
#define BCH_FLASH1LAYOUT1_SET_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH1LAYOUT1_SET_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH1LAYOUT1_SET_ECCN_MASK          (0xF800U)
#define BCH_FLASH1LAYOUT1_SET_ECCN_SHIFT         (11U)
#define BCH_FLASH1LAYOUT1_SET_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_SET_ECCN_SHIFT)) & BCH_FLASH1LAYOUT1_SET_ECCN_MASK)
#define BCH_FLASH1LAYOUT1_SET_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH1LAYOUT1_SET_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH1LAYOUT1_SET_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_SET_PAGE_SIZE_SHIFT)) & BCH_FLASH1LAYOUT1_SET_PAGE_SIZE_MASK)

/*! @name FLASH1LAYOUT1_CLR - Hardware BCH ECC Flash 1 Layout 1 Register */
#define BCH_FLASH1LAYOUT1_CLR_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH1LAYOUT1_CLR_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH1LAYOUT1_CLR_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_CLR_DATAN_SIZE_SHIFT)) & BCH_FLASH1LAYOUT1_CLR_DATAN_SIZE_MASK)
#define BCH_FLASH1LAYOUT1_CLR_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH1LAYOUT1_CLR_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH1LAYOUT1_CLR_ECCN_MASK          (0xF800U)
#define BCH_FLASH1LAYOUT1_CLR_ECCN_SHIFT         (11U)
#define BCH_FLASH1LAYOUT1_CLR_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_CLR_ECCN_SHIFT)) & BCH_FLASH1LAYOUT1_CLR_ECCN_MASK)
#define BCH_FLASH1LAYOUT1_CLR_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH1LAYOUT1_CLR_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH1LAYOUT1_CLR_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_CLR_PAGE_SIZE_SHIFT)) & BCH_FLASH1LAYOUT1_CLR_PAGE_SIZE_MASK)

/*! @name FLASH1LAYOUT1_TOG - Hardware BCH ECC Flash 1 Layout 1 Register */
#define BCH_FLASH1LAYOUT1_TOG_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH1LAYOUT1_TOG_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH1LAYOUT1_TOG_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_TOG_DATAN_SIZE_SHIFT)) & BCH_FLASH1LAYOUT1_TOG_DATAN_SIZE_MASK)
#define BCH_FLASH1LAYOUT1_TOG_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH1LAYOUT1_TOG_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH1LAYOUT1_TOG_ECCN_MASK          (0xF800U)
#define BCH_FLASH1LAYOUT1_TOG_ECCN_SHIFT         (11U)
#define BCH_FLASH1LAYOUT1_TOG_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_TOG_ECCN_SHIFT)) & BCH_FLASH1LAYOUT1_TOG_ECCN_MASK)
#define BCH_FLASH1LAYOUT1_TOG_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH1LAYOUT1_TOG_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH1LAYOUT1_TOG_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH1LAYOUT1_TOG_PAGE_SIZE_SHIFT)) & BCH_FLASH1LAYOUT1_TOG_PAGE_SIZE_MASK)

/*! @name FLASH2LAYOUT0 - Hardware BCH ECC Flash 2 Layout 0 Register */
#define BCH_FLASH2LAYOUT0_DATA0_SIZE_MASK        (0x3FFU)
#define BCH_FLASH2LAYOUT0_DATA0_SIZE_SHIFT       (0U)
#define BCH_FLASH2LAYOUT0_DATA0_SIZE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_DATA0_SIZE_SHIFT)) & BCH_FLASH2LAYOUT0_DATA0_SIZE_MASK)
#define BCH_FLASH2LAYOUT0_GF13_0_GF14_1_MASK     (0x400U)
#define BCH_FLASH2LAYOUT0_GF13_0_GF14_1_SHIFT    (10U)
#define BCH_FLASH2LAYOUT0_ECC0_MASK              (0xF800U)
#define BCH_FLASH2LAYOUT0_ECC0_SHIFT             (11U)
#define BCH_FLASH2LAYOUT0_ECC0(x)                (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_ECC0_SHIFT)) & BCH_FLASH2LAYOUT0_ECC0_MASK)
#define BCH_FLASH2LAYOUT0_META_SIZE_MASK         (0xFF0000U)
#define BCH_FLASH2LAYOUT0_META_SIZE_SHIFT        (16U)
#define BCH_FLASH2LAYOUT0_META_SIZE(x)           (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_META_SIZE_SHIFT)) & BCH_FLASH2LAYOUT0_META_SIZE_MASK)
#define BCH_FLASH2LAYOUT0_NBLOCKS_MASK           (0xFF000000U)
#define BCH_FLASH2LAYOUT0_NBLOCKS_SHIFT          (24U)
#define BCH_FLASH2LAYOUT0_NBLOCKS(x)             (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_NBLOCKS_SHIFT)) & BCH_FLASH2LAYOUT0_NBLOCKS_MASK)

/*! @name FLASH2LAYOUT0_SET - Hardware BCH ECC Flash 2 Layout 0 Register */
#define BCH_FLASH2LAYOUT0_SET_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH2LAYOUT0_SET_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH2LAYOUT0_SET_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_SET_DATA0_SIZE_SHIFT)) & BCH_FLASH2LAYOUT0_SET_DATA0_SIZE_MASK)
#define BCH_FLASH2LAYOUT0_SET_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH2LAYOUT0_SET_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH2LAYOUT0_SET_ECC0_MASK          (0xF800U)
#define BCH_FLASH2LAYOUT0_SET_ECC0_SHIFT         (11U)
#define BCH_FLASH2LAYOUT0_SET_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_SET_ECC0_SHIFT)) & BCH_FLASH2LAYOUT0_SET_ECC0_MASK)
#define BCH_FLASH2LAYOUT0_SET_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH2LAYOUT0_SET_META_SIZE_SHIFT    (16U)
#define BCH_FLASH2LAYOUT0_SET_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_SET_META_SIZE_SHIFT)) & BCH_FLASH2LAYOUT0_SET_META_SIZE_MASK)
#define BCH_FLASH2LAYOUT0_SET_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH2LAYOUT0_SET_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH2LAYOUT0_SET_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_SET_NBLOCKS_SHIFT)) & BCH_FLASH2LAYOUT0_SET_NBLOCKS_MASK)

/*! @name FLASH2LAYOUT0_CLR - Hardware BCH ECC Flash 2 Layout 0 Register */
#define BCH_FLASH2LAYOUT0_CLR_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH2LAYOUT0_CLR_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH2LAYOUT0_CLR_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_CLR_DATA0_SIZE_SHIFT)) & BCH_FLASH2LAYOUT0_CLR_DATA0_SIZE_MASK)
#define BCH_FLASH2LAYOUT0_CLR_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH2LAYOUT0_CLR_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH2LAYOUT0_CLR_ECC0_MASK          (0xF800U)
#define BCH_FLASH2LAYOUT0_CLR_ECC0_SHIFT         (11U)
#define BCH_FLASH2LAYOUT0_CLR_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_CLR_ECC0_SHIFT)) & BCH_FLASH2LAYOUT0_CLR_ECC0_MASK)
#define BCH_FLASH2LAYOUT0_CLR_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH2LAYOUT0_CLR_META_SIZE_SHIFT    (16U)
#define BCH_FLASH2LAYOUT0_CLR_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_CLR_META_SIZE_SHIFT)) & BCH_FLASH2LAYOUT0_CLR_META_SIZE_MASK)
#define BCH_FLASH2LAYOUT0_CLR_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH2LAYOUT0_CLR_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH2LAYOUT0_CLR_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_CLR_NBLOCKS_SHIFT)) & BCH_FLASH2LAYOUT0_CLR_NBLOCKS_MASK)

/*! @name FLASH2LAYOUT0_TOG - Hardware BCH ECC Flash 2 Layout 0 Register */
#define BCH_FLASH2LAYOUT0_TOG_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH2LAYOUT0_TOG_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH2LAYOUT0_TOG_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_TOG_DATA0_SIZE_SHIFT)) & BCH_FLASH2LAYOUT0_TOG_DATA0_SIZE_MASK)
#define BCH_FLASH2LAYOUT0_TOG_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH2LAYOUT0_TOG_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH2LAYOUT0_TOG_ECC0_MASK          (0xF800U)
#define BCH_FLASH2LAYOUT0_TOG_ECC0_SHIFT         (11U)
#define BCH_FLASH2LAYOUT0_TOG_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_TOG_ECC0_SHIFT)) & BCH_FLASH2LAYOUT0_TOG_ECC0_MASK)
#define BCH_FLASH2LAYOUT0_TOG_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH2LAYOUT0_TOG_META_SIZE_SHIFT    (16U)
#define BCH_FLASH2LAYOUT0_TOG_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_TOG_META_SIZE_SHIFT)) & BCH_FLASH2LAYOUT0_TOG_META_SIZE_MASK)
#define BCH_FLASH2LAYOUT0_TOG_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH2LAYOUT0_TOG_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH2LAYOUT0_TOG_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT0_TOG_NBLOCKS_SHIFT)) & BCH_FLASH2LAYOUT0_TOG_NBLOCKS_MASK)

/*! @name FLASH2LAYOUT1 - Hardware BCH ECC Flash 2 Layout 1 Register */
#define BCH_FLASH2LAYOUT1_DATAN_SIZE_MASK        (0x3FFU)
#define BCH_FLASH2LAYOUT1_DATAN_SIZE_SHIFT       (0U)
#define BCH_FLASH2LAYOUT1_DATAN_SIZE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_DATAN_SIZE_SHIFT)) & BCH_FLASH2LAYOUT1_DATAN_SIZE_MASK)
#define BCH_FLASH2LAYOUT1_GF13_0_GF14_1_MASK     (0x400U)
#define BCH_FLASH2LAYOUT1_GF13_0_GF14_1_SHIFT    (10U)
#define BCH_FLASH2LAYOUT1_ECCN_MASK              (0xF800U)
#define BCH_FLASH2LAYOUT1_ECCN_SHIFT             (11U)
#define BCH_FLASH2LAYOUT1_ECCN(x)                (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_ECCN_SHIFT)) & BCH_FLASH2LAYOUT1_ECCN_MASK)
#define BCH_FLASH2LAYOUT1_PAGE_SIZE_MASK         (0xFFFF0000U)
#define BCH_FLASH2LAYOUT1_PAGE_SIZE_SHIFT        (16U)
#define BCH_FLASH2LAYOUT1_PAGE_SIZE(x)           (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_PAGE_SIZE_SHIFT)) & BCH_FLASH2LAYOUT1_PAGE_SIZE_MASK)

/*! @name FLASH2LAYOUT1_SET - Hardware BCH ECC Flash 2 Layout 1 Register */
#define BCH_FLASH2LAYOUT1_SET_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH2LAYOUT1_SET_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH2LAYOUT1_SET_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_SET_DATAN_SIZE_SHIFT)) & BCH_FLASH2LAYOUT1_SET_DATAN_SIZE_MASK)
#define BCH_FLASH2LAYOUT1_SET_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH2LAYOUT1_SET_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH2LAYOUT1_SET_ECCN_MASK          (0xF800U)
#define BCH_FLASH2LAYOUT1_SET_ECCN_SHIFT         (11U)
#define BCH_FLASH2LAYOUT1_SET_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_SET_ECCN_SHIFT)) & BCH_FLASH2LAYOUT1_SET_ECCN_MASK)
#define BCH_FLASH2LAYOUT1_SET_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH2LAYOUT1_SET_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH2LAYOUT1_SET_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_SET_PAGE_SIZE_SHIFT)) & BCH_FLASH2LAYOUT1_SET_PAGE_SIZE_MASK)

/*! @name FLASH2LAYOUT1_CLR - Hardware BCH ECC Flash 2 Layout 1 Register */
#define BCH_FLASH2LAYOUT1_CLR_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH2LAYOUT1_CLR_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH2LAYOUT1_CLR_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_CLR_DATAN_SIZE_SHIFT)) & BCH_FLASH2LAYOUT1_CLR_DATAN_SIZE_MASK)
#define BCH_FLASH2LAYOUT1_CLR_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH2LAYOUT1_CLR_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH2LAYOUT1_CLR_ECCN_MASK          (0xF800U)
#define BCH_FLASH2LAYOUT1_CLR_ECCN_SHIFT         (11U)
#define BCH_FLASH2LAYOUT1_CLR_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_CLR_ECCN_SHIFT)) & BCH_FLASH2LAYOUT1_CLR_ECCN_MASK)
#define BCH_FLASH2LAYOUT1_CLR_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH2LAYOUT1_CLR_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH2LAYOUT1_CLR_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_CLR_PAGE_SIZE_SHIFT)) & BCH_FLASH2LAYOUT1_CLR_PAGE_SIZE_MASK)

/*! @name FLASH2LAYOUT1_TOG - Hardware BCH ECC Flash 2 Layout 1 Register */
#define BCH_FLASH2LAYOUT1_TOG_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH2LAYOUT1_TOG_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH2LAYOUT1_TOG_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_TOG_DATAN_SIZE_SHIFT)) & BCH_FLASH2LAYOUT1_TOG_DATAN_SIZE_MASK)
#define BCH_FLASH2LAYOUT1_TOG_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH2LAYOUT1_TOG_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH2LAYOUT1_TOG_ECCN_MASK          (0xF800U)
#define BCH_FLASH2LAYOUT1_TOG_ECCN_SHIFT         (11U)
#define BCH_FLASH2LAYOUT1_TOG_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_TOG_ECCN_SHIFT)) & BCH_FLASH2LAYOUT1_TOG_ECCN_MASK)
#define BCH_FLASH2LAYOUT1_TOG_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH2LAYOUT1_TOG_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH2LAYOUT1_TOG_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH2LAYOUT1_TOG_PAGE_SIZE_SHIFT)) & BCH_FLASH2LAYOUT1_TOG_PAGE_SIZE_MASK)

/*! @name FLASH3LAYOUT0 - Hardware BCH ECC Flash 3 Layout 0 Register */
#define BCH_FLASH3LAYOUT0_DATA0_SIZE_MASK        (0x3FFU)
#define BCH_FLASH3LAYOUT0_DATA0_SIZE_SHIFT       (0U)
#define BCH_FLASH3LAYOUT0_DATA0_SIZE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_DATA0_SIZE_SHIFT)) & BCH_FLASH3LAYOUT0_DATA0_SIZE_MASK)
#define BCH_FLASH3LAYOUT0_GF13_0_GF14_1_MASK     (0x400U)
#define BCH_FLASH3LAYOUT0_GF13_0_GF14_1_SHIFT    (10U)
#define BCH_FLASH3LAYOUT0_ECC0_MASK              (0xF800U)
#define BCH_FLASH3LAYOUT0_ECC0_SHIFT             (11U)
#define BCH_FLASH3LAYOUT0_ECC0(x)                (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_ECC0_SHIFT)) & BCH_FLASH3LAYOUT0_ECC0_MASK)
#define BCH_FLASH3LAYOUT0_META_SIZE_MASK         (0xFF0000U)
#define BCH_FLASH3LAYOUT0_META_SIZE_SHIFT        (16U)
#define BCH_FLASH3LAYOUT0_META_SIZE(x)           (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_META_SIZE_SHIFT)) & BCH_FLASH3LAYOUT0_META_SIZE_MASK)
#define BCH_FLASH3LAYOUT0_NBLOCKS_MASK           (0xFF000000U)
#define BCH_FLASH3LAYOUT0_NBLOCKS_SHIFT          (24U)
#define BCH_FLASH3LAYOUT0_NBLOCKS(x)             (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_NBLOCKS_SHIFT)) & BCH_FLASH3LAYOUT0_NBLOCKS_MASK)

/*! @name FLASH3LAYOUT0_SET - Hardware BCH ECC Flash 3 Layout 0 Register */
#define BCH_FLASH3LAYOUT0_SET_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH3LAYOUT0_SET_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH3LAYOUT0_SET_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_SET_DATA0_SIZE_SHIFT)) & BCH_FLASH3LAYOUT0_SET_DATA0_SIZE_MASK)
#define BCH_FLASH3LAYOUT0_SET_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH3LAYOUT0_SET_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH3LAYOUT0_SET_ECC0_MASK          (0xF800U)
#define BCH_FLASH3LAYOUT0_SET_ECC0_SHIFT         (11U)
#define BCH_FLASH3LAYOUT0_SET_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_SET_ECC0_SHIFT)) & BCH_FLASH3LAYOUT0_SET_ECC0_MASK)
#define BCH_FLASH3LAYOUT0_SET_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH3LAYOUT0_SET_META_SIZE_SHIFT    (16U)
#define BCH_FLASH3LAYOUT0_SET_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_SET_META_SIZE_SHIFT)) & BCH_FLASH3LAYOUT0_SET_META_SIZE_MASK)
#define BCH_FLASH3LAYOUT0_SET_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH3LAYOUT0_SET_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH3LAYOUT0_SET_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_SET_NBLOCKS_SHIFT)) & BCH_FLASH3LAYOUT0_SET_NBLOCKS_MASK)

/*! @name FLASH3LAYOUT0_CLR - Hardware BCH ECC Flash 3 Layout 0 Register */
#define BCH_FLASH3LAYOUT0_CLR_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH3LAYOUT0_CLR_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH3LAYOUT0_CLR_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_CLR_DATA0_SIZE_SHIFT)) & BCH_FLASH3LAYOUT0_CLR_DATA0_SIZE_MASK)
#define BCH_FLASH3LAYOUT0_CLR_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH3LAYOUT0_CLR_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH3LAYOUT0_CLR_ECC0_MASK          (0xF800U)
#define BCH_FLASH3LAYOUT0_CLR_ECC0_SHIFT         (11U)
#define BCH_FLASH3LAYOUT0_CLR_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_CLR_ECC0_SHIFT)) & BCH_FLASH3LAYOUT0_CLR_ECC0_MASK)
#define BCH_FLASH3LAYOUT0_CLR_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH3LAYOUT0_CLR_META_SIZE_SHIFT    (16U)
#define BCH_FLASH3LAYOUT0_CLR_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_CLR_META_SIZE_SHIFT)) & BCH_FLASH3LAYOUT0_CLR_META_SIZE_MASK)
#define BCH_FLASH3LAYOUT0_CLR_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH3LAYOUT0_CLR_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH3LAYOUT0_CLR_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_CLR_NBLOCKS_SHIFT)) & BCH_FLASH3LAYOUT0_CLR_NBLOCKS_MASK)

/*! @name FLASH3LAYOUT0_TOG - Hardware BCH ECC Flash 3 Layout 0 Register */
#define BCH_FLASH3LAYOUT0_TOG_DATA0_SIZE_MASK    (0x3FFU)
#define BCH_FLASH3LAYOUT0_TOG_DATA0_SIZE_SHIFT   (0U)
#define BCH_FLASH3LAYOUT0_TOG_DATA0_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_TOG_DATA0_SIZE_SHIFT)) & BCH_FLASH3LAYOUT0_TOG_DATA0_SIZE_MASK)
#define BCH_FLASH3LAYOUT0_TOG_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH3LAYOUT0_TOG_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH3LAYOUT0_TOG_ECC0_MASK          (0xF800U)
#define BCH_FLASH3LAYOUT0_TOG_ECC0_SHIFT         (11U)
#define BCH_FLASH3LAYOUT0_TOG_ECC0(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_TOG_ECC0_SHIFT)) & BCH_FLASH3LAYOUT0_TOG_ECC0_MASK)
#define BCH_FLASH3LAYOUT0_TOG_META_SIZE_MASK     (0xFF0000U)
#define BCH_FLASH3LAYOUT0_TOG_META_SIZE_SHIFT    (16U)
#define BCH_FLASH3LAYOUT0_TOG_META_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_TOG_META_SIZE_SHIFT)) & BCH_FLASH3LAYOUT0_TOG_META_SIZE_MASK)
#define BCH_FLASH3LAYOUT0_TOG_NBLOCKS_MASK       (0xFF000000U)
#define BCH_FLASH3LAYOUT0_TOG_NBLOCKS_SHIFT      (24U)
#define BCH_FLASH3LAYOUT0_TOG_NBLOCKS(x)         (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT0_TOG_NBLOCKS_SHIFT)) & BCH_FLASH3LAYOUT0_TOG_NBLOCKS_MASK)

/*! @name FLASH3LAYOUT1 - Hardware BCH ECC Flash 3 Layout 1 Register */
#define BCH_FLASH3LAYOUT1_DATAN_SIZE_MASK        (0x3FFU)
#define BCH_FLASH3LAYOUT1_DATAN_SIZE_SHIFT       (0U)
#define BCH_FLASH3LAYOUT1_DATAN_SIZE(x)          (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_DATAN_SIZE_SHIFT)) & BCH_FLASH3LAYOUT1_DATAN_SIZE_MASK)
#define BCH_FLASH3LAYOUT1_GF13_0_GF14_1_MASK     (0x400U)
#define BCH_FLASH3LAYOUT1_GF13_0_GF14_1_SHIFT    (10U)
#define BCH_FLASH3LAYOUT1_ECCN_MASK              (0xF800U)
#define BCH_FLASH3LAYOUT1_ECCN_SHIFT             (11U)
#define BCH_FLASH3LAYOUT1_ECCN(x)                (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_ECCN_SHIFT)) & BCH_FLASH3LAYOUT1_ECCN_MASK)
#define BCH_FLASH3LAYOUT1_PAGE_SIZE_MASK         (0xFFFF0000U)
#define BCH_FLASH3LAYOUT1_PAGE_SIZE_SHIFT        (16U)
#define BCH_FLASH3LAYOUT1_PAGE_SIZE(x)           (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_PAGE_SIZE_SHIFT)) & BCH_FLASH3LAYOUT1_PAGE_SIZE_MASK)

/*! @name FLASH3LAYOUT1_SET - Hardware BCH ECC Flash 3 Layout 1 Register */
#define BCH_FLASH3LAYOUT1_SET_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH3LAYOUT1_SET_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH3LAYOUT1_SET_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_SET_DATAN_SIZE_SHIFT)) & BCH_FLASH3LAYOUT1_SET_DATAN_SIZE_MASK)
#define BCH_FLASH3LAYOUT1_SET_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH3LAYOUT1_SET_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH3LAYOUT1_SET_ECCN_MASK          (0xF800U)
#define BCH_FLASH3LAYOUT1_SET_ECCN_SHIFT         (11U)
#define BCH_FLASH3LAYOUT1_SET_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_SET_ECCN_SHIFT)) & BCH_FLASH3LAYOUT1_SET_ECCN_MASK)
#define BCH_FLASH3LAYOUT1_SET_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH3LAYOUT1_SET_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH3LAYOUT1_SET_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_SET_PAGE_SIZE_SHIFT)) & BCH_FLASH3LAYOUT1_SET_PAGE_SIZE_MASK)

/*! @name FLASH3LAYOUT1_CLR - Hardware BCH ECC Flash 3 Layout 1 Register */
#define BCH_FLASH3LAYOUT1_CLR_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH3LAYOUT1_CLR_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH3LAYOUT1_CLR_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_CLR_DATAN_SIZE_SHIFT)) & BCH_FLASH3LAYOUT1_CLR_DATAN_SIZE_MASK)
#define BCH_FLASH3LAYOUT1_CLR_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH3LAYOUT1_CLR_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH3LAYOUT1_CLR_ECCN_MASK          (0xF800U)
#define BCH_FLASH3LAYOUT1_CLR_ECCN_SHIFT         (11U)
#define BCH_FLASH3LAYOUT1_CLR_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_CLR_ECCN_SHIFT)) & BCH_FLASH3LAYOUT1_CLR_ECCN_MASK)
#define BCH_FLASH3LAYOUT1_CLR_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH3LAYOUT1_CLR_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH3LAYOUT1_CLR_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_CLR_PAGE_SIZE_SHIFT)) & BCH_FLASH3LAYOUT1_CLR_PAGE_SIZE_MASK)

/*! @name FLASH3LAYOUT1_TOG - Hardware BCH ECC Flash 3 Layout 1 Register */
#define BCH_FLASH3LAYOUT1_TOG_DATAN_SIZE_MASK    (0x3FFU)
#define BCH_FLASH3LAYOUT1_TOG_DATAN_SIZE_SHIFT   (0U)
#define BCH_FLASH3LAYOUT1_TOG_DATAN_SIZE(x)      (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_TOG_DATAN_SIZE_SHIFT)) & BCH_FLASH3LAYOUT1_TOG_DATAN_SIZE_MASK)
#define BCH_FLASH3LAYOUT1_TOG_GF13_0_GF14_1_MASK (0x400U)
#define BCH_FLASH3LAYOUT1_TOG_GF13_0_GF14_1_SHIFT (10U)
#define BCH_FLASH3LAYOUT1_TOG_ECCN_MASK          (0xF800U)
#define BCH_FLASH3LAYOUT1_TOG_ECCN_SHIFT         (11U)
#define BCH_FLASH3LAYOUT1_TOG_ECCN(x)            (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_TOG_ECCN_SHIFT)) & BCH_FLASH3LAYOUT1_TOG_ECCN_MASK)
#define BCH_FLASH3LAYOUT1_TOG_PAGE_SIZE_MASK     (0xFFFF0000U)
#define BCH_FLASH3LAYOUT1_TOG_PAGE_SIZE_SHIFT    (16U)
#define BCH_FLASH3LAYOUT1_TOG_PAGE_SIZE(x)       (((uint32_t)(((uint32_t)(x)) << BCH_FLASH3LAYOUT1_TOG_PAGE_SIZE_SHIFT)) & BCH_FLASH3LAYOUT1_TOG_PAGE_SIZE_MASK)

/*! @name DEBUG0 - Hardware BCH ECC Debug Register0 */
#define BCH_DEBUG0_DEBUG_REG_SELECT_MASK         (0x3FU)
#define BCH_DEBUG0_DEBUG_REG_SELECT_SHIFT        (0U)
#define BCH_DEBUG0_DEBUG_REG_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_DEBUG_REG_SELECT_SHIFT)) & BCH_DEBUG0_DEBUG_REG_SELECT_MASK)
#define BCH_DEBUG0_RSVD0_MASK                    (0xC0U)
#define BCH_DEBUG0_RSVD0_SHIFT                   (6U)
#define BCH_DEBUG0_RSVD0(x)                      (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_RSVD0_SHIFT)) & BCH_DEBUG0_RSVD0_MASK)
#define BCH_DEBUG0_BM_KES_TEST_BYPASS_MASK       (0x100U)
#define BCH_DEBUG0_BM_KES_TEST_BYPASS_SHIFT      (8U)
#define BCH_DEBUG0_KES_DEBUG_STALL_MASK          (0x200U)
#define BCH_DEBUG0_KES_DEBUG_STALL_SHIFT         (9U)
#define BCH_DEBUG0_KES_DEBUG_STEP_MASK           (0x400U)
#define BCH_DEBUG0_KES_DEBUG_STEP_SHIFT          (10U)
#define BCH_DEBUG0_KES_STANDALONE_MASK           (0x800U)
#define BCH_DEBUG0_KES_STANDALONE_SHIFT          (11U)
#define BCH_DEBUG0_KES_DEBUG_KICK_MASK           (0x1000U)
#define BCH_DEBUG0_KES_DEBUG_KICK_SHIFT          (12U)
#define BCH_DEBUG0_KES_DEBUG_MODE4K_MASK         (0x2000U)
#define BCH_DEBUG0_KES_DEBUG_MODE4K_SHIFT        (13U)
#define BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG_MASK   (0x4000U)
#define BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG_SHIFT  (14U)
#define BCH_DEBUG0_KES_DEBUG_SHIFT_SYND_MASK     (0x8000U)
#define BCH_DEBUG0_KES_DEBUG_SHIFT_SYND_SHIFT    (15U)
#define BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL_MASK (0x1FF0000U)
#define BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL_SHIFT (16U)
#define BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(x)  (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL_SHIFT)) & BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL_MASK)
#define BCH_DEBUG0_RSVD1_MASK                    (0xFE000000U)
#define BCH_DEBUG0_RSVD1_SHIFT                   (25U)
#define BCH_DEBUG0_RSVD1(x)                      (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_RSVD1_SHIFT)) & BCH_DEBUG0_RSVD1_MASK)

/*! @name DEBUG0_SET - Hardware BCH ECC Debug Register0 */
#define BCH_DEBUG0_SET_DEBUG_REG_SELECT_MASK     (0x3FU)
#define BCH_DEBUG0_SET_DEBUG_REG_SELECT_SHIFT    (0U)
#define BCH_DEBUG0_SET_DEBUG_REG_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_SET_DEBUG_REG_SELECT_SHIFT)) & BCH_DEBUG0_SET_DEBUG_REG_SELECT_MASK)
#define BCH_DEBUG0_SET_RSVD0_MASK                (0xC0U)
#define BCH_DEBUG0_SET_RSVD0_SHIFT               (6U)
#define BCH_DEBUG0_SET_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_SET_RSVD0_SHIFT)) & BCH_DEBUG0_SET_RSVD0_MASK)
#define BCH_DEBUG0_SET_BM_KES_TEST_BYPASS_MASK   (0x100U)
#define BCH_DEBUG0_SET_BM_KES_TEST_BYPASS_SHIFT  (8U)
#define BCH_DEBUG0_SET_KES_DEBUG_STALL_MASK      (0x200U)
#define BCH_DEBUG0_SET_KES_DEBUG_STALL_SHIFT     (9U)
#define BCH_DEBUG0_SET_KES_DEBUG_STEP_MASK       (0x400U)
#define BCH_DEBUG0_SET_KES_DEBUG_STEP_SHIFT      (10U)
#define BCH_DEBUG0_SET_KES_STANDALONE_MASK       (0x800U)
#define BCH_DEBUG0_SET_KES_STANDALONE_SHIFT      (11U)
#define BCH_DEBUG0_SET_KES_DEBUG_KICK_MASK       (0x1000U)
#define BCH_DEBUG0_SET_KES_DEBUG_KICK_SHIFT      (12U)
#define BCH_DEBUG0_SET_KES_DEBUG_MODE4K_MASK     (0x2000U)
#define BCH_DEBUG0_SET_KES_DEBUG_MODE4K_SHIFT    (13U)
#define BCH_DEBUG0_SET_KES_DEBUG_PAYLOAD_FLAG_MASK (0x4000U)
#define BCH_DEBUG0_SET_KES_DEBUG_PAYLOAD_FLAG_SHIFT (14U)
#define BCH_DEBUG0_SET_KES_DEBUG_SHIFT_SYND_MASK (0x8000U)
#define BCH_DEBUG0_SET_KES_DEBUG_SHIFT_SYND_SHIFT (15U)
#define BCH_DEBUG0_SET_KES_DEBUG_SYNDROME_SYMBOL_MASK (0x1FF0000U)
#define BCH_DEBUG0_SET_KES_DEBUG_SYNDROME_SYMBOL_SHIFT (16U)
#define BCH_DEBUG0_SET_KES_DEBUG_SYNDROME_SYMBOL(x) (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_SET_KES_DEBUG_SYNDROME_SYMBOL_SHIFT)) & BCH_DEBUG0_SET_KES_DEBUG_SYNDROME_SYMBOL_MASK)
#define BCH_DEBUG0_SET_RSVD1_MASK                (0xFE000000U)
#define BCH_DEBUG0_SET_RSVD1_SHIFT               (25U)
#define BCH_DEBUG0_SET_RSVD1(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_SET_RSVD1_SHIFT)) & BCH_DEBUG0_SET_RSVD1_MASK)

/*! @name DEBUG0_CLR - Hardware BCH ECC Debug Register0 */
#define BCH_DEBUG0_CLR_DEBUG_REG_SELECT_MASK     (0x3FU)
#define BCH_DEBUG0_CLR_DEBUG_REG_SELECT_SHIFT    (0U)
#define BCH_DEBUG0_CLR_DEBUG_REG_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_CLR_DEBUG_REG_SELECT_SHIFT)) & BCH_DEBUG0_CLR_DEBUG_REG_SELECT_MASK)
#define BCH_DEBUG0_CLR_RSVD0_MASK                (0xC0U)
#define BCH_DEBUG0_CLR_RSVD0_SHIFT               (6U)
#define BCH_DEBUG0_CLR_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_CLR_RSVD0_SHIFT)) & BCH_DEBUG0_CLR_RSVD0_MASK)
#define BCH_DEBUG0_CLR_BM_KES_TEST_BYPASS_MASK   (0x100U)
#define BCH_DEBUG0_CLR_BM_KES_TEST_BYPASS_SHIFT  (8U)
#define BCH_DEBUG0_CLR_KES_DEBUG_STALL_MASK      (0x200U)
#define BCH_DEBUG0_CLR_KES_DEBUG_STALL_SHIFT     (9U)
#define BCH_DEBUG0_CLR_KES_DEBUG_STEP_MASK       (0x400U)
#define BCH_DEBUG0_CLR_KES_DEBUG_STEP_SHIFT      (10U)
#define BCH_DEBUG0_CLR_KES_STANDALONE_MASK       (0x800U)
#define BCH_DEBUG0_CLR_KES_STANDALONE_SHIFT      (11U)
#define BCH_DEBUG0_CLR_KES_DEBUG_KICK_MASK       (0x1000U)
#define BCH_DEBUG0_CLR_KES_DEBUG_KICK_SHIFT      (12U)
#define BCH_DEBUG0_CLR_KES_DEBUG_MODE4K_MASK     (0x2000U)
#define BCH_DEBUG0_CLR_KES_DEBUG_MODE4K_SHIFT    (13U)
#define BCH_DEBUG0_CLR_KES_DEBUG_PAYLOAD_FLAG_MASK (0x4000U)
#define BCH_DEBUG0_CLR_KES_DEBUG_PAYLOAD_FLAG_SHIFT (14U)
#define BCH_DEBUG0_CLR_KES_DEBUG_SHIFT_SYND_MASK (0x8000U)
#define BCH_DEBUG0_CLR_KES_DEBUG_SHIFT_SYND_SHIFT (15U)
#define BCH_DEBUG0_CLR_KES_DEBUG_SYNDROME_SYMBOL_MASK (0x1FF0000U)
#define BCH_DEBUG0_CLR_KES_DEBUG_SYNDROME_SYMBOL_SHIFT (16U)
#define BCH_DEBUG0_CLR_KES_DEBUG_SYNDROME_SYMBOL(x) (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_CLR_KES_DEBUG_SYNDROME_SYMBOL_SHIFT)) & BCH_DEBUG0_CLR_KES_DEBUG_SYNDROME_SYMBOL_MASK)
#define BCH_DEBUG0_CLR_RSVD1_MASK                (0xFE000000U)
#define BCH_DEBUG0_CLR_RSVD1_SHIFT               (25U)
#define BCH_DEBUG0_CLR_RSVD1(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_CLR_RSVD1_SHIFT)) & BCH_DEBUG0_CLR_RSVD1_MASK)

/*! @name DEBUG0_TOG - Hardware BCH ECC Debug Register0 */
#define BCH_DEBUG0_TOG_DEBUG_REG_SELECT_MASK     (0x3FU)
#define BCH_DEBUG0_TOG_DEBUG_REG_SELECT_SHIFT    (0U)
#define BCH_DEBUG0_TOG_DEBUG_REG_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_TOG_DEBUG_REG_SELECT_SHIFT)) & BCH_DEBUG0_TOG_DEBUG_REG_SELECT_MASK)
#define BCH_DEBUG0_TOG_RSVD0_MASK                (0xC0U)
#define BCH_DEBUG0_TOG_RSVD0_SHIFT               (6U)
#define BCH_DEBUG0_TOG_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_TOG_RSVD0_SHIFT)) & BCH_DEBUG0_TOG_RSVD0_MASK)
#define BCH_DEBUG0_TOG_BM_KES_TEST_BYPASS_MASK   (0x100U)
#define BCH_DEBUG0_TOG_BM_KES_TEST_BYPASS_SHIFT  (8U)
#define BCH_DEBUG0_TOG_KES_DEBUG_STALL_MASK      (0x200U)
#define BCH_DEBUG0_TOG_KES_DEBUG_STALL_SHIFT     (9U)
#define BCH_DEBUG0_TOG_KES_DEBUG_STEP_MASK       (0x400U)
#define BCH_DEBUG0_TOG_KES_DEBUG_STEP_SHIFT      (10U)
#define BCH_DEBUG0_TOG_KES_STANDALONE_MASK       (0x800U)
#define BCH_DEBUG0_TOG_KES_STANDALONE_SHIFT      (11U)
#define BCH_DEBUG0_TOG_KES_DEBUG_KICK_MASK       (0x1000U)
#define BCH_DEBUG0_TOG_KES_DEBUG_KICK_SHIFT      (12U)
#define BCH_DEBUG0_TOG_KES_DEBUG_MODE4K_MASK     (0x2000U)
#define BCH_DEBUG0_TOG_KES_DEBUG_MODE4K_SHIFT    (13U)
#define BCH_DEBUG0_TOG_KES_DEBUG_PAYLOAD_FLAG_MASK (0x4000U)
#define BCH_DEBUG0_TOG_KES_DEBUG_PAYLOAD_FLAG_SHIFT (14U)
#define BCH_DEBUG0_TOG_KES_DEBUG_SHIFT_SYND_MASK (0x8000U)
#define BCH_DEBUG0_TOG_KES_DEBUG_SHIFT_SYND_SHIFT (15U)
#define BCH_DEBUG0_TOG_KES_DEBUG_SYNDROME_SYMBOL_MASK (0x1FF0000U)
#define BCH_DEBUG0_TOG_KES_DEBUG_SYNDROME_SYMBOL_SHIFT (16U)
#define BCH_DEBUG0_TOG_KES_DEBUG_SYNDROME_SYMBOL(x) (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_TOG_KES_DEBUG_SYNDROME_SYMBOL_SHIFT)) & BCH_DEBUG0_TOG_KES_DEBUG_SYNDROME_SYMBOL_MASK)
#define BCH_DEBUG0_TOG_RSVD1_MASK                (0xFE000000U)
#define BCH_DEBUG0_TOG_RSVD1_SHIFT               (25U)
#define BCH_DEBUG0_TOG_RSVD1(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG0_TOG_RSVD1_SHIFT)) & BCH_DEBUG0_TOG_RSVD1_MASK)

/*! @name DBGKESREAD - KES Debug Read Register */
#define BCH_DBGKESREAD_VALUES_MASK               (0xFFFFFFFFU)
#define BCH_DBGKESREAD_VALUES_SHIFT              (0U)
#define BCH_DBGKESREAD_VALUES(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_DBGKESREAD_VALUES_SHIFT)) & BCH_DBGKESREAD_VALUES_MASK)

/*! @name DBGKESREAD_SET - KES Debug Read Register */
#define BCH_DBGKESREAD_SET_VALUES_MASK           (0xFFFFFFFFU)
#define BCH_DBGKESREAD_SET_VALUES_SHIFT          (0U)
#define BCH_DBGKESREAD_SET_VALUES(x)             (((uint32_t)(((uint32_t)(x)) << BCH_DBGKESREAD_SET_VALUES_SHIFT)) & BCH_DBGKESREAD_SET_VALUES_MASK)

/*! @name DBGKESREAD_CLR - KES Debug Read Register */
#define BCH_DBGKESREAD_CLR_VALUES_MASK           (0xFFFFFFFFU)
#define BCH_DBGKESREAD_CLR_VALUES_SHIFT          (0U)
#define BCH_DBGKESREAD_CLR_VALUES(x)             (((uint32_t)(((uint32_t)(x)) << BCH_DBGKESREAD_CLR_VALUES_SHIFT)) & BCH_DBGKESREAD_CLR_VALUES_MASK)

/*! @name DBGKESREAD_TOG - KES Debug Read Register */
#define BCH_DBGKESREAD_TOG_VALUES_MASK           (0xFFFFFFFFU)
#define BCH_DBGKESREAD_TOG_VALUES_SHIFT          (0U)
#define BCH_DBGKESREAD_TOG_VALUES(x)             (((uint32_t)(((uint32_t)(x)) << BCH_DBGKESREAD_TOG_VALUES_SHIFT)) & BCH_DBGKESREAD_TOG_VALUES_MASK)

/*! @name DBGCSFEREAD - Chien Search Debug Read Register */
#define BCH_DBGCSFEREAD_VALUES_MASK              (0xFFFFFFFFU)
#define BCH_DBGCSFEREAD_VALUES_SHIFT             (0U)
#define BCH_DBGCSFEREAD_VALUES(x)                (((uint32_t)(((uint32_t)(x)) << BCH_DBGCSFEREAD_VALUES_SHIFT)) & BCH_DBGCSFEREAD_VALUES_MASK)

/*! @name DBGCSFEREAD_SET - Chien Search Debug Read Register */
#define BCH_DBGCSFEREAD_SET_VALUES_MASK          (0xFFFFFFFFU)
#define BCH_DBGCSFEREAD_SET_VALUES_SHIFT         (0U)
#define BCH_DBGCSFEREAD_SET_VALUES(x)            (((uint32_t)(((uint32_t)(x)) << BCH_DBGCSFEREAD_SET_VALUES_SHIFT)) & BCH_DBGCSFEREAD_SET_VALUES_MASK)

/*! @name DBGCSFEREAD_CLR - Chien Search Debug Read Register */
#define BCH_DBGCSFEREAD_CLR_VALUES_MASK          (0xFFFFFFFFU)
#define BCH_DBGCSFEREAD_CLR_VALUES_SHIFT         (0U)
#define BCH_DBGCSFEREAD_CLR_VALUES(x)            (((uint32_t)(((uint32_t)(x)) << BCH_DBGCSFEREAD_CLR_VALUES_SHIFT)) & BCH_DBGCSFEREAD_CLR_VALUES_MASK)

/*! @name DBGCSFEREAD_TOG - Chien Search Debug Read Register */
#define BCH_DBGCSFEREAD_TOG_VALUES_MASK          (0xFFFFFFFFU)
#define BCH_DBGCSFEREAD_TOG_VALUES_SHIFT         (0U)
#define BCH_DBGCSFEREAD_TOG_VALUES(x)            (((uint32_t)(((uint32_t)(x)) << BCH_DBGCSFEREAD_TOG_VALUES_SHIFT)) & BCH_DBGCSFEREAD_TOG_VALUES_MASK)

/*! @name DBGSYNDGENREAD - Syndrome Generator Debug Read Register */
#define BCH_DBGSYNDGENREAD_VALUES_MASK           (0xFFFFFFFFU)
#define BCH_DBGSYNDGENREAD_VALUES_SHIFT          (0U)
#define BCH_DBGSYNDGENREAD_VALUES(x)             (((uint32_t)(((uint32_t)(x)) << BCH_DBGSYNDGENREAD_VALUES_SHIFT)) & BCH_DBGSYNDGENREAD_VALUES_MASK)

/*! @name DBGSYNDGENREAD_SET - Syndrome Generator Debug Read Register */
#define BCH_DBGSYNDGENREAD_SET_VALUES_MASK       (0xFFFFFFFFU)
#define BCH_DBGSYNDGENREAD_SET_VALUES_SHIFT      (0U)
#define BCH_DBGSYNDGENREAD_SET_VALUES(x)         (((uint32_t)(((uint32_t)(x)) << BCH_DBGSYNDGENREAD_SET_VALUES_SHIFT)) & BCH_DBGSYNDGENREAD_SET_VALUES_MASK)

/*! @name DBGSYNDGENREAD_CLR - Syndrome Generator Debug Read Register */
#define BCH_DBGSYNDGENREAD_CLR_VALUES_MASK       (0xFFFFFFFFU)
#define BCH_DBGSYNDGENREAD_CLR_VALUES_SHIFT      (0U)
#define BCH_DBGSYNDGENREAD_CLR_VALUES(x)         (((uint32_t)(((uint32_t)(x)) << BCH_DBGSYNDGENREAD_CLR_VALUES_SHIFT)) & BCH_DBGSYNDGENREAD_CLR_VALUES_MASK)

/*! @name DBGSYNDGENREAD_TOG - Syndrome Generator Debug Read Register */
#define BCH_DBGSYNDGENREAD_TOG_VALUES_MASK       (0xFFFFFFFFU)
#define BCH_DBGSYNDGENREAD_TOG_VALUES_SHIFT      (0U)
#define BCH_DBGSYNDGENREAD_TOG_VALUES(x)         (((uint32_t)(((uint32_t)(x)) << BCH_DBGSYNDGENREAD_TOG_VALUES_SHIFT)) & BCH_DBGSYNDGENREAD_TOG_VALUES_MASK)

/*! @name DBGAHBMREAD - Bus Master and ECC Controller Debug Read Register */
#define BCH_DBGAHBMREAD_VALUES_MASK              (0xFFFFFFFFU)
#define BCH_DBGAHBMREAD_VALUES_SHIFT             (0U)
#define BCH_DBGAHBMREAD_VALUES(x)                (((uint32_t)(((uint32_t)(x)) << BCH_DBGAHBMREAD_VALUES_SHIFT)) & BCH_DBGAHBMREAD_VALUES_MASK)

/*! @name DBGAHBMREAD_SET - Bus Master and ECC Controller Debug Read Register */
#define BCH_DBGAHBMREAD_SET_VALUES_MASK          (0xFFFFFFFFU)
#define BCH_DBGAHBMREAD_SET_VALUES_SHIFT         (0U)
#define BCH_DBGAHBMREAD_SET_VALUES(x)            (((uint32_t)(((uint32_t)(x)) << BCH_DBGAHBMREAD_SET_VALUES_SHIFT)) & BCH_DBGAHBMREAD_SET_VALUES_MASK)

/*! @name DBGAHBMREAD_CLR - Bus Master and ECC Controller Debug Read Register */
#define BCH_DBGAHBMREAD_CLR_VALUES_MASK          (0xFFFFFFFFU)
#define BCH_DBGAHBMREAD_CLR_VALUES_SHIFT         (0U)
#define BCH_DBGAHBMREAD_CLR_VALUES(x)            (((uint32_t)(((uint32_t)(x)) << BCH_DBGAHBMREAD_CLR_VALUES_SHIFT)) & BCH_DBGAHBMREAD_CLR_VALUES_MASK)

/*! @name DBGAHBMREAD_TOG - Bus Master and ECC Controller Debug Read Register */
#define BCH_DBGAHBMREAD_TOG_VALUES_MASK          (0xFFFFFFFFU)
#define BCH_DBGAHBMREAD_TOG_VALUES_SHIFT         (0U)
#define BCH_DBGAHBMREAD_TOG_VALUES(x)            (((uint32_t)(((uint32_t)(x)) << BCH_DBGAHBMREAD_TOG_VALUES_SHIFT)) & BCH_DBGAHBMREAD_TOG_VALUES_MASK)

/*! @name BLOCKNAME - Block Name Register */
#define BCH_BLOCKNAME_NAME_MASK                  (0xFFFFFFFFU)
#define BCH_BLOCKNAME_NAME_SHIFT                 (0U)
#define BCH_BLOCKNAME_NAME(x)                    (((uint32_t)(((uint32_t)(x)) << BCH_BLOCKNAME_NAME_SHIFT)) & BCH_BLOCKNAME_NAME_MASK)

/*! @name BLOCKNAME_SET - Block Name Register */
#define BCH_BLOCKNAME_SET_NAME_MASK              (0xFFFFFFFFU)
#define BCH_BLOCKNAME_SET_NAME_SHIFT             (0U)
#define BCH_BLOCKNAME_SET_NAME(x)                (((uint32_t)(((uint32_t)(x)) << BCH_BLOCKNAME_SET_NAME_SHIFT)) & BCH_BLOCKNAME_SET_NAME_MASK)

/*! @name BLOCKNAME_CLR - Block Name Register */
#define BCH_BLOCKNAME_CLR_NAME_MASK              (0xFFFFFFFFU)
#define BCH_BLOCKNAME_CLR_NAME_SHIFT             (0U)
#define BCH_BLOCKNAME_CLR_NAME(x)                (((uint32_t)(((uint32_t)(x)) << BCH_BLOCKNAME_CLR_NAME_SHIFT)) & BCH_BLOCKNAME_CLR_NAME_MASK)

/*! @name BLOCKNAME_TOG - Block Name Register */
#define BCH_BLOCKNAME_TOG_NAME_MASK              (0xFFFFFFFFU)
#define BCH_BLOCKNAME_TOG_NAME_SHIFT             (0U)
#define BCH_BLOCKNAME_TOG_NAME(x)                (((uint32_t)(((uint32_t)(x)) << BCH_BLOCKNAME_TOG_NAME_SHIFT)) & BCH_BLOCKNAME_TOG_NAME_MASK)

/*! @name VERSION - BCH Version Register */
#define BCH_VERSION_STEP_MASK                    (0xFFFFU)
#define BCH_VERSION_STEP_SHIFT                   (0U)
#define BCH_VERSION_STEP(x)                      (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_STEP_SHIFT)) & BCH_VERSION_STEP_MASK)
#define BCH_VERSION_MINOR_MASK                   (0xFF0000U)
#define BCH_VERSION_MINOR_SHIFT                  (16U)
#define BCH_VERSION_MINOR(x)                     (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_MINOR_SHIFT)) & BCH_VERSION_MINOR_MASK)
#define BCH_VERSION_MAJOR_MASK                   (0xFF000000U)
#define BCH_VERSION_MAJOR_SHIFT                  (24U)
#define BCH_VERSION_MAJOR(x)                     (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_MAJOR_SHIFT)) & BCH_VERSION_MAJOR_MASK)

/*! @name VERSION_SET - BCH Version Register */
#define BCH_VERSION_SET_STEP_MASK                (0xFFFFU)
#define BCH_VERSION_SET_STEP_SHIFT               (0U)
#define BCH_VERSION_SET_STEP(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_SET_STEP_SHIFT)) & BCH_VERSION_SET_STEP_MASK)
#define BCH_VERSION_SET_MINOR_MASK               (0xFF0000U)
#define BCH_VERSION_SET_MINOR_SHIFT              (16U)
#define BCH_VERSION_SET_MINOR(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_SET_MINOR_SHIFT)) & BCH_VERSION_SET_MINOR_MASK)
#define BCH_VERSION_SET_MAJOR_MASK               (0xFF000000U)
#define BCH_VERSION_SET_MAJOR_SHIFT              (24U)
#define BCH_VERSION_SET_MAJOR(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_SET_MAJOR_SHIFT)) & BCH_VERSION_SET_MAJOR_MASK)

/*! @name VERSION_CLR - BCH Version Register */
#define BCH_VERSION_CLR_STEP_MASK                (0xFFFFU)
#define BCH_VERSION_CLR_STEP_SHIFT               (0U)
#define BCH_VERSION_CLR_STEP(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_CLR_STEP_SHIFT)) & BCH_VERSION_CLR_STEP_MASK)
#define BCH_VERSION_CLR_MINOR_MASK               (0xFF0000U)
#define BCH_VERSION_CLR_MINOR_SHIFT              (16U)
#define BCH_VERSION_CLR_MINOR(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_CLR_MINOR_SHIFT)) & BCH_VERSION_CLR_MINOR_MASK)
#define BCH_VERSION_CLR_MAJOR_MASK               (0xFF000000U)
#define BCH_VERSION_CLR_MAJOR_SHIFT              (24U)
#define BCH_VERSION_CLR_MAJOR(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_CLR_MAJOR_SHIFT)) & BCH_VERSION_CLR_MAJOR_MASK)

/*! @name VERSION_TOG - BCH Version Register */
#define BCH_VERSION_TOG_STEP_MASK                (0xFFFFU)
#define BCH_VERSION_TOG_STEP_SHIFT               (0U)
#define BCH_VERSION_TOG_STEP(x)                  (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_TOG_STEP_SHIFT)) & BCH_VERSION_TOG_STEP_MASK)
#define BCH_VERSION_TOG_MINOR_MASK               (0xFF0000U)
#define BCH_VERSION_TOG_MINOR_SHIFT              (16U)
#define BCH_VERSION_TOG_MINOR(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_TOG_MINOR_SHIFT)) & BCH_VERSION_TOG_MINOR_MASK)
#define BCH_VERSION_TOG_MAJOR_MASK               (0xFF000000U)
#define BCH_VERSION_TOG_MAJOR_SHIFT              (24U)
#define BCH_VERSION_TOG_MAJOR(x)                 (((uint32_t)(((uint32_t)(x)) << BCH_VERSION_TOG_MAJOR_SHIFT)) & BCH_VERSION_TOG_MAJOR_MASK)

/*! @name DEBUG1 - Hardware BCH ECC Debug Register 1 */
#define BCH_DEBUG1_ERASED_ZERO_COUNT_MASK        (0x1FFU)
#define BCH_DEBUG1_ERASED_ZERO_COUNT_SHIFT       (0U)
#define BCH_DEBUG1_ERASED_ZERO_COUNT(x)          (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG1_ERASED_ZERO_COUNT_SHIFT)) & BCH_DEBUG1_ERASED_ZERO_COUNT_MASK)
#define BCH_DEBUG1_RSVD_MASK                     (0x7FFFFE00U)
#define BCH_DEBUG1_RSVD_SHIFT                    (9U)
#define BCH_DEBUG1_RSVD(x)                       (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG1_RSVD_SHIFT)) & BCH_DEBUG1_RSVD_MASK)
#define BCH_DEBUG1_DEBUG1_PREERASECHK_MASK       (0x80000000U)
#define BCH_DEBUG1_DEBUG1_PREERASECHK_SHIFT      (31U)

/*! @name DEBUG1_SET - Hardware BCH ECC Debug Register 1 */
#define BCH_DEBUG1_SET_ERASED_ZERO_COUNT_MASK    (0x1FFU)
#define BCH_DEBUG1_SET_ERASED_ZERO_COUNT_SHIFT   (0U)
#define BCH_DEBUG1_SET_ERASED_ZERO_COUNT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG1_SET_ERASED_ZERO_COUNT_SHIFT)) & BCH_DEBUG1_SET_ERASED_ZERO_COUNT_MASK)
#define BCH_DEBUG1_SET_RSVD_MASK                 (0x7FFFFE00U)
#define BCH_DEBUG1_SET_RSVD_SHIFT                (9U)
#define BCH_DEBUG1_SET_RSVD(x)                   (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG1_SET_RSVD_SHIFT)) & BCH_DEBUG1_SET_RSVD_MASK)
#define BCH_DEBUG1_SET_DEBUG1_PREERASECHK_MASK   (0x80000000U)
#define BCH_DEBUG1_SET_DEBUG1_PREERASECHK_SHIFT  (31U)

/*! @name DEBUG1_CLR - Hardware BCH ECC Debug Register 1 */
#define BCH_DEBUG1_CLR_ERASED_ZERO_COUNT_MASK    (0x1FFU)
#define BCH_DEBUG1_CLR_ERASED_ZERO_COUNT_SHIFT   (0U)
#define BCH_DEBUG1_CLR_ERASED_ZERO_COUNT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG1_CLR_ERASED_ZERO_COUNT_SHIFT)) & BCH_DEBUG1_CLR_ERASED_ZERO_COUNT_MASK)
#define BCH_DEBUG1_CLR_RSVD_MASK                 (0x7FFFFE00U)
#define BCH_DEBUG1_CLR_RSVD_SHIFT                (9U)
#define BCH_DEBUG1_CLR_RSVD(x)                   (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG1_CLR_RSVD_SHIFT)) & BCH_DEBUG1_CLR_RSVD_MASK)
#define BCH_DEBUG1_CLR_DEBUG1_PREERASECHK_MASK   (0x80000000U)
#define BCH_DEBUG1_CLR_DEBUG1_PREERASECHK_SHIFT  (31U)

/*! @name DEBUG1_TOG - Hardware BCH ECC Debug Register 1 */
#define BCH_DEBUG1_TOG_ERASED_ZERO_COUNT_MASK    (0x1FFU)
#define BCH_DEBUG1_TOG_ERASED_ZERO_COUNT_SHIFT   (0U)
#define BCH_DEBUG1_TOG_ERASED_ZERO_COUNT(x)      (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG1_TOG_ERASED_ZERO_COUNT_SHIFT)) & BCH_DEBUG1_TOG_ERASED_ZERO_COUNT_MASK)
#define BCH_DEBUG1_TOG_RSVD_MASK                 (0x7FFFFE00U)
#define BCH_DEBUG1_TOG_RSVD_SHIFT                (9U)
#define BCH_DEBUG1_TOG_RSVD(x)                   (((uint32_t)(((uint32_t)(x)) << BCH_DEBUG1_TOG_RSVD_SHIFT)) & BCH_DEBUG1_TOG_RSVD_MASK)
#define BCH_DEBUG1_TOG_DEBUG1_PREERASECHK_MASK   (0x80000000U)
#define BCH_DEBUG1_TOG_DEBUG1_PREERASECHK_SHIFT  (31U)


/*!
 * @}
 */ /* end of group BCH_Register_Masks */


/* BCH - Peripheral instance base addresses */
/** Peripheral BCH base pointer */
#define BCH_BASE_PTR                             ((BCH_MemMapPtr)0x33004000u)
/** Array initializer of BCH peripheral base pointers */
#define BCH_BASE_PTRS                            { BCH_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- BCH - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup BCH_Register_Accessor_Macros BCH - Register accessor macros
 * @{
 */


/* BCH - Register instance definitions */
/* BCH */
#define BCH_CTRL                                 BCH_CTRL_REG(BCH_BASE_PTR)
#define BCH_CTRL_SET                             BCH_CTRL_SET_REG(BCH_BASE_PTR)
#define BCH_CTRL_CLR                             BCH_CTRL_CLR_REG(BCH_BASE_PTR)
#define BCH_CTRL_TOG                             BCH_CTRL_TOG_REG(BCH_BASE_PTR)
#define BCH_STATUS0                              BCH_STATUS0_REG(BCH_BASE_PTR)
#define BCH_STATUS0_SET                          BCH_STATUS0_SET_REG(BCH_BASE_PTR)
#define BCH_STATUS0_CLR                          BCH_STATUS0_CLR_REG(BCH_BASE_PTR)
#define BCH_STATUS0_TOG                          BCH_STATUS0_TOG_REG(BCH_BASE_PTR)
#define BCH_MODE                                 BCH_MODE_REG(BCH_BASE_PTR)
#define BCH_MODE_SET                             BCH_MODE_SET_REG(BCH_BASE_PTR)
#define BCH_MODE_CLR                             BCH_MODE_CLR_REG(BCH_BASE_PTR)
#define BCH_MODE_TOG                             BCH_MODE_TOG_REG(BCH_BASE_PTR)
#define BCH_ENCODEPTR                            BCH_ENCODEPTR_REG(BCH_BASE_PTR)
#define BCH_ENCODEPTR_SET                        BCH_ENCODEPTR_SET_REG(BCH_BASE_PTR)
#define BCH_ENCODEPTR_CLR                        BCH_ENCODEPTR_CLR_REG(BCH_BASE_PTR)
#define BCH_ENCODEPTR_TOG                        BCH_ENCODEPTR_TOG_REG(BCH_BASE_PTR)
#define BCH_DATAPTR                              BCH_DATAPTR_REG(BCH_BASE_PTR)
#define BCH_DATAPTR_SET                          BCH_DATAPTR_SET_REG(BCH_BASE_PTR)
#define BCH_DATAPTR_CLR                          BCH_DATAPTR_CLR_REG(BCH_BASE_PTR)
#define BCH_DATAPTR_TOG                          BCH_DATAPTR_TOG_REG(BCH_BASE_PTR)
#define BCH_METAPTR                              BCH_METAPTR_REG(BCH_BASE_PTR)
#define BCH_METAPTR_SET                          BCH_METAPTR_SET_REG(BCH_BASE_PTR)
#define BCH_METAPTR_CLR                          BCH_METAPTR_CLR_REG(BCH_BASE_PTR)
#define BCH_METAPTR_TOG                          BCH_METAPTR_TOG_REG(BCH_BASE_PTR)
#define BCH_LAYOUTSELECT                         BCH_LAYOUTSELECT_REG(BCH_BASE_PTR)
#define BCH_LAYOUTSELECT_SET                     BCH_LAYOUTSELECT_SET_REG(BCH_BASE_PTR)
#define BCH_LAYOUTSELECT_CLR                     BCH_LAYOUTSELECT_CLR_REG(BCH_BASE_PTR)
#define BCH_LAYOUTSELECT_TOG                     BCH_LAYOUTSELECT_TOG_REG(BCH_BASE_PTR)
#define BCH_FLASH0LAYOUT0                        BCH_FLASH0LAYOUT0_REG(BCH_BASE_PTR)
#define BCH_FLASH0LAYOUT0_SET                    BCH_FLASH0LAYOUT0_SET_REG(BCH_BASE_PTR)
#define BCH_FLASH0LAYOUT0_CLR                    BCH_FLASH0LAYOUT0_CLR_REG(BCH_BASE_PTR)
#define BCH_FLASH0LAYOUT0_TOG                    BCH_FLASH0LAYOUT0_TOG_REG(BCH_BASE_PTR)
#define BCH_FLASH0LAYOUT1                        BCH_FLASH0LAYOUT1_REG(BCH_BASE_PTR)
#define BCH_FLASH0LAYOUT1_SET                    BCH_FLASH0LAYOUT1_SET_REG(BCH_BASE_PTR)
#define BCH_FLASH0LAYOUT1_CLR                    BCH_FLASH0LAYOUT1_CLR_REG(BCH_BASE_PTR)
#define BCH_FLASH0LAYOUT1_TOG                    BCH_FLASH0LAYOUT1_TOG_REG(BCH_BASE_PTR)
#define BCH_FLASH1LAYOUT0                        BCH_FLASH1LAYOUT0_REG(BCH_BASE_PTR)
#define BCH_FLASH1LAYOUT0_SET                    BCH_FLASH1LAYOUT0_SET_REG(BCH_BASE_PTR)
#define BCH_FLASH1LAYOUT0_CLR                    BCH_FLASH1LAYOUT0_CLR_REG(BCH_BASE_PTR)
#define BCH_FLASH1LAYOUT0_TOG                    BCH_FLASH1LAYOUT0_TOG_REG(BCH_BASE_PTR)
#define BCH_FLASH1LAYOUT1                        BCH_FLASH1LAYOUT1_REG(BCH_BASE_PTR)
#define BCH_FLASH1LAYOUT1_SET                    BCH_FLASH1LAYOUT1_SET_REG(BCH_BASE_PTR)
#define BCH_FLASH1LAYOUT1_CLR                    BCH_FLASH1LAYOUT1_CLR_REG(BCH_BASE_PTR)
#define BCH_FLASH1LAYOUT1_TOG                    BCH_FLASH1LAYOUT1_TOG_REG(BCH_BASE_PTR)
#define BCH_FLASH2LAYOUT0                        BCH_FLASH2LAYOUT0_REG(BCH_BASE_PTR)
#define BCH_FLASH2LAYOUT0_SET                    BCH_FLASH2LAYOUT0_SET_REG(BCH_BASE_PTR)
#define BCH_FLASH2LAYOUT0_CLR                    BCH_FLASH2LAYOUT0_CLR_REG(BCH_BASE_PTR)
#define BCH_FLASH2LAYOUT0_TOG                    BCH_FLASH2LAYOUT0_TOG_REG(BCH_BASE_PTR)
#define BCH_FLASH2LAYOUT1                        BCH_FLASH2LAYOUT1_REG(BCH_BASE_PTR)
#define BCH_FLASH2LAYOUT1_SET                    BCH_FLASH2LAYOUT1_SET_REG(BCH_BASE_PTR)
#define BCH_FLASH2LAYOUT1_CLR                    BCH_FLASH2LAYOUT1_CLR_REG(BCH_BASE_PTR)
#define BCH_FLASH2LAYOUT1_TOG                    BCH_FLASH2LAYOUT1_TOG_REG(BCH_BASE_PTR)
#define BCH_FLASH3LAYOUT0                        BCH_FLASH3LAYOUT0_REG(BCH_BASE_PTR)
#define BCH_FLASH3LAYOUT0_SET                    BCH_FLASH3LAYOUT0_SET_REG(BCH_BASE_PTR)
#define BCH_FLASH3LAYOUT0_CLR                    BCH_FLASH3LAYOUT0_CLR_REG(BCH_BASE_PTR)
#define BCH_FLASH3LAYOUT0_TOG                    BCH_FLASH3LAYOUT0_TOG_REG(BCH_BASE_PTR)
#define BCH_FLASH3LAYOUT1                        BCH_FLASH3LAYOUT1_REG(BCH_BASE_PTR)
#define BCH_FLASH3LAYOUT1_SET                    BCH_FLASH3LAYOUT1_SET_REG(BCH_BASE_PTR)
#define BCH_FLASH3LAYOUT1_CLR                    BCH_FLASH3LAYOUT1_CLR_REG(BCH_BASE_PTR)
#define BCH_FLASH3LAYOUT1_TOG                    BCH_FLASH3LAYOUT1_TOG_REG(BCH_BASE_PTR)
#define BCH_DEBUG0                               BCH_DEBUG0_REG(BCH_BASE_PTR)
#define BCH_DEBUG0_SET                           BCH_DEBUG0_SET_REG(BCH_BASE_PTR)
#define BCH_DEBUG0_CLR                           BCH_DEBUG0_CLR_REG(BCH_BASE_PTR)
#define BCH_DEBUG0_TOG                           BCH_DEBUG0_TOG_REG(BCH_BASE_PTR)
#define BCH_DBGKESREAD                           BCH_DBGKESREAD_REG(BCH_BASE_PTR)
#define BCH_DBGKESREAD_SET                       BCH_DBGKESREAD_SET_REG(BCH_BASE_PTR)
#define BCH_DBGKESREAD_CLR                       BCH_DBGKESREAD_CLR_REG(BCH_BASE_PTR)
#define BCH_DBGKESREAD_TOG                       BCH_DBGKESREAD_TOG_REG(BCH_BASE_PTR)
#define BCH_DBGCSFEREAD                          BCH_DBGCSFEREAD_REG(BCH_BASE_PTR)
#define BCH_DBGCSFEREAD_SET                      BCH_DBGCSFEREAD_SET_REG(BCH_BASE_PTR)
#define BCH_DBGCSFEREAD_CLR                      BCH_DBGCSFEREAD_CLR_REG(BCH_BASE_PTR)
#define BCH_DBGCSFEREAD_TOG                      BCH_DBGCSFEREAD_TOG_REG(BCH_BASE_PTR)
#define BCH_DBGSYNDGENREAD                       BCH_DBGSYNDGENREAD_REG(BCH_BASE_PTR)
#define BCH_DBGSYNDGENREAD_SET                   BCH_DBGSYNDGENREAD_SET_REG(BCH_BASE_PTR)
#define BCH_DBGSYNDGENREAD_CLR                   BCH_DBGSYNDGENREAD_CLR_REG(BCH_BASE_PTR)
#define BCH_DBGSYNDGENREAD_TOG                   BCH_DBGSYNDGENREAD_TOG_REG(BCH_BASE_PTR)
#define BCH_DBGAHBMREAD                          BCH_DBGAHBMREAD_REG(BCH_BASE_PTR)
#define BCH_DBGAHBMREAD_SET                      BCH_DBGAHBMREAD_SET_REG(BCH_BASE_PTR)
#define BCH_DBGAHBMREAD_CLR                      BCH_DBGAHBMREAD_CLR_REG(BCH_BASE_PTR)
#define BCH_DBGAHBMREAD_TOG                      BCH_DBGAHBMREAD_TOG_REG(BCH_BASE_PTR)
#define BCH_BLOCKNAME                            BCH_BLOCKNAME_REG(BCH_BASE_PTR)
#define BCH_BLOCKNAME_SET                        BCH_BLOCKNAME_SET_REG(BCH_BASE_PTR)
#define BCH_BLOCKNAME_CLR                        BCH_BLOCKNAME_CLR_REG(BCH_BASE_PTR)
#define BCH_BLOCKNAME_TOG                        BCH_BLOCKNAME_TOG_REG(BCH_BASE_PTR)
#define BCH_VERSION                              BCH_VERSION_REG(BCH_BASE_PTR)
#define BCH_VERSION_SET                          BCH_VERSION_SET_REG(BCH_BASE_PTR)
#define BCH_VERSION_CLR                          BCH_VERSION_CLR_REG(BCH_BASE_PTR)
#define BCH_VERSION_TOG                          BCH_VERSION_TOG_REG(BCH_BASE_PTR)
#define BCH_DEBUG1                               BCH_DEBUG1_REG(BCH_BASE_PTR)
#define BCH_DEBUG1_SET                           BCH_DEBUG1_SET_REG(BCH_BASE_PTR)
#define BCH_DEBUG1_CLR                           BCH_DEBUG1_CLR_REG(BCH_BASE_PTR)
#define BCH_DEBUG1_TOG                           BCH_DEBUG1_TOG_REG(BCH_BASE_PTR)

/*!
 * @}
 */ /* end of group BCH_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group BCH_Peripheral */


/* ----------------------------------------------------------------------------
   -- CAN
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CAN_Peripheral CAN
 * @{
 */

/** CAN - Peripheral register structure */
typedef struct CAN_MemMap {
  uint32_t MCR;                                    /**< Module Configuration Register, offset: 0x0 */
  uint32_t CTRL1;                                  /**< Control 1 Register, offset: 0x4 */
  uint32_t TIMER;                                  /**< Free Running Timer Register, offset: 0x8 */
  uint8_t RESERVED_0[4];
  uint32_t RXMGMASK;                               /**< Rx Mailboxes Global Mask Register, offset: 0x10 */
  uint32_t RX14MASK;                               /**< Rx Buffer 14 Mask Register, offset: 0x14 */
  uint32_t RX15MASK;                               /**< Rx Buffer 15 Mask Register, offset: 0x18 */
  uint32_t ECR;                                    /**< Error Counter Register, offset: 0x1C */
  uint32_t ESR1;                                   /**< Error and Status 1 Register, offset: 0x20 */
  uint32_t IMASK2;                                 /**< Interrupt Masks 2 Register, offset: 0x24 */
  uint32_t IMASK1;                                 /**< Interrupt Masks 1 Register, offset: 0x28 */
  uint32_t IFLAG2;                                 /**< Interrupt Flags 2 Register, offset: 0x2C */
  uint32_t IFLAG1;                                 /**< Interrupt Flags 1 Register, offset: 0x30 */
  uint32_t CTRL2;                                  /**< Control 2 Register, offset: 0x34 */
  uint32_t ESR2;                                   /**< Error and Status 2 Register, offset: 0x38 */
  uint8_t RESERVED_1[8];
  uint32_t CRCR;                                   /**< CRC Register, offset: 0x44 */
  uint32_t RXFGMASK;                               /**< Rx FIFO Global Mask Register, offset: 0x48 */
  uint32_t RXFIR;                                  /**< Rx FIFO Information Register, offset: 0x4C */
  uint8_t RESERVED_2[48];
  struct {                                         /* offset: 0x80, array step: 0x10 */
    uint32_t CS;                                     /**< Message Buffer 0 CS Register..Message Buffer 63 CS Register, array offset: 0x80, array step: 0x10 */
    uint32_t ID;                                     /**< Message Buffer 0 ID Register..Message Buffer 63 ID Register, array offset: 0x84, array step: 0x10 */
    uint32_t WORD0;                                  /**< Message Buffer 0 WORD0 Register..Message Buffer 63 WORD0 Register, array offset: 0x88, array step: 0x10 */
    uint32_t WORD1;                                  /**< Message Buffer 0 WORD1 Register..Message Buffer 63 WORD1 Register, array offset: 0x8C, array step: 0x10 */
  } MB[64];
  uint8_t RESERVED_3[1024];
  uint32_t RXIMR[64];                              /**< Rx Individual Mask Registers, array offset: 0x880, array step: 0x4 */
  uint8_t RESERVED_4[96];
  uint32_t GFWR;                                   /**< Glitch Filter Width Registers, offset: 0x9E0 */
} volatile *CAN_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- CAN - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CAN_Register_Accessor_Macros CAN - Register accessor macros
 * @{
 */


/* CAN - Register accessors */
#define CAN_MCR_REG(base)                        ((base)->MCR)
#define CAN_CTRL1_REG(base)                      ((base)->CTRL1)
#define CAN_TIMER_REG(base)                      ((base)->TIMER)
#define CAN_RXMGMASK_REG(base)                   ((base)->RXMGMASK)
#define CAN_RX14MASK_REG(base)                   ((base)->RX14MASK)
#define CAN_RX15MASK_REG(base)                   ((base)->RX15MASK)
#define CAN_ECR_REG(base)                        ((base)->ECR)
#define CAN_ESR1_REG(base)                       ((base)->ESR1)
#define CAN_IMASK2_REG(base)                     ((base)->IMASK2)
#define CAN_IMASK1_REG(base)                     ((base)->IMASK1)
#define CAN_IFLAG2_REG(base)                     ((base)->IFLAG2)
#define CAN_IFLAG1_REG(base)                     ((base)->IFLAG1)
#define CAN_CTRL2_REG(base)                      ((base)->CTRL2)
#define CAN_ESR2_REG(base)                       ((base)->ESR2)
#define CAN_CRCR_REG(base)                       ((base)->CRCR)
#define CAN_RXFGMASK_REG(base)                   ((base)->RXFGMASK)
#define CAN_RXFIR_REG(base)                      ((base)->RXFIR)
#define CAN_CS_REG(base,index)                   ((base)->MB[index].CS)
#define CAN_ID_REG(base,index)                   ((base)->MB[index].ID)
#define CAN_WORD0_REG(base,index)                ((base)->MB[index].WORD0)
#define CAN_WORD1_REG(base,index)                ((base)->MB[index].WORD1)
#define CAN_RXIMR_REG(base,index)                ((base)->RXIMR[index])
#define CAN_GFWR_REG(base)                       ((base)->GFWR)

/*!
 * @}
 */ /* end of group CAN_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- CAN Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CAN_Register_Masks CAN Register Masks
 * @{
 */

/*! @name MCR - Module Configuration Register */
#define CAN_MCR_MAXMB_MASK                       (0x7FU)
#define CAN_MCR_MAXMB_SHIFT                      (0U)
#define CAN_MCR_MAXMB(x)                         (((uint32_t)(((uint32_t)(x)) << CAN_MCR_MAXMB_SHIFT)) & CAN_MCR_MAXMB_MASK)
#define CAN_MCR_IDAM_MASK                        (0x300U)
#define CAN_MCR_IDAM_SHIFT                       (8U)
#define CAN_MCR_IDAM(x)                          (((uint32_t)(((uint32_t)(x)) << CAN_MCR_IDAM_SHIFT)) & CAN_MCR_IDAM_MASK)
#define CAN_MCR_AEN_MASK                         (0x1000U)
#define CAN_MCR_AEN_SHIFT                        (12U)
#define CAN_MCR_LPRIOEN_MASK                     (0x2000U)
#define CAN_MCR_LPRIOEN_SHIFT                    (13U)
#define CAN_MCR_IRMQ_MASK                        (0x10000U)
#define CAN_MCR_IRMQ_SHIFT                       (16U)
#define CAN_MCR_SRXDIS_MASK                      (0x20000U)
#define CAN_MCR_SRXDIS_SHIFT                     (17U)
#define CAN_MCR_WAKSRC_MASK                      (0x80000U)
#define CAN_MCR_WAKSRC_SHIFT                     (19U)
#define CAN_MCR_LPMACK_MASK                      (0x100000U)
#define CAN_MCR_LPMACK_SHIFT                     (20U)
#define CAN_MCR_WRNEN_MASK                       (0x200000U)
#define CAN_MCR_WRNEN_SHIFT                      (21U)
#define CAN_MCR_SLFWAK_MASK                      (0x400000U)
#define CAN_MCR_SLFWAK_SHIFT                     (22U)
#define CAN_MCR_SUPV_MASK                        (0x800000U)
#define CAN_MCR_SUPV_SHIFT                       (23U)
#define CAN_MCR_FRZACK_MASK                      (0x1000000U)
#define CAN_MCR_FRZACK_SHIFT                     (24U)
#define CAN_MCR_SOFTRST_MASK                     (0x2000000U)
#define CAN_MCR_SOFTRST_SHIFT                    (25U)
#define CAN_MCR_WAKMSK_MASK                      (0x4000000U)
#define CAN_MCR_WAKMSK_SHIFT                     (26U)
#define CAN_MCR_NOTRDY_MASK                      (0x8000000U)
#define CAN_MCR_NOTRDY_SHIFT                     (27U)
#define CAN_MCR_HALT_MASK                        (0x10000000U)
#define CAN_MCR_HALT_SHIFT                       (28U)
#define CAN_MCR_RFEN_MASK                        (0x20000000U)
#define CAN_MCR_RFEN_SHIFT                       (29U)
#define CAN_MCR_FRZ_MASK                         (0x40000000U)
#define CAN_MCR_FRZ_SHIFT                        (30U)
#define CAN_MCR_MDIS_MASK                        (0x80000000U)
#define CAN_MCR_MDIS_SHIFT                       (31U)

/*! @name CTRL1 - Control 1 Register */
#define CAN_CTRL1_PROPSEG_MASK                   (0x7U)
#define CAN_CTRL1_PROPSEG_SHIFT                  (0U)
#define CAN_CTRL1_PROPSEG(x)                     (((uint32_t)(((uint32_t)(x)) << CAN_CTRL1_PROPSEG_SHIFT)) & CAN_CTRL1_PROPSEG_MASK)
#define CAN_CTRL1_LOM_MASK                       (0x8U)
#define CAN_CTRL1_LOM_SHIFT                      (3U)
#define CAN_CTRL1_LBUF_MASK                      (0x10U)
#define CAN_CTRL1_LBUF_SHIFT                     (4U)
#define CAN_CTRL1_TSYN_MASK                      (0x20U)
#define CAN_CTRL1_TSYN_SHIFT                     (5U)
#define CAN_CTRL1_BOFFREC_MASK                   (0x40U)
#define CAN_CTRL1_BOFFREC_SHIFT                  (6U)
#define CAN_CTRL1_SMP_MASK                       (0x80U)
#define CAN_CTRL1_SMP_SHIFT                      (7U)
#define CAN_CTRL1_RWRNMSK_MASK                   (0x400U)
#define CAN_CTRL1_RWRNMSK_SHIFT                  (10U)
#define CAN_CTRL1_TWRNMSK_MASK                   (0x800U)
#define CAN_CTRL1_TWRNMSK_SHIFT                  (11U)
#define CAN_CTRL1_LPB_MASK                       (0x1000U)
#define CAN_CTRL1_LPB_SHIFT                      (12U)
#define CAN_CTRL1_ERRMSK_MASK                    (0x4000U)
#define CAN_CTRL1_ERRMSK_SHIFT                   (14U)
#define CAN_CTRL1_BOFFMSK_MASK                   (0x8000U)
#define CAN_CTRL1_BOFFMSK_SHIFT                  (15U)
#define CAN_CTRL1_PSEG2_MASK                     (0x70000U)
#define CAN_CTRL1_PSEG2_SHIFT                    (16U)
#define CAN_CTRL1_PSEG2(x)                       (((uint32_t)(((uint32_t)(x)) << CAN_CTRL1_PSEG2_SHIFT)) & CAN_CTRL1_PSEG2_MASK)
#define CAN_CTRL1_PSEG1_MASK                     (0x380000U)
#define CAN_CTRL1_PSEG1_SHIFT                    (19U)
#define CAN_CTRL1_PSEG1(x)                       (((uint32_t)(((uint32_t)(x)) << CAN_CTRL1_PSEG1_SHIFT)) & CAN_CTRL1_PSEG1_MASK)
#define CAN_CTRL1_RJW_MASK                       (0xC00000U)
#define CAN_CTRL1_RJW_SHIFT                      (22U)
#define CAN_CTRL1_RJW(x)                         (((uint32_t)(((uint32_t)(x)) << CAN_CTRL1_RJW_SHIFT)) & CAN_CTRL1_RJW_MASK)
#define CAN_CTRL1_PRESDIV_MASK                   (0xFF000000U)
#define CAN_CTRL1_PRESDIV_SHIFT                  (24U)
#define CAN_CTRL1_PRESDIV(x)                     (((uint32_t)(((uint32_t)(x)) << CAN_CTRL1_PRESDIV_SHIFT)) & CAN_CTRL1_PRESDIV_MASK)

/*! @name TIMER - Free Running Timer Register */
#define CAN_TIMER_TIMER_MASK                     (0xFFFFU)
#define CAN_TIMER_TIMER_SHIFT                    (0U)
#define CAN_TIMER_TIMER(x)                       (((uint32_t)(((uint32_t)(x)) << CAN_TIMER_TIMER_SHIFT)) & CAN_TIMER_TIMER_MASK)

/*! @name RXMGMASK - Rx Mailboxes Global Mask Register */
#define CAN_RXMGMASK_MG_MASK                     (0xFFFFFFFFU)
#define CAN_RXMGMASK_MG_SHIFT                    (0U)
#define CAN_RXMGMASK_MG(x)                       (((uint32_t)(((uint32_t)(x)) << CAN_RXMGMASK_MG_SHIFT)) & CAN_RXMGMASK_MG_MASK)

/*! @name RX14MASK - Rx Buffer 14 Mask Register */
#define CAN_RX14MASK_RX14M_MASK                  (0xFFFFFFFFU)
#define CAN_RX14MASK_RX14M_SHIFT                 (0U)
#define CAN_RX14MASK_RX14M(x)                    (((uint32_t)(((uint32_t)(x)) << CAN_RX14MASK_RX14M_SHIFT)) & CAN_RX14MASK_RX14M_MASK)

/*! @name RX15MASK - Rx Buffer 15 Mask Register */
#define CAN_RX15MASK_RX15M_MASK                  (0xFFFFFFFFU)
#define CAN_RX15MASK_RX15M_SHIFT                 (0U)
#define CAN_RX15MASK_RX15M(x)                    (((uint32_t)(((uint32_t)(x)) << CAN_RX15MASK_RX15M_SHIFT)) & CAN_RX15MASK_RX15M_MASK)

/*! @name ECR - Error Counter Register */
#define CAN_ECR_Tx_Err_Counter_MASK              (0xFFU)
#define CAN_ECR_Tx_Err_Counter_SHIFT             (0U)
#define CAN_ECR_Tx_Err_Counter(x)                (((uint32_t)(((uint32_t)(x)) << CAN_ECR_Tx_Err_Counter_SHIFT)) & CAN_ECR_Tx_Err_Counter_MASK)
#define CAN_ECR_Rx_Err_Counter_MASK              (0xFF00U)
#define CAN_ECR_Rx_Err_Counter_SHIFT             (8U)
#define CAN_ECR_Rx_Err_Counter(x)                (((uint32_t)(((uint32_t)(x)) << CAN_ECR_Rx_Err_Counter_SHIFT)) & CAN_ECR_Rx_Err_Counter_MASK)

/*! @name ESR1 - Error and Status 1 Register */
#define CAN_ESR1_WAKINT_MASK                     (0x1U)
#define CAN_ESR1_WAKINT_SHIFT                    (0U)
#define CAN_ESR1_ERRINT_MASK                     (0x2U)
#define CAN_ESR1_ERRINT_SHIFT                    (1U)
#define CAN_ESR1_BOFFINT_MASK                    (0x4U)
#define CAN_ESR1_BOFFINT_SHIFT                   (2U)
#define CAN_ESR1_RX_MASK                         (0x8U)
#define CAN_ESR1_RX_SHIFT                        (3U)
#define CAN_ESR1_FLTCONF_MASK                    (0x30U)
#define CAN_ESR1_FLTCONF_SHIFT                   (4U)
#define CAN_ESR1_FLTCONF(x)                      (((uint32_t)(((uint32_t)(x)) << CAN_ESR1_FLTCONF_SHIFT)) & CAN_ESR1_FLTCONF_MASK)
#define CAN_ESR1_TX_MASK                         (0x40U)
#define CAN_ESR1_TX_SHIFT                        (6U)
#define CAN_ESR1_IDLE_MASK                       (0x80U)
#define CAN_ESR1_IDLE_SHIFT                      (7U)
#define CAN_ESR1_RXWRN_MASK                      (0x100U)
#define CAN_ESR1_RXWRN_SHIFT                     (8U)
#define CAN_ESR1_TXWRN_MASK                      (0x200U)
#define CAN_ESR1_TXWRN_SHIFT                     (9U)
#define CAN_ESR1_STFERR_MASK                     (0x400U)
#define CAN_ESR1_STFERR_SHIFT                    (10U)
#define CAN_ESR1_FRMERR_MASK                     (0x800U)
#define CAN_ESR1_FRMERR_SHIFT                    (11U)
#define CAN_ESR1_CRCERR_MASK                     (0x1000U)
#define CAN_ESR1_CRCERR_SHIFT                    (12U)
#define CAN_ESR1_ACKERR_MASK                     (0x2000U)
#define CAN_ESR1_ACKERR_SHIFT                    (13U)
#define CAN_ESR1_BIT0ERR_MASK                    (0x4000U)
#define CAN_ESR1_BIT0ERR_SHIFT                   (14U)
#define CAN_ESR1_BIT1ERR_MASK                    (0x8000U)
#define CAN_ESR1_BIT1ERR_SHIFT                   (15U)
#define CAN_ESR1_RWRNINT_MASK                    (0x10000U)
#define CAN_ESR1_RWRNINT_SHIFT                   (16U)
#define CAN_ESR1_TWRNINT_MASK                    (0x20000U)
#define CAN_ESR1_TWRNINT_SHIFT                   (17U)
#define CAN_ESR1_SYNCH_MASK                      (0x40000U)
#define CAN_ESR1_SYNCH_SHIFT                     (18U)

/*! @name IMASK2 - Interrupt Masks 2 Register */
#define CAN_IMASK2_BUFHM_MASK                    (0xFFFFFFFFU)
#define CAN_IMASK2_BUFHM_SHIFT                   (0U)
#define CAN_IMASK2_BUFHM(x)                      (((uint32_t)(((uint32_t)(x)) << CAN_IMASK2_BUFHM_SHIFT)) & CAN_IMASK2_BUFHM_MASK)

/*! @name IMASK1 - Interrupt Masks 1 Register */
#define CAN_IMASK1_BUFLM_MASK                    (0xFFFFFFFFU)
#define CAN_IMASK1_BUFLM_SHIFT                   (0U)
#define CAN_IMASK1_BUFLM(x)                      (((uint32_t)(((uint32_t)(x)) << CAN_IMASK1_BUFLM_SHIFT)) & CAN_IMASK1_BUFLM_MASK)

/*! @name IFLAG2 - Interrupt Flags 2 Register */
#define CAN_IFLAG2_BUFHI_MASK                    (0xFFFFFFFFU)
#define CAN_IFLAG2_BUFHI_SHIFT                   (0U)
#define CAN_IFLAG2_BUFHI(x)                      (((uint32_t)(((uint32_t)(x)) << CAN_IFLAG2_BUFHI_SHIFT)) & CAN_IFLAG2_BUFHI_MASK)

/*! @name IFLAG1 - Interrupt Flags 1 Register */
#define CAN_IFLAG1_BUF4TO0I_MASK                 (0x1FU)
#define CAN_IFLAG1_BUF4TO0I_SHIFT                (0U)
#define CAN_IFLAG1_BUF4TO0I(x)                   (((uint32_t)(((uint32_t)(x)) << CAN_IFLAG1_BUF4TO0I_SHIFT)) & CAN_IFLAG1_BUF4TO0I_MASK)
#define CAN_IFLAG1_BUF5I_MASK                    (0x20U)
#define CAN_IFLAG1_BUF5I_SHIFT                   (5U)
#define CAN_IFLAG1_BUF6I_MASK                    (0x40U)
#define CAN_IFLAG1_BUF6I_SHIFT                   (6U)
#define CAN_IFLAG1_BUF7I_MASK                    (0x80U)
#define CAN_IFLAG1_BUF7I_SHIFT                   (7U)
#define CAN_IFLAG1_BUF31TO8I_MASK                (0xFFFFFF00U)
#define CAN_IFLAG1_BUF31TO8I_SHIFT               (8U)
#define CAN_IFLAG1_BUF31TO8I(x)                  (((uint32_t)(((uint32_t)(x)) << CAN_IFLAG1_BUF31TO8I_SHIFT)) & CAN_IFLAG1_BUF31TO8I_MASK)

/*! @name CTRL2 - Control 2 Register */
#define CAN_CTRL2_EACEN_MASK                     (0x10000U)
#define CAN_CTRL2_EACEN_SHIFT                    (16U)
#define CAN_CTRL2_RRS_MASK                       (0x20000U)
#define CAN_CTRL2_RRS_SHIFT                      (17U)
#define CAN_CTRL2_MRP_MASK                       (0x40000U)
#define CAN_CTRL2_MRP_SHIFT                      (18U)
#define CAN_CTRL2_TASD_MASK                      (0xF80000U)
#define CAN_CTRL2_TASD_SHIFT                     (19U)
#define CAN_CTRL2_TASD(x)                        (((uint32_t)(((uint32_t)(x)) << CAN_CTRL2_TASD_SHIFT)) & CAN_CTRL2_TASD_MASK)
#define CAN_CTRL2_RFFN_MASK                      (0xF000000U)
#define CAN_CTRL2_RFFN_SHIFT                     (24U)
#define CAN_CTRL2_RFFN(x)                        (((uint32_t)(((uint32_t)(x)) << CAN_CTRL2_RFFN_SHIFT)) & CAN_CTRL2_RFFN_MASK)
#define CAN_CTRL2_WRMFRZ_MASK                    (0x10000000U)
#define CAN_CTRL2_WRMFRZ_SHIFT                   (28U)

/*! @name ESR2 - Error and Status 2 Register */
#define CAN_ESR2_IMB_MASK                        (0x2000U)
#define CAN_ESR2_IMB_SHIFT                       (13U)
#define CAN_ESR2_VPS_MASK                        (0x4000U)
#define CAN_ESR2_VPS_SHIFT                       (14U)
#define CAN_ESR2_LPTM_MASK                       (0x7F0000U)
#define CAN_ESR2_LPTM_SHIFT                      (16U)
#define CAN_ESR2_LPTM(x)                         (((uint32_t)(((uint32_t)(x)) << CAN_ESR2_LPTM_SHIFT)) & CAN_ESR2_LPTM_MASK)

/*! @name CRCR - CRC Register */
#define CAN_CRCR_TXCRC_MASK                      (0x7FFFU)
#define CAN_CRCR_TXCRC_SHIFT                     (0U)
#define CAN_CRCR_TXCRC(x)                        (((uint32_t)(((uint32_t)(x)) << CAN_CRCR_TXCRC_SHIFT)) & CAN_CRCR_TXCRC_MASK)
#define CAN_CRCR_MBCRC_MASK                      (0x7F0000U)
#define CAN_CRCR_MBCRC_SHIFT                     (16U)
#define CAN_CRCR_MBCRC(x)                        (((uint32_t)(((uint32_t)(x)) << CAN_CRCR_MBCRC_SHIFT)) & CAN_CRCR_MBCRC_MASK)

/*! @name RXFGMASK - Rx FIFO Global Mask Register */
#define CAN_RXFGMASK_FGM_MASK                    (0xFFFFFFFFU)
#define CAN_RXFGMASK_FGM_SHIFT                   (0U)
#define CAN_RXFGMASK_FGM(x)                      (((uint32_t)(((uint32_t)(x)) << CAN_RXFGMASK_FGM_SHIFT)) & CAN_RXFGMASK_FGM_MASK)

/*! @name RXFIR - Rx FIFO Information Register */
#define CAN_RXFIR_IDHIT_MASK                     (0x1FFU)
#define CAN_RXFIR_IDHIT_SHIFT                    (0U)
#define CAN_RXFIR_IDHIT(x)                       (((uint32_t)(((uint32_t)(x)) << CAN_RXFIR_IDHIT_SHIFT)) & CAN_RXFIR_IDHIT_MASK)

/*! @name CS - Message Buffer 0 CS Register..Message Buffer 63 CS Register */
#define CAN_CS_TIME_STAMP_MASK                   (0xFFFFU)
#define CAN_CS_TIME_STAMP_SHIFT                  (0U)
#define CAN_CS_TIME_STAMP(x)                     (((uint32_t)(((uint32_t)(x)) << CAN_CS_TIME_STAMP_SHIFT)) & CAN_CS_TIME_STAMP_MASK)
#define CAN_CS_DLC_MASK                          (0xF0000U)
#define CAN_CS_DLC_SHIFT                         (16U)
#define CAN_CS_DLC(x)                            (((uint32_t)(((uint32_t)(x)) << CAN_CS_DLC_SHIFT)) & CAN_CS_DLC_MASK)
#define CAN_CS_RTR_MASK                          (0x100000U)
#define CAN_CS_RTR_SHIFT                         (20U)
#define CAN_CS_IDE_MASK                          (0x200000U)
#define CAN_CS_IDE_SHIFT                         (21U)
#define CAN_CS_SRR_MASK                          (0x400000U)
#define CAN_CS_SRR_SHIFT                         (22U)
#define CAN_CS_CODE_MASK                         (0xF000000U)
#define CAN_CS_CODE_SHIFT                        (24U)
#define CAN_CS_CODE(x)                           (((uint32_t)(((uint32_t)(x)) << CAN_CS_CODE_SHIFT)) & CAN_CS_CODE_MASK)

/* The count of CAN_CS */
#define CAN_CS_COUNT                             (64U)

/*! @name ID - Message Buffer 0 ID Register..Message Buffer 63 ID Register */
#define CAN_ID_EXT_MASK                          (0x3FFFFU)
#define CAN_ID_EXT_SHIFT                         (0U)
#define CAN_ID_EXT(x)                            (((uint32_t)(((uint32_t)(x)) << CAN_ID_EXT_SHIFT)) & CAN_ID_EXT_MASK)
#define CAN_ID_STD_MASK                          (0x1FFC0000U)
#define CAN_ID_STD_SHIFT                         (18U)
#define CAN_ID_STD(x)                            (((uint32_t)(((uint32_t)(x)) << CAN_ID_STD_SHIFT)) & CAN_ID_STD_MASK)
#define CAN_ID_PRIO_MASK                         (0xE0000000U)
#define CAN_ID_PRIO_SHIFT                        (29U)
#define CAN_ID_PRIO(x)                           (((uint32_t)(((uint32_t)(x)) << CAN_ID_PRIO_SHIFT)) & CAN_ID_PRIO_MASK)

/* The count of CAN_ID */
#define CAN_ID_COUNT                             (64U)

/*! @name WORD0 - Message Buffer 0 WORD0 Register..Message Buffer 63 WORD0 Register */
#define CAN_WORD0_DATA_BYTE_3_MASK               (0xFFU)
#define CAN_WORD0_DATA_BYTE_3_SHIFT              (0U)
#define CAN_WORD0_DATA_BYTE_3(x)                 (((uint32_t)(((uint32_t)(x)) << CAN_WORD0_DATA_BYTE_3_SHIFT)) & CAN_WORD0_DATA_BYTE_3_MASK)
#define CAN_WORD0_DATA_BYTE_2_MASK               (0xFF00U)
#define CAN_WORD0_DATA_BYTE_2_SHIFT              (8U)
#define CAN_WORD0_DATA_BYTE_2(x)                 (((uint32_t)(((uint32_t)(x)) << CAN_WORD0_DATA_BYTE_2_SHIFT)) & CAN_WORD0_DATA_BYTE_2_MASK)
#define CAN_WORD0_DATA_BYTE_1_MASK               (0xFF0000U)
#define CAN_WORD0_DATA_BYTE_1_SHIFT              (16U)
#define CAN_WORD0_DATA_BYTE_1(x)                 (((uint32_t)(((uint32_t)(x)) << CAN_WORD0_DATA_BYTE_1_SHIFT)) & CAN_WORD0_DATA_BYTE_1_MASK)
#define CAN_WORD0_DATA_BYTE_0_MASK               (0xFF000000U)
#define CAN_WORD0_DATA_BYTE_0_SHIFT              (24U)
#define CAN_WORD0_DATA_BYTE_0(x)                 (((uint32_t)(((uint32_t)(x)) << CAN_WORD0_DATA_BYTE_0_SHIFT)) & CAN_WORD0_DATA_BYTE_0_MASK)

/* The count of CAN_WORD0 */
#define CAN_WORD0_COUNT                          (64U)

/*! @name WORD1 - Message Buffer 0 WORD1 Register..Message Buffer 63 WORD1 Register */
#define CAN_WORD1_DATA_BYTE_7_MASK               (0xFFU)
#define CAN_WORD1_DATA_BYTE_7_SHIFT              (0U)
#define CAN_WORD1_DATA_BYTE_7(x)                 (((uint32_t)(((uint32_t)(x)) << CAN_WORD1_DATA_BYTE_7_SHIFT)) & CAN_WORD1_DATA_BYTE_7_MASK)
#define CAN_WORD1_DATA_BYTE_6_MASK               (0xFF00U)
#define CAN_WORD1_DATA_BYTE_6_SHIFT              (8U)
#define CAN_WORD1_DATA_BYTE_6(x)                 (((uint32_t)(((uint32_t)(x)) << CAN_WORD1_DATA_BYTE_6_SHIFT)) & CAN_WORD1_DATA_BYTE_6_MASK)
#define CAN_WORD1_DATA_BYTE_5_MASK               (0xFF0000U)
#define CAN_WORD1_DATA_BYTE_5_SHIFT              (16U)
#define CAN_WORD1_DATA_BYTE_5(x)                 (((uint32_t)(((uint32_t)(x)) << CAN_WORD1_DATA_BYTE_5_SHIFT)) & CAN_WORD1_DATA_BYTE_5_MASK)
#define CAN_WORD1_DATA_BYTE_4_MASK               (0xFF000000U)
#define CAN_WORD1_DATA_BYTE_4_SHIFT              (24U)
#define CAN_WORD1_DATA_BYTE_4(x)                 (((uint32_t)(((uint32_t)(x)) << CAN_WORD1_DATA_BYTE_4_SHIFT)) & CAN_WORD1_DATA_BYTE_4_MASK)

/* The count of CAN_WORD1 */
#define CAN_WORD1_COUNT                          (64U)

/*! @name RXIMR - Rx Individual Mask Registers */
#define CAN_RXIMR_MI_MASK                        (0xFFFFFFFFU)
#define CAN_RXIMR_MI_SHIFT                       (0U)
#define CAN_RXIMR_MI(x)                          (((uint32_t)(((uint32_t)(x)) << CAN_RXIMR_MI_SHIFT)) & CAN_RXIMR_MI_MASK)

/* The count of CAN_RXIMR */
#define CAN_RXIMR_COUNT                          (64U)

/*! @name GFWR - Glitch Filter Width Registers */
#define CAN_GFWR_GFWR_MASK                       (0xFFU)
#define CAN_GFWR_GFWR_SHIFT                      (0U)
#define CAN_GFWR_GFWR(x)                         (((uint32_t)(((uint32_t)(x)) << CAN_GFWR_GFWR_SHIFT)) & CAN_GFWR_GFWR_MASK)


/*!
 * @}
 */ /* end of group CAN_Register_Masks */


/* CAN - Peripheral instance base addresses */
/** Peripheral CAN1 base pointer */
#define CAN1_BASE_PTR                            ((CAN_MemMapPtr)0x30A00000u)
/** Peripheral CAN2 base pointer */
#define CAN2_BASE_PTR                            ((CAN_MemMapPtr)0x30A10000u)
/** Array initializer of CAN peripheral base pointers */
#define CAN_BASE_PTRS                            { CAN1_BASE_PTR, CAN2_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- CAN - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CAN_Register_Accessor_Macros CAN - Register accessor macros
 * @{
 */


/* CAN - Register instance definitions */
/* CAN1 */
#define CAN1_MCR                                 CAN_MCR_REG(CAN1_BASE_PTR)
#define CAN1_CTRL1                               CAN_CTRL1_REG(CAN1_BASE_PTR)
#define CAN1_TIMER                               CAN_TIMER_REG(CAN1_BASE_PTR)
#define CAN1_RXMGMASK                            CAN_RXMGMASK_REG(CAN1_BASE_PTR)
#define CAN1_RX14MASK                            CAN_RX14MASK_REG(CAN1_BASE_PTR)
#define CAN1_RX15MASK                            CAN_RX15MASK_REG(CAN1_BASE_PTR)
#define CAN1_ECR                                 CAN_ECR_REG(CAN1_BASE_PTR)
#define CAN1_ESR1                                CAN_ESR1_REG(CAN1_BASE_PTR)
#define CAN1_IMASK2                              CAN_IMASK2_REG(CAN1_BASE_PTR)
#define CAN1_IMASK1                              CAN_IMASK1_REG(CAN1_BASE_PTR)
#define CAN1_IFLAG2                              CAN_IFLAG2_REG(CAN1_BASE_PTR)
#define CAN1_IFLAG1                              CAN_IFLAG1_REG(CAN1_BASE_PTR)
#define CAN1_CTRL2                               CAN_CTRL2_REG(CAN1_BASE_PTR)
#define CAN1_ESR2                                CAN_ESR2_REG(CAN1_BASE_PTR)
#define CAN1_CRCR                                CAN_CRCR_REG(CAN1_BASE_PTR)
#define CAN1_RXFGMASK                            CAN_RXFGMASK_REG(CAN1_BASE_PTR)
#define CAN1_RXFIR                               CAN_RXFIR_REG(CAN1_BASE_PTR)
#define CAN1_CS0                                 CAN_CS_REG(CAN1_BASE_PTR,0)
#define CAN1_ID0                                 CAN_ID_REG(CAN1_BASE_PTR,0)
#define CAN1_WORD00                              CAN_WORD0_REG(CAN1_BASE_PTR,0)
#define CAN1_WORD10                              CAN_WORD1_REG(CAN1_BASE_PTR,0)
#define CAN1_CS1                                 CAN_CS_REG(CAN1_BASE_PTR,1)
#define CAN1_ID1                                 CAN_ID_REG(CAN1_BASE_PTR,1)
#define CAN1_WORD01                              CAN_WORD0_REG(CAN1_BASE_PTR,1)
#define CAN1_WORD11                              CAN_WORD1_REG(CAN1_BASE_PTR,1)
#define CAN1_CS2                                 CAN_CS_REG(CAN1_BASE_PTR,2)
#define CAN1_ID2                                 CAN_ID_REG(CAN1_BASE_PTR,2)
#define CAN1_WORD02                              CAN_WORD0_REG(CAN1_BASE_PTR,2)
#define CAN1_WORD12                              CAN_WORD1_REG(CAN1_BASE_PTR,2)
#define CAN1_CS3                                 CAN_CS_REG(CAN1_BASE_PTR,3)
#define CAN1_ID3                                 CAN_ID_REG(CAN1_BASE_PTR,3)
#define CAN1_WORD03                              CAN_WORD0_REG(CAN1_BASE_PTR,3)
#define CAN1_WORD13                              CAN_WORD1_REG(CAN1_BASE_PTR,3)
#define CAN1_CS4                                 CAN_CS_REG(CAN1_BASE_PTR,4)
#define CAN1_ID4                                 CAN_ID_REG(CAN1_BASE_PTR,4)
#define CAN1_WORD04                              CAN_WORD0_REG(CAN1_BASE_PTR,4)
#define CAN1_WORD14                              CAN_WORD1_REG(CAN1_BASE_PTR,4)
#define CAN1_CS5                                 CAN_CS_REG(CAN1_BASE_PTR,5)
#define CAN1_ID5                                 CAN_ID_REG(CAN1_BASE_PTR,5)
#define CAN1_WORD05                              CAN_WORD0_REG(CAN1_BASE_PTR,5)
#define CAN1_WORD15                              CAN_WORD1_REG(CAN1_BASE_PTR,5)
#define CAN1_CS6                                 CAN_CS_REG(CAN1_BASE_PTR,6)
#define CAN1_ID6                                 CAN_ID_REG(CAN1_BASE_PTR,6)
#define CAN1_WORD06                              CAN_WORD0_REG(CAN1_BASE_PTR,6)
#define CAN1_WORD16                              CAN_WORD1_REG(CAN1_BASE_PTR,6)
#define CAN1_CS7                                 CAN_CS_REG(CAN1_BASE_PTR,7)
#define CAN1_ID7                                 CAN_ID_REG(CAN1_BASE_PTR,7)
#define CAN1_WORD07                              CAN_WORD0_REG(CAN1_BASE_PTR,7)
#define CAN1_WORD17                              CAN_WORD1_REG(CAN1_BASE_PTR,7)
#define CAN1_CS8                                 CAN_CS_REG(CAN1_BASE_PTR,8)
#define CAN1_ID8                                 CAN_ID_REG(CAN1_BASE_PTR,8)
#define CAN1_WORD08                              CAN_WORD0_REG(CAN1_BASE_PTR,8)
#define CAN1_WORD18                              CAN_WORD1_REG(CAN1_BASE_PTR,8)
#define CAN1_CS9                                 CAN_CS_REG(CAN1_BASE_PTR,9)
#define CAN1_ID9                                 CAN_ID_REG(CAN1_BASE_PTR,9)
#define CAN1_WORD09                              CAN_WORD0_REG(CAN1_BASE_PTR,9)
#define CAN1_WORD19                              CAN_WORD1_REG(CAN1_BASE_PTR,9)
#define CAN1_CS10                                CAN_CS_REG(CAN1_BASE_PTR,10)
#define CAN1_ID10                                CAN_ID_REG(CAN1_BASE_PTR,10)
#define CAN1_WORD010                             CAN_WORD0_REG(CAN1_BASE_PTR,10)
#define CAN1_WORD110                             CAN_WORD1_REG(CAN1_BASE_PTR,10)
#define CAN1_CS11                                CAN_CS_REG(CAN1_BASE_PTR,11)
#define CAN1_ID11                                CAN_ID_REG(CAN1_BASE_PTR,11)
#define CAN1_WORD011                             CAN_WORD0_REG(CAN1_BASE_PTR,11)
#define CAN1_WORD111                             CAN_WORD1_REG(CAN1_BASE_PTR,11)
#define CAN1_CS12                                CAN_CS_REG(CAN1_BASE_PTR,12)
#define CAN1_ID12                                CAN_ID_REG(CAN1_BASE_PTR,12)
#define CAN1_WORD012                             CAN_WORD0_REG(CAN1_BASE_PTR,12)
#define CAN1_WORD112                             CAN_WORD1_REG(CAN1_BASE_PTR,12)
#define CAN1_CS13                                CAN_CS_REG(CAN1_BASE_PTR,13)
#define CAN1_ID13                                CAN_ID_REG(CAN1_BASE_PTR,13)
#define CAN1_WORD013                             CAN_WORD0_REG(CAN1_BASE_PTR,13)
#define CAN1_WORD113                             CAN_WORD1_REG(CAN1_BASE_PTR,13)
#define CAN1_CS14                                CAN_CS_REG(CAN1_BASE_PTR,14)
#define CAN1_ID14                                CAN_ID_REG(CAN1_BASE_PTR,14)
#define CAN1_WORD014                             CAN_WORD0_REG(CAN1_BASE_PTR,14)
#define CAN1_WORD114                             CAN_WORD1_REG(CAN1_BASE_PTR,14)
#define CAN1_CS15                                CAN_CS_REG(CAN1_BASE_PTR,15)
#define CAN1_ID15                                CAN_ID_REG(CAN1_BASE_PTR,15)
#define CAN1_WORD015                             CAN_WORD0_REG(CAN1_BASE_PTR,15)
#define CAN1_WORD115                             CAN_WORD1_REG(CAN1_BASE_PTR,15)
#define CAN1_CS16                                CAN_CS_REG(CAN1_BASE_PTR,16)
#define CAN1_ID16                                CAN_ID_REG(CAN1_BASE_PTR,16)
#define CAN1_WORD016                             CAN_WORD0_REG(CAN1_BASE_PTR,16)
#define CAN1_WORD116                             CAN_WORD1_REG(CAN1_BASE_PTR,16)
#define CAN1_CS17                                CAN_CS_REG(CAN1_BASE_PTR,17)
#define CAN1_ID17                                CAN_ID_REG(CAN1_BASE_PTR,17)
#define CAN1_WORD017                             CAN_WORD0_REG(CAN1_BASE_PTR,17)
#define CAN1_WORD117                             CAN_WORD1_REG(CAN1_BASE_PTR,17)
#define CAN1_CS18                                CAN_CS_REG(CAN1_BASE_PTR,18)
#define CAN1_ID18                                CAN_ID_REG(CAN1_BASE_PTR,18)
#define CAN1_WORD018                             CAN_WORD0_REG(CAN1_BASE_PTR,18)
#define CAN1_WORD118                             CAN_WORD1_REG(CAN1_BASE_PTR,18)
#define CAN1_CS19                                CAN_CS_REG(CAN1_BASE_PTR,19)
#define CAN1_ID19                                CAN_ID_REG(CAN1_BASE_PTR,19)
#define CAN1_WORD019                             CAN_WORD0_REG(CAN1_BASE_PTR,19)
#define CAN1_WORD119                             CAN_WORD1_REG(CAN1_BASE_PTR,19)
#define CAN1_CS20                                CAN_CS_REG(CAN1_BASE_PTR,20)
#define CAN1_ID20                                CAN_ID_REG(CAN1_BASE_PTR,20)
#define CAN1_WORD020                             CAN_WORD0_REG(CAN1_BASE_PTR,20)
#define CAN1_WORD120                             CAN_WORD1_REG(CAN1_BASE_PTR,20)
#define CAN1_CS21                                CAN_CS_REG(CAN1_BASE_PTR,21)
#define CAN1_ID21                                CAN_ID_REG(CAN1_BASE_PTR,21)
#define CAN1_WORD021                             CAN_WORD0_REG(CAN1_BASE_PTR,21)
#define CAN1_WORD121                             CAN_WORD1_REG(CAN1_BASE_PTR,21)
#define CAN1_CS22                                CAN_CS_REG(CAN1_BASE_PTR,22)
#define CAN1_ID22                                CAN_ID_REG(CAN1_BASE_PTR,22)
#define CAN1_WORD022                             CAN_WORD0_REG(CAN1_BASE_PTR,22)
#define CAN1_WORD122                             CAN_WORD1_REG(CAN1_BASE_PTR,22)
#define CAN1_CS23                                CAN_CS_REG(CAN1_BASE_PTR,23)
#define CAN1_ID23                                CAN_ID_REG(CAN1_BASE_PTR,23)
#define CAN1_WORD023                             CAN_WORD0_REG(CAN1_BASE_PTR,23)
#define CAN1_WORD123                             CAN_WORD1_REG(CAN1_BASE_PTR,23)
#define CAN1_CS24                                CAN_CS_REG(CAN1_BASE_PTR,24)
#define CAN1_ID24                                CAN_ID_REG(CAN1_BASE_PTR,24)
#define CAN1_WORD024                             CAN_WORD0_REG(CAN1_BASE_PTR,24)
#define CAN1_WORD124                             CAN_WORD1_REG(CAN1_BASE_PTR,24)
#define CAN1_CS25                                CAN_CS_REG(CAN1_BASE_PTR,25)
#define CAN1_ID25                                CAN_ID_REG(CAN1_BASE_PTR,25)
#define CAN1_WORD025                             CAN_WORD0_REG(CAN1_BASE_PTR,25)
#define CAN1_WORD125                             CAN_WORD1_REG(CAN1_BASE_PTR,25)
#define CAN1_CS26                                CAN_CS_REG(CAN1_BASE_PTR,26)
#define CAN1_ID26                                CAN_ID_REG(CAN1_BASE_PTR,26)
#define CAN1_WORD026                             CAN_WORD0_REG(CAN1_BASE_PTR,26)
#define CAN1_WORD126                             CAN_WORD1_REG(CAN1_BASE_PTR,26)
#define CAN1_CS27                                CAN_CS_REG(CAN1_BASE_PTR,27)
#define CAN1_ID27                                CAN_ID_REG(CAN1_BASE_PTR,27)
#define CAN1_WORD027                             CAN_WORD0_REG(CAN1_BASE_PTR,27)
#define CAN1_WORD127                             CAN_WORD1_REG(CAN1_BASE_PTR,27)
#define CAN1_CS28                                CAN_CS_REG(CAN1_BASE_PTR,28)
#define CAN1_ID28                                CAN_ID_REG(CAN1_BASE_PTR,28)
#define CAN1_WORD028                             CAN_WORD0_REG(CAN1_BASE_PTR,28)
#define CAN1_WORD128                             CAN_WORD1_REG(CAN1_BASE_PTR,28)
#define CAN1_CS29                                CAN_CS_REG(CAN1_BASE_PTR,29)
#define CAN1_ID29                                CAN_ID_REG(CAN1_BASE_PTR,29)
#define CAN1_WORD029                             CAN_WORD0_REG(CAN1_BASE_PTR,29)
#define CAN1_WORD129                             CAN_WORD1_REG(CAN1_BASE_PTR,29)
#define CAN1_CS30                                CAN_CS_REG(CAN1_BASE_PTR,30)
#define CAN1_ID30                                CAN_ID_REG(CAN1_BASE_PTR,30)
#define CAN1_WORD030                             CAN_WORD0_REG(CAN1_BASE_PTR,30)
#define CAN1_WORD130                             CAN_WORD1_REG(CAN1_BASE_PTR,30)
#define CAN1_CS31                                CAN_CS_REG(CAN1_BASE_PTR,31)
#define CAN1_ID31                                CAN_ID_REG(CAN1_BASE_PTR,31)
#define CAN1_WORD031                             CAN_WORD0_REG(CAN1_BASE_PTR,31)
#define CAN1_WORD131                             CAN_WORD1_REG(CAN1_BASE_PTR,31)
#define CAN1_CS32                                CAN_CS_REG(CAN1_BASE_PTR,32)
#define CAN1_ID32                                CAN_ID_REG(CAN1_BASE_PTR,32)
#define CAN1_WORD032                             CAN_WORD0_REG(CAN1_BASE_PTR,32)
#define CAN1_WORD132                             CAN_WORD1_REG(CAN1_BASE_PTR,32)
#define CAN1_CS33                                CAN_CS_REG(CAN1_BASE_PTR,33)
#define CAN1_ID33                                CAN_ID_REG(CAN1_BASE_PTR,33)
#define CAN1_WORD033                             CAN_WORD0_REG(CAN1_BASE_PTR,33)
#define CAN1_WORD133                             CAN_WORD1_REG(CAN1_BASE_PTR,33)
#define CAN1_CS34                                CAN_CS_REG(CAN1_BASE_PTR,34)
#define CAN1_ID34                                CAN_ID_REG(CAN1_BASE_PTR,34)
#define CAN1_WORD034                             CAN_WORD0_REG(CAN1_BASE_PTR,34)
#define CAN1_WORD134                             CAN_WORD1_REG(CAN1_BASE_PTR,34)
#define CAN1_CS35                                CAN_CS_REG(CAN1_BASE_PTR,35)
#define CAN1_ID35                                CAN_ID_REG(CAN1_BASE_PTR,35)
#define CAN1_WORD035                             CAN_WORD0_REG(CAN1_BASE_PTR,35)
#define CAN1_WORD135                             CAN_WORD1_REG(CAN1_BASE_PTR,35)
#define CAN1_CS36                                CAN_CS_REG(CAN1_BASE_PTR,36)
#define CAN1_ID36                                CAN_ID_REG(CAN1_BASE_PTR,36)
#define CAN1_WORD036                             CAN_WORD0_REG(CAN1_BASE_PTR,36)
#define CAN1_WORD136                             CAN_WORD1_REG(CAN1_BASE_PTR,36)
#define CAN1_CS37                                CAN_CS_REG(CAN1_BASE_PTR,37)
#define CAN1_ID37                                CAN_ID_REG(CAN1_BASE_PTR,37)
#define CAN1_WORD037                             CAN_WORD0_REG(CAN1_BASE_PTR,37)
#define CAN1_WORD137                             CAN_WORD1_REG(CAN1_BASE_PTR,37)
#define CAN1_CS38                                CAN_CS_REG(CAN1_BASE_PTR,38)
#define CAN1_ID38                                CAN_ID_REG(CAN1_BASE_PTR,38)
#define CAN1_WORD038                             CAN_WORD0_REG(CAN1_BASE_PTR,38)
#define CAN1_WORD138                             CAN_WORD1_REG(CAN1_BASE_PTR,38)
#define CAN1_CS39                                CAN_CS_REG(CAN1_BASE_PTR,39)
#define CAN1_ID39                                CAN_ID_REG(CAN1_BASE_PTR,39)
#define CAN1_WORD039                             CAN_WORD0_REG(CAN1_BASE_PTR,39)
#define CAN1_WORD139                             CAN_WORD1_REG(CAN1_BASE_PTR,39)
#define CAN1_CS40                                CAN_CS_REG(CAN1_BASE_PTR,40)
#define CAN1_ID40                                CAN_ID_REG(CAN1_BASE_PTR,40)
#define CAN1_WORD040                             CAN_WORD0_REG(CAN1_BASE_PTR,40)
#define CAN1_WORD140                             CAN_WORD1_REG(CAN1_BASE_PTR,40)
#define CAN1_CS41                                CAN_CS_REG(CAN1_BASE_PTR,41)
#define CAN1_ID41                                CAN_ID_REG(CAN1_BASE_PTR,41)
#define CAN1_WORD041                             CAN_WORD0_REG(CAN1_BASE_PTR,41)
#define CAN1_WORD141                             CAN_WORD1_REG(CAN1_BASE_PTR,41)
#define CAN1_CS42                                CAN_CS_REG(CAN1_BASE_PTR,42)
#define CAN1_ID42                                CAN_ID_REG(CAN1_BASE_PTR,42)
#define CAN1_WORD042                             CAN_WORD0_REG(CAN1_BASE_PTR,42)
#define CAN1_WORD142                             CAN_WORD1_REG(CAN1_BASE_PTR,42)
#define CAN1_CS43                                CAN_CS_REG(CAN1_BASE_PTR,43)
#define CAN1_ID43                                CAN_ID_REG(CAN1_BASE_PTR,43)
#define CAN1_WORD043                             CAN_WORD0_REG(CAN1_BASE_PTR,43)
#define CAN1_WORD143                             CAN_WORD1_REG(CAN1_BASE_PTR,43)
#define CAN1_CS44                                CAN_CS_REG(CAN1_BASE_PTR,44)
#define CAN1_ID44                                CAN_ID_REG(CAN1_BASE_PTR,44)
#define CAN1_WORD044                             CAN_WORD0_REG(CAN1_BASE_PTR,44)
#define CAN1_WORD144                             CAN_WORD1_REG(CAN1_BASE_PTR,44)
#define CAN1_CS45                                CAN_CS_REG(CAN1_BASE_PTR,45)
#define CAN1_ID45                                CAN_ID_REG(CAN1_BASE_PTR,45)
#define CAN1_WORD045                             CAN_WORD0_REG(CAN1_BASE_PTR,45)
#define CAN1_WORD145                             CAN_WORD1_REG(CAN1_BASE_PTR,45)
#define CAN1_CS46                                CAN_CS_REG(CAN1_BASE_PTR,46)
#define CAN1_ID46                                CAN_ID_REG(CAN1_BASE_PTR,46)
#define CAN1_WORD046                             CAN_WORD0_REG(CAN1_BASE_PTR,46)
#define CAN1_WORD146                             CAN_WORD1_REG(CAN1_BASE_PTR,46)
#define CAN1_CS47                                CAN_CS_REG(CAN1_BASE_PTR,47)
#define CAN1_ID47                                CAN_ID_REG(CAN1_BASE_PTR,47)
#define CAN1_WORD047                             CAN_WORD0_REG(CAN1_BASE_PTR,47)
#define CAN1_WORD147                             CAN_WORD1_REG(CAN1_BASE_PTR,47)
#define CAN1_CS48                                CAN_CS_REG(CAN1_BASE_PTR,48)
#define CAN1_ID48                                CAN_ID_REG(CAN1_BASE_PTR,48)
#define CAN1_WORD048                             CAN_WORD0_REG(CAN1_BASE_PTR,48)
#define CAN1_WORD148                             CAN_WORD1_REG(CAN1_BASE_PTR,48)
#define CAN1_CS49                                CAN_CS_REG(CAN1_BASE_PTR,49)
#define CAN1_ID49                                CAN_ID_REG(CAN1_BASE_PTR,49)
#define CAN1_WORD049                             CAN_WORD0_REG(CAN1_BASE_PTR,49)
#define CAN1_WORD149                             CAN_WORD1_REG(CAN1_BASE_PTR,49)
#define CAN1_CS50                                CAN_CS_REG(CAN1_BASE_PTR,50)
#define CAN1_ID50                                CAN_ID_REG(CAN1_BASE_PTR,50)
#define CAN1_WORD050                             CAN_WORD0_REG(CAN1_BASE_PTR,50)
#define CAN1_WORD150                             CAN_WORD1_REG(CAN1_BASE_PTR,50)
#define CAN1_CS51                                CAN_CS_REG(CAN1_BASE_PTR,51)
#define CAN1_ID51                                CAN_ID_REG(CAN1_BASE_PTR,51)
#define CAN1_WORD051                             CAN_WORD0_REG(CAN1_BASE_PTR,51)
#define CAN1_WORD151                             CAN_WORD1_REG(CAN1_BASE_PTR,51)
#define CAN1_CS52                                CAN_CS_REG(CAN1_BASE_PTR,52)
#define CAN1_ID52                                CAN_ID_REG(CAN1_BASE_PTR,52)
#define CAN1_WORD052                             CAN_WORD0_REG(CAN1_BASE_PTR,52)
#define CAN1_WORD152                             CAN_WORD1_REG(CAN1_BASE_PTR,52)
#define CAN1_CS53                                CAN_CS_REG(CAN1_BASE_PTR,53)
#define CAN1_ID53                                CAN_ID_REG(CAN1_BASE_PTR,53)
#define CAN1_WORD053                             CAN_WORD0_REG(CAN1_BASE_PTR,53)
#define CAN1_WORD153                             CAN_WORD1_REG(CAN1_BASE_PTR,53)
#define CAN1_CS54                                CAN_CS_REG(CAN1_BASE_PTR,54)
#define CAN1_ID54                                CAN_ID_REG(CAN1_BASE_PTR,54)
#define CAN1_WORD054                             CAN_WORD0_REG(CAN1_BASE_PTR,54)
#define CAN1_WORD154                             CAN_WORD1_REG(CAN1_BASE_PTR,54)
#define CAN1_CS55                                CAN_CS_REG(CAN1_BASE_PTR,55)
#define CAN1_ID55                                CAN_ID_REG(CAN1_BASE_PTR,55)
#define CAN1_WORD055                             CAN_WORD0_REG(CAN1_BASE_PTR,55)
#define CAN1_WORD155                             CAN_WORD1_REG(CAN1_BASE_PTR,55)
#define CAN1_CS56                                CAN_CS_REG(CAN1_BASE_PTR,56)
#define CAN1_ID56                                CAN_ID_REG(CAN1_BASE_PTR,56)
#define CAN1_WORD056                             CAN_WORD0_REG(CAN1_BASE_PTR,56)
#define CAN1_WORD156                             CAN_WORD1_REG(CAN1_BASE_PTR,56)
#define CAN1_CS57                                CAN_CS_REG(CAN1_BASE_PTR,57)
#define CAN1_ID57                                CAN_ID_REG(CAN1_BASE_PTR,57)
#define CAN1_WORD057                             CAN_WORD0_REG(CAN1_BASE_PTR,57)
#define CAN1_WORD157                             CAN_WORD1_REG(CAN1_BASE_PTR,57)
#define CAN1_CS58                                CAN_CS_REG(CAN1_BASE_PTR,58)
#define CAN1_ID58                                CAN_ID_REG(CAN1_BASE_PTR,58)
#define CAN1_WORD058                             CAN_WORD0_REG(CAN1_BASE_PTR,58)
#define CAN1_WORD158                             CAN_WORD1_REG(CAN1_BASE_PTR,58)
#define CAN1_CS59                                CAN_CS_REG(CAN1_BASE_PTR,59)
#define CAN1_ID59                                CAN_ID_REG(CAN1_BASE_PTR,59)
#define CAN1_WORD059                             CAN_WORD0_REG(CAN1_BASE_PTR,59)
#define CAN1_WORD159                             CAN_WORD1_REG(CAN1_BASE_PTR,59)
#define CAN1_CS60                                CAN_CS_REG(CAN1_BASE_PTR,60)
#define CAN1_ID60                                CAN_ID_REG(CAN1_BASE_PTR,60)
#define CAN1_WORD060                             CAN_WORD0_REG(CAN1_BASE_PTR,60)
#define CAN1_WORD160                             CAN_WORD1_REG(CAN1_BASE_PTR,60)
#define CAN1_CS61                                CAN_CS_REG(CAN1_BASE_PTR,61)
#define CAN1_ID61                                CAN_ID_REG(CAN1_BASE_PTR,61)
#define CAN1_WORD061                             CAN_WORD0_REG(CAN1_BASE_PTR,61)
#define CAN1_WORD161                             CAN_WORD1_REG(CAN1_BASE_PTR,61)
#define CAN1_CS62                                CAN_CS_REG(CAN1_BASE_PTR,62)
#define CAN1_ID62                                CAN_ID_REG(CAN1_BASE_PTR,62)
#define CAN1_WORD062                             CAN_WORD0_REG(CAN1_BASE_PTR,62)
#define CAN1_WORD162                             CAN_WORD1_REG(CAN1_BASE_PTR,62)
#define CAN1_CS63                                CAN_CS_REG(CAN1_BASE_PTR,63)
#define CAN1_ID63                                CAN_ID_REG(CAN1_BASE_PTR,63)
#define CAN1_WORD063                             CAN_WORD0_REG(CAN1_BASE_PTR,63)
#define CAN1_WORD163                             CAN_WORD1_REG(CAN1_BASE_PTR,63)
#define CAN1_RXIMR0                              CAN_RXIMR_REG(CAN1_BASE_PTR,0)
#define CAN1_RXIMR1                              CAN_RXIMR_REG(CAN1_BASE_PTR,1)
#define CAN1_RXIMR2                              CAN_RXIMR_REG(CAN1_BASE_PTR,2)
#define CAN1_RXIMR3                              CAN_RXIMR_REG(CAN1_BASE_PTR,3)
#define CAN1_RXIMR4                              CAN_RXIMR_REG(CAN1_BASE_PTR,4)
#define CAN1_RXIMR5                              CAN_RXIMR_REG(CAN1_BASE_PTR,5)
#define CAN1_RXIMR6                              CAN_RXIMR_REG(CAN1_BASE_PTR,6)
#define CAN1_RXIMR7                              CAN_RXIMR_REG(CAN1_BASE_PTR,7)
#define CAN1_RXIMR8                              CAN_RXIMR_REG(CAN1_BASE_PTR,8)
#define CAN1_RXIMR9                              CAN_RXIMR_REG(CAN1_BASE_PTR,9)
#define CAN1_RXIMR10                             CAN_RXIMR_REG(CAN1_BASE_PTR,10)
#define CAN1_RXIMR11                             CAN_RXIMR_REG(CAN1_BASE_PTR,11)
#define CAN1_RXIMR12                             CAN_RXIMR_REG(CAN1_BASE_PTR,12)
#define CAN1_RXIMR13                             CAN_RXIMR_REG(CAN1_BASE_PTR,13)
#define CAN1_RXIMR14                             CAN_RXIMR_REG(CAN1_BASE_PTR,14)
#define CAN1_RXIMR15                             CAN_RXIMR_REG(CAN1_BASE_PTR,15)
#define CAN1_RXIMR16                             CAN_RXIMR_REG(CAN1_BASE_PTR,16)
#define CAN1_RXIMR17                             CAN_RXIMR_REG(CAN1_BASE_PTR,17)
#define CAN1_RXIMR18                             CAN_RXIMR_REG(CAN1_BASE_PTR,18)
#define CAN1_RXIMR19                             CAN_RXIMR_REG(CAN1_BASE_PTR,19)
#define CAN1_RXIMR20                             CAN_RXIMR_REG(CAN1_BASE_PTR,20)
#define CAN1_RXIMR21                             CAN_RXIMR_REG(CAN1_BASE_PTR,21)
#define CAN1_RXIMR22                             CAN_RXIMR_REG(CAN1_BASE_PTR,22)
#define CAN1_RXIMR23                             CAN_RXIMR_REG(CAN1_BASE_PTR,23)
#define CAN1_RXIMR24                             CAN_RXIMR_REG(CAN1_BASE_PTR,24)
#define CAN1_RXIMR25                             CAN_RXIMR_REG(CAN1_BASE_PTR,25)
#define CAN1_RXIMR26                             CAN_RXIMR_REG(CAN1_BASE_PTR,26)
#define CAN1_RXIMR27                             CAN_RXIMR_REG(CAN1_BASE_PTR,27)
#define CAN1_RXIMR28                             CAN_RXIMR_REG(CAN1_BASE_PTR,28)
#define CAN1_RXIMR29                             CAN_RXIMR_REG(CAN1_BASE_PTR,29)
#define CAN1_RXIMR30                             CAN_RXIMR_REG(CAN1_BASE_PTR,30)
#define CAN1_RXIMR31                             CAN_RXIMR_REG(CAN1_BASE_PTR,31)
#define CAN1_RXIMR32                             CAN_RXIMR_REG(CAN1_BASE_PTR,32)
#define CAN1_RXIMR33                             CAN_RXIMR_REG(CAN1_BASE_PTR,33)
#define CAN1_RXIMR34                             CAN_RXIMR_REG(CAN1_BASE_PTR,34)
#define CAN1_RXIMR35                             CAN_RXIMR_REG(CAN1_BASE_PTR,35)
#define CAN1_RXIMR36                             CAN_RXIMR_REG(CAN1_BASE_PTR,36)
#define CAN1_RXIMR37                             CAN_RXIMR_REG(CAN1_BASE_PTR,37)
#define CAN1_RXIMR38                             CAN_RXIMR_REG(CAN1_BASE_PTR,38)
#define CAN1_RXIMR39                             CAN_RXIMR_REG(CAN1_BASE_PTR,39)
#define CAN1_RXIMR40                             CAN_RXIMR_REG(CAN1_BASE_PTR,40)
#define CAN1_RXIMR41                             CAN_RXIMR_REG(CAN1_BASE_PTR,41)
#define CAN1_RXIMR42                             CAN_RXIMR_REG(CAN1_BASE_PTR,42)
#define CAN1_RXIMR43                             CAN_RXIMR_REG(CAN1_BASE_PTR,43)
#define CAN1_RXIMR44                             CAN_RXIMR_REG(CAN1_BASE_PTR,44)
#define CAN1_RXIMR45                             CAN_RXIMR_REG(CAN1_BASE_PTR,45)
#define CAN1_RXIMR46                             CAN_RXIMR_REG(CAN1_BASE_PTR,46)
#define CAN1_RXIMR47                             CAN_RXIMR_REG(CAN1_BASE_PTR,47)
#define CAN1_RXIMR48                             CAN_RXIMR_REG(CAN1_BASE_PTR,48)
#define CAN1_RXIMR49                             CAN_RXIMR_REG(CAN1_BASE_PTR,49)
#define CAN1_RXIMR50                             CAN_RXIMR_REG(CAN1_BASE_PTR,50)
#define CAN1_RXIMR51                             CAN_RXIMR_REG(CAN1_BASE_PTR,51)
#define CAN1_RXIMR52                             CAN_RXIMR_REG(CAN1_BASE_PTR,52)
#define CAN1_RXIMR53                             CAN_RXIMR_REG(CAN1_BASE_PTR,53)
#define CAN1_RXIMR54                             CAN_RXIMR_REG(CAN1_BASE_PTR,54)
#define CAN1_RXIMR55                             CAN_RXIMR_REG(CAN1_BASE_PTR,55)
#define CAN1_RXIMR56                             CAN_RXIMR_REG(CAN1_BASE_PTR,56)
#define CAN1_RXIMR57                             CAN_RXIMR_REG(CAN1_BASE_PTR,57)
#define CAN1_RXIMR58                             CAN_RXIMR_REG(CAN1_BASE_PTR,58)
#define CAN1_RXIMR59                             CAN_RXIMR_REG(CAN1_BASE_PTR,59)
#define CAN1_RXIMR60                             CAN_RXIMR_REG(CAN1_BASE_PTR,60)
#define CAN1_RXIMR61                             CAN_RXIMR_REG(CAN1_BASE_PTR,61)
#define CAN1_RXIMR62                             CAN_RXIMR_REG(CAN1_BASE_PTR,62)
#define CAN1_RXIMR63                             CAN_RXIMR_REG(CAN1_BASE_PTR,63)
#define CAN1_GFWR                                CAN_GFWR_REG(CAN1_BASE_PTR)
/* CAN2 */
#define CAN2_MCR                                 CAN_MCR_REG(CAN2_BASE_PTR)
#define CAN2_CTRL1                               CAN_CTRL1_REG(CAN2_BASE_PTR)
#define CAN2_TIMER                               CAN_TIMER_REG(CAN2_BASE_PTR)
#define CAN2_RXMGMASK                            CAN_RXMGMASK_REG(CAN2_BASE_PTR)
#define CAN2_RX14MASK                            CAN_RX14MASK_REG(CAN2_BASE_PTR)
#define CAN2_RX15MASK                            CAN_RX15MASK_REG(CAN2_BASE_PTR)
#define CAN2_ECR                                 CAN_ECR_REG(CAN2_BASE_PTR)
#define CAN2_ESR1                                CAN_ESR1_REG(CAN2_BASE_PTR)
#define CAN2_IMASK2                              CAN_IMASK2_REG(CAN2_BASE_PTR)
#define CAN2_IMASK1                              CAN_IMASK1_REG(CAN2_BASE_PTR)
#define CAN2_IFLAG2                              CAN_IFLAG2_REG(CAN2_BASE_PTR)
#define CAN2_IFLAG1                              CAN_IFLAG1_REG(CAN2_BASE_PTR)
#define CAN2_CTRL2                               CAN_CTRL2_REG(CAN2_BASE_PTR)
#define CAN2_ESR2                                CAN_ESR2_REG(CAN2_BASE_PTR)
#define CAN2_CRCR                                CAN_CRCR_REG(CAN2_BASE_PTR)
#define CAN2_RXFGMASK                            CAN_RXFGMASK_REG(CAN2_BASE_PTR)
#define CAN2_RXFIR                               CAN_RXFIR_REG(CAN2_BASE_PTR)
#define CAN2_CS0                                 CAN_CS_REG(CAN2_BASE_PTR,0)
#define CAN2_ID0                                 CAN_ID_REG(CAN2_BASE_PTR,0)
#define CAN2_WORD00                              CAN_WORD0_REG(CAN2_BASE_PTR,0)
#define CAN2_WORD10                              CAN_WORD1_REG(CAN2_BASE_PTR,0)
#define CAN2_CS1                                 CAN_CS_REG(CAN2_BASE_PTR,1)
#define CAN2_ID1                                 CAN_ID_REG(CAN2_BASE_PTR,1)
#define CAN2_WORD01                              CAN_WORD0_REG(CAN2_BASE_PTR,1)
#define CAN2_WORD11                              CAN_WORD1_REG(CAN2_BASE_PTR,1)
#define CAN2_CS2                                 CAN_CS_REG(CAN2_BASE_PTR,2)
#define CAN2_ID2                                 CAN_ID_REG(CAN2_BASE_PTR,2)
#define CAN2_WORD02                              CAN_WORD0_REG(CAN2_BASE_PTR,2)
#define CAN2_WORD12                              CAN_WORD1_REG(CAN2_BASE_PTR,2)
#define CAN2_CS3                                 CAN_CS_REG(CAN2_BASE_PTR,3)
#define CAN2_ID3                                 CAN_ID_REG(CAN2_BASE_PTR,3)
#define CAN2_WORD03                              CAN_WORD0_REG(CAN2_BASE_PTR,3)
#define CAN2_WORD13                              CAN_WORD1_REG(CAN2_BASE_PTR,3)
#define CAN2_CS4                                 CAN_CS_REG(CAN2_BASE_PTR,4)
#define CAN2_ID4                                 CAN_ID_REG(CAN2_BASE_PTR,4)
#define CAN2_WORD04                              CAN_WORD0_REG(CAN2_BASE_PTR,4)
#define CAN2_WORD14                              CAN_WORD1_REG(CAN2_BASE_PTR,4)
#define CAN2_CS5                                 CAN_CS_REG(CAN2_BASE_PTR,5)
#define CAN2_ID5                                 CAN_ID_REG(CAN2_BASE_PTR,5)
#define CAN2_WORD05                              CAN_WORD0_REG(CAN2_BASE_PTR,5)
#define CAN2_WORD15                              CAN_WORD1_REG(CAN2_BASE_PTR,5)
#define CAN2_CS6                                 CAN_CS_REG(CAN2_BASE_PTR,6)
#define CAN2_ID6                                 CAN_ID_REG(CAN2_BASE_PTR,6)
#define CAN2_WORD06                              CAN_WORD0_REG(CAN2_BASE_PTR,6)
#define CAN2_WORD16                              CAN_WORD1_REG(CAN2_BASE_PTR,6)
#define CAN2_CS7                                 CAN_CS_REG(CAN2_BASE_PTR,7)
#define CAN2_ID7                                 CAN_ID_REG(CAN2_BASE_PTR,7)
#define CAN2_WORD07                              CAN_WORD0_REG(CAN2_BASE_PTR,7)
#define CAN2_WORD17                              CAN_WORD1_REG(CAN2_BASE_PTR,7)
#define CAN2_CS8                                 CAN_CS_REG(CAN2_BASE_PTR,8)
#define CAN2_ID8                                 CAN_ID_REG(CAN2_BASE_PTR,8)
#define CAN2_WORD08                              CAN_WORD0_REG(CAN2_BASE_PTR,8)
#define CAN2_WORD18                              CAN_WORD1_REG(CAN2_BASE_PTR,8)
#define CAN2_CS9                                 CAN_CS_REG(CAN2_BASE_PTR,9)
#define CAN2_ID9                                 CAN_ID_REG(CAN2_BASE_PTR,9)
#define CAN2_WORD09                              CAN_WORD0_REG(CAN2_BASE_PTR,9)
#define CAN2_WORD19                              CAN_WORD1_REG(CAN2_BASE_PTR,9)
#define CAN2_CS10                                CAN_CS_REG(CAN2_BASE_PTR,10)
#define CAN2_ID10                                CAN_ID_REG(CAN2_BASE_PTR,10)
#define CAN2_WORD010                             CAN_WORD0_REG(CAN2_BASE_PTR,10)
#define CAN2_WORD110                             CAN_WORD1_REG(CAN2_BASE_PTR,10)
#define CAN2_CS11                                CAN_CS_REG(CAN2_BASE_PTR,11)
#define CAN2_ID11                                CAN_ID_REG(CAN2_BASE_PTR,11)
#define CAN2_WORD011                             CAN_WORD0_REG(CAN2_BASE_PTR,11)
#define CAN2_WORD111                             CAN_WORD1_REG(CAN2_BASE_PTR,11)
#define CAN2_CS12                                CAN_CS_REG(CAN2_BASE_PTR,12)
#define CAN2_ID12                                CAN_ID_REG(CAN2_BASE_PTR,12)
#define CAN2_WORD012                             CAN_WORD0_REG(CAN2_BASE_PTR,12)
#define CAN2_WORD112                             CAN_WORD1_REG(CAN2_BASE_PTR,12)
#define CAN2_CS13                                CAN_CS_REG(CAN2_BASE_PTR,13)
#define CAN2_ID13                                CAN_ID_REG(CAN2_BASE_PTR,13)
#define CAN2_WORD013                             CAN_WORD0_REG(CAN2_BASE_PTR,13)
#define CAN2_WORD113                             CAN_WORD1_REG(CAN2_BASE_PTR,13)
#define CAN2_CS14                                CAN_CS_REG(CAN2_BASE_PTR,14)
#define CAN2_ID14                                CAN_ID_REG(CAN2_BASE_PTR,14)
#define CAN2_WORD014                             CAN_WORD0_REG(CAN2_BASE_PTR,14)
#define CAN2_WORD114                             CAN_WORD1_REG(CAN2_BASE_PTR,14)
#define CAN2_CS15                                CAN_CS_REG(CAN2_BASE_PTR,15)
#define CAN2_ID15                                CAN_ID_REG(CAN2_BASE_PTR,15)
#define CAN2_WORD015                             CAN_WORD0_REG(CAN2_BASE_PTR,15)
#define CAN2_WORD115                             CAN_WORD1_REG(CAN2_BASE_PTR,15)
#define CAN2_CS16                                CAN_CS_REG(CAN2_BASE_PTR,16)
#define CAN2_ID16                                CAN_ID_REG(CAN2_BASE_PTR,16)
#define CAN2_WORD016                             CAN_WORD0_REG(CAN2_BASE_PTR,16)
#define CAN2_WORD116                             CAN_WORD1_REG(CAN2_BASE_PTR,16)
#define CAN2_CS17                                CAN_CS_REG(CAN2_BASE_PTR,17)
#define CAN2_ID17                                CAN_ID_REG(CAN2_BASE_PTR,17)
#define CAN2_WORD017                             CAN_WORD0_REG(CAN2_BASE_PTR,17)
#define CAN2_WORD117                             CAN_WORD1_REG(CAN2_BASE_PTR,17)
#define CAN2_CS18                                CAN_CS_REG(CAN2_BASE_PTR,18)
#define CAN2_ID18                                CAN_ID_REG(CAN2_BASE_PTR,18)
#define CAN2_WORD018                             CAN_WORD0_REG(CAN2_BASE_PTR,18)
#define CAN2_WORD118                             CAN_WORD1_REG(CAN2_BASE_PTR,18)
#define CAN2_CS19                                CAN_CS_REG(CAN2_BASE_PTR,19)
#define CAN2_ID19                                CAN_ID_REG(CAN2_BASE_PTR,19)
#define CAN2_WORD019                             CAN_WORD0_REG(CAN2_BASE_PTR,19)
#define CAN2_WORD119                             CAN_WORD1_REG(CAN2_BASE_PTR,19)
#define CAN2_CS20                                CAN_CS_REG(CAN2_BASE_PTR,20)
#define CAN2_ID20                                CAN_ID_REG(CAN2_BASE_PTR,20)
#define CAN2_WORD020                             CAN_WORD0_REG(CAN2_BASE_PTR,20)
#define CAN2_WORD120                             CAN_WORD1_REG(CAN2_BASE_PTR,20)
#define CAN2_CS21                                CAN_CS_REG(CAN2_BASE_PTR,21)
#define CAN2_ID21                                CAN_ID_REG(CAN2_BASE_PTR,21)
#define CAN2_WORD021                             CAN_WORD0_REG(CAN2_BASE_PTR,21)
#define CAN2_WORD121                             CAN_WORD1_REG(CAN2_BASE_PTR,21)
#define CAN2_CS22                                CAN_CS_REG(CAN2_BASE_PTR,22)
#define CAN2_ID22                                CAN_ID_REG(CAN2_BASE_PTR,22)
#define CAN2_WORD022                             CAN_WORD0_REG(CAN2_BASE_PTR,22)
#define CAN2_WORD122                             CAN_WORD1_REG(CAN2_BASE_PTR,22)
#define CAN2_CS23                                CAN_CS_REG(CAN2_BASE_PTR,23)
#define CAN2_ID23                                CAN_ID_REG(CAN2_BASE_PTR,23)
#define CAN2_WORD023                             CAN_WORD0_REG(CAN2_BASE_PTR,23)
#define CAN2_WORD123                             CAN_WORD1_REG(CAN2_BASE_PTR,23)
#define CAN2_CS24                                CAN_CS_REG(CAN2_BASE_PTR,24)
#define CAN2_ID24                                CAN_ID_REG(CAN2_BASE_PTR,24)
#define CAN2_WORD024                             CAN_WORD0_REG(CAN2_BASE_PTR,24)
#define CAN2_WORD124                             CAN_WORD1_REG(CAN2_BASE_PTR,24)
#define CAN2_CS25                                CAN_CS_REG(CAN2_BASE_PTR,25)
#define CAN2_ID25                                CAN_ID_REG(CAN2_BASE_PTR,25)
#define CAN2_WORD025                             CAN_WORD0_REG(CAN2_BASE_PTR,25)
#define CAN2_WORD125                             CAN_WORD1_REG(CAN2_BASE_PTR,25)
#define CAN2_CS26                                CAN_CS_REG(CAN2_BASE_PTR,26)
#define CAN2_ID26                                CAN_ID_REG(CAN2_BASE_PTR,26)
#define CAN2_WORD026                             CAN_WORD0_REG(CAN2_BASE_PTR,26)
#define CAN2_WORD126                             CAN_WORD1_REG(CAN2_BASE_PTR,26)
#define CAN2_CS27                                CAN_CS_REG(CAN2_BASE_PTR,27)
#define CAN2_ID27                                CAN_ID_REG(CAN2_BASE_PTR,27)
#define CAN2_WORD027                             CAN_WORD0_REG(CAN2_BASE_PTR,27)
#define CAN2_WORD127                             CAN_WORD1_REG(CAN2_BASE_PTR,27)
#define CAN2_CS28                                CAN_CS_REG(CAN2_BASE_PTR,28)
#define CAN2_ID28                                CAN_ID_REG(CAN2_BASE_PTR,28)
#define CAN2_WORD028                             CAN_WORD0_REG(CAN2_BASE_PTR,28)
#define CAN2_WORD128                             CAN_WORD1_REG(CAN2_BASE_PTR,28)
#define CAN2_CS29                                CAN_CS_REG(CAN2_BASE_PTR,29)
#define CAN2_ID29                                CAN_ID_REG(CAN2_BASE_PTR,29)
#define CAN2_WORD029                             CAN_WORD0_REG(CAN2_BASE_PTR,29)
#define CAN2_WORD129                             CAN_WORD1_REG(CAN2_BASE_PTR,29)
#define CAN2_CS30                                CAN_CS_REG(CAN2_BASE_PTR,30)
#define CAN2_ID30                                CAN_ID_REG(CAN2_BASE_PTR,30)
#define CAN2_WORD030                             CAN_WORD0_REG(CAN2_BASE_PTR,30)
#define CAN2_WORD130                             CAN_WORD1_REG(CAN2_BASE_PTR,30)
#define CAN2_CS31                                CAN_CS_REG(CAN2_BASE_PTR,31)
#define CAN2_ID31                                CAN_ID_REG(CAN2_BASE_PTR,31)
#define CAN2_WORD031                             CAN_WORD0_REG(CAN2_BASE_PTR,31)
#define CAN2_WORD131                             CAN_WORD1_REG(CAN2_BASE_PTR,31)
#define CAN2_CS32                                CAN_CS_REG(CAN2_BASE_PTR,32)
#define CAN2_ID32                                CAN_ID_REG(CAN2_BASE_PTR,32)
#define CAN2_WORD032                             CAN_WORD0_REG(CAN2_BASE_PTR,32)
#define CAN2_WORD132                             CAN_WORD1_REG(CAN2_BASE_PTR,32)
#define CAN2_CS33                                CAN_CS_REG(CAN2_BASE_PTR,33)
#define CAN2_ID33                                CAN_ID_REG(CAN2_BASE_PTR,33)
#define CAN2_WORD033                             CAN_WORD0_REG(CAN2_BASE_PTR,33)
#define CAN2_WORD133                             CAN_WORD1_REG(CAN2_BASE_PTR,33)
#define CAN2_CS34                                CAN_CS_REG(CAN2_BASE_PTR,34)
#define CAN2_ID34                                CAN_ID_REG(CAN2_BASE_PTR,34)
#define CAN2_WORD034                             CAN_WORD0_REG(CAN2_BASE_PTR,34)
#define CAN2_WORD134                             CAN_WORD1_REG(CAN2_BASE_PTR,34)
#define CAN2_CS35                                CAN_CS_REG(CAN2_BASE_PTR,35)
#define CAN2_ID35                                CAN_ID_REG(CAN2_BASE_PTR,35)
#define CAN2_WORD035                             CAN_WORD0_REG(CAN2_BASE_PTR,35)
#define CAN2_WORD135                             CAN_WORD1_REG(CAN2_BASE_PTR,35)
#define CAN2_CS36                                CAN_CS_REG(CAN2_BASE_PTR,36)
#define CAN2_ID36                                CAN_ID_REG(CAN2_BASE_PTR,36)
#define CAN2_WORD036                             CAN_WORD0_REG(CAN2_BASE_PTR,36)
#define CAN2_WORD136                             CAN_WORD1_REG(CAN2_BASE_PTR,36)
#define CAN2_CS37                                CAN_CS_REG(CAN2_BASE_PTR,37)
#define CAN2_ID37                                CAN_ID_REG(CAN2_BASE_PTR,37)
#define CAN2_WORD037                             CAN_WORD0_REG(CAN2_BASE_PTR,37)
#define CAN2_WORD137                             CAN_WORD1_REG(CAN2_BASE_PTR,37)
#define CAN2_CS38                                CAN_CS_REG(CAN2_BASE_PTR,38)
#define CAN2_ID38                                CAN_ID_REG(CAN2_BASE_PTR,38)
#define CAN2_WORD038                             CAN_WORD0_REG(CAN2_BASE_PTR,38)
#define CAN2_WORD138                             CAN_WORD1_REG(CAN2_BASE_PTR,38)
#define CAN2_CS39                                CAN_CS_REG(CAN2_BASE_PTR,39)
#define CAN2_ID39                                CAN_ID_REG(CAN2_BASE_PTR,39)
#define CAN2_WORD039                             CAN_WORD0_REG(CAN2_BASE_PTR,39)
#define CAN2_WORD139                             CAN_WORD1_REG(CAN2_BASE_PTR,39)
#define CAN2_CS40                                CAN_CS_REG(CAN2_BASE_PTR,40)
#define CAN2_ID40                                CAN_ID_REG(CAN2_BASE_PTR,40)
#define CAN2_WORD040                             CAN_WORD0_REG(CAN2_BASE_PTR,40)
#define CAN2_WORD140                             CAN_WORD1_REG(CAN2_BASE_PTR,40)
#define CAN2_CS41                                CAN_CS_REG(CAN2_BASE_PTR,41)
#define CAN2_ID41                                CAN_ID_REG(CAN2_BASE_PTR,41)
#define CAN2_WORD041                             CAN_WORD0_REG(CAN2_BASE_PTR,41)
#define CAN2_WORD141                             CAN_WORD1_REG(CAN2_BASE_PTR,41)
#define CAN2_CS42                                CAN_CS_REG(CAN2_BASE_PTR,42)
#define CAN2_ID42                                CAN_ID_REG(CAN2_BASE_PTR,42)
#define CAN2_WORD042                             CAN_WORD0_REG(CAN2_BASE_PTR,42)
#define CAN2_WORD142                             CAN_WORD1_REG(CAN2_BASE_PTR,42)
#define CAN2_CS43                                CAN_CS_REG(CAN2_BASE_PTR,43)
#define CAN2_ID43                                CAN_ID_REG(CAN2_BASE_PTR,43)
#define CAN2_WORD043                             CAN_WORD0_REG(CAN2_BASE_PTR,43)
#define CAN2_WORD143                             CAN_WORD1_REG(CAN2_BASE_PTR,43)
#define CAN2_CS44                                CAN_CS_REG(CAN2_BASE_PTR,44)
#define CAN2_ID44                                CAN_ID_REG(CAN2_BASE_PTR,44)
#define CAN2_WORD044                             CAN_WORD0_REG(CAN2_BASE_PTR,44)
#define CAN2_WORD144                             CAN_WORD1_REG(CAN2_BASE_PTR,44)
#define CAN2_CS45                                CAN_CS_REG(CAN2_BASE_PTR,45)
#define CAN2_ID45                                CAN_ID_REG(CAN2_BASE_PTR,45)
#define CAN2_WORD045                             CAN_WORD0_REG(CAN2_BASE_PTR,45)
#define CAN2_WORD145                             CAN_WORD1_REG(CAN2_BASE_PTR,45)
#define CAN2_CS46                                CAN_CS_REG(CAN2_BASE_PTR,46)
#define CAN2_ID46                                CAN_ID_REG(CAN2_BASE_PTR,46)
#define CAN2_WORD046                             CAN_WORD0_REG(CAN2_BASE_PTR,46)
#define CAN2_WORD146                             CAN_WORD1_REG(CAN2_BASE_PTR,46)
#define CAN2_CS47                                CAN_CS_REG(CAN2_BASE_PTR,47)
#define CAN2_ID47                                CAN_ID_REG(CAN2_BASE_PTR,47)
#define CAN2_WORD047                             CAN_WORD0_REG(CAN2_BASE_PTR,47)
#define CAN2_WORD147                             CAN_WORD1_REG(CAN2_BASE_PTR,47)
#define CAN2_CS48                                CAN_CS_REG(CAN2_BASE_PTR,48)
#define CAN2_ID48                                CAN_ID_REG(CAN2_BASE_PTR,48)
#define CAN2_WORD048                             CAN_WORD0_REG(CAN2_BASE_PTR,48)
#define CAN2_WORD148                             CAN_WORD1_REG(CAN2_BASE_PTR,48)
#define CAN2_CS49                                CAN_CS_REG(CAN2_BASE_PTR,49)
#define CAN2_ID49                                CAN_ID_REG(CAN2_BASE_PTR,49)
#define CAN2_WORD049                             CAN_WORD0_REG(CAN2_BASE_PTR,49)
#define CAN2_WORD149                             CAN_WORD1_REG(CAN2_BASE_PTR,49)
#define CAN2_CS50                                CAN_CS_REG(CAN2_BASE_PTR,50)
#define CAN2_ID50                                CAN_ID_REG(CAN2_BASE_PTR,50)
#define CAN2_WORD050                             CAN_WORD0_REG(CAN2_BASE_PTR,50)
#define CAN2_WORD150                             CAN_WORD1_REG(CAN2_BASE_PTR,50)
#define CAN2_CS51                                CAN_CS_REG(CAN2_BASE_PTR,51)
#define CAN2_ID51                                CAN_ID_REG(CAN2_BASE_PTR,51)
#define CAN2_WORD051                             CAN_WORD0_REG(CAN2_BASE_PTR,51)
#define CAN2_WORD151                             CAN_WORD1_REG(CAN2_BASE_PTR,51)
#define CAN2_CS52                                CAN_CS_REG(CAN2_BASE_PTR,52)
#define CAN2_ID52                                CAN_ID_REG(CAN2_BASE_PTR,52)
#define CAN2_WORD052                             CAN_WORD0_REG(CAN2_BASE_PTR,52)
#define CAN2_WORD152                             CAN_WORD1_REG(CAN2_BASE_PTR,52)
#define CAN2_CS53                                CAN_CS_REG(CAN2_BASE_PTR,53)
#define CAN2_ID53                                CAN_ID_REG(CAN2_BASE_PTR,53)
#define CAN2_WORD053                             CAN_WORD0_REG(CAN2_BASE_PTR,53)
#define CAN2_WORD153                             CAN_WORD1_REG(CAN2_BASE_PTR,53)
#define CAN2_CS54                                CAN_CS_REG(CAN2_BASE_PTR,54)
#define CAN2_ID54                                CAN_ID_REG(CAN2_BASE_PTR,54)
#define CAN2_WORD054                             CAN_WORD0_REG(CAN2_BASE_PTR,54)
#define CAN2_WORD154                             CAN_WORD1_REG(CAN2_BASE_PTR,54)
#define CAN2_CS55                                CAN_CS_REG(CAN2_BASE_PTR,55)
#define CAN2_ID55                                CAN_ID_REG(CAN2_BASE_PTR,55)
#define CAN2_WORD055                             CAN_WORD0_REG(CAN2_BASE_PTR,55)
#define CAN2_WORD155                             CAN_WORD1_REG(CAN2_BASE_PTR,55)
#define CAN2_CS56                                CAN_CS_REG(CAN2_BASE_PTR,56)
#define CAN2_ID56                                CAN_ID_REG(CAN2_BASE_PTR,56)
#define CAN2_WORD056                             CAN_WORD0_REG(CAN2_BASE_PTR,56)
#define CAN2_WORD156                             CAN_WORD1_REG(CAN2_BASE_PTR,56)
#define CAN2_CS57                                CAN_CS_REG(CAN2_BASE_PTR,57)
#define CAN2_ID57                                CAN_ID_REG(CAN2_BASE_PTR,57)
#define CAN2_WORD057                             CAN_WORD0_REG(CAN2_BASE_PTR,57)
#define CAN2_WORD157                             CAN_WORD1_REG(CAN2_BASE_PTR,57)
#define CAN2_CS58                                CAN_CS_REG(CAN2_BASE_PTR,58)
#define CAN2_ID58                                CAN_ID_REG(CAN2_BASE_PTR,58)
#define CAN2_WORD058                             CAN_WORD0_REG(CAN2_BASE_PTR,58)
#define CAN2_WORD158                             CAN_WORD1_REG(CAN2_BASE_PTR,58)
#define CAN2_CS59                                CAN_CS_REG(CAN2_BASE_PTR,59)
#define CAN2_ID59                                CAN_ID_REG(CAN2_BASE_PTR,59)
#define CAN2_WORD059                             CAN_WORD0_REG(CAN2_BASE_PTR,59)
#define CAN2_WORD159                             CAN_WORD1_REG(CAN2_BASE_PTR,59)
#define CAN2_CS60                                CAN_CS_REG(CAN2_BASE_PTR,60)
#define CAN2_ID60                                CAN_ID_REG(CAN2_BASE_PTR,60)
#define CAN2_WORD060                             CAN_WORD0_REG(CAN2_BASE_PTR,60)
#define CAN2_WORD160                             CAN_WORD1_REG(CAN2_BASE_PTR,60)
#define CAN2_CS61                                CAN_CS_REG(CAN2_BASE_PTR,61)
#define CAN2_ID61                                CAN_ID_REG(CAN2_BASE_PTR,61)
#define CAN2_WORD061                             CAN_WORD0_REG(CAN2_BASE_PTR,61)
#define CAN2_WORD161                             CAN_WORD1_REG(CAN2_BASE_PTR,61)
#define CAN2_CS62                                CAN_CS_REG(CAN2_BASE_PTR,62)
#define CAN2_ID62                                CAN_ID_REG(CAN2_BASE_PTR,62)
#define CAN2_WORD062                             CAN_WORD0_REG(CAN2_BASE_PTR,62)
#define CAN2_WORD162                             CAN_WORD1_REG(CAN2_BASE_PTR,62)
#define CAN2_CS63                                CAN_CS_REG(CAN2_BASE_PTR,63)
#define CAN2_ID63                                CAN_ID_REG(CAN2_BASE_PTR,63)
#define CAN2_WORD063                             CAN_WORD0_REG(CAN2_BASE_PTR,63)
#define CAN2_WORD163                             CAN_WORD1_REG(CAN2_BASE_PTR,63)
#define CAN2_RXIMR0                              CAN_RXIMR_REG(CAN2_BASE_PTR,0)
#define CAN2_RXIMR1                              CAN_RXIMR_REG(CAN2_BASE_PTR,1)
#define CAN2_RXIMR2                              CAN_RXIMR_REG(CAN2_BASE_PTR,2)
#define CAN2_RXIMR3                              CAN_RXIMR_REG(CAN2_BASE_PTR,3)
#define CAN2_RXIMR4                              CAN_RXIMR_REG(CAN2_BASE_PTR,4)
#define CAN2_RXIMR5                              CAN_RXIMR_REG(CAN2_BASE_PTR,5)
#define CAN2_RXIMR6                              CAN_RXIMR_REG(CAN2_BASE_PTR,6)
#define CAN2_RXIMR7                              CAN_RXIMR_REG(CAN2_BASE_PTR,7)
#define CAN2_RXIMR8                              CAN_RXIMR_REG(CAN2_BASE_PTR,8)
#define CAN2_RXIMR9                              CAN_RXIMR_REG(CAN2_BASE_PTR,9)
#define CAN2_RXIMR10                             CAN_RXIMR_REG(CAN2_BASE_PTR,10)
#define CAN2_RXIMR11                             CAN_RXIMR_REG(CAN2_BASE_PTR,11)
#define CAN2_RXIMR12                             CAN_RXIMR_REG(CAN2_BASE_PTR,12)
#define CAN2_RXIMR13                             CAN_RXIMR_REG(CAN2_BASE_PTR,13)
#define CAN2_RXIMR14                             CAN_RXIMR_REG(CAN2_BASE_PTR,14)
#define CAN2_RXIMR15                             CAN_RXIMR_REG(CAN2_BASE_PTR,15)
#define CAN2_RXIMR16                             CAN_RXIMR_REG(CAN2_BASE_PTR,16)
#define CAN2_RXIMR17                             CAN_RXIMR_REG(CAN2_BASE_PTR,17)
#define CAN2_RXIMR18                             CAN_RXIMR_REG(CAN2_BASE_PTR,18)
#define CAN2_RXIMR19                             CAN_RXIMR_REG(CAN2_BASE_PTR,19)
#define CAN2_RXIMR20                             CAN_RXIMR_REG(CAN2_BASE_PTR,20)
#define CAN2_RXIMR21                             CAN_RXIMR_REG(CAN2_BASE_PTR,21)
#define CAN2_RXIMR22                             CAN_RXIMR_REG(CAN2_BASE_PTR,22)
#define CAN2_RXIMR23                             CAN_RXIMR_REG(CAN2_BASE_PTR,23)
#define CAN2_RXIMR24                             CAN_RXIMR_REG(CAN2_BASE_PTR,24)
#define CAN2_RXIMR25                             CAN_RXIMR_REG(CAN2_BASE_PTR,25)
#define CAN2_RXIMR26                             CAN_RXIMR_REG(CAN2_BASE_PTR,26)
#define CAN2_RXIMR27                             CAN_RXIMR_REG(CAN2_BASE_PTR,27)
#define CAN2_RXIMR28                             CAN_RXIMR_REG(CAN2_BASE_PTR,28)
#define CAN2_RXIMR29                             CAN_RXIMR_REG(CAN2_BASE_PTR,29)
#define CAN2_RXIMR30                             CAN_RXIMR_REG(CAN2_BASE_PTR,30)
#define CAN2_RXIMR31                             CAN_RXIMR_REG(CAN2_BASE_PTR,31)
#define CAN2_RXIMR32                             CAN_RXIMR_REG(CAN2_BASE_PTR,32)
#define CAN2_RXIMR33                             CAN_RXIMR_REG(CAN2_BASE_PTR,33)
#define CAN2_RXIMR34                             CAN_RXIMR_REG(CAN2_BASE_PTR,34)
#define CAN2_RXIMR35                             CAN_RXIMR_REG(CAN2_BASE_PTR,35)
#define CAN2_RXIMR36                             CAN_RXIMR_REG(CAN2_BASE_PTR,36)
#define CAN2_RXIMR37                             CAN_RXIMR_REG(CAN2_BASE_PTR,37)
#define CAN2_RXIMR38                             CAN_RXIMR_REG(CAN2_BASE_PTR,38)
#define CAN2_RXIMR39                             CAN_RXIMR_REG(CAN2_BASE_PTR,39)
#define CAN2_RXIMR40                             CAN_RXIMR_REG(CAN2_BASE_PTR,40)
#define CAN2_RXIMR41                             CAN_RXIMR_REG(CAN2_BASE_PTR,41)
#define CAN2_RXIMR42                             CAN_RXIMR_REG(CAN2_BASE_PTR,42)
#define CAN2_RXIMR43                             CAN_RXIMR_REG(CAN2_BASE_PTR,43)
#define CAN2_RXIMR44                             CAN_RXIMR_REG(CAN2_BASE_PTR,44)
#define CAN2_RXIMR45                             CAN_RXIMR_REG(CAN2_BASE_PTR,45)
#define CAN2_RXIMR46                             CAN_RXIMR_REG(CAN2_BASE_PTR,46)
#define CAN2_RXIMR47                             CAN_RXIMR_REG(CAN2_BASE_PTR,47)
#define CAN2_RXIMR48                             CAN_RXIMR_REG(CAN2_BASE_PTR,48)
#define CAN2_RXIMR49                             CAN_RXIMR_REG(CAN2_BASE_PTR,49)
#define CAN2_RXIMR50                             CAN_RXIMR_REG(CAN2_BASE_PTR,50)
#define CAN2_RXIMR51                             CAN_RXIMR_REG(CAN2_BASE_PTR,51)
#define CAN2_RXIMR52                             CAN_RXIMR_REG(CAN2_BASE_PTR,52)
#define CAN2_RXIMR53                             CAN_RXIMR_REG(CAN2_BASE_PTR,53)
#define CAN2_RXIMR54                             CAN_RXIMR_REG(CAN2_BASE_PTR,54)
#define CAN2_RXIMR55                             CAN_RXIMR_REG(CAN2_BASE_PTR,55)
#define CAN2_RXIMR56                             CAN_RXIMR_REG(CAN2_BASE_PTR,56)
#define CAN2_RXIMR57                             CAN_RXIMR_REG(CAN2_BASE_PTR,57)
#define CAN2_RXIMR58                             CAN_RXIMR_REG(CAN2_BASE_PTR,58)
#define CAN2_RXIMR59                             CAN_RXIMR_REG(CAN2_BASE_PTR,59)
#define CAN2_RXIMR60                             CAN_RXIMR_REG(CAN2_BASE_PTR,60)
#define CAN2_RXIMR61                             CAN_RXIMR_REG(CAN2_BASE_PTR,61)
#define CAN2_RXIMR62                             CAN_RXIMR_REG(CAN2_BASE_PTR,62)
#define CAN2_RXIMR63                             CAN_RXIMR_REG(CAN2_BASE_PTR,63)
#define CAN2_GFWR                                CAN_GFWR_REG(CAN2_BASE_PTR)

/* CAN - Register array accessors */
#define CAN1_CS(index)                           CAN_CS_REG(CAN1_BASE_PTR,index)
#define CAN2_CS(index)                           CAN_CS_REG(CAN2_BASE_PTR,index)
#define CAN1_ID(index)                           CAN_ID_REG(CAN1_BASE_PTR,index)
#define CAN2_ID(index)                           CAN_ID_REG(CAN2_BASE_PTR,index)
#define CAN1_WORD0(index)                        CAN_WORD0_REG(CAN1_BASE_PTR,index)
#define CAN2_WORD0(index)                        CAN_WORD0_REG(CAN2_BASE_PTR,index)
#define CAN1_WORD1(index)                        CAN_WORD1_REG(CAN1_BASE_PTR,index)
#define CAN2_WORD1(index)                        CAN_WORD1_REG(CAN2_BASE_PTR,index)
#define CAN1_RXIMR(index)                        CAN_RXIMR_REG(CAN1_BASE_PTR,index)
#define CAN2_RXIMR(index)                        CAN_RXIMR_REG(CAN2_BASE_PTR,index)

/*!
 * @}
 */ /* end of group CAN_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group CAN_Peripheral */


/* ----------------------------------------------------------------------------
   -- CCM
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CCM_Peripheral CCM
 * @{
 */

/** CCM - Peripheral register structure */
typedef struct CCM_MemMap {
  uint32_t GPR0;                                   /**< General Purpose Register, offset: 0x0 */
  uint32_t GPR0_SET;                               /**< General Purpose Register, offset: 0x4 */
  uint32_t GPR0_CLR;                               /**< General Purpose Register, offset: 0x8 */
  uint32_t GPR0_TOG;                               /**< General Purpose Register, offset: 0xC */
  uint8_t RESERVED_0[2032];
  struct {                                         /* offset: 0x800, array step: 0x10 */
    uint32_t PLL_CTRL;                               /**< CCM PLL Control Register, array offset: 0x800, array step: 0x10 */
    uint32_t PLL_CTRL_SET;                           /**< CCM PLL Control Register, array offset: 0x804, array step: 0x10 */
    uint32_t PLL_CTRL_CLR;                           /**< CCM PLL Control Register, array offset: 0x808, array step: 0x10 */
    uint32_t PLL_CTRL_TOG;                           /**< CCM PLL Control Register, array offset: 0x80C, array step: 0x10 */
  } PLL_CTRL[33];
  uint8_t RESERVED_1[13808];
  struct {                                         /* offset: 0x4000, array step: 0x10 */
    uint32_t CCGR;                                   /**< CCM Clock Gating Register, array offset: 0x4000, array step: 0x10 */
    uint32_t CCGR_SET;                               /**< CCM Clock Gating Register, array offset: 0x4004, array step: 0x10 */
    uint32_t CCGR_CLR;                               /**< CCM Clock Gating Register, array offset: 0x4008, array step: 0x10 */
    uint32_t CCGR_TOG;                               /**< CCM Clock Gating Register, array offset: 0x400C, array step: 0x10 */
  } CCGR[191];
  uint8_t RESERVED_2[13328];
  struct {                                         /* offset: 0x8000, array step: 0x80 */
    uint32_t TARGET_ROOT;                            /**< Target Register, array offset: 0x8000, array step: 0x80 */
    uint32_t TARGET_ROOT_SET;                        /**< Target Register, array offset: 0x8004, array step: 0x80 */
    uint32_t TARGET_ROOT_CLR;                        /**< Target Register, array offset: 0x8008, array step: 0x80 */
    uint32_t TARGET_ROOT_TOG;                        /**< Target Register, array offset: 0x800C, array step: 0x80 */
    uint32_t MISC;                                   /**< Miscellaneous Register, array offset: 0x8010, array step: 0x80 */
    uint32_t MISC_ROOT_SET;                          /**< Miscellaneous Register, array offset: 0x8014, array step: 0x80 */
    uint32_t MISC_ROOT_CLR;                          /**< Miscellaneous Register, array offset: 0x8018, array step: 0x80 */
    uint32_t MISC_ROOT_TOG;                          /**< Miscellaneous Register, array offset: 0x801C, array step: 0x80 */
    uint32_t POST;                                   /**< Post Divider Register, array offset: 0x8020, array step: 0x80 */
    uint32_t POST_ROOT_SET;                          /**< Post Divider Register, array offset: 0x8024, array step: 0x80 */
    uint32_t POST_ROOT_CLR;                          /**< Post Divider Register, array offset: 0x8028, array step: 0x80 */
    uint32_t POST_ROOT_TOG;                          /**< Post Divider Register, array offset: 0x802C, array step: 0x80 */
    uint32_t PRE;                                    /**< Pre Divider Register, array offset: 0x8030, array step: 0x80 */
    uint32_t PRE_ROOT_SET;                           /**< Pre Divider Register, array offset: 0x8034, array step: 0x80 */
    uint32_t PRE_ROOT_CLR;                           /**< Pre Divider Register, array offset: 0x8038, array step: 0x80 */
    uint32_t PRE_ROOT_TOG;                           /**< Pre Divider Register, array offset: 0x803C, array step: 0x80 */
    uint8_t RESERVED_0[48];
    uint32_t ACCESS_CTRL;                            /**< Access Control Register, array offset: 0x8070, array step: 0x80 */
    uint32_t ACCESS_CTRL_ROOT_SET;                   /**< Access Control Register, array offset: 0x8074, array step: 0x80 */
    uint32_t ACCESS_CTRL_ROOT_CLR;                   /**< Access Control Register, array offset: 0x8078, array step: 0x80 */
    uint32_t ACCESS_CTRL_ROOT_TOG;                   /**< Access Control Register, array offset: 0x807C, array step: 0x80 */
  } ROOT[125];
} volatile *CCM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- CCM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CCM_Register_Accessor_Macros CCM - Register accessor macros
 * @{
 */


/* CCM - Register accessors */
#define CCM_GPR0_REG(base)                       ((base)->GPR0)
#define CCM_GPR0_SET_REG(base)                   ((base)->GPR0_SET)
#define CCM_GPR0_CLR_REG(base)                   ((base)->GPR0_CLR)
#define CCM_GPR0_TOG_REG(base)                   ((base)->GPR0_TOG)
#define CCM_PLL_CTRL_REG(base,index)             ((base)->PLL_CTRL[index].PLL_CTRL)
#define CCM_PLL_CTRL_SET_REG(base,index)         ((base)->PLL_CTRL[index].PLL_CTRL_SET)
#define CCM_PLL_CTRL_CLR_REG(base,index)         ((base)->PLL_CTRL[index].PLL_CTRL_CLR)
#define CCM_PLL_CTRL_TOG_REG(base,index)         ((base)->PLL_CTRL[index].PLL_CTRL_TOG)
#define CCM_CCGR_REG(base,index)                 ((base)->CCGR[index].CCGR)
#define CCM_CCGR_SET_REG(base,index)             ((base)->CCGR[index].CCGR_SET)
#define CCM_CCGR_CLR_REG(base,index)             ((base)->CCGR[index].CCGR_CLR)
#define CCM_CCGR_TOG_REG(base,index)             ((base)->CCGR[index].CCGR_TOG)
#define CCM_TARGET_ROOT_REG(base,index)          ((base)->ROOT[index].TARGET_ROOT)
#define CCM_TARGET_ROOT_SET_REG(base,index)      ((base)->ROOT[index].TARGET_ROOT_SET)
#define CCM_TARGET_ROOT_CLR_REG(base,index)      ((base)->ROOT[index].TARGET_ROOT_CLR)
#define CCM_TARGET_ROOT_TOG_REG(base,index)      ((base)->ROOT[index].TARGET_ROOT_TOG)
#define CCM_MISC_REG(base,index)                 ((base)->ROOT[index].MISC)
#define CCM_MISC_ROOT_SET_REG(base,index)        ((base)->ROOT[index].MISC_ROOT_SET)
#define CCM_MISC_ROOT_CLR_REG(base,index)        ((base)->ROOT[index].MISC_ROOT_CLR)
#define CCM_MISC_ROOT_TOG_REG(base,index)        ((base)->ROOT[index].MISC_ROOT_TOG)
#define CCM_POST_REG(base,index)                 ((base)->ROOT[index].POST)
#define CCM_POST_ROOT_SET_REG(base,index)        ((base)->ROOT[index].POST_ROOT_SET)
#define CCM_POST_ROOT_CLR_REG(base,index)        ((base)->ROOT[index].POST_ROOT_CLR)
#define CCM_POST_ROOT_TOG_REG(base,index)        ((base)->ROOT[index].POST_ROOT_TOG)
#define CCM_PRE_REG(base,index)                  ((base)->ROOT[index].PRE)
#define CCM_PRE_ROOT_SET_REG(base,index)         ((base)->ROOT[index].PRE_ROOT_SET)
#define CCM_PRE_ROOT_CLR_REG(base,index)         ((base)->ROOT[index].PRE_ROOT_CLR)
#define CCM_PRE_ROOT_TOG_REG(base,index)         ((base)->ROOT[index].PRE_ROOT_TOG)
#define CCM_ACCESS_CTRL_REG(base,index)          ((base)->ROOT[index].ACCESS_CTRL)
#define CCM_ACCESS_CTRL_ROOT_SET_REG(base,index) ((base)->ROOT[index].ACCESS_CTRL_ROOT_SET)
#define CCM_ACCESS_CTRL_ROOT_CLR_REG(base,index) ((base)->ROOT[index].ACCESS_CTRL_ROOT_CLR)
#define CCM_ACCESS_CTRL_ROOT_TOG_REG(base,index) ((base)->ROOT[index].ACCESS_CTRL_ROOT_TOG)

/*!
 * @}
 */ /* end of group CCM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- CCM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CCM_Register_Masks CCM Register Masks
 * @{
 */

/*! @name GPR0 - General Purpose Register */
#define CCM_GPR0_GP0_MASK                        (0xFFFFFFFFU)
#define CCM_GPR0_GP0_SHIFT                       (0U)
#define CCM_GPR0_GP0(x)                          (((uint32_t)(((uint32_t)(x)) << CCM_GPR0_GP0_SHIFT)) & CCM_GPR0_GP0_MASK)

/*! @name GPR0_SET - General Purpose Register */
#define CCM_GPR0_SET_GP0_MASK                    (0xFFFFFFFFU)
#define CCM_GPR0_SET_GP0_SHIFT                   (0U)
#define CCM_GPR0_SET_GP0(x)                      (((uint32_t)(((uint32_t)(x)) << CCM_GPR0_SET_GP0_SHIFT)) & CCM_GPR0_SET_GP0_MASK)

/*! @name GPR0_CLR - General Purpose Register */
#define CCM_GPR0_CLR_GP0_MASK                    (0xFFFFFFFFU)
#define CCM_GPR0_CLR_GP0_SHIFT                   (0U)
#define CCM_GPR0_CLR_GP0(x)                      (((uint32_t)(((uint32_t)(x)) << CCM_GPR0_CLR_GP0_SHIFT)) & CCM_GPR0_CLR_GP0_MASK)

/*! @name GPR0_TOG - General Purpose Register */
#define CCM_GPR0_TOG_GP0_MASK                    (0xFFFFFFFFU)
#define CCM_GPR0_TOG_GP0_SHIFT                   (0U)
#define CCM_GPR0_TOG_GP0(x)                      (((uint32_t)(((uint32_t)(x)) << CCM_GPR0_TOG_GP0_SHIFT)) & CCM_GPR0_TOG_GP0_MASK)

/*! @name PLL_CTRL - CCM PLL Control Register */
#define CCM_PLL_CTRL_SETTING0_MASK               (0x3U)
#define CCM_PLL_CTRL_SETTING0_SHIFT              (0U)
#define CCM_PLL_CTRL_SETTING0(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_SETTING0_SHIFT)) & CCM_PLL_CTRL_SETTING0_MASK)
#define CCM_PLL_CTRL_SETTING1_MASK               (0x30U)
#define CCM_PLL_CTRL_SETTING1_SHIFT              (4U)
#define CCM_PLL_CTRL_SETTING1(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_SETTING1_SHIFT)) & CCM_PLL_CTRL_SETTING1_MASK)
#define CCM_PLL_CTRL_SETTING2_MASK               (0x300U)
#define CCM_PLL_CTRL_SETTING2_SHIFT              (8U)
#define CCM_PLL_CTRL_SETTING2(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_SETTING2_SHIFT)) & CCM_PLL_CTRL_SETTING2_MASK)
#define CCM_PLL_CTRL_SETTING3_MASK               (0x3000U)
#define CCM_PLL_CTRL_SETTING3_SHIFT              (12U)
#define CCM_PLL_CTRL_SETTING3(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_SETTING3_SHIFT)) & CCM_PLL_CTRL_SETTING3_MASK)

/* The count of CCM_PLL_CTRL */
#define CCM_PLL_CTRL_COUNT                       (33U)

/*! @name PLL_CTRL_SET - CCM PLL Control Register */
#define CCM_PLL_CTRL_SET_SETTING0_MASK           (0x3U)
#define CCM_PLL_CTRL_SET_SETTING0_SHIFT          (0U)
#define CCM_PLL_CTRL_SET_SETTING0(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_SET_SETTING0_SHIFT)) & CCM_PLL_CTRL_SET_SETTING0_MASK)
#define CCM_PLL_CTRL_SET_SETTING1_MASK           (0x30U)
#define CCM_PLL_CTRL_SET_SETTING1_SHIFT          (4U)
#define CCM_PLL_CTRL_SET_SETTING1(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_SET_SETTING1_SHIFT)) & CCM_PLL_CTRL_SET_SETTING1_MASK)
#define CCM_PLL_CTRL_SET_SETTING2_MASK           (0x300U)
#define CCM_PLL_CTRL_SET_SETTING2_SHIFT          (8U)
#define CCM_PLL_CTRL_SET_SETTING2(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_SET_SETTING2_SHIFT)) & CCM_PLL_CTRL_SET_SETTING2_MASK)
#define CCM_PLL_CTRL_SET_SETTING3_MASK           (0x3000U)
#define CCM_PLL_CTRL_SET_SETTING3_SHIFT          (12U)
#define CCM_PLL_CTRL_SET_SETTING3(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_SET_SETTING3_SHIFT)) & CCM_PLL_CTRL_SET_SETTING3_MASK)

/* The count of CCM_PLL_CTRL_SET */
#define CCM_PLL_CTRL_SET_COUNT                   (33U)

/*! @name PLL_CTRL_CLR - CCM PLL Control Register */
#define CCM_PLL_CTRL_CLR_SETTING0_MASK           (0x3U)
#define CCM_PLL_CTRL_CLR_SETTING0_SHIFT          (0U)
#define CCM_PLL_CTRL_CLR_SETTING0(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_CLR_SETTING0_SHIFT)) & CCM_PLL_CTRL_CLR_SETTING0_MASK)
#define CCM_PLL_CTRL_CLR_SETTING1_MASK           (0x30U)
#define CCM_PLL_CTRL_CLR_SETTING1_SHIFT          (4U)
#define CCM_PLL_CTRL_CLR_SETTING1(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_CLR_SETTING1_SHIFT)) & CCM_PLL_CTRL_CLR_SETTING1_MASK)
#define CCM_PLL_CTRL_CLR_SETTING2_MASK           (0x300U)
#define CCM_PLL_CTRL_CLR_SETTING2_SHIFT          (8U)
#define CCM_PLL_CTRL_CLR_SETTING2(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_CLR_SETTING2_SHIFT)) & CCM_PLL_CTRL_CLR_SETTING2_MASK)
#define CCM_PLL_CTRL_CLR_SETTING3_MASK           (0x3000U)
#define CCM_PLL_CTRL_CLR_SETTING3_SHIFT          (12U)
#define CCM_PLL_CTRL_CLR_SETTING3(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_CLR_SETTING3_SHIFT)) & CCM_PLL_CTRL_CLR_SETTING3_MASK)

/* The count of CCM_PLL_CTRL_CLR */
#define CCM_PLL_CTRL_CLR_COUNT                   (33U)

/*! @name PLL_CTRL_TOG - CCM PLL Control Register */
#define CCM_PLL_CTRL_TOG_SETTING0_MASK           (0x3U)
#define CCM_PLL_CTRL_TOG_SETTING0_SHIFT          (0U)
#define CCM_PLL_CTRL_TOG_SETTING0(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_TOG_SETTING0_SHIFT)) & CCM_PLL_CTRL_TOG_SETTING0_MASK)
#define CCM_PLL_CTRL_TOG_SETTING1_MASK           (0x30U)
#define CCM_PLL_CTRL_TOG_SETTING1_SHIFT          (4U)
#define CCM_PLL_CTRL_TOG_SETTING1(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_TOG_SETTING1_SHIFT)) & CCM_PLL_CTRL_TOG_SETTING1_MASK)
#define CCM_PLL_CTRL_TOG_SETTING2_MASK           (0x300U)
#define CCM_PLL_CTRL_TOG_SETTING2_SHIFT          (8U)
#define CCM_PLL_CTRL_TOG_SETTING2(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_TOG_SETTING2_SHIFT)) & CCM_PLL_CTRL_TOG_SETTING2_MASK)
#define CCM_PLL_CTRL_TOG_SETTING3_MASK           (0x3000U)
#define CCM_PLL_CTRL_TOG_SETTING3_SHIFT          (12U)
#define CCM_PLL_CTRL_TOG_SETTING3(x)             (((uint32_t)(((uint32_t)(x)) << CCM_PLL_CTRL_TOG_SETTING3_SHIFT)) & CCM_PLL_CTRL_TOG_SETTING3_MASK)

/* The count of CCM_PLL_CTRL_TOG */
#define CCM_PLL_CTRL_TOG_COUNT                   (33U)

/*! @name CCGR - CCM Clock Gating Register */
#define CCM_CCGR_SETTING0_MASK                   (0x3U)
#define CCM_CCGR_SETTING0_SHIFT                  (0U)
#define CCM_CCGR_SETTING0(x)                     (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_SETTING0_SHIFT)) & CCM_CCGR_SETTING0_MASK)
#define CCM_CCGR_SETTING1_MASK                   (0x30U)
#define CCM_CCGR_SETTING1_SHIFT                  (4U)
#define CCM_CCGR_SETTING1(x)                     (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_SETTING1_SHIFT)) & CCM_CCGR_SETTING1_MASK)
#define CCM_CCGR_SETTING2_MASK                   (0x300U)
#define CCM_CCGR_SETTING2_SHIFT                  (8U)
#define CCM_CCGR_SETTING2(x)                     (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_SETTING2_SHIFT)) & CCM_CCGR_SETTING2_MASK)
#define CCM_CCGR_SETTING3_MASK                   (0x3000U)
#define CCM_CCGR_SETTING3_SHIFT                  (12U)
#define CCM_CCGR_SETTING3(x)                     (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_SETTING3_SHIFT)) & CCM_CCGR_SETTING3_MASK)

/* The count of CCM_CCGR */
#define CCM_CCGR_COUNT                           (191U)

/*! @name CCGR_SET - CCM Clock Gating Register */
#define CCM_CCGR_SET_SETTING0_MASK               (0x3U)
#define CCM_CCGR_SET_SETTING0_SHIFT              (0U)
#define CCM_CCGR_SET_SETTING0(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_SET_SETTING0_SHIFT)) & CCM_CCGR_SET_SETTING0_MASK)
#define CCM_CCGR_SET_SETTING1_MASK               (0x30U)
#define CCM_CCGR_SET_SETTING1_SHIFT              (4U)
#define CCM_CCGR_SET_SETTING1(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_SET_SETTING1_SHIFT)) & CCM_CCGR_SET_SETTING1_MASK)
#define CCM_CCGR_SET_SETTING2_MASK               (0x300U)
#define CCM_CCGR_SET_SETTING2_SHIFT              (8U)
#define CCM_CCGR_SET_SETTING2(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_SET_SETTING2_SHIFT)) & CCM_CCGR_SET_SETTING2_MASK)
#define CCM_CCGR_SET_SETTING3_MASK               (0x3000U)
#define CCM_CCGR_SET_SETTING3_SHIFT              (12U)
#define CCM_CCGR_SET_SETTING3(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_SET_SETTING3_SHIFT)) & CCM_CCGR_SET_SETTING3_MASK)

/* The count of CCM_CCGR_SET */
#define CCM_CCGR_SET_COUNT                       (191U)

/*! @name CCGR_CLR - CCM Clock Gating Register */
#define CCM_CCGR_CLR_SETTING0_MASK               (0x3U)
#define CCM_CCGR_CLR_SETTING0_SHIFT              (0U)
#define CCM_CCGR_CLR_SETTING0(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_CLR_SETTING0_SHIFT)) & CCM_CCGR_CLR_SETTING0_MASK)
#define CCM_CCGR_CLR_SETTING1_MASK               (0x30U)
#define CCM_CCGR_CLR_SETTING1_SHIFT              (4U)
#define CCM_CCGR_CLR_SETTING1(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_CLR_SETTING1_SHIFT)) & CCM_CCGR_CLR_SETTING1_MASK)
#define CCM_CCGR_CLR_SETTING2_MASK               (0x300U)
#define CCM_CCGR_CLR_SETTING2_SHIFT              (8U)
#define CCM_CCGR_CLR_SETTING2(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_CLR_SETTING2_SHIFT)) & CCM_CCGR_CLR_SETTING2_MASK)
#define CCM_CCGR_CLR_SETTING3_MASK               (0x3000U)
#define CCM_CCGR_CLR_SETTING3_SHIFT              (12U)
#define CCM_CCGR_CLR_SETTING3(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_CLR_SETTING3_SHIFT)) & CCM_CCGR_CLR_SETTING3_MASK)

/* The count of CCM_CCGR_CLR */
#define CCM_CCGR_CLR_COUNT                       (191U)

/*! @name CCGR_TOG - CCM Clock Gating Register */
#define CCM_CCGR_TOG_SETTING0_MASK               (0x3U)
#define CCM_CCGR_TOG_SETTING0_SHIFT              (0U)
#define CCM_CCGR_TOG_SETTING0(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_TOG_SETTING0_SHIFT)) & CCM_CCGR_TOG_SETTING0_MASK)
#define CCM_CCGR_TOG_SETTING1_MASK               (0x30U)
#define CCM_CCGR_TOG_SETTING1_SHIFT              (4U)
#define CCM_CCGR_TOG_SETTING1(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_TOG_SETTING1_SHIFT)) & CCM_CCGR_TOG_SETTING1_MASK)
#define CCM_CCGR_TOG_SETTING2_MASK               (0x300U)
#define CCM_CCGR_TOG_SETTING2_SHIFT              (8U)
#define CCM_CCGR_TOG_SETTING2(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_TOG_SETTING2_SHIFT)) & CCM_CCGR_TOG_SETTING2_MASK)
#define CCM_CCGR_TOG_SETTING3_MASK               (0x3000U)
#define CCM_CCGR_TOG_SETTING3_SHIFT              (12U)
#define CCM_CCGR_TOG_SETTING3(x)                 (((uint32_t)(((uint32_t)(x)) << CCM_CCGR_TOG_SETTING3_SHIFT)) & CCM_CCGR_TOG_SETTING3_MASK)

/* The count of CCM_CCGR_TOG */
#define CCM_CCGR_TOG_COUNT                       (191U)

/*! @name TARGET_ROOT - Target Register */
#define CCM_TARGET_ROOT_POST_PODF_MASK           (0x3FU)
#define CCM_TARGET_ROOT_POST_PODF_SHIFT          (0U)
#define CCM_TARGET_ROOT_POST_PODF(x)             (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_POST_PODF_SHIFT)) & CCM_TARGET_ROOT_POST_PODF_MASK)
#define CCM_TARGET_ROOT_PRE_PODF_MASK            (0x70000U)
#define CCM_TARGET_ROOT_PRE_PODF_SHIFT           (16U)
#define CCM_TARGET_ROOT_PRE_PODF(x)              (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_PRE_PODF_SHIFT)) & CCM_TARGET_ROOT_PRE_PODF_MASK)
#define CCM_TARGET_ROOT_MUX_MASK                 (0x7000000U)
#define CCM_TARGET_ROOT_MUX_SHIFT                (24U)
#define CCM_TARGET_ROOT_MUX(x)                   (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_MUX_SHIFT)) & CCM_TARGET_ROOT_MUX_MASK)
#define CCM_TARGET_ROOT_ENABLE_MASK              (0x10000000U)
#define CCM_TARGET_ROOT_ENABLE_SHIFT             (28U)

/* The count of CCM_TARGET_ROOT */
#define CCM_TARGET_ROOT_COUNT                    (125U)

/*! @name TARGET_ROOT_SET - Target Register */
#define CCM_TARGET_ROOT_SET_POST_PODF_MASK       (0x3FU)
#define CCM_TARGET_ROOT_SET_POST_PODF_SHIFT      (0U)
#define CCM_TARGET_ROOT_SET_POST_PODF(x)         (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_SET_POST_PODF_SHIFT)) & CCM_TARGET_ROOT_SET_POST_PODF_MASK)
#define CCM_TARGET_ROOT_SET_PRE_PODF_MASK        (0x70000U)
#define CCM_TARGET_ROOT_SET_PRE_PODF_SHIFT       (16U)
#define CCM_TARGET_ROOT_SET_PRE_PODF(x)          (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_SET_PRE_PODF_SHIFT)) & CCM_TARGET_ROOT_SET_PRE_PODF_MASK)
#define CCM_TARGET_ROOT_SET_MUX_MASK             (0x7000000U)
#define CCM_TARGET_ROOT_SET_MUX_SHIFT            (24U)
#define CCM_TARGET_ROOT_SET_MUX(x)               (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_SET_MUX_SHIFT)) & CCM_TARGET_ROOT_SET_MUX_MASK)
#define CCM_TARGET_ROOT_SET_ENABLE_MASK          (0x10000000U)
#define CCM_TARGET_ROOT_SET_ENABLE_SHIFT         (28U)

/* The count of CCM_TARGET_ROOT_SET */
#define CCM_TARGET_ROOT_SET_COUNT                (125U)

/*! @name TARGET_ROOT_CLR - Target Register */
#define CCM_TARGET_ROOT_CLR_POST_PODF_MASK       (0x3FU)
#define CCM_TARGET_ROOT_CLR_POST_PODF_SHIFT      (0U)
#define CCM_TARGET_ROOT_CLR_POST_PODF(x)         (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_CLR_POST_PODF_SHIFT)) & CCM_TARGET_ROOT_CLR_POST_PODF_MASK)
#define CCM_TARGET_ROOT_CLR_PRE_PODF_MASK        (0x70000U)
#define CCM_TARGET_ROOT_CLR_PRE_PODF_SHIFT       (16U)
#define CCM_TARGET_ROOT_CLR_PRE_PODF(x)          (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_CLR_PRE_PODF_SHIFT)) & CCM_TARGET_ROOT_CLR_PRE_PODF_MASK)
#define CCM_TARGET_ROOT_CLR_MUX_MASK             (0x7000000U)
#define CCM_TARGET_ROOT_CLR_MUX_SHIFT            (24U)
#define CCM_TARGET_ROOT_CLR_MUX(x)               (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_CLR_MUX_SHIFT)) & CCM_TARGET_ROOT_CLR_MUX_MASK)
#define CCM_TARGET_ROOT_CLR_ENABLE_MASK          (0x10000000U)
#define CCM_TARGET_ROOT_CLR_ENABLE_SHIFT         (28U)

/* The count of CCM_TARGET_ROOT_CLR */
#define CCM_TARGET_ROOT_CLR_COUNT                (125U)

/*! @name TARGET_ROOT_TOG - Target Register */
#define CCM_TARGET_ROOT_TOG_POST_PODF_MASK       (0x3FU)
#define CCM_TARGET_ROOT_TOG_POST_PODF_SHIFT      (0U)
#define CCM_TARGET_ROOT_TOG_POST_PODF(x)         (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_TOG_POST_PODF_SHIFT)) & CCM_TARGET_ROOT_TOG_POST_PODF_MASK)
#define CCM_TARGET_ROOT_TOG_PRE_PODF_MASK        (0x70000U)
#define CCM_TARGET_ROOT_TOG_PRE_PODF_SHIFT       (16U)
#define CCM_TARGET_ROOT_TOG_PRE_PODF(x)          (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_TOG_PRE_PODF_SHIFT)) & CCM_TARGET_ROOT_TOG_PRE_PODF_MASK)
#define CCM_TARGET_ROOT_TOG_MUX_MASK             (0x7000000U)
#define CCM_TARGET_ROOT_TOG_MUX_SHIFT            (24U)
#define CCM_TARGET_ROOT_TOG_MUX(x)               (((uint32_t)(((uint32_t)(x)) << CCM_TARGET_ROOT_TOG_MUX_SHIFT)) & CCM_TARGET_ROOT_TOG_MUX_MASK)
#define CCM_TARGET_ROOT_TOG_ENABLE_MASK          (0x10000000U)
#define CCM_TARGET_ROOT_TOG_ENABLE_SHIFT         (28U)

/* The count of CCM_TARGET_ROOT_TOG */
#define CCM_TARGET_ROOT_TOG_COUNT                (125U)

/*! @name MISC - Miscellaneous Register */
#define CCM_MISC_AUTHEN_FAIL_MASK                (0x1U)
#define CCM_MISC_AUTHEN_FAIL_SHIFT               (0U)
#define CCM_MISC_TIMEOUT_MASK                    (0x10U)
#define CCM_MISC_TIMEOUT_SHIFT                   (4U)
#define CCM_MISC_VIOLATE_MASK                    (0x100U)
#define CCM_MISC_VIOLATE_SHIFT                   (8U)

/* The count of CCM_MISC */
#define CCM_MISC_COUNT                           (125U)

/*! @name MISC_ROOT_SET - Miscellaneous Register */
#define CCM_MISC_ROOT_SET_AUTHEN_FAIL_MASK       (0x1U)
#define CCM_MISC_ROOT_SET_AUTHEN_FAIL_SHIFT      (0U)
#define CCM_MISC_ROOT_SET_TIMEOUT_MASK           (0x10U)
#define CCM_MISC_ROOT_SET_TIMEOUT_SHIFT          (4U)
#define CCM_MISC_ROOT_SET_VIOLATE_MASK           (0x100U)
#define CCM_MISC_ROOT_SET_VIOLATE_SHIFT          (8U)

/* The count of CCM_MISC_ROOT_SET */
#define CCM_MISC_ROOT_SET_COUNT                  (125U)

/*! @name MISC_ROOT_CLR - Miscellaneous Register */
#define CCM_MISC_ROOT_CLR_AUTHEN_FAIL_MASK       (0x1U)
#define CCM_MISC_ROOT_CLR_AUTHEN_FAIL_SHIFT      (0U)
#define CCM_MISC_ROOT_CLR_TIMEOUT_MASK           (0x10U)
#define CCM_MISC_ROOT_CLR_TIMEOUT_SHIFT          (4U)
#define CCM_MISC_ROOT_CLR_VIOLATE_MASK           (0x100U)
#define CCM_MISC_ROOT_CLR_VIOLATE_SHIFT          (8U)

/* The count of CCM_MISC_ROOT_CLR */
#define CCM_MISC_ROOT_CLR_COUNT                  (125U)

/*! @name MISC_ROOT_TOG - Miscellaneous Register */
#define CCM_MISC_ROOT_TOG_AUTHEN_FAIL_MASK       (0x1U)
#define CCM_MISC_ROOT_TOG_AUTHEN_FAIL_SHIFT      (0U)
#define CCM_MISC_ROOT_TOG_TIMEOUT_MASK           (0x10U)
#define CCM_MISC_ROOT_TOG_TIMEOUT_SHIFT          (4U)
#define CCM_MISC_ROOT_TOG_VIOLATE_MASK           (0x100U)
#define CCM_MISC_ROOT_TOG_VIOLATE_SHIFT          (8U)

/* The count of CCM_MISC_ROOT_TOG */
#define CCM_MISC_ROOT_TOG_COUNT                  (125U)

/*! @name POST - Post Divider Register */
#define CCM_POST_POST_PODF_MASK                  (0x3FU)
#define CCM_POST_POST_PODF_SHIFT                 (0U)
#define CCM_POST_POST_PODF(x)                    (((uint32_t)(((uint32_t)(x)) << CCM_POST_POST_PODF_SHIFT)) & CCM_POST_POST_PODF_MASK)
#define CCM_POST_BUSY1_MASK                      (0x80U)
#define CCM_POST_BUSY1_SHIFT                     (7U)
#define CCM_POST_SELECT_MASK                     (0x10000000U)
#define CCM_POST_SELECT_SHIFT                    (28U)
#define CCM_POST_BUSY2_MASK                      (0x80000000U)
#define CCM_POST_BUSY2_SHIFT                     (31U)

/* The count of CCM_POST */
#define CCM_POST_COUNT                           (125U)

/*! @name POST_ROOT_SET - Post Divider Register */
#define CCM_POST_ROOT_SET_POST_PODF_MASK         (0x3FU)
#define CCM_POST_ROOT_SET_POST_PODF_SHIFT        (0U)
#define CCM_POST_ROOT_SET_POST_PODF(x)           (((uint32_t)(((uint32_t)(x)) << CCM_POST_ROOT_SET_POST_PODF_SHIFT)) & CCM_POST_ROOT_SET_POST_PODF_MASK)
#define CCM_POST_ROOT_SET_BUSY1_MASK             (0x80U)
#define CCM_POST_ROOT_SET_BUSY1_SHIFT            (7U)
#define CCM_POST_ROOT_SET_SELECT_MASK            (0x10000000U)
#define CCM_POST_ROOT_SET_SELECT_SHIFT           (28U)
#define CCM_POST_ROOT_SET_BUSY2_MASK             (0x80000000U)
#define CCM_POST_ROOT_SET_BUSY2_SHIFT            (31U)

/* The count of CCM_POST_ROOT_SET */
#define CCM_POST_ROOT_SET_COUNT                  (125U)

/*! @name POST_ROOT_CLR - Post Divider Register */
#define CCM_POST_ROOT_CLR_POST_PODF_MASK         (0x3FU)
#define CCM_POST_ROOT_CLR_POST_PODF_SHIFT        (0U)
#define CCM_POST_ROOT_CLR_POST_PODF(x)           (((uint32_t)(((uint32_t)(x)) << CCM_POST_ROOT_CLR_POST_PODF_SHIFT)) & CCM_POST_ROOT_CLR_POST_PODF_MASK)
#define CCM_POST_ROOT_CLR_BUSY1_MASK             (0x80U)
#define CCM_POST_ROOT_CLR_BUSY1_SHIFT            (7U)
#define CCM_POST_ROOT_CLR_SELECT_MASK            (0x10000000U)
#define CCM_POST_ROOT_CLR_SELECT_SHIFT           (28U)
#define CCM_POST_ROOT_CLR_BUSY2_MASK             (0x80000000U)
#define CCM_POST_ROOT_CLR_BUSY2_SHIFT            (31U)

/* The count of CCM_POST_ROOT_CLR */
#define CCM_POST_ROOT_CLR_COUNT                  (125U)

/*! @name POST_ROOT_TOG - Post Divider Register */
#define CCM_POST_ROOT_TOG_POST_PODF_MASK         (0x3FU)
#define CCM_POST_ROOT_TOG_POST_PODF_SHIFT        (0U)
#define CCM_POST_ROOT_TOG_POST_PODF(x)           (((uint32_t)(((uint32_t)(x)) << CCM_POST_ROOT_TOG_POST_PODF_SHIFT)) & CCM_POST_ROOT_TOG_POST_PODF_MASK)
#define CCM_POST_ROOT_TOG_BUSY1_MASK             (0x80U)
#define CCM_POST_ROOT_TOG_BUSY1_SHIFT            (7U)
#define CCM_POST_ROOT_TOG_SELECT_MASK            (0x10000000U)
#define CCM_POST_ROOT_TOG_SELECT_SHIFT           (28U)
#define CCM_POST_ROOT_TOG_BUSY2_MASK             (0x80000000U)
#define CCM_POST_ROOT_TOG_BUSY2_SHIFT            (31U)

/* The count of CCM_POST_ROOT_TOG */
#define CCM_POST_ROOT_TOG_COUNT                  (125U)

/*! @name PRE - Pre Divider Register */
#define CCM_PRE_PRE_PODF_B_MASK                  (0x7U)
#define CCM_PRE_PRE_PODF_B_SHIFT                 (0U)
#define CCM_PRE_PRE_PODF_B(x)                    (((uint32_t)(((uint32_t)(x)) << CCM_PRE_PRE_PODF_B_SHIFT)) & CCM_PRE_PRE_PODF_B_MASK)
#define CCM_PRE_BUSY0_MASK                       (0x8U)
#define CCM_PRE_BUSY0_SHIFT                      (3U)
#define CCM_PRE_MUX_B_MASK                       (0x700U)
#define CCM_PRE_MUX_B_SHIFT                      (8U)
#define CCM_PRE_MUX_B(x)                         (((uint32_t)(((uint32_t)(x)) << CCM_PRE_MUX_B_SHIFT)) & CCM_PRE_MUX_B_MASK)
#define CCM_PRE_EN_B_MASK                        (0x1000U)
#define CCM_PRE_EN_B_SHIFT                       (12U)
#define CCM_PRE_BUSY1_MASK                       (0x8000U)
#define CCM_PRE_BUSY1_SHIFT                      (15U)
#define CCM_PRE_PRE_PODF_A_MASK                  (0x70000U)
#define CCM_PRE_PRE_PODF_A_SHIFT                 (16U)
#define CCM_PRE_PRE_PODF_A(x)                    (((uint32_t)(((uint32_t)(x)) << CCM_PRE_PRE_PODF_A_SHIFT)) & CCM_PRE_PRE_PODF_A_MASK)
#define CCM_PRE_BUSY3_MASK                       (0x80000U)
#define CCM_PRE_BUSY3_SHIFT                      (19U)
#define CCM_PRE_MUX_A_MASK                       (0x7000000U)
#define CCM_PRE_MUX_A_SHIFT                      (24U)
#define CCM_PRE_MUX_A(x)                         (((uint32_t)(((uint32_t)(x)) << CCM_PRE_MUX_A_SHIFT)) & CCM_PRE_MUX_A_MASK)
#define CCM_PRE_EN_A_MASK                        (0x10000000U)
#define CCM_PRE_EN_A_SHIFT                       (28U)
#define CCM_PRE_BUSY4_MASK                       (0x80000000U)
#define CCM_PRE_BUSY4_SHIFT                      (31U)

/* The count of CCM_PRE */
#define CCM_PRE_COUNT                            (125U)

/*! @name PRE_ROOT_SET - Pre Divider Register */
#define CCM_PRE_ROOT_SET_PRE_PODF_B_MASK         (0x7U)
#define CCM_PRE_ROOT_SET_PRE_PODF_B_SHIFT        (0U)
#define CCM_PRE_ROOT_SET_PRE_PODF_B(x)           (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_SET_PRE_PODF_B_SHIFT)) & CCM_PRE_ROOT_SET_PRE_PODF_B_MASK)
#define CCM_PRE_ROOT_SET_BUSY0_MASK              (0x8U)
#define CCM_PRE_ROOT_SET_BUSY0_SHIFT             (3U)
#define CCM_PRE_ROOT_SET_MUX_B_MASK              (0x700U)
#define CCM_PRE_ROOT_SET_MUX_B_SHIFT             (8U)
#define CCM_PRE_ROOT_SET_MUX_B(x)                (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_SET_MUX_B_SHIFT)) & CCM_PRE_ROOT_SET_MUX_B_MASK)
#define CCM_PRE_ROOT_SET_EN_B_MASK               (0x1000U)
#define CCM_PRE_ROOT_SET_EN_B_SHIFT              (12U)
#define CCM_PRE_ROOT_SET_BUSY1_MASK              (0x8000U)
#define CCM_PRE_ROOT_SET_BUSY1_SHIFT             (15U)
#define CCM_PRE_ROOT_SET_PRE_PODF_A_MASK         (0x70000U)
#define CCM_PRE_ROOT_SET_PRE_PODF_A_SHIFT        (16U)
#define CCM_PRE_ROOT_SET_PRE_PODF_A(x)           (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_SET_PRE_PODF_A_SHIFT)) & CCM_PRE_ROOT_SET_PRE_PODF_A_MASK)
#define CCM_PRE_ROOT_SET_BUSY3_MASK              (0x80000U)
#define CCM_PRE_ROOT_SET_BUSY3_SHIFT             (19U)
#define CCM_PRE_ROOT_SET_MUX_A_MASK              (0x7000000U)
#define CCM_PRE_ROOT_SET_MUX_A_SHIFT             (24U)
#define CCM_PRE_ROOT_SET_MUX_A(x)                (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_SET_MUX_A_SHIFT)) & CCM_PRE_ROOT_SET_MUX_A_MASK)
#define CCM_PRE_ROOT_SET_EN_A_MASK               (0x10000000U)
#define CCM_PRE_ROOT_SET_EN_A_SHIFT              (28U)
#define CCM_PRE_ROOT_SET_BUSY4_MASK              (0x80000000U)
#define CCM_PRE_ROOT_SET_BUSY4_SHIFT             (31U)

/* The count of CCM_PRE_ROOT_SET */
#define CCM_PRE_ROOT_SET_COUNT                   (125U)

/*! @name PRE_ROOT_CLR - Pre Divider Register */
#define CCM_PRE_ROOT_CLR_PRE_PODF_B_MASK         (0x7U)
#define CCM_PRE_ROOT_CLR_PRE_PODF_B_SHIFT        (0U)
#define CCM_PRE_ROOT_CLR_PRE_PODF_B(x)           (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_CLR_PRE_PODF_B_SHIFT)) & CCM_PRE_ROOT_CLR_PRE_PODF_B_MASK)
#define CCM_PRE_ROOT_CLR_BUSY0_MASK              (0x8U)
#define CCM_PRE_ROOT_CLR_BUSY0_SHIFT             (3U)
#define CCM_PRE_ROOT_CLR_MUX_B_MASK              (0x700U)
#define CCM_PRE_ROOT_CLR_MUX_B_SHIFT             (8U)
#define CCM_PRE_ROOT_CLR_MUX_B(x)                (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_CLR_MUX_B_SHIFT)) & CCM_PRE_ROOT_CLR_MUX_B_MASK)
#define CCM_PRE_ROOT_CLR_EN_B_MASK               (0x1000U)
#define CCM_PRE_ROOT_CLR_EN_B_SHIFT              (12U)
#define CCM_PRE_ROOT_CLR_BUSY1_MASK              (0x8000U)
#define CCM_PRE_ROOT_CLR_BUSY1_SHIFT             (15U)
#define CCM_PRE_ROOT_CLR_PRE_PODF_A_MASK         (0x70000U)
#define CCM_PRE_ROOT_CLR_PRE_PODF_A_SHIFT        (16U)
#define CCM_PRE_ROOT_CLR_PRE_PODF_A(x)           (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_CLR_PRE_PODF_A_SHIFT)) & CCM_PRE_ROOT_CLR_PRE_PODF_A_MASK)
#define CCM_PRE_ROOT_CLR_BUSY3_MASK              (0x80000U)
#define CCM_PRE_ROOT_CLR_BUSY3_SHIFT             (19U)
#define CCM_PRE_ROOT_CLR_MUX_A_MASK              (0x7000000U)
#define CCM_PRE_ROOT_CLR_MUX_A_SHIFT             (24U)
#define CCM_PRE_ROOT_CLR_MUX_A(x)                (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_CLR_MUX_A_SHIFT)) & CCM_PRE_ROOT_CLR_MUX_A_MASK)
#define CCM_PRE_ROOT_CLR_EN_A_MASK               (0x10000000U)
#define CCM_PRE_ROOT_CLR_EN_A_SHIFT              (28U)
#define CCM_PRE_ROOT_CLR_BUSY4_MASK              (0x80000000U)
#define CCM_PRE_ROOT_CLR_BUSY4_SHIFT             (31U)

/* The count of CCM_PRE_ROOT_CLR */
#define CCM_PRE_ROOT_CLR_COUNT                   (125U)

/*! @name PRE_ROOT_TOG - Pre Divider Register */
#define CCM_PRE_ROOT_TOG_PRE_PODF_B_MASK         (0x7U)
#define CCM_PRE_ROOT_TOG_PRE_PODF_B_SHIFT        (0U)
#define CCM_PRE_ROOT_TOG_PRE_PODF_B(x)           (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_TOG_PRE_PODF_B_SHIFT)) & CCM_PRE_ROOT_TOG_PRE_PODF_B_MASK)
#define CCM_PRE_ROOT_TOG_BUSY0_MASK              (0x8U)
#define CCM_PRE_ROOT_TOG_BUSY0_SHIFT             (3U)
#define CCM_PRE_ROOT_TOG_MUX_B_MASK              (0x700U)
#define CCM_PRE_ROOT_TOG_MUX_B_SHIFT             (8U)
#define CCM_PRE_ROOT_TOG_MUX_B(x)                (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_TOG_MUX_B_SHIFT)) & CCM_PRE_ROOT_TOG_MUX_B_MASK)
#define CCM_PRE_ROOT_TOG_EN_B_MASK               (0x1000U)
#define CCM_PRE_ROOT_TOG_EN_B_SHIFT              (12U)
#define CCM_PRE_ROOT_TOG_BUSY1_MASK              (0x8000U)
#define CCM_PRE_ROOT_TOG_BUSY1_SHIFT             (15U)
#define CCM_PRE_ROOT_TOG_PRE_PODF_A_MASK         (0x70000U)
#define CCM_PRE_ROOT_TOG_PRE_PODF_A_SHIFT        (16U)
#define CCM_PRE_ROOT_TOG_PRE_PODF_A(x)           (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_TOG_PRE_PODF_A_SHIFT)) & CCM_PRE_ROOT_TOG_PRE_PODF_A_MASK)
#define CCM_PRE_ROOT_TOG_BUSY3_MASK              (0x80000U)
#define CCM_PRE_ROOT_TOG_BUSY3_SHIFT             (19U)
#define CCM_PRE_ROOT_TOG_MUX_A_MASK              (0x7000000U)
#define CCM_PRE_ROOT_TOG_MUX_A_SHIFT             (24U)
#define CCM_PRE_ROOT_TOG_MUX_A(x)                (((uint32_t)(((uint32_t)(x)) << CCM_PRE_ROOT_TOG_MUX_A_SHIFT)) & CCM_PRE_ROOT_TOG_MUX_A_MASK)
#define CCM_PRE_ROOT_TOG_EN_A_MASK               (0x10000000U)
#define CCM_PRE_ROOT_TOG_EN_A_SHIFT              (28U)
#define CCM_PRE_ROOT_TOG_BUSY4_MASK              (0x80000000U)
#define CCM_PRE_ROOT_TOG_BUSY4_SHIFT             (31U)

/* The count of CCM_PRE_ROOT_TOG */
#define CCM_PRE_ROOT_TOG_COUNT                   (125U)

/*! @name ACCESS_CTRL - Access Control Register */
#define CCM_ACCESS_CTRL_DOMAIN0_INFO_MASK        (0xFU)
#define CCM_ACCESS_CTRL_DOMAIN0_INFO_SHIFT       (0U)
#define CCM_ACCESS_CTRL_DOMAIN0_INFO(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_DOMAIN0_INFO_SHIFT)) & CCM_ACCESS_CTRL_DOMAIN0_INFO_MASK)
#define CCM_ACCESS_CTRL_DOMAIN1_INFO_MASK        (0xF0U)
#define CCM_ACCESS_CTRL_DOMAIN1_INFO_SHIFT       (4U)
#define CCM_ACCESS_CTRL_DOMAIN1_INFO(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_DOMAIN1_INFO_SHIFT)) & CCM_ACCESS_CTRL_DOMAIN1_INFO_MASK)
#define CCM_ACCESS_CTRL_DOMAIN2_INFO_MASK        (0xF00U)
#define CCM_ACCESS_CTRL_DOMAIN2_INFO_SHIFT       (8U)
#define CCM_ACCESS_CTRL_DOMAIN2_INFO(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_DOMAIN2_INFO_SHIFT)) & CCM_ACCESS_CTRL_DOMAIN2_INFO_MASK)
#define CCM_ACCESS_CTRL_DOMAIN3_INFO_MASK        (0xF000U)
#define CCM_ACCESS_CTRL_DOMAIN3_INFO_SHIFT       (12U)
#define CCM_ACCESS_CTRL_DOMAIN3_INFO(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_DOMAIN3_INFO_SHIFT)) & CCM_ACCESS_CTRL_DOMAIN3_INFO_MASK)
#define CCM_ACCESS_CTRL_OWNER_ID_MASK            (0x30000U)
#define CCM_ACCESS_CTRL_OWNER_ID_SHIFT           (16U)
#define CCM_ACCESS_CTRL_OWNER_ID(x)              (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_OWNER_ID_SHIFT)) & CCM_ACCESS_CTRL_OWNER_ID_MASK)
#define CCM_ACCESS_CTRL_MUTEX_MASK               (0x100000U)
#define CCM_ACCESS_CTRL_MUTEX_SHIFT              (20U)
#define CCM_ACCESS_CTRL_DOMAIN0_WHITELIST_MASK   (0x1000000U)
#define CCM_ACCESS_CTRL_DOMAIN0_WHITELIST_SHIFT  (24U)
#define CCM_ACCESS_CTRL_DOMAIN1_WHITELIST_MASK   (0x2000000U)
#define CCM_ACCESS_CTRL_DOMAIN1_WHITELIST_SHIFT  (25U)
#define CCM_ACCESS_CTRL_DOMAIN2_WHITELIST_MASK   (0x4000000U)
#define CCM_ACCESS_CTRL_DOMAIN2_WHITELIST_SHIFT  (26U)
#define CCM_ACCESS_CTRL_DOMAIN3_WHITELIST_MASK   (0x8000000U)
#define CCM_ACCESS_CTRL_DOMAIN3_WHITELIST_SHIFT  (27U)
#define CCM_ACCESS_CTRL_SEMA_EN_MASK             (0x10000000U)
#define CCM_ACCESS_CTRL_SEMA_EN_SHIFT            (28U)
#define CCM_ACCESS_CTRL_LOCK_MASK                (0x80000000U)
#define CCM_ACCESS_CTRL_LOCK_SHIFT               (31U)

/* The count of CCM_ACCESS_CTRL */
#define CCM_ACCESS_CTRL_COUNT                    (125U)

/*! @name ACCESS_CTRL_ROOT_SET - Access Control Register */
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN0_INFO_MASK (0xFU)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN0_INFO_SHIFT (0U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN0_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_SET_DOMAIN0_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_SET_DOMAIN0_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN1_INFO_MASK (0xF0U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN1_INFO_SHIFT (4U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN1_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_SET_DOMAIN1_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_SET_DOMAIN1_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN2_INFO_MASK (0xF00U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN2_INFO_SHIFT (8U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN2_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_SET_DOMAIN2_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_SET_DOMAIN2_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN3_INFO_MASK (0xF000U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN3_INFO_SHIFT (12U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN3_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_SET_DOMAIN3_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_SET_DOMAIN3_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_SET_OWNER_ID_MASK   (0x30000U)
#define CCM_ACCESS_CTRL_ROOT_SET_OWNER_ID_SHIFT  (16U)
#define CCM_ACCESS_CTRL_ROOT_SET_OWNER_ID(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_SET_OWNER_ID_SHIFT)) & CCM_ACCESS_CTRL_ROOT_SET_OWNER_ID_MASK)
#define CCM_ACCESS_CTRL_ROOT_SET_MUTEX_MASK      (0x100000U)
#define CCM_ACCESS_CTRL_ROOT_SET_MUTEX_SHIFT     (20U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN0_WHITELIST_MASK (0x1000000U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN0_WHITELIST_SHIFT (24U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN1_WHITELIST_MASK (0x2000000U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN1_WHITELIST_SHIFT (25U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN2_WHITELIST_MASK (0x4000000U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN2_WHITELIST_SHIFT (26U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN3_WHITELIST_MASK (0x8000000U)
#define CCM_ACCESS_CTRL_ROOT_SET_DOMAIN3_WHITELIST_SHIFT (27U)
#define CCM_ACCESS_CTRL_ROOT_SET_SEMA_EN_MASK    (0x10000000U)
#define CCM_ACCESS_CTRL_ROOT_SET_SEMA_EN_SHIFT   (28U)
#define CCM_ACCESS_CTRL_ROOT_SET_LOCK_MASK       (0x80000000U)
#define CCM_ACCESS_CTRL_ROOT_SET_LOCK_SHIFT      (31U)

/* The count of CCM_ACCESS_CTRL_ROOT_SET */
#define CCM_ACCESS_CTRL_ROOT_SET_COUNT           (125U)

/*! @name ACCESS_CTRL_ROOT_CLR - Access Control Register */
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN0_INFO_MASK (0xFU)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN0_INFO_SHIFT (0U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN0_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN0_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN0_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN1_INFO_MASK (0xF0U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN1_INFO_SHIFT (4U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN1_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN1_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN1_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN2_INFO_MASK (0xF00U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN2_INFO_SHIFT (8U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN2_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN2_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN2_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN3_INFO_MASK (0xF000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN3_INFO_SHIFT (12U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN3_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN3_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN3_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_CLR_OWNER_ID_MASK   (0x30000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_OWNER_ID_SHIFT  (16U)
#define CCM_ACCESS_CTRL_ROOT_CLR_OWNER_ID(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_CLR_OWNER_ID_SHIFT)) & CCM_ACCESS_CTRL_ROOT_CLR_OWNER_ID_MASK)
#define CCM_ACCESS_CTRL_ROOT_CLR_MUTEX_MASK      (0x100000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_MUTEX_SHIFT     (20U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN0_WHITELIST_MASK (0x1000000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN0_WHITELIST_SHIFT (24U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN1_WHITELIST_MASK (0x2000000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN1_WHITELIST_SHIFT (25U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN2_WHITELIST_MASK (0x4000000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN2_WHITELIST_SHIFT (26U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN3_WHITELIST_MASK (0x8000000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_DOMAIN3_WHITELIST_SHIFT (27U)
#define CCM_ACCESS_CTRL_ROOT_CLR_SEMA_EN_MASK    (0x10000000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_SEMA_EN_SHIFT   (28U)
#define CCM_ACCESS_CTRL_ROOT_CLR_LOCK_MASK       (0x80000000U)
#define CCM_ACCESS_CTRL_ROOT_CLR_LOCK_SHIFT      (31U)

/* The count of CCM_ACCESS_CTRL_ROOT_CLR */
#define CCM_ACCESS_CTRL_ROOT_CLR_COUNT           (125U)

/*! @name ACCESS_CTRL_ROOT_TOG - Access Control Register */
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN0_INFO_MASK (0xFU)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN0_INFO_SHIFT (0U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN0_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN0_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN0_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN1_INFO_MASK (0xF0U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN1_INFO_SHIFT (4U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN1_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN1_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN1_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN2_INFO_MASK (0xF00U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN2_INFO_SHIFT (8U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN2_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN2_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN2_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN3_INFO_MASK (0xF000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN3_INFO_SHIFT (12U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN3_INFO(x) (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN3_INFO_SHIFT)) & CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN3_INFO_MASK)
#define CCM_ACCESS_CTRL_ROOT_TOG_OWNER_ID_MASK   (0x30000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_OWNER_ID_SHIFT  (16U)
#define CCM_ACCESS_CTRL_ROOT_TOG_OWNER_ID(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ACCESS_CTRL_ROOT_TOG_OWNER_ID_SHIFT)) & CCM_ACCESS_CTRL_ROOT_TOG_OWNER_ID_MASK)
#define CCM_ACCESS_CTRL_ROOT_TOG_MUTEX_MASK      (0x100000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_MUTEX_SHIFT     (20U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN0_WHITELIST_MASK (0x1000000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN0_WHITELIST_SHIFT (24U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN1_WHITELIST_MASK (0x2000000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN1_WHITELIST_SHIFT (25U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN2_WHITELIST_MASK (0x4000000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN2_WHITELIST_SHIFT (26U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN3_WHITELIST_MASK (0x8000000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_DOMAIN3_WHITELIST_SHIFT (27U)
#define CCM_ACCESS_CTRL_ROOT_TOG_SEMA_EN_MASK    (0x10000000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_SEMA_EN_SHIFT   (28U)
#define CCM_ACCESS_CTRL_ROOT_TOG_LOCK_MASK       (0x80000000U)
#define CCM_ACCESS_CTRL_ROOT_TOG_LOCK_SHIFT      (31U)

/* The count of CCM_ACCESS_CTRL_ROOT_TOG */
#define CCM_ACCESS_CTRL_ROOT_TOG_COUNT           (125U)


/*!
 * @}
 */ /* end of group CCM_Register_Masks */


/* CCM - Peripheral instance base addresses */
/** Peripheral CCM base pointer */
#define CCM_BASE_PTR                             ((CCM_MemMapPtr)0x30380000u)
/** Array initializer of CCM peripheral base pointers */
#define CCM_BASE_PTRS                            { CCM_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- CCM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CCM_Register_Accessor_Macros CCM - Register accessor macros
 * @{
 */


/* CCM - Register instance definitions */
/* CCM */
#define CCM_GPR0                                 CCM_GPR0_REG(CCM_BASE_PTR)
#define CCM_GPR0_SET                             CCM_GPR0_SET_REG(CCM_BASE_PTR)
#define CCM_GPR0_CLR                             CCM_GPR0_CLR_REG(CCM_BASE_PTR)
#define CCM_GPR0_TOG                             CCM_GPR0_TOG_REG(CCM_BASE_PTR)
#define CCM_PLL_CTRL0                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,0)
#define CCM_PLL_CTRL0_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,0)
#define CCM_PLL_CTRL0_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,0)
#define CCM_PLL_CTRL0_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,0)
#define CCM_PLL_CTRL1                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,1)
#define CCM_PLL_CTRL1_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,1)
#define CCM_PLL_CTRL1_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,1)
#define CCM_PLL_CTRL1_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,1)
#define CCM_PLL_CTRL2                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,2)
#define CCM_PLL_CTRL2_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,2)
#define CCM_PLL_CTRL2_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,2)
#define CCM_PLL_CTRL2_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,2)
#define CCM_PLL_CTRL3                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,3)
#define CCM_PLL_CTRL3_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,3)
#define CCM_PLL_CTRL3_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,3)
#define CCM_PLL_CTRL3_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,3)
#define CCM_PLL_CTRL4                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,4)
#define CCM_PLL_CTRL4_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,4)
#define CCM_PLL_CTRL4_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,4)
#define CCM_PLL_CTRL4_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,4)
#define CCM_PLL_CTRL5                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,5)
#define CCM_PLL_CTRL5_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,5)
#define CCM_PLL_CTRL5_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,5)
#define CCM_PLL_CTRL5_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,5)
#define CCM_PLL_CTRL6                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,6)
#define CCM_PLL_CTRL6_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,6)
#define CCM_PLL_CTRL6_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,6)
#define CCM_PLL_CTRL6_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,6)
#define CCM_PLL_CTRL7                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,7)
#define CCM_PLL_CTRL7_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,7)
#define CCM_PLL_CTRL7_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,7)
#define CCM_PLL_CTRL7_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,7)
#define CCM_PLL_CTRL8                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,8)
#define CCM_PLL_CTRL8_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,8)
#define CCM_PLL_CTRL8_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,8)
#define CCM_PLL_CTRL8_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,8)
#define CCM_PLL_CTRL9                            CCM_PLL_CTRL_REG(CCM_BASE_PTR,9)
#define CCM_PLL_CTRL9_SET                        CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,9)
#define CCM_PLL_CTRL9_CLR                        CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,9)
#define CCM_PLL_CTRL9_TOG                        CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,9)
#define CCM_PLL_CTRL10                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,10)
#define CCM_PLL_CTRL10_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,10)
#define CCM_PLL_CTRL10_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,10)
#define CCM_PLL_CTRL10_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,10)
#define CCM_PLL_CTRL11                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,11)
#define CCM_PLL_CTRL11_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,11)
#define CCM_PLL_CTRL11_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,11)
#define CCM_PLL_CTRL11_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,11)
#define CCM_PLL_CTRL12                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,12)
#define CCM_PLL_CTRL12_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,12)
#define CCM_PLL_CTRL12_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,12)
#define CCM_PLL_CTRL12_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,12)
#define CCM_PLL_CTRL13                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,13)
#define CCM_PLL_CTRL13_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,13)
#define CCM_PLL_CTRL13_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,13)
#define CCM_PLL_CTRL13_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,13)
#define CCM_PLL_CTRL14                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,14)
#define CCM_PLL_CTRL14_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,14)
#define CCM_PLL_CTRL14_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,14)
#define CCM_PLL_CTRL14_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,14)
#define CCM_PLL_CTRL15                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,15)
#define CCM_PLL_CTRL15_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,15)
#define CCM_PLL_CTRL15_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,15)
#define CCM_PLL_CTRL15_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,15)
#define CCM_PLL_CTRL16                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,16)
#define CCM_PLL_CTRL16_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,16)
#define CCM_PLL_CTRL16_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,16)
#define CCM_PLL_CTRL16_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,16)
#define CCM_PLL_CTRL17                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,17)
#define CCM_PLL_CTRL17_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,17)
#define CCM_PLL_CTRL17_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,17)
#define CCM_PLL_CTRL17_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,17)
#define CCM_PLL_CTRL18                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,18)
#define CCM_PLL_CTRL18_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,18)
#define CCM_PLL_CTRL18_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,18)
#define CCM_PLL_CTRL18_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,18)
#define CCM_PLL_CTRL19                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,19)
#define CCM_PLL_CTRL19_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,19)
#define CCM_PLL_CTRL19_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,19)
#define CCM_PLL_CTRL19_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,19)
#define CCM_PLL_CTRL20                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,20)
#define CCM_PLL_CTRL20_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,20)
#define CCM_PLL_CTRL20_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,20)
#define CCM_PLL_CTRL20_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,20)
#define CCM_PLL_CTRL21                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,21)
#define CCM_PLL_CTRL21_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,21)
#define CCM_PLL_CTRL21_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,21)
#define CCM_PLL_CTRL21_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,21)
#define CCM_PLL_CTRL22                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,22)
#define CCM_PLL_CTRL22_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,22)
#define CCM_PLL_CTRL22_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,22)
#define CCM_PLL_CTRL22_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,22)
#define CCM_PLL_CTRL23                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,23)
#define CCM_PLL_CTRL23_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,23)
#define CCM_PLL_CTRL23_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,23)
#define CCM_PLL_CTRL23_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,23)
#define CCM_PLL_CTRL24                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,24)
#define CCM_PLL_CTRL24_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,24)
#define CCM_PLL_CTRL24_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,24)
#define CCM_PLL_CTRL24_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,24)
#define CCM_PLL_CTRL25                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,25)
#define CCM_PLL_CTRL25_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,25)
#define CCM_PLL_CTRL25_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,25)
#define CCM_PLL_CTRL25_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,25)
#define CCM_PLL_CTRL26                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,26)
#define CCM_PLL_CTRL26_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,26)
#define CCM_PLL_CTRL26_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,26)
#define CCM_PLL_CTRL26_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,26)
#define CCM_PLL_CTRL27                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,27)
#define CCM_PLL_CTRL27_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,27)
#define CCM_PLL_CTRL27_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,27)
#define CCM_PLL_CTRL27_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,27)
#define CCM_PLL_CTRL28                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,28)
#define CCM_PLL_CTRL28_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,28)
#define CCM_PLL_CTRL28_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,28)
#define CCM_PLL_CTRL28_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,28)
#define CCM_PLL_CTRL29                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,29)
#define CCM_PLL_CTRL29_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,29)
#define CCM_PLL_CTRL29_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,29)
#define CCM_PLL_CTRL29_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,29)
#define CCM_PLL_CTRL30                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,30)
#define CCM_PLL_CTRL30_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,30)
#define CCM_PLL_CTRL30_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,30)
#define CCM_PLL_CTRL30_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,30)
#define CCM_PLL_CTRL31                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,31)
#define CCM_PLL_CTRL31_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,31)
#define CCM_PLL_CTRL31_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,31)
#define CCM_PLL_CTRL31_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,31)
#define CCM_PLL_CTRL32                           CCM_PLL_CTRL_REG(CCM_BASE_PTR,32)
#define CCM_PLL_CTRL32_SET                       CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,32)
#define CCM_PLL_CTRL32_CLR                       CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,32)
#define CCM_PLL_CTRL32_TOG                       CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,32)
#define CCM_CCGR0                                CCM_CCGR_REG(CCM_BASE_PTR,0)
#define CCM_CCGR0_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,0)
#define CCM_CCGR0_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,0)
#define CCM_CCGR0_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,0)
#define CCM_CCGR1                                CCM_CCGR_REG(CCM_BASE_PTR,1)
#define CCM_CCGR1_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,1)
#define CCM_CCGR1_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,1)
#define CCM_CCGR1_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,1)
#define CCM_CCGR2                                CCM_CCGR_REG(CCM_BASE_PTR,2)
#define CCM_CCGR2_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,2)
#define CCM_CCGR2_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,2)
#define CCM_CCGR2_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,2)
#define CCM_CCGR3                                CCM_CCGR_REG(CCM_BASE_PTR,3)
#define CCM_CCGR3_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,3)
#define CCM_CCGR3_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,3)
#define CCM_CCGR3_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,3)
#define CCM_CCGR4                                CCM_CCGR_REG(CCM_BASE_PTR,4)
#define CCM_CCGR4_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,4)
#define CCM_CCGR4_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,4)
#define CCM_CCGR4_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,4)
#define CCM_CCGR5                                CCM_CCGR_REG(CCM_BASE_PTR,5)
#define CCM_CCGR5_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,5)
#define CCM_CCGR5_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,5)
#define CCM_CCGR5_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,5)
#define CCM_CCGR6                                CCM_CCGR_REG(CCM_BASE_PTR,6)
#define CCM_CCGR6_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,6)
#define CCM_CCGR6_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,6)
#define CCM_CCGR6_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,6)
#define CCM_CCGR7                                CCM_CCGR_REG(CCM_BASE_PTR,7)
#define CCM_CCGR7_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,7)
#define CCM_CCGR7_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,7)
#define CCM_CCGR7_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,7)
#define CCM_CCGR8                                CCM_CCGR_REG(CCM_BASE_PTR,8)
#define CCM_CCGR8_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,8)
#define CCM_CCGR8_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,8)
#define CCM_CCGR8_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,8)
#define CCM_CCGR9                                CCM_CCGR_REG(CCM_BASE_PTR,9)
#define CCM_CCGR9_SET                            CCM_CCGR_SET_REG(CCM_BASE_PTR,9)
#define CCM_CCGR9_CLR                            CCM_CCGR_CLR_REG(CCM_BASE_PTR,9)
#define CCM_CCGR9_TOG                            CCM_CCGR_TOG_REG(CCM_BASE_PTR,9)
#define CCM_CCGR10                               CCM_CCGR_REG(CCM_BASE_PTR,10)
#define CCM_CCGR10_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,10)
#define CCM_CCGR10_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,10)
#define CCM_CCGR10_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,10)
#define CCM_CCGR11                               CCM_CCGR_REG(CCM_BASE_PTR,11)
#define CCM_CCGR11_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,11)
#define CCM_CCGR11_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,11)
#define CCM_CCGR11_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,11)
#define CCM_CCGR12                               CCM_CCGR_REG(CCM_BASE_PTR,12)
#define CCM_CCGR12_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,12)
#define CCM_CCGR12_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,12)
#define CCM_CCGR12_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,12)
#define CCM_CCGR13                               CCM_CCGR_REG(CCM_BASE_PTR,13)
#define CCM_CCGR13_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,13)
#define CCM_CCGR13_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,13)
#define CCM_CCGR13_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,13)
#define CCM_CCGR14                               CCM_CCGR_REG(CCM_BASE_PTR,14)
#define CCM_CCGR14_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,14)
#define CCM_CCGR14_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,14)
#define CCM_CCGR14_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,14)
#define CCM_CCGR15                               CCM_CCGR_REG(CCM_BASE_PTR,15)
#define CCM_CCGR15_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,15)
#define CCM_CCGR15_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,15)
#define CCM_CCGR15_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,15)
#define CCM_CCGR16                               CCM_CCGR_REG(CCM_BASE_PTR,16)
#define CCM_CCGR16_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,16)
#define CCM_CCGR16_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,16)
#define CCM_CCGR16_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,16)
#define CCM_CCGR17                               CCM_CCGR_REG(CCM_BASE_PTR,17)
#define CCM_CCGR17_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,17)
#define CCM_CCGR17_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,17)
#define CCM_CCGR17_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,17)
#define CCM_CCGR18                               CCM_CCGR_REG(CCM_BASE_PTR,18)
#define CCM_CCGR18_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,18)
#define CCM_CCGR18_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,18)
#define CCM_CCGR18_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,18)
#define CCM_CCGR19                               CCM_CCGR_REG(CCM_BASE_PTR,19)
#define CCM_CCGR19_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,19)
#define CCM_CCGR19_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,19)
#define CCM_CCGR19_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,19)
#define CCM_CCGR20                               CCM_CCGR_REG(CCM_BASE_PTR,20)
#define CCM_CCGR20_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,20)
#define CCM_CCGR20_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,20)
#define CCM_CCGR20_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,20)
#define CCM_CCGR21                               CCM_CCGR_REG(CCM_BASE_PTR,21)
#define CCM_CCGR21_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,21)
#define CCM_CCGR21_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,21)
#define CCM_CCGR21_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,21)
#define CCM_CCGR22                               CCM_CCGR_REG(CCM_BASE_PTR,22)
#define CCM_CCGR22_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,22)
#define CCM_CCGR22_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,22)
#define CCM_CCGR22_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,22)
#define CCM_CCGR23                               CCM_CCGR_REG(CCM_BASE_PTR,23)
#define CCM_CCGR23_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,23)
#define CCM_CCGR23_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,23)
#define CCM_CCGR23_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,23)
#define CCM_CCGR24                               CCM_CCGR_REG(CCM_BASE_PTR,24)
#define CCM_CCGR24_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,24)
#define CCM_CCGR24_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,24)
#define CCM_CCGR24_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,24)
#define CCM_CCGR25                               CCM_CCGR_REG(CCM_BASE_PTR,25)
#define CCM_CCGR25_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,25)
#define CCM_CCGR25_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,25)
#define CCM_CCGR25_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,25)
#define CCM_CCGR26                               CCM_CCGR_REG(CCM_BASE_PTR,26)
#define CCM_CCGR26_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,26)
#define CCM_CCGR26_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,26)
#define CCM_CCGR26_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,26)
#define CCM_CCGR27                               CCM_CCGR_REG(CCM_BASE_PTR,27)
#define CCM_CCGR27_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,27)
#define CCM_CCGR27_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,27)
#define CCM_CCGR27_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,27)
#define CCM_CCGR28                               CCM_CCGR_REG(CCM_BASE_PTR,28)
#define CCM_CCGR28_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,28)
#define CCM_CCGR28_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,28)
#define CCM_CCGR28_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,28)
#define CCM_CCGR29                               CCM_CCGR_REG(CCM_BASE_PTR,29)
#define CCM_CCGR29_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,29)
#define CCM_CCGR29_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,29)
#define CCM_CCGR29_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,29)
#define CCM_CCGR30                               CCM_CCGR_REG(CCM_BASE_PTR,30)
#define CCM_CCGR30_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,30)
#define CCM_CCGR30_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,30)
#define CCM_CCGR30_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,30)
#define CCM_CCGR31                               CCM_CCGR_REG(CCM_BASE_PTR,31)
#define CCM_CCGR31_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,31)
#define CCM_CCGR31_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,31)
#define CCM_CCGR31_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,31)
#define CCM_CCGR32                               CCM_CCGR_REG(CCM_BASE_PTR,32)
#define CCM_CCGR32_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,32)
#define CCM_CCGR32_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,32)
#define CCM_CCGR32_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,32)
#define CCM_CCGR33                               CCM_CCGR_REG(CCM_BASE_PTR,33)
#define CCM_CCGR33_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,33)
#define CCM_CCGR33_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,33)
#define CCM_CCGR33_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,33)
#define CCM_CCGR34                               CCM_CCGR_REG(CCM_BASE_PTR,34)
#define CCM_CCGR34_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,34)
#define CCM_CCGR34_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,34)
#define CCM_CCGR34_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,34)
#define CCM_CCGR35                               CCM_CCGR_REG(CCM_BASE_PTR,35)
#define CCM_CCGR35_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,35)
#define CCM_CCGR35_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,35)
#define CCM_CCGR35_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,35)
#define CCM_CCGR36                               CCM_CCGR_REG(CCM_BASE_PTR,36)
#define CCM_CCGR36_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,36)
#define CCM_CCGR36_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,36)
#define CCM_CCGR36_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,36)
#define CCM_CCGR37                               CCM_CCGR_REG(CCM_BASE_PTR,37)
#define CCM_CCGR37_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,37)
#define CCM_CCGR37_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,37)
#define CCM_CCGR37_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,37)
#define CCM_CCGR38                               CCM_CCGR_REG(CCM_BASE_PTR,38)
#define CCM_CCGR38_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,38)
#define CCM_CCGR38_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,38)
#define CCM_CCGR38_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,38)
#define CCM_CCGR39                               CCM_CCGR_REG(CCM_BASE_PTR,39)
#define CCM_CCGR39_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,39)
#define CCM_CCGR39_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,39)
#define CCM_CCGR39_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,39)
#define CCM_CCGR40                               CCM_CCGR_REG(CCM_BASE_PTR,40)
#define CCM_CCGR40_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,40)
#define CCM_CCGR40_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,40)
#define CCM_CCGR40_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,40)
#define CCM_CCGR41                               CCM_CCGR_REG(CCM_BASE_PTR,41)
#define CCM_CCGR41_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,41)
#define CCM_CCGR41_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,41)
#define CCM_CCGR41_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,41)
#define CCM_CCGR42                               CCM_CCGR_REG(CCM_BASE_PTR,42)
#define CCM_CCGR42_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,42)
#define CCM_CCGR42_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,42)
#define CCM_CCGR42_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,42)
#define CCM_CCGR43                               CCM_CCGR_REG(CCM_BASE_PTR,43)
#define CCM_CCGR43_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,43)
#define CCM_CCGR43_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,43)
#define CCM_CCGR43_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,43)
#define CCM_CCGR44                               CCM_CCGR_REG(CCM_BASE_PTR,44)
#define CCM_CCGR44_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,44)
#define CCM_CCGR44_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,44)
#define CCM_CCGR44_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,44)
#define CCM_CCGR45                               CCM_CCGR_REG(CCM_BASE_PTR,45)
#define CCM_CCGR45_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,45)
#define CCM_CCGR45_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,45)
#define CCM_CCGR45_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,45)
#define CCM_CCGR46                               CCM_CCGR_REG(CCM_BASE_PTR,46)
#define CCM_CCGR46_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,46)
#define CCM_CCGR46_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,46)
#define CCM_CCGR46_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,46)
#define CCM_CCGR47                               CCM_CCGR_REG(CCM_BASE_PTR,47)
#define CCM_CCGR47_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,47)
#define CCM_CCGR47_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,47)
#define CCM_CCGR47_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,47)
#define CCM_CCGR48                               CCM_CCGR_REG(CCM_BASE_PTR,48)
#define CCM_CCGR48_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,48)
#define CCM_CCGR48_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,48)
#define CCM_CCGR48_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,48)
#define CCM_CCGR49                               CCM_CCGR_REG(CCM_BASE_PTR,49)
#define CCM_CCGR49_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,49)
#define CCM_CCGR49_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,49)
#define CCM_CCGR49_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,49)
#define CCM_CCGR50                               CCM_CCGR_REG(CCM_BASE_PTR,50)
#define CCM_CCGR50_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,50)
#define CCM_CCGR50_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,50)
#define CCM_CCGR50_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,50)
#define CCM_CCGR51                               CCM_CCGR_REG(CCM_BASE_PTR,51)
#define CCM_CCGR51_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,51)
#define CCM_CCGR51_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,51)
#define CCM_CCGR51_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,51)
#define CCM_CCGR52                               CCM_CCGR_REG(CCM_BASE_PTR,52)
#define CCM_CCGR52_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,52)
#define CCM_CCGR52_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,52)
#define CCM_CCGR52_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,52)
#define CCM_CCGR53                               CCM_CCGR_REG(CCM_BASE_PTR,53)
#define CCM_CCGR53_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,53)
#define CCM_CCGR53_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,53)
#define CCM_CCGR53_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,53)
#define CCM_CCGR54                               CCM_CCGR_REG(CCM_BASE_PTR,54)
#define CCM_CCGR54_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,54)
#define CCM_CCGR54_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,54)
#define CCM_CCGR54_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,54)
#define CCM_CCGR55                               CCM_CCGR_REG(CCM_BASE_PTR,55)
#define CCM_CCGR55_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,55)
#define CCM_CCGR55_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,55)
#define CCM_CCGR55_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,55)
#define CCM_CCGR56                               CCM_CCGR_REG(CCM_BASE_PTR,56)
#define CCM_CCGR56_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,56)
#define CCM_CCGR56_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,56)
#define CCM_CCGR56_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,56)
#define CCM_CCGR57                               CCM_CCGR_REG(CCM_BASE_PTR,57)
#define CCM_CCGR57_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,57)
#define CCM_CCGR57_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,57)
#define CCM_CCGR57_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,57)
#define CCM_CCGR58                               CCM_CCGR_REG(CCM_BASE_PTR,58)
#define CCM_CCGR58_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,58)
#define CCM_CCGR58_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,58)
#define CCM_CCGR58_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,58)
#define CCM_CCGR59                               CCM_CCGR_REG(CCM_BASE_PTR,59)
#define CCM_CCGR59_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,59)
#define CCM_CCGR59_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,59)
#define CCM_CCGR59_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,59)
#define CCM_CCGR60                               CCM_CCGR_REG(CCM_BASE_PTR,60)
#define CCM_CCGR60_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,60)
#define CCM_CCGR60_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,60)
#define CCM_CCGR60_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,60)
#define CCM_CCGR61                               CCM_CCGR_REG(CCM_BASE_PTR,61)
#define CCM_CCGR61_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,61)
#define CCM_CCGR61_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,61)
#define CCM_CCGR61_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,61)
#define CCM_CCGR62                               CCM_CCGR_REG(CCM_BASE_PTR,62)
#define CCM_CCGR62_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,62)
#define CCM_CCGR62_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,62)
#define CCM_CCGR62_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,62)
#define CCM_CCGR63                               CCM_CCGR_REG(CCM_BASE_PTR,63)
#define CCM_CCGR63_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,63)
#define CCM_CCGR63_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,63)
#define CCM_CCGR63_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,63)
#define CCM_CCGR64                               CCM_CCGR_REG(CCM_BASE_PTR,64)
#define CCM_CCGR64_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,64)
#define CCM_CCGR64_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,64)
#define CCM_CCGR64_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,64)
#define CCM_CCGR65                               CCM_CCGR_REG(CCM_BASE_PTR,65)
#define CCM_CCGR65_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,65)
#define CCM_CCGR65_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,65)
#define CCM_CCGR65_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,65)
#define CCM_CCGR66                               CCM_CCGR_REG(CCM_BASE_PTR,66)
#define CCM_CCGR66_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,66)
#define CCM_CCGR66_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,66)
#define CCM_CCGR66_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,66)
#define CCM_CCGR67                               CCM_CCGR_REG(CCM_BASE_PTR,67)
#define CCM_CCGR67_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,67)
#define CCM_CCGR67_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,67)
#define CCM_CCGR67_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,67)
#define CCM_CCGR68                               CCM_CCGR_REG(CCM_BASE_PTR,68)
#define CCM_CCGR68_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,68)
#define CCM_CCGR68_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,68)
#define CCM_CCGR68_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,68)
#define CCM_CCGR69                               CCM_CCGR_REG(CCM_BASE_PTR,69)
#define CCM_CCGR69_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,69)
#define CCM_CCGR69_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,69)
#define CCM_CCGR69_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,69)
#define CCM_CCGR70                               CCM_CCGR_REG(CCM_BASE_PTR,70)
#define CCM_CCGR70_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,70)
#define CCM_CCGR70_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,70)
#define CCM_CCGR70_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,70)
#define CCM_CCGR71                               CCM_CCGR_REG(CCM_BASE_PTR,71)
#define CCM_CCGR71_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,71)
#define CCM_CCGR71_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,71)
#define CCM_CCGR71_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,71)
#define CCM_CCGR72                               CCM_CCGR_REG(CCM_BASE_PTR,72)
#define CCM_CCGR72_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,72)
#define CCM_CCGR72_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,72)
#define CCM_CCGR72_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,72)
#define CCM_CCGR73                               CCM_CCGR_REG(CCM_BASE_PTR,73)
#define CCM_CCGR73_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,73)
#define CCM_CCGR73_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,73)
#define CCM_CCGR73_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,73)
#define CCM_CCGR74                               CCM_CCGR_REG(CCM_BASE_PTR,74)
#define CCM_CCGR74_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,74)
#define CCM_CCGR74_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,74)
#define CCM_CCGR74_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,74)
#define CCM_CCGR75                               CCM_CCGR_REG(CCM_BASE_PTR,75)
#define CCM_CCGR75_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,75)
#define CCM_CCGR75_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,75)
#define CCM_CCGR75_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,75)
#define CCM_CCGR76                               CCM_CCGR_REG(CCM_BASE_PTR,76)
#define CCM_CCGR76_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,76)
#define CCM_CCGR76_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,76)
#define CCM_CCGR76_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,76)
#define CCM_CCGR77                               CCM_CCGR_REG(CCM_BASE_PTR,77)
#define CCM_CCGR77_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,77)
#define CCM_CCGR77_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,77)
#define CCM_CCGR77_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,77)
#define CCM_CCGR78                               CCM_CCGR_REG(CCM_BASE_PTR,78)
#define CCM_CCGR78_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,78)
#define CCM_CCGR78_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,78)
#define CCM_CCGR78_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,78)
#define CCM_CCGR79                               CCM_CCGR_REG(CCM_BASE_PTR,79)
#define CCM_CCGR79_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,79)
#define CCM_CCGR79_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,79)
#define CCM_CCGR79_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,79)
#define CCM_CCGR80                               CCM_CCGR_REG(CCM_BASE_PTR,80)
#define CCM_CCGR80_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,80)
#define CCM_CCGR80_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,80)
#define CCM_CCGR80_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,80)
#define CCM_CCGR81                               CCM_CCGR_REG(CCM_BASE_PTR,81)
#define CCM_CCGR81_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,81)
#define CCM_CCGR81_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,81)
#define CCM_CCGR81_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,81)
#define CCM_CCGR82                               CCM_CCGR_REG(CCM_BASE_PTR,82)
#define CCM_CCGR82_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,82)
#define CCM_CCGR82_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,82)
#define CCM_CCGR82_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,82)
#define CCM_CCGR83                               CCM_CCGR_REG(CCM_BASE_PTR,83)
#define CCM_CCGR83_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,83)
#define CCM_CCGR83_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,83)
#define CCM_CCGR83_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,83)
#define CCM_CCGR84                               CCM_CCGR_REG(CCM_BASE_PTR,84)
#define CCM_CCGR84_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,84)
#define CCM_CCGR84_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,84)
#define CCM_CCGR84_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,84)
#define CCM_CCGR85                               CCM_CCGR_REG(CCM_BASE_PTR,85)
#define CCM_CCGR85_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,85)
#define CCM_CCGR85_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,85)
#define CCM_CCGR85_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,85)
#define CCM_CCGR86                               CCM_CCGR_REG(CCM_BASE_PTR,86)
#define CCM_CCGR86_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,86)
#define CCM_CCGR86_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,86)
#define CCM_CCGR86_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,86)
#define CCM_CCGR87                               CCM_CCGR_REG(CCM_BASE_PTR,87)
#define CCM_CCGR87_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,87)
#define CCM_CCGR87_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,87)
#define CCM_CCGR87_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,87)
#define CCM_CCGR88                               CCM_CCGR_REG(CCM_BASE_PTR,88)
#define CCM_CCGR88_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,88)
#define CCM_CCGR88_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,88)
#define CCM_CCGR88_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,88)
#define CCM_CCGR89                               CCM_CCGR_REG(CCM_BASE_PTR,89)
#define CCM_CCGR89_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,89)
#define CCM_CCGR89_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,89)
#define CCM_CCGR89_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,89)
#define CCM_CCGR90                               CCM_CCGR_REG(CCM_BASE_PTR,90)
#define CCM_CCGR90_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,90)
#define CCM_CCGR90_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,90)
#define CCM_CCGR90_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,90)
#define CCM_CCGR91                               CCM_CCGR_REG(CCM_BASE_PTR,91)
#define CCM_CCGR91_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,91)
#define CCM_CCGR91_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,91)
#define CCM_CCGR91_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,91)
#define CCM_CCGR92                               CCM_CCGR_REG(CCM_BASE_PTR,92)
#define CCM_CCGR92_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,92)
#define CCM_CCGR92_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,92)
#define CCM_CCGR92_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,92)
#define CCM_CCGR93                               CCM_CCGR_REG(CCM_BASE_PTR,93)
#define CCM_CCGR93_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,93)
#define CCM_CCGR93_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,93)
#define CCM_CCGR93_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,93)
#define CCM_CCGR94                               CCM_CCGR_REG(CCM_BASE_PTR,94)
#define CCM_CCGR94_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,94)
#define CCM_CCGR94_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,94)
#define CCM_CCGR94_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,94)
#define CCM_CCGR95                               CCM_CCGR_REG(CCM_BASE_PTR,95)
#define CCM_CCGR95_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,95)
#define CCM_CCGR95_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,95)
#define CCM_CCGR95_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,95)
#define CCM_CCGR96                               CCM_CCGR_REG(CCM_BASE_PTR,96)
#define CCM_CCGR96_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,96)
#define CCM_CCGR96_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,96)
#define CCM_CCGR96_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,96)
#define CCM_CCGR97                               CCM_CCGR_REG(CCM_BASE_PTR,97)
#define CCM_CCGR97_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,97)
#define CCM_CCGR97_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,97)
#define CCM_CCGR97_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,97)
#define CCM_CCGR98                               CCM_CCGR_REG(CCM_BASE_PTR,98)
#define CCM_CCGR98_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,98)
#define CCM_CCGR98_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,98)
#define CCM_CCGR98_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,98)
#define CCM_CCGR99                               CCM_CCGR_REG(CCM_BASE_PTR,99)
#define CCM_CCGR99_SET                           CCM_CCGR_SET_REG(CCM_BASE_PTR,99)
#define CCM_CCGR99_CLR                           CCM_CCGR_CLR_REG(CCM_BASE_PTR,99)
#define CCM_CCGR99_TOG                           CCM_CCGR_TOG_REG(CCM_BASE_PTR,99)
#define CCM_CCGR100                              CCM_CCGR_REG(CCM_BASE_PTR,100)
#define CCM_CCGR100_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,100)
#define CCM_CCGR100_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,100)
#define CCM_CCGR100_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,100)
#define CCM_CCGR101                              CCM_CCGR_REG(CCM_BASE_PTR,101)
#define CCM_CCGR101_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,101)
#define CCM_CCGR101_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,101)
#define CCM_CCGR101_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,101)
#define CCM_CCGR102                              CCM_CCGR_REG(CCM_BASE_PTR,102)
#define CCM_CCGR102_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,102)
#define CCM_CCGR102_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,102)
#define CCM_CCGR102_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,102)
#define CCM_CCGR103                              CCM_CCGR_REG(CCM_BASE_PTR,103)
#define CCM_CCGR103_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,103)
#define CCM_CCGR103_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,103)
#define CCM_CCGR103_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,103)
#define CCM_CCGR104                              CCM_CCGR_REG(CCM_BASE_PTR,104)
#define CCM_CCGR104_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,104)
#define CCM_CCGR104_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,104)
#define CCM_CCGR104_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,104)
#define CCM_CCGR105                              CCM_CCGR_REG(CCM_BASE_PTR,105)
#define CCM_CCGR105_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,105)
#define CCM_CCGR105_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,105)
#define CCM_CCGR105_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,105)
#define CCM_CCGR106                              CCM_CCGR_REG(CCM_BASE_PTR,106)
#define CCM_CCGR106_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,106)
#define CCM_CCGR106_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,106)
#define CCM_CCGR106_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,106)
#define CCM_CCGR107                              CCM_CCGR_REG(CCM_BASE_PTR,107)
#define CCM_CCGR107_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,107)
#define CCM_CCGR107_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,107)
#define CCM_CCGR107_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,107)
#define CCM_CCGR108                              CCM_CCGR_REG(CCM_BASE_PTR,108)
#define CCM_CCGR108_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,108)
#define CCM_CCGR108_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,108)
#define CCM_CCGR108_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,108)
#define CCM_CCGR109                              CCM_CCGR_REG(CCM_BASE_PTR,109)
#define CCM_CCGR109_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,109)
#define CCM_CCGR109_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,109)
#define CCM_CCGR109_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,109)
#define CCM_CCGR110                              CCM_CCGR_REG(CCM_BASE_PTR,110)
#define CCM_CCGR110_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,110)
#define CCM_CCGR110_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,110)
#define CCM_CCGR110_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,110)
#define CCM_CCGR111                              CCM_CCGR_REG(CCM_BASE_PTR,111)
#define CCM_CCGR111_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,111)
#define CCM_CCGR111_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,111)
#define CCM_CCGR111_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,111)
#define CCM_CCGR112                              CCM_CCGR_REG(CCM_BASE_PTR,112)
#define CCM_CCGR112_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,112)
#define CCM_CCGR112_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,112)
#define CCM_CCGR112_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,112)
#define CCM_CCGR113                              CCM_CCGR_REG(CCM_BASE_PTR,113)
#define CCM_CCGR113_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,113)
#define CCM_CCGR113_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,113)
#define CCM_CCGR113_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,113)
#define CCM_CCGR114                              CCM_CCGR_REG(CCM_BASE_PTR,114)
#define CCM_CCGR114_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,114)
#define CCM_CCGR114_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,114)
#define CCM_CCGR114_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,114)
#define CCM_CCGR115                              CCM_CCGR_REG(CCM_BASE_PTR,115)
#define CCM_CCGR115_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,115)
#define CCM_CCGR115_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,115)
#define CCM_CCGR115_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,115)
#define CCM_CCGR116                              CCM_CCGR_REG(CCM_BASE_PTR,116)
#define CCM_CCGR116_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,116)
#define CCM_CCGR116_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,116)
#define CCM_CCGR116_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,116)
#define CCM_CCGR117                              CCM_CCGR_REG(CCM_BASE_PTR,117)
#define CCM_CCGR117_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,117)
#define CCM_CCGR117_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,117)
#define CCM_CCGR117_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,117)
#define CCM_CCGR118                              CCM_CCGR_REG(CCM_BASE_PTR,118)
#define CCM_CCGR118_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,118)
#define CCM_CCGR118_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,118)
#define CCM_CCGR118_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,118)
#define CCM_CCGR119                              CCM_CCGR_REG(CCM_BASE_PTR,119)
#define CCM_CCGR119_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,119)
#define CCM_CCGR119_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,119)
#define CCM_CCGR119_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,119)
#define CCM_CCGR120                              CCM_CCGR_REG(CCM_BASE_PTR,120)
#define CCM_CCGR120_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,120)
#define CCM_CCGR120_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,120)
#define CCM_CCGR120_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,120)
#define CCM_CCGR121                              CCM_CCGR_REG(CCM_BASE_PTR,121)
#define CCM_CCGR121_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,121)
#define CCM_CCGR121_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,121)
#define CCM_CCGR121_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,121)
#define CCM_CCGR122                              CCM_CCGR_REG(CCM_BASE_PTR,122)
#define CCM_CCGR122_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,122)
#define CCM_CCGR122_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,122)
#define CCM_CCGR122_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,122)
#define CCM_CCGR123                              CCM_CCGR_REG(CCM_BASE_PTR,123)
#define CCM_CCGR123_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,123)
#define CCM_CCGR123_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,123)
#define CCM_CCGR123_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,123)
#define CCM_CCGR124                              CCM_CCGR_REG(CCM_BASE_PTR,124)
#define CCM_CCGR124_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,124)
#define CCM_CCGR124_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,124)
#define CCM_CCGR124_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,124)
#define CCM_CCGR125                              CCM_CCGR_REG(CCM_BASE_PTR,125)
#define CCM_CCGR125_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,125)
#define CCM_CCGR125_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,125)
#define CCM_CCGR125_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,125)
#define CCM_CCGR126                              CCM_CCGR_REG(CCM_BASE_PTR,126)
#define CCM_CCGR126_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,126)
#define CCM_CCGR126_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,126)
#define CCM_CCGR126_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,126)
#define CCM_CCGR127                              CCM_CCGR_REG(CCM_BASE_PTR,127)
#define CCM_CCGR127_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,127)
#define CCM_CCGR127_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,127)
#define CCM_CCGR127_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,127)
#define CCM_CCGR128                              CCM_CCGR_REG(CCM_BASE_PTR,128)
#define CCM_CCGR128_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,128)
#define CCM_CCGR128_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,128)
#define CCM_CCGR128_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,128)
#define CCM_CCGR129                              CCM_CCGR_REG(CCM_BASE_PTR,129)
#define CCM_CCGR129_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,129)
#define CCM_CCGR129_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,129)
#define CCM_CCGR129_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,129)
#define CCM_CCGR130                              CCM_CCGR_REG(CCM_BASE_PTR,130)
#define CCM_CCGR130_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,130)
#define CCM_CCGR130_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,130)
#define CCM_CCGR130_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,130)
#define CCM_CCGR131                              CCM_CCGR_REG(CCM_BASE_PTR,131)
#define CCM_CCGR131_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,131)
#define CCM_CCGR131_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,131)
#define CCM_CCGR131_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,131)
#define CCM_CCGR132                              CCM_CCGR_REG(CCM_BASE_PTR,132)
#define CCM_CCGR132_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,132)
#define CCM_CCGR132_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,132)
#define CCM_CCGR132_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,132)
#define CCM_CCGR133                              CCM_CCGR_REG(CCM_BASE_PTR,133)
#define CCM_CCGR133_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,133)
#define CCM_CCGR133_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,133)
#define CCM_CCGR133_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,133)
#define CCM_CCGR134                              CCM_CCGR_REG(CCM_BASE_PTR,134)
#define CCM_CCGR134_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,134)
#define CCM_CCGR134_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,134)
#define CCM_CCGR134_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,134)
#define CCM_CCGR135                              CCM_CCGR_REG(CCM_BASE_PTR,135)
#define CCM_CCGR135_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,135)
#define CCM_CCGR135_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,135)
#define CCM_CCGR135_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,135)
#define CCM_CCGR136                              CCM_CCGR_REG(CCM_BASE_PTR,136)
#define CCM_CCGR136_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,136)
#define CCM_CCGR136_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,136)
#define CCM_CCGR136_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,136)
#define CCM_CCGR137                              CCM_CCGR_REG(CCM_BASE_PTR,137)
#define CCM_CCGR137_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,137)
#define CCM_CCGR137_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,137)
#define CCM_CCGR137_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,137)
#define CCM_CCGR138                              CCM_CCGR_REG(CCM_BASE_PTR,138)
#define CCM_CCGR138_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,138)
#define CCM_CCGR138_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,138)
#define CCM_CCGR138_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,138)
#define CCM_CCGR139                              CCM_CCGR_REG(CCM_BASE_PTR,139)
#define CCM_CCGR139_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,139)
#define CCM_CCGR139_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,139)
#define CCM_CCGR139_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,139)
#define CCM_CCGR140                              CCM_CCGR_REG(CCM_BASE_PTR,140)
#define CCM_CCGR140_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,140)
#define CCM_CCGR140_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,140)
#define CCM_CCGR140_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,140)
#define CCM_CCGR141                              CCM_CCGR_REG(CCM_BASE_PTR,141)
#define CCM_CCGR141_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,141)
#define CCM_CCGR141_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,141)
#define CCM_CCGR141_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,141)
#define CCM_CCGR142                              CCM_CCGR_REG(CCM_BASE_PTR,142)
#define CCM_CCGR142_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,142)
#define CCM_CCGR142_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,142)
#define CCM_CCGR142_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,142)
#define CCM_CCGR143                              CCM_CCGR_REG(CCM_BASE_PTR,143)
#define CCM_CCGR143_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,143)
#define CCM_CCGR143_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,143)
#define CCM_CCGR143_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,143)
#define CCM_CCGR144                              CCM_CCGR_REG(CCM_BASE_PTR,144)
#define CCM_CCGR144_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,144)
#define CCM_CCGR144_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,144)
#define CCM_CCGR144_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,144)
#define CCM_CCGR145                              CCM_CCGR_REG(CCM_BASE_PTR,145)
#define CCM_CCGR145_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,145)
#define CCM_CCGR145_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,145)
#define CCM_CCGR145_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,145)
#define CCM_CCGR146                              CCM_CCGR_REG(CCM_BASE_PTR,146)
#define CCM_CCGR146_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,146)
#define CCM_CCGR146_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,146)
#define CCM_CCGR146_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,146)
#define CCM_CCGR147                              CCM_CCGR_REG(CCM_BASE_PTR,147)
#define CCM_CCGR147_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,147)
#define CCM_CCGR147_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,147)
#define CCM_CCGR147_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,147)
#define CCM_CCGR148                              CCM_CCGR_REG(CCM_BASE_PTR,148)
#define CCM_CCGR148_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,148)
#define CCM_CCGR148_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,148)
#define CCM_CCGR148_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,148)
#define CCM_CCGR149                              CCM_CCGR_REG(CCM_BASE_PTR,149)
#define CCM_CCGR149_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,149)
#define CCM_CCGR149_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,149)
#define CCM_CCGR149_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,149)
#define CCM_CCGR150                              CCM_CCGR_REG(CCM_BASE_PTR,150)
#define CCM_CCGR150_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,150)
#define CCM_CCGR150_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,150)
#define CCM_CCGR150_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,150)
#define CCM_CCGR151                              CCM_CCGR_REG(CCM_BASE_PTR,151)
#define CCM_CCGR151_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,151)
#define CCM_CCGR151_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,151)
#define CCM_CCGR151_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,151)
#define CCM_CCGR152                              CCM_CCGR_REG(CCM_BASE_PTR,152)
#define CCM_CCGR152_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,152)
#define CCM_CCGR152_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,152)
#define CCM_CCGR152_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,152)
#define CCM_CCGR153                              CCM_CCGR_REG(CCM_BASE_PTR,153)
#define CCM_CCGR153_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,153)
#define CCM_CCGR153_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,153)
#define CCM_CCGR153_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,153)
#define CCM_CCGR154                              CCM_CCGR_REG(CCM_BASE_PTR,154)
#define CCM_CCGR154_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,154)
#define CCM_CCGR154_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,154)
#define CCM_CCGR154_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,154)
#define CCM_CCGR155                              CCM_CCGR_REG(CCM_BASE_PTR,155)
#define CCM_CCGR155_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,155)
#define CCM_CCGR155_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,155)
#define CCM_CCGR155_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,155)
#define CCM_CCGR156                              CCM_CCGR_REG(CCM_BASE_PTR,156)
#define CCM_CCGR156_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,156)
#define CCM_CCGR156_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,156)
#define CCM_CCGR156_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,156)
#define CCM_CCGR157                              CCM_CCGR_REG(CCM_BASE_PTR,157)
#define CCM_CCGR157_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,157)
#define CCM_CCGR157_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,157)
#define CCM_CCGR157_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,157)
#define CCM_CCGR158                              CCM_CCGR_REG(CCM_BASE_PTR,158)
#define CCM_CCGR158_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,158)
#define CCM_CCGR158_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,158)
#define CCM_CCGR158_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,158)
#define CCM_CCGR159                              CCM_CCGR_REG(CCM_BASE_PTR,159)
#define CCM_CCGR159_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,159)
#define CCM_CCGR159_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,159)
#define CCM_CCGR159_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,159)
#define CCM_CCGR160                              CCM_CCGR_REG(CCM_BASE_PTR,160)
#define CCM_CCGR160_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,160)
#define CCM_CCGR160_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,160)
#define CCM_CCGR160_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,160)
#define CCM_CCGR161                              CCM_CCGR_REG(CCM_BASE_PTR,161)
#define CCM_CCGR161_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,161)
#define CCM_CCGR161_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,161)
#define CCM_CCGR161_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,161)
#define CCM_CCGR162                              CCM_CCGR_REG(CCM_BASE_PTR,162)
#define CCM_CCGR162_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,162)
#define CCM_CCGR162_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,162)
#define CCM_CCGR162_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,162)
#define CCM_CCGR163                              CCM_CCGR_REG(CCM_BASE_PTR,163)
#define CCM_CCGR163_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,163)
#define CCM_CCGR163_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,163)
#define CCM_CCGR163_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,163)
#define CCM_CCGR164                              CCM_CCGR_REG(CCM_BASE_PTR,164)
#define CCM_CCGR164_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,164)
#define CCM_CCGR164_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,164)
#define CCM_CCGR164_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,164)
#define CCM_CCGR165                              CCM_CCGR_REG(CCM_BASE_PTR,165)
#define CCM_CCGR165_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,165)
#define CCM_CCGR165_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,165)
#define CCM_CCGR165_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,165)
#define CCM_CCGR166                              CCM_CCGR_REG(CCM_BASE_PTR,166)
#define CCM_CCGR166_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,166)
#define CCM_CCGR166_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,166)
#define CCM_CCGR166_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,166)
#define CCM_CCGR167                              CCM_CCGR_REG(CCM_BASE_PTR,167)
#define CCM_CCGR167_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,167)
#define CCM_CCGR167_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,167)
#define CCM_CCGR167_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,167)
#define CCM_CCGR168                              CCM_CCGR_REG(CCM_BASE_PTR,168)
#define CCM_CCGR168_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,168)
#define CCM_CCGR168_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,168)
#define CCM_CCGR168_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,168)
#define CCM_CCGR169                              CCM_CCGR_REG(CCM_BASE_PTR,169)
#define CCM_CCGR169_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,169)
#define CCM_CCGR169_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,169)
#define CCM_CCGR169_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,169)
#define CCM_CCGR170                              CCM_CCGR_REG(CCM_BASE_PTR,170)
#define CCM_CCGR170_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,170)
#define CCM_CCGR170_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,170)
#define CCM_CCGR170_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,170)
#define CCM_CCGR171                              CCM_CCGR_REG(CCM_BASE_PTR,171)
#define CCM_CCGR171_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,171)
#define CCM_CCGR171_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,171)
#define CCM_CCGR171_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,171)
#define CCM_CCGR172                              CCM_CCGR_REG(CCM_BASE_PTR,172)
#define CCM_CCGR172_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,172)
#define CCM_CCGR172_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,172)
#define CCM_CCGR172_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,172)
#define CCM_CCGR173                              CCM_CCGR_REG(CCM_BASE_PTR,173)
#define CCM_CCGR173_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,173)
#define CCM_CCGR173_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,173)
#define CCM_CCGR173_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,173)
#define CCM_CCGR174                              CCM_CCGR_REG(CCM_BASE_PTR,174)
#define CCM_CCGR174_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,174)
#define CCM_CCGR174_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,174)
#define CCM_CCGR174_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,174)
#define CCM_CCGR175                              CCM_CCGR_REG(CCM_BASE_PTR,175)
#define CCM_CCGR175_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,175)
#define CCM_CCGR175_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,175)
#define CCM_CCGR175_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,175)
#define CCM_CCGR176                              CCM_CCGR_REG(CCM_BASE_PTR,176)
#define CCM_CCGR176_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,176)
#define CCM_CCGR176_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,176)
#define CCM_CCGR176_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,176)
#define CCM_CCGR177                              CCM_CCGR_REG(CCM_BASE_PTR,177)
#define CCM_CCGR177_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,177)
#define CCM_CCGR177_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,177)
#define CCM_CCGR177_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,177)
#define CCM_CCGR178                              CCM_CCGR_REG(CCM_BASE_PTR,178)
#define CCM_CCGR178_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,178)
#define CCM_CCGR178_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,178)
#define CCM_CCGR178_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,178)
#define CCM_CCGR179                              CCM_CCGR_REG(CCM_BASE_PTR,179)
#define CCM_CCGR179_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,179)
#define CCM_CCGR179_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,179)
#define CCM_CCGR179_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,179)
#define CCM_CCGR180                              CCM_CCGR_REG(CCM_BASE_PTR,180)
#define CCM_CCGR180_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,180)
#define CCM_CCGR180_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,180)
#define CCM_CCGR180_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,180)
#define CCM_CCGR181                              CCM_CCGR_REG(CCM_BASE_PTR,181)
#define CCM_CCGR181_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,181)
#define CCM_CCGR181_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,181)
#define CCM_CCGR181_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,181)
#define CCM_CCGR182                              CCM_CCGR_REG(CCM_BASE_PTR,182)
#define CCM_CCGR182_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,182)
#define CCM_CCGR182_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,182)
#define CCM_CCGR182_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,182)
#define CCM_CCGR183                              CCM_CCGR_REG(CCM_BASE_PTR,183)
#define CCM_CCGR183_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,183)
#define CCM_CCGR183_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,183)
#define CCM_CCGR183_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,183)
#define CCM_CCGR184                              CCM_CCGR_REG(CCM_BASE_PTR,184)
#define CCM_CCGR184_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,184)
#define CCM_CCGR184_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,184)
#define CCM_CCGR184_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,184)
#define CCM_CCGR185                              CCM_CCGR_REG(CCM_BASE_PTR,185)
#define CCM_CCGR185_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,185)
#define CCM_CCGR185_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,185)
#define CCM_CCGR185_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,185)
#define CCM_CCGR186                              CCM_CCGR_REG(CCM_BASE_PTR,186)
#define CCM_CCGR186_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,186)
#define CCM_CCGR186_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,186)
#define CCM_CCGR186_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,186)
#define CCM_CCGR187                              CCM_CCGR_REG(CCM_BASE_PTR,187)
#define CCM_CCGR187_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,187)
#define CCM_CCGR187_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,187)
#define CCM_CCGR187_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,187)
#define CCM_CCGR188                              CCM_CCGR_REG(CCM_BASE_PTR,188)
#define CCM_CCGR188_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,188)
#define CCM_CCGR188_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,188)
#define CCM_CCGR188_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,188)
#define CCM_CCGR189                              CCM_CCGR_REG(CCM_BASE_PTR,189)
#define CCM_CCGR189_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,189)
#define CCM_CCGR189_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,189)
#define CCM_CCGR189_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,189)
#define CCM_CCGR190                              CCM_CCGR_REG(CCM_BASE_PTR,190)
#define CCM_CCGR190_SET                          CCM_CCGR_SET_REG(CCM_BASE_PTR,190)
#define CCM_CCGR190_CLR                          CCM_CCGR_CLR_REG(CCM_BASE_PTR,190)
#define CCM_CCGR190_TOG                          CCM_CCGR_TOG_REG(CCM_BASE_PTR,190)
#define CCM_TARGET_ROOT0                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,0)
#define CCM_TARGET_ROOT0_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,0)
#define CCM_TARGET_ROOT0_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,0)
#define CCM_TARGET_ROOT0_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,0)
#define CCM_MISC0                                CCM_MISC_REG(CCM_BASE_PTR,0)
#define CCM_MISC_ROOT0_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,0)
#define CCM_MISC_ROOT0_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,0)
#define CCM_MISC_ROOT0_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,0)
#define CCM_POST0                                CCM_POST_REG(CCM_BASE_PTR,0)
#define CCM_POST_ROOT0_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,0)
#define CCM_POST_ROOT0_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,0)
#define CCM_POST_ROOT0_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,0)
#define CCM_PRE0                                 CCM_PRE_REG(CCM_BASE_PTR,0)
#define CCM_PRE_ROOT0_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,0)
#define CCM_PRE_ROOT0_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,0)
#define CCM_PRE_ROOT0_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,0)
#define CCM_ACCESS_CTRL0                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,0)
#define CCM_ACCESS_CTRL_ROOT0_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,0)
#define CCM_ACCESS_CTRL_ROOT0_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,0)
#define CCM_ACCESS_CTRL_ROOT0_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,0)
#define CCM_TARGET_ROOT1                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,1)
#define CCM_TARGET_ROOT1_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,1)
#define CCM_TARGET_ROOT1_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,1)
#define CCM_TARGET_ROOT1_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,1)
#define CCM_MISC1                                CCM_MISC_REG(CCM_BASE_PTR,1)
#define CCM_MISC_ROOT1_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,1)
#define CCM_MISC_ROOT1_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,1)
#define CCM_MISC_ROOT1_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,1)
#define CCM_POST1                                CCM_POST_REG(CCM_BASE_PTR,1)
#define CCM_POST_ROOT1_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,1)
#define CCM_POST_ROOT1_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,1)
#define CCM_POST_ROOT1_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,1)
#define CCM_PRE1                                 CCM_PRE_REG(CCM_BASE_PTR,1)
#define CCM_PRE_ROOT1_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,1)
#define CCM_PRE_ROOT1_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,1)
#define CCM_PRE_ROOT1_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,1)
#define CCM_ACCESS_CTRL1                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,1)
#define CCM_ACCESS_CTRL_ROOT1_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,1)
#define CCM_ACCESS_CTRL_ROOT1_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,1)
#define CCM_ACCESS_CTRL_ROOT1_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,1)
#define CCM_TARGET_ROOT2                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,2)
#define CCM_TARGET_ROOT2_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,2)
#define CCM_TARGET_ROOT2_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,2)
#define CCM_TARGET_ROOT2_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,2)
#define CCM_MISC2                                CCM_MISC_REG(CCM_BASE_PTR,2)
#define CCM_MISC_ROOT2_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,2)
#define CCM_MISC_ROOT2_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,2)
#define CCM_MISC_ROOT2_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,2)
#define CCM_POST2                                CCM_POST_REG(CCM_BASE_PTR,2)
#define CCM_POST_ROOT2_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,2)
#define CCM_POST_ROOT2_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,2)
#define CCM_POST_ROOT2_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,2)
#define CCM_PRE2                                 CCM_PRE_REG(CCM_BASE_PTR,2)
#define CCM_PRE_ROOT2_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,2)
#define CCM_PRE_ROOT2_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,2)
#define CCM_PRE_ROOT2_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,2)
#define CCM_ACCESS_CTRL2                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,2)
#define CCM_ACCESS_CTRL_ROOT2_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,2)
#define CCM_ACCESS_CTRL_ROOT2_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,2)
#define CCM_ACCESS_CTRL_ROOT2_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,2)
#define CCM_TARGET_ROOT3                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,3)
#define CCM_TARGET_ROOT3_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,3)
#define CCM_TARGET_ROOT3_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,3)
#define CCM_TARGET_ROOT3_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,3)
#define CCM_MISC3                                CCM_MISC_REG(CCM_BASE_PTR,3)
#define CCM_MISC_ROOT3_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,3)
#define CCM_MISC_ROOT3_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,3)
#define CCM_MISC_ROOT3_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,3)
#define CCM_POST3                                CCM_POST_REG(CCM_BASE_PTR,3)
#define CCM_POST_ROOT3_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,3)
#define CCM_POST_ROOT3_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,3)
#define CCM_POST_ROOT3_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,3)
#define CCM_PRE3                                 CCM_PRE_REG(CCM_BASE_PTR,3)
#define CCM_PRE_ROOT3_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,3)
#define CCM_PRE_ROOT3_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,3)
#define CCM_PRE_ROOT3_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,3)
#define CCM_ACCESS_CTRL3                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,3)
#define CCM_ACCESS_CTRL_ROOT3_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,3)
#define CCM_ACCESS_CTRL_ROOT3_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,3)
#define CCM_ACCESS_CTRL_ROOT3_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,3)
#define CCM_TARGET_ROOT4                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,4)
#define CCM_TARGET_ROOT4_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,4)
#define CCM_TARGET_ROOT4_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,4)
#define CCM_TARGET_ROOT4_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,4)
#define CCM_MISC4                                CCM_MISC_REG(CCM_BASE_PTR,4)
#define CCM_MISC_ROOT4_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,4)
#define CCM_MISC_ROOT4_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,4)
#define CCM_MISC_ROOT4_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,4)
#define CCM_POST4                                CCM_POST_REG(CCM_BASE_PTR,4)
#define CCM_POST_ROOT4_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,4)
#define CCM_POST_ROOT4_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,4)
#define CCM_POST_ROOT4_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,4)
#define CCM_PRE4                                 CCM_PRE_REG(CCM_BASE_PTR,4)
#define CCM_PRE_ROOT4_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,4)
#define CCM_PRE_ROOT4_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,4)
#define CCM_PRE_ROOT4_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,4)
#define CCM_ACCESS_CTRL4                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,4)
#define CCM_ACCESS_CTRL_ROOT4_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,4)
#define CCM_ACCESS_CTRL_ROOT4_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,4)
#define CCM_ACCESS_CTRL_ROOT4_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,4)
#define CCM_TARGET_ROOT5                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,5)
#define CCM_TARGET_ROOT5_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,5)
#define CCM_TARGET_ROOT5_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,5)
#define CCM_TARGET_ROOT5_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,5)
#define CCM_MISC5                                CCM_MISC_REG(CCM_BASE_PTR,5)
#define CCM_MISC_ROOT5_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,5)
#define CCM_MISC_ROOT5_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,5)
#define CCM_MISC_ROOT5_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,5)
#define CCM_POST5                                CCM_POST_REG(CCM_BASE_PTR,5)
#define CCM_POST_ROOT5_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,5)
#define CCM_POST_ROOT5_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,5)
#define CCM_POST_ROOT5_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,5)
#define CCM_PRE5                                 CCM_PRE_REG(CCM_BASE_PTR,5)
#define CCM_PRE_ROOT5_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,5)
#define CCM_PRE_ROOT5_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,5)
#define CCM_PRE_ROOT5_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,5)
#define CCM_ACCESS_CTRL5                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,5)
#define CCM_ACCESS_CTRL_ROOT5_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,5)
#define CCM_ACCESS_CTRL_ROOT5_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,5)
#define CCM_ACCESS_CTRL_ROOT5_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,5)
#define CCM_TARGET_ROOT6                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,6)
#define CCM_TARGET_ROOT6_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,6)
#define CCM_TARGET_ROOT6_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,6)
#define CCM_TARGET_ROOT6_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,6)
#define CCM_MISC6                                CCM_MISC_REG(CCM_BASE_PTR,6)
#define CCM_MISC_ROOT6_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,6)
#define CCM_MISC_ROOT6_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,6)
#define CCM_MISC_ROOT6_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,6)
#define CCM_POST6                                CCM_POST_REG(CCM_BASE_PTR,6)
#define CCM_POST_ROOT6_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,6)
#define CCM_POST_ROOT6_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,6)
#define CCM_POST_ROOT6_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,6)
#define CCM_PRE6                                 CCM_PRE_REG(CCM_BASE_PTR,6)
#define CCM_PRE_ROOT6_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,6)
#define CCM_PRE_ROOT6_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,6)
#define CCM_PRE_ROOT6_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,6)
#define CCM_ACCESS_CTRL6                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,6)
#define CCM_ACCESS_CTRL_ROOT6_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,6)
#define CCM_ACCESS_CTRL_ROOT6_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,6)
#define CCM_ACCESS_CTRL_ROOT6_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,6)
#define CCM_TARGET_ROOT7                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,7)
#define CCM_TARGET_ROOT7_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,7)
#define CCM_TARGET_ROOT7_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,7)
#define CCM_TARGET_ROOT7_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,7)
#define CCM_MISC7                                CCM_MISC_REG(CCM_BASE_PTR,7)
#define CCM_MISC_ROOT7_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,7)
#define CCM_MISC_ROOT7_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,7)
#define CCM_MISC_ROOT7_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,7)
#define CCM_POST7                                CCM_POST_REG(CCM_BASE_PTR,7)
#define CCM_POST_ROOT7_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,7)
#define CCM_POST_ROOT7_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,7)
#define CCM_POST_ROOT7_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,7)
#define CCM_PRE7                                 CCM_PRE_REG(CCM_BASE_PTR,7)
#define CCM_PRE_ROOT7_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,7)
#define CCM_PRE_ROOT7_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,7)
#define CCM_PRE_ROOT7_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,7)
#define CCM_ACCESS_CTRL7                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,7)
#define CCM_ACCESS_CTRL_ROOT7_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,7)
#define CCM_ACCESS_CTRL_ROOT7_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,7)
#define CCM_ACCESS_CTRL_ROOT7_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,7)
#define CCM_TARGET_ROOT8                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,8)
#define CCM_TARGET_ROOT8_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,8)
#define CCM_TARGET_ROOT8_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,8)
#define CCM_TARGET_ROOT8_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,8)
#define CCM_MISC8                                CCM_MISC_REG(CCM_BASE_PTR,8)
#define CCM_MISC_ROOT8_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,8)
#define CCM_MISC_ROOT8_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,8)
#define CCM_MISC_ROOT8_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,8)
#define CCM_POST8                                CCM_POST_REG(CCM_BASE_PTR,8)
#define CCM_POST_ROOT8_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,8)
#define CCM_POST_ROOT8_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,8)
#define CCM_POST_ROOT8_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,8)
#define CCM_PRE8                                 CCM_PRE_REG(CCM_BASE_PTR,8)
#define CCM_PRE_ROOT8_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,8)
#define CCM_PRE_ROOT8_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,8)
#define CCM_PRE_ROOT8_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,8)
#define CCM_ACCESS_CTRL8                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,8)
#define CCM_ACCESS_CTRL_ROOT8_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,8)
#define CCM_ACCESS_CTRL_ROOT8_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,8)
#define CCM_ACCESS_CTRL_ROOT8_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,8)
#define CCM_TARGET_ROOT9                         CCM_TARGET_ROOT_REG(CCM_BASE_PTR,9)
#define CCM_TARGET_ROOT9_SET                     CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,9)
#define CCM_TARGET_ROOT9_CLR                     CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,9)
#define CCM_TARGET_ROOT9_TOG                     CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,9)
#define CCM_MISC9                                CCM_MISC_REG(CCM_BASE_PTR,9)
#define CCM_MISC_ROOT9_SET                       CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,9)
#define CCM_MISC_ROOT9_CLR                       CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,9)
#define CCM_MISC_ROOT9_TOG                       CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,9)
#define CCM_POST9                                CCM_POST_REG(CCM_BASE_PTR,9)
#define CCM_POST_ROOT9_SET                       CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,9)
#define CCM_POST_ROOT9_CLR                       CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,9)
#define CCM_POST_ROOT9_TOG                       CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,9)
#define CCM_PRE9                                 CCM_PRE_REG(CCM_BASE_PTR,9)
#define CCM_PRE_ROOT9_SET                        CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,9)
#define CCM_PRE_ROOT9_CLR                        CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,9)
#define CCM_PRE_ROOT9_TOG                        CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,9)
#define CCM_ACCESS_CTRL9                         CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,9)
#define CCM_ACCESS_CTRL_ROOT9_SET                CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,9)
#define CCM_ACCESS_CTRL_ROOT9_CLR                CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,9)
#define CCM_ACCESS_CTRL_ROOT9_TOG                CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,9)
#define CCM_TARGET_ROOT10                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,10)
#define CCM_TARGET_ROOT10_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,10)
#define CCM_TARGET_ROOT10_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,10)
#define CCM_TARGET_ROOT10_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,10)
#define CCM_MISC10                               CCM_MISC_REG(CCM_BASE_PTR,10)
#define CCM_MISC_ROOT10_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,10)
#define CCM_MISC_ROOT10_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,10)
#define CCM_MISC_ROOT10_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,10)
#define CCM_POST10                               CCM_POST_REG(CCM_BASE_PTR,10)
#define CCM_POST_ROOT10_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,10)
#define CCM_POST_ROOT10_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,10)
#define CCM_POST_ROOT10_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,10)
#define CCM_PRE10                                CCM_PRE_REG(CCM_BASE_PTR,10)
#define CCM_PRE_ROOT10_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,10)
#define CCM_PRE_ROOT10_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,10)
#define CCM_PRE_ROOT10_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,10)
#define CCM_ACCESS_CTRL10                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,10)
#define CCM_ACCESS_CTRL_ROOT10_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,10)
#define CCM_ACCESS_CTRL_ROOT10_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,10)
#define CCM_ACCESS_CTRL_ROOT10_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,10)
#define CCM_TARGET_ROOT11                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,11)
#define CCM_TARGET_ROOT11_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,11)
#define CCM_TARGET_ROOT11_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,11)
#define CCM_TARGET_ROOT11_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,11)
#define CCM_MISC11                               CCM_MISC_REG(CCM_BASE_PTR,11)
#define CCM_MISC_ROOT11_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,11)
#define CCM_MISC_ROOT11_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,11)
#define CCM_MISC_ROOT11_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,11)
#define CCM_POST11                               CCM_POST_REG(CCM_BASE_PTR,11)
#define CCM_POST_ROOT11_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,11)
#define CCM_POST_ROOT11_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,11)
#define CCM_POST_ROOT11_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,11)
#define CCM_PRE11                                CCM_PRE_REG(CCM_BASE_PTR,11)
#define CCM_PRE_ROOT11_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,11)
#define CCM_PRE_ROOT11_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,11)
#define CCM_PRE_ROOT11_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,11)
#define CCM_ACCESS_CTRL11                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,11)
#define CCM_ACCESS_CTRL_ROOT11_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,11)
#define CCM_ACCESS_CTRL_ROOT11_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,11)
#define CCM_ACCESS_CTRL_ROOT11_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,11)
#define CCM_TARGET_ROOT12                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,12)
#define CCM_TARGET_ROOT12_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,12)
#define CCM_TARGET_ROOT12_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,12)
#define CCM_TARGET_ROOT12_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,12)
#define CCM_MISC12                               CCM_MISC_REG(CCM_BASE_PTR,12)
#define CCM_MISC_ROOT12_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,12)
#define CCM_MISC_ROOT12_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,12)
#define CCM_MISC_ROOT12_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,12)
#define CCM_POST12                               CCM_POST_REG(CCM_BASE_PTR,12)
#define CCM_POST_ROOT12_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,12)
#define CCM_POST_ROOT12_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,12)
#define CCM_POST_ROOT12_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,12)
#define CCM_PRE12                                CCM_PRE_REG(CCM_BASE_PTR,12)
#define CCM_PRE_ROOT12_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,12)
#define CCM_PRE_ROOT12_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,12)
#define CCM_PRE_ROOT12_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,12)
#define CCM_ACCESS_CTRL12                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,12)
#define CCM_ACCESS_CTRL_ROOT12_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,12)
#define CCM_ACCESS_CTRL_ROOT12_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,12)
#define CCM_ACCESS_CTRL_ROOT12_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,12)
#define CCM_TARGET_ROOT13                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,13)
#define CCM_TARGET_ROOT13_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,13)
#define CCM_TARGET_ROOT13_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,13)
#define CCM_TARGET_ROOT13_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,13)
#define CCM_MISC13                               CCM_MISC_REG(CCM_BASE_PTR,13)
#define CCM_MISC_ROOT13_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,13)
#define CCM_MISC_ROOT13_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,13)
#define CCM_MISC_ROOT13_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,13)
#define CCM_POST13                               CCM_POST_REG(CCM_BASE_PTR,13)
#define CCM_POST_ROOT13_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,13)
#define CCM_POST_ROOT13_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,13)
#define CCM_POST_ROOT13_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,13)
#define CCM_PRE13                                CCM_PRE_REG(CCM_BASE_PTR,13)
#define CCM_PRE_ROOT13_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,13)
#define CCM_PRE_ROOT13_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,13)
#define CCM_PRE_ROOT13_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,13)
#define CCM_ACCESS_CTRL13                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,13)
#define CCM_ACCESS_CTRL_ROOT13_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,13)
#define CCM_ACCESS_CTRL_ROOT13_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,13)
#define CCM_ACCESS_CTRL_ROOT13_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,13)
#define CCM_TARGET_ROOT14                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,14)
#define CCM_TARGET_ROOT14_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,14)
#define CCM_TARGET_ROOT14_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,14)
#define CCM_TARGET_ROOT14_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,14)
#define CCM_MISC14                               CCM_MISC_REG(CCM_BASE_PTR,14)
#define CCM_MISC_ROOT14_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,14)
#define CCM_MISC_ROOT14_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,14)
#define CCM_MISC_ROOT14_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,14)
#define CCM_POST14                               CCM_POST_REG(CCM_BASE_PTR,14)
#define CCM_POST_ROOT14_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,14)
#define CCM_POST_ROOT14_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,14)
#define CCM_POST_ROOT14_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,14)
#define CCM_PRE14                                CCM_PRE_REG(CCM_BASE_PTR,14)
#define CCM_PRE_ROOT14_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,14)
#define CCM_PRE_ROOT14_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,14)
#define CCM_PRE_ROOT14_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,14)
#define CCM_ACCESS_CTRL14                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,14)
#define CCM_ACCESS_CTRL_ROOT14_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,14)
#define CCM_ACCESS_CTRL_ROOT14_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,14)
#define CCM_ACCESS_CTRL_ROOT14_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,14)
#define CCM_TARGET_ROOT15                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,15)
#define CCM_TARGET_ROOT15_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,15)
#define CCM_TARGET_ROOT15_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,15)
#define CCM_TARGET_ROOT15_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,15)
#define CCM_MISC15                               CCM_MISC_REG(CCM_BASE_PTR,15)
#define CCM_MISC_ROOT15_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,15)
#define CCM_MISC_ROOT15_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,15)
#define CCM_MISC_ROOT15_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,15)
#define CCM_POST15                               CCM_POST_REG(CCM_BASE_PTR,15)
#define CCM_POST_ROOT15_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,15)
#define CCM_POST_ROOT15_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,15)
#define CCM_POST_ROOT15_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,15)
#define CCM_PRE15                                CCM_PRE_REG(CCM_BASE_PTR,15)
#define CCM_PRE_ROOT15_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,15)
#define CCM_PRE_ROOT15_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,15)
#define CCM_PRE_ROOT15_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,15)
#define CCM_ACCESS_CTRL15                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,15)
#define CCM_ACCESS_CTRL_ROOT15_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,15)
#define CCM_ACCESS_CTRL_ROOT15_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,15)
#define CCM_ACCESS_CTRL_ROOT15_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,15)
#define CCM_TARGET_ROOT16                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,16)
#define CCM_TARGET_ROOT16_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,16)
#define CCM_TARGET_ROOT16_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,16)
#define CCM_TARGET_ROOT16_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,16)
#define CCM_MISC16                               CCM_MISC_REG(CCM_BASE_PTR,16)
#define CCM_MISC_ROOT16_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,16)
#define CCM_MISC_ROOT16_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,16)
#define CCM_MISC_ROOT16_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,16)
#define CCM_POST16                               CCM_POST_REG(CCM_BASE_PTR,16)
#define CCM_POST_ROOT16_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,16)
#define CCM_POST_ROOT16_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,16)
#define CCM_POST_ROOT16_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,16)
#define CCM_PRE16                                CCM_PRE_REG(CCM_BASE_PTR,16)
#define CCM_PRE_ROOT16_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,16)
#define CCM_PRE_ROOT16_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,16)
#define CCM_PRE_ROOT16_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,16)
#define CCM_ACCESS_CTRL16                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,16)
#define CCM_ACCESS_CTRL_ROOT16_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,16)
#define CCM_ACCESS_CTRL_ROOT16_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,16)
#define CCM_ACCESS_CTRL_ROOT16_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,16)
#define CCM_TARGET_ROOT17                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,17)
#define CCM_TARGET_ROOT17_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,17)
#define CCM_TARGET_ROOT17_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,17)
#define CCM_TARGET_ROOT17_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,17)
#define CCM_MISC17                               CCM_MISC_REG(CCM_BASE_PTR,17)
#define CCM_MISC_ROOT17_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,17)
#define CCM_MISC_ROOT17_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,17)
#define CCM_MISC_ROOT17_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,17)
#define CCM_POST17                               CCM_POST_REG(CCM_BASE_PTR,17)
#define CCM_POST_ROOT17_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,17)
#define CCM_POST_ROOT17_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,17)
#define CCM_POST_ROOT17_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,17)
#define CCM_PRE17                                CCM_PRE_REG(CCM_BASE_PTR,17)
#define CCM_PRE_ROOT17_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,17)
#define CCM_PRE_ROOT17_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,17)
#define CCM_PRE_ROOT17_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,17)
#define CCM_ACCESS_CTRL17                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,17)
#define CCM_ACCESS_CTRL_ROOT17_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,17)
#define CCM_ACCESS_CTRL_ROOT17_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,17)
#define CCM_ACCESS_CTRL_ROOT17_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,17)
#define CCM_TARGET_ROOT18                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,18)
#define CCM_TARGET_ROOT18_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,18)
#define CCM_TARGET_ROOT18_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,18)
#define CCM_TARGET_ROOT18_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,18)
#define CCM_MISC18                               CCM_MISC_REG(CCM_BASE_PTR,18)
#define CCM_MISC_ROOT18_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,18)
#define CCM_MISC_ROOT18_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,18)
#define CCM_MISC_ROOT18_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,18)
#define CCM_POST18                               CCM_POST_REG(CCM_BASE_PTR,18)
#define CCM_POST_ROOT18_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,18)
#define CCM_POST_ROOT18_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,18)
#define CCM_POST_ROOT18_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,18)
#define CCM_PRE18                                CCM_PRE_REG(CCM_BASE_PTR,18)
#define CCM_PRE_ROOT18_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,18)
#define CCM_PRE_ROOT18_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,18)
#define CCM_PRE_ROOT18_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,18)
#define CCM_ACCESS_CTRL18                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,18)
#define CCM_ACCESS_CTRL_ROOT18_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,18)
#define CCM_ACCESS_CTRL_ROOT18_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,18)
#define CCM_ACCESS_CTRL_ROOT18_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,18)
#define CCM_TARGET_ROOT19                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,19)
#define CCM_TARGET_ROOT19_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,19)
#define CCM_TARGET_ROOT19_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,19)
#define CCM_TARGET_ROOT19_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,19)
#define CCM_MISC19                               CCM_MISC_REG(CCM_BASE_PTR,19)
#define CCM_MISC_ROOT19_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,19)
#define CCM_MISC_ROOT19_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,19)
#define CCM_MISC_ROOT19_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,19)
#define CCM_POST19                               CCM_POST_REG(CCM_BASE_PTR,19)
#define CCM_POST_ROOT19_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,19)
#define CCM_POST_ROOT19_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,19)
#define CCM_POST_ROOT19_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,19)
#define CCM_PRE19                                CCM_PRE_REG(CCM_BASE_PTR,19)
#define CCM_PRE_ROOT19_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,19)
#define CCM_PRE_ROOT19_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,19)
#define CCM_PRE_ROOT19_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,19)
#define CCM_ACCESS_CTRL19                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,19)
#define CCM_ACCESS_CTRL_ROOT19_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,19)
#define CCM_ACCESS_CTRL_ROOT19_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,19)
#define CCM_ACCESS_CTRL_ROOT19_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,19)
#define CCM_TARGET_ROOT20                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,20)
#define CCM_TARGET_ROOT20_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,20)
#define CCM_TARGET_ROOT20_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,20)
#define CCM_TARGET_ROOT20_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,20)
#define CCM_MISC20                               CCM_MISC_REG(CCM_BASE_PTR,20)
#define CCM_MISC_ROOT20_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,20)
#define CCM_MISC_ROOT20_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,20)
#define CCM_MISC_ROOT20_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,20)
#define CCM_POST20                               CCM_POST_REG(CCM_BASE_PTR,20)
#define CCM_POST_ROOT20_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,20)
#define CCM_POST_ROOT20_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,20)
#define CCM_POST_ROOT20_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,20)
#define CCM_PRE20                                CCM_PRE_REG(CCM_BASE_PTR,20)
#define CCM_PRE_ROOT20_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,20)
#define CCM_PRE_ROOT20_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,20)
#define CCM_PRE_ROOT20_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,20)
#define CCM_ACCESS_CTRL20                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,20)
#define CCM_ACCESS_CTRL_ROOT20_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,20)
#define CCM_ACCESS_CTRL_ROOT20_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,20)
#define CCM_ACCESS_CTRL_ROOT20_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,20)
#define CCM_TARGET_ROOT21                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,21)
#define CCM_TARGET_ROOT21_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,21)
#define CCM_TARGET_ROOT21_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,21)
#define CCM_TARGET_ROOT21_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,21)
#define CCM_MISC21                               CCM_MISC_REG(CCM_BASE_PTR,21)
#define CCM_MISC_ROOT21_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,21)
#define CCM_MISC_ROOT21_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,21)
#define CCM_MISC_ROOT21_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,21)
#define CCM_POST21                               CCM_POST_REG(CCM_BASE_PTR,21)
#define CCM_POST_ROOT21_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,21)
#define CCM_POST_ROOT21_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,21)
#define CCM_POST_ROOT21_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,21)
#define CCM_PRE21                                CCM_PRE_REG(CCM_BASE_PTR,21)
#define CCM_PRE_ROOT21_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,21)
#define CCM_PRE_ROOT21_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,21)
#define CCM_PRE_ROOT21_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,21)
#define CCM_ACCESS_CTRL21                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,21)
#define CCM_ACCESS_CTRL_ROOT21_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,21)
#define CCM_ACCESS_CTRL_ROOT21_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,21)
#define CCM_ACCESS_CTRL_ROOT21_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,21)
#define CCM_TARGET_ROOT22                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,22)
#define CCM_TARGET_ROOT22_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,22)
#define CCM_TARGET_ROOT22_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,22)
#define CCM_TARGET_ROOT22_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,22)
#define CCM_MISC22                               CCM_MISC_REG(CCM_BASE_PTR,22)
#define CCM_MISC_ROOT22_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,22)
#define CCM_MISC_ROOT22_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,22)
#define CCM_MISC_ROOT22_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,22)
#define CCM_POST22                               CCM_POST_REG(CCM_BASE_PTR,22)
#define CCM_POST_ROOT22_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,22)
#define CCM_POST_ROOT22_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,22)
#define CCM_POST_ROOT22_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,22)
#define CCM_PRE22                                CCM_PRE_REG(CCM_BASE_PTR,22)
#define CCM_PRE_ROOT22_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,22)
#define CCM_PRE_ROOT22_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,22)
#define CCM_PRE_ROOT22_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,22)
#define CCM_ACCESS_CTRL22                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,22)
#define CCM_ACCESS_CTRL_ROOT22_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,22)
#define CCM_ACCESS_CTRL_ROOT22_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,22)
#define CCM_ACCESS_CTRL_ROOT22_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,22)
#define CCM_TARGET_ROOT23                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,23)
#define CCM_TARGET_ROOT23_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,23)
#define CCM_TARGET_ROOT23_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,23)
#define CCM_TARGET_ROOT23_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,23)
#define CCM_MISC23                               CCM_MISC_REG(CCM_BASE_PTR,23)
#define CCM_MISC_ROOT23_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,23)
#define CCM_MISC_ROOT23_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,23)
#define CCM_MISC_ROOT23_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,23)
#define CCM_POST23                               CCM_POST_REG(CCM_BASE_PTR,23)
#define CCM_POST_ROOT23_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,23)
#define CCM_POST_ROOT23_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,23)
#define CCM_POST_ROOT23_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,23)
#define CCM_PRE23                                CCM_PRE_REG(CCM_BASE_PTR,23)
#define CCM_PRE_ROOT23_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,23)
#define CCM_PRE_ROOT23_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,23)
#define CCM_PRE_ROOT23_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,23)
#define CCM_ACCESS_CTRL23                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,23)
#define CCM_ACCESS_CTRL_ROOT23_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,23)
#define CCM_ACCESS_CTRL_ROOT23_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,23)
#define CCM_ACCESS_CTRL_ROOT23_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,23)
#define CCM_TARGET_ROOT24                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,24)
#define CCM_TARGET_ROOT24_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,24)
#define CCM_TARGET_ROOT24_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,24)
#define CCM_TARGET_ROOT24_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,24)
#define CCM_MISC24                               CCM_MISC_REG(CCM_BASE_PTR,24)
#define CCM_MISC_ROOT24_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,24)
#define CCM_MISC_ROOT24_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,24)
#define CCM_MISC_ROOT24_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,24)
#define CCM_POST24                               CCM_POST_REG(CCM_BASE_PTR,24)
#define CCM_POST_ROOT24_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,24)
#define CCM_POST_ROOT24_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,24)
#define CCM_POST_ROOT24_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,24)
#define CCM_PRE24                                CCM_PRE_REG(CCM_BASE_PTR,24)
#define CCM_PRE_ROOT24_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,24)
#define CCM_PRE_ROOT24_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,24)
#define CCM_PRE_ROOT24_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,24)
#define CCM_ACCESS_CTRL24                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,24)
#define CCM_ACCESS_CTRL_ROOT24_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,24)
#define CCM_ACCESS_CTRL_ROOT24_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,24)
#define CCM_ACCESS_CTRL_ROOT24_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,24)
#define CCM_TARGET_ROOT25                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,25)
#define CCM_TARGET_ROOT25_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,25)
#define CCM_TARGET_ROOT25_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,25)
#define CCM_TARGET_ROOT25_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,25)
#define CCM_MISC25                               CCM_MISC_REG(CCM_BASE_PTR,25)
#define CCM_MISC_ROOT25_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,25)
#define CCM_MISC_ROOT25_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,25)
#define CCM_MISC_ROOT25_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,25)
#define CCM_POST25                               CCM_POST_REG(CCM_BASE_PTR,25)
#define CCM_POST_ROOT25_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,25)
#define CCM_POST_ROOT25_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,25)
#define CCM_POST_ROOT25_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,25)
#define CCM_PRE25                                CCM_PRE_REG(CCM_BASE_PTR,25)
#define CCM_PRE_ROOT25_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,25)
#define CCM_PRE_ROOT25_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,25)
#define CCM_PRE_ROOT25_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,25)
#define CCM_ACCESS_CTRL25                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,25)
#define CCM_ACCESS_CTRL_ROOT25_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,25)
#define CCM_ACCESS_CTRL_ROOT25_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,25)
#define CCM_ACCESS_CTRL_ROOT25_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,25)
#define CCM_TARGET_ROOT26                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,26)
#define CCM_TARGET_ROOT26_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,26)
#define CCM_TARGET_ROOT26_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,26)
#define CCM_TARGET_ROOT26_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,26)
#define CCM_MISC26                               CCM_MISC_REG(CCM_BASE_PTR,26)
#define CCM_MISC_ROOT26_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,26)
#define CCM_MISC_ROOT26_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,26)
#define CCM_MISC_ROOT26_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,26)
#define CCM_POST26                               CCM_POST_REG(CCM_BASE_PTR,26)
#define CCM_POST_ROOT26_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,26)
#define CCM_POST_ROOT26_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,26)
#define CCM_POST_ROOT26_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,26)
#define CCM_PRE26                                CCM_PRE_REG(CCM_BASE_PTR,26)
#define CCM_PRE_ROOT26_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,26)
#define CCM_PRE_ROOT26_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,26)
#define CCM_PRE_ROOT26_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,26)
#define CCM_ACCESS_CTRL26                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,26)
#define CCM_ACCESS_CTRL_ROOT26_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,26)
#define CCM_ACCESS_CTRL_ROOT26_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,26)
#define CCM_ACCESS_CTRL_ROOT26_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,26)
#define CCM_TARGET_ROOT27                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,27)
#define CCM_TARGET_ROOT27_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,27)
#define CCM_TARGET_ROOT27_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,27)
#define CCM_TARGET_ROOT27_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,27)
#define CCM_MISC27                               CCM_MISC_REG(CCM_BASE_PTR,27)
#define CCM_MISC_ROOT27_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,27)
#define CCM_MISC_ROOT27_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,27)
#define CCM_MISC_ROOT27_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,27)
#define CCM_POST27                               CCM_POST_REG(CCM_BASE_PTR,27)
#define CCM_POST_ROOT27_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,27)
#define CCM_POST_ROOT27_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,27)
#define CCM_POST_ROOT27_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,27)
#define CCM_PRE27                                CCM_PRE_REG(CCM_BASE_PTR,27)
#define CCM_PRE_ROOT27_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,27)
#define CCM_PRE_ROOT27_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,27)
#define CCM_PRE_ROOT27_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,27)
#define CCM_ACCESS_CTRL27                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,27)
#define CCM_ACCESS_CTRL_ROOT27_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,27)
#define CCM_ACCESS_CTRL_ROOT27_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,27)
#define CCM_ACCESS_CTRL_ROOT27_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,27)
#define CCM_TARGET_ROOT28                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,28)
#define CCM_TARGET_ROOT28_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,28)
#define CCM_TARGET_ROOT28_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,28)
#define CCM_TARGET_ROOT28_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,28)
#define CCM_MISC28                               CCM_MISC_REG(CCM_BASE_PTR,28)
#define CCM_MISC_ROOT28_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,28)
#define CCM_MISC_ROOT28_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,28)
#define CCM_MISC_ROOT28_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,28)
#define CCM_POST28                               CCM_POST_REG(CCM_BASE_PTR,28)
#define CCM_POST_ROOT28_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,28)
#define CCM_POST_ROOT28_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,28)
#define CCM_POST_ROOT28_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,28)
#define CCM_PRE28                                CCM_PRE_REG(CCM_BASE_PTR,28)
#define CCM_PRE_ROOT28_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,28)
#define CCM_PRE_ROOT28_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,28)
#define CCM_PRE_ROOT28_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,28)
#define CCM_ACCESS_CTRL28                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,28)
#define CCM_ACCESS_CTRL_ROOT28_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,28)
#define CCM_ACCESS_CTRL_ROOT28_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,28)
#define CCM_ACCESS_CTRL_ROOT28_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,28)
#define CCM_TARGET_ROOT29                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,29)
#define CCM_TARGET_ROOT29_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,29)
#define CCM_TARGET_ROOT29_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,29)
#define CCM_TARGET_ROOT29_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,29)
#define CCM_MISC29                               CCM_MISC_REG(CCM_BASE_PTR,29)
#define CCM_MISC_ROOT29_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,29)
#define CCM_MISC_ROOT29_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,29)
#define CCM_MISC_ROOT29_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,29)
#define CCM_POST29                               CCM_POST_REG(CCM_BASE_PTR,29)
#define CCM_POST_ROOT29_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,29)
#define CCM_POST_ROOT29_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,29)
#define CCM_POST_ROOT29_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,29)
#define CCM_PRE29                                CCM_PRE_REG(CCM_BASE_PTR,29)
#define CCM_PRE_ROOT29_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,29)
#define CCM_PRE_ROOT29_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,29)
#define CCM_PRE_ROOT29_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,29)
#define CCM_ACCESS_CTRL29                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,29)
#define CCM_ACCESS_CTRL_ROOT29_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,29)
#define CCM_ACCESS_CTRL_ROOT29_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,29)
#define CCM_ACCESS_CTRL_ROOT29_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,29)
#define CCM_TARGET_ROOT30                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,30)
#define CCM_TARGET_ROOT30_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,30)
#define CCM_TARGET_ROOT30_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,30)
#define CCM_TARGET_ROOT30_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,30)
#define CCM_MISC30                               CCM_MISC_REG(CCM_BASE_PTR,30)
#define CCM_MISC_ROOT30_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,30)
#define CCM_MISC_ROOT30_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,30)
#define CCM_MISC_ROOT30_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,30)
#define CCM_POST30                               CCM_POST_REG(CCM_BASE_PTR,30)
#define CCM_POST_ROOT30_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,30)
#define CCM_POST_ROOT30_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,30)
#define CCM_POST_ROOT30_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,30)
#define CCM_PRE30                                CCM_PRE_REG(CCM_BASE_PTR,30)
#define CCM_PRE_ROOT30_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,30)
#define CCM_PRE_ROOT30_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,30)
#define CCM_PRE_ROOT30_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,30)
#define CCM_ACCESS_CTRL30                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,30)
#define CCM_ACCESS_CTRL_ROOT30_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,30)
#define CCM_ACCESS_CTRL_ROOT30_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,30)
#define CCM_ACCESS_CTRL_ROOT30_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,30)
#define CCM_TARGET_ROOT31                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,31)
#define CCM_TARGET_ROOT31_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,31)
#define CCM_TARGET_ROOT31_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,31)
#define CCM_TARGET_ROOT31_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,31)
#define CCM_MISC31                               CCM_MISC_REG(CCM_BASE_PTR,31)
#define CCM_MISC_ROOT31_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,31)
#define CCM_MISC_ROOT31_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,31)
#define CCM_MISC_ROOT31_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,31)
#define CCM_POST31                               CCM_POST_REG(CCM_BASE_PTR,31)
#define CCM_POST_ROOT31_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,31)
#define CCM_POST_ROOT31_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,31)
#define CCM_POST_ROOT31_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,31)
#define CCM_PRE31                                CCM_PRE_REG(CCM_BASE_PTR,31)
#define CCM_PRE_ROOT31_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,31)
#define CCM_PRE_ROOT31_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,31)
#define CCM_PRE_ROOT31_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,31)
#define CCM_ACCESS_CTRL31                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,31)
#define CCM_ACCESS_CTRL_ROOT31_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,31)
#define CCM_ACCESS_CTRL_ROOT31_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,31)
#define CCM_ACCESS_CTRL_ROOT31_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,31)
#define CCM_TARGET_ROOT32                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,32)
#define CCM_TARGET_ROOT32_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,32)
#define CCM_TARGET_ROOT32_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,32)
#define CCM_TARGET_ROOT32_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,32)
#define CCM_MISC32                               CCM_MISC_REG(CCM_BASE_PTR,32)
#define CCM_MISC_ROOT32_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,32)
#define CCM_MISC_ROOT32_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,32)
#define CCM_MISC_ROOT32_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,32)
#define CCM_POST32                               CCM_POST_REG(CCM_BASE_PTR,32)
#define CCM_POST_ROOT32_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,32)
#define CCM_POST_ROOT32_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,32)
#define CCM_POST_ROOT32_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,32)
#define CCM_PRE32                                CCM_PRE_REG(CCM_BASE_PTR,32)
#define CCM_PRE_ROOT32_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,32)
#define CCM_PRE_ROOT32_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,32)
#define CCM_PRE_ROOT32_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,32)
#define CCM_ACCESS_CTRL32                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,32)
#define CCM_ACCESS_CTRL_ROOT32_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,32)
#define CCM_ACCESS_CTRL_ROOT32_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,32)
#define CCM_ACCESS_CTRL_ROOT32_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,32)
#define CCM_TARGET_ROOT33                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,33)
#define CCM_TARGET_ROOT33_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,33)
#define CCM_TARGET_ROOT33_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,33)
#define CCM_TARGET_ROOT33_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,33)
#define CCM_MISC33                               CCM_MISC_REG(CCM_BASE_PTR,33)
#define CCM_MISC_ROOT33_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,33)
#define CCM_MISC_ROOT33_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,33)
#define CCM_MISC_ROOT33_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,33)
#define CCM_POST33                               CCM_POST_REG(CCM_BASE_PTR,33)
#define CCM_POST_ROOT33_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,33)
#define CCM_POST_ROOT33_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,33)
#define CCM_POST_ROOT33_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,33)
#define CCM_PRE33                                CCM_PRE_REG(CCM_BASE_PTR,33)
#define CCM_PRE_ROOT33_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,33)
#define CCM_PRE_ROOT33_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,33)
#define CCM_PRE_ROOT33_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,33)
#define CCM_ACCESS_CTRL33                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,33)
#define CCM_ACCESS_CTRL_ROOT33_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,33)
#define CCM_ACCESS_CTRL_ROOT33_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,33)
#define CCM_ACCESS_CTRL_ROOT33_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,33)
#define CCM_TARGET_ROOT34                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,34)
#define CCM_TARGET_ROOT34_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,34)
#define CCM_TARGET_ROOT34_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,34)
#define CCM_TARGET_ROOT34_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,34)
#define CCM_MISC34                               CCM_MISC_REG(CCM_BASE_PTR,34)
#define CCM_MISC_ROOT34_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,34)
#define CCM_MISC_ROOT34_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,34)
#define CCM_MISC_ROOT34_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,34)
#define CCM_POST34                               CCM_POST_REG(CCM_BASE_PTR,34)
#define CCM_POST_ROOT34_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,34)
#define CCM_POST_ROOT34_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,34)
#define CCM_POST_ROOT34_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,34)
#define CCM_PRE34                                CCM_PRE_REG(CCM_BASE_PTR,34)
#define CCM_PRE_ROOT34_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,34)
#define CCM_PRE_ROOT34_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,34)
#define CCM_PRE_ROOT34_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,34)
#define CCM_ACCESS_CTRL34                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,34)
#define CCM_ACCESS_CTRL_ROOT34_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,34)
#define CCM_ACCESS_CTRL_ROOT34_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,34)
#define CCM_ACCESS_CTRL_ROOT34_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,34)
#define CCM_TARGET_ROOT35                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,35)
#define CCM_TARGET_ROOT35_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,35)
#define CCM_TARGET_ROOT35_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,35)
#define CCM_TARGET_ROOT35_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,35)
#define CCM_MISC35                               CCM_MISC_REG(CCM_BASE_PTR,35)
#define CCM_MISC_ROOT35_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,35)
#define CCM_MISC_ROOT35_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,35)
#define CCM_MISC_ROOT35_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,35)
#define CCM_POST35                               CCM_POST_REG(CCM_BASE_PTR,35)
#define CCM_POST_ROOT35_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,35)
#define CCM_POST_ROOT35_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,35)
#define CCM_POST_ROOT35_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,35)
#define CCM_PRE35                                CCM_PRE_REG(CCM_BASE_PTR,35)
#define CCM_PRE_ROOT35_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,35)
#define CCM_PRE_ROOT35_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,35)
#define CCM_PRE_ROOT35_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,35)
#define CCM_ACCESS_CTRL35                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,35)
#define CCM_ACCESS_CTRL_ROOT35_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,35)
#define CCM_ACCESS_CTRL_ROOT35_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,35)
#define CCM_ACCESS_CTRL_ROOT35_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,35)
#define CCM_TARGET_ROOT36                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,36)
#define CCM_TARGET_ROOT36_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,36)
#define CCM_TARGET_ROOT36_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,36)
#define CCM_TARGET_ROOT36_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,36)
#define CCM_MISC36                               CCM_MISC_REG(CCM_BASE_PTR,36)
#define CCM_MISC_ROOT36_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,36)
#define CCM_MISC_ROOT36_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,36)
#define CCM_MISC_ROOT36_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,36)
#define CCM_POST36                               CCM_POST_REG(CCM_BASE_PTR,36)
#define CCM_POST_ROOT36_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,36)
#define CCM_POST_ROOT36_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,36)
#define CCM_POST_ROOT36_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,36)
#define CCM_PRE36                                CCM_PRE_REG(CCM_BASE_PTR,36)
#define CCM_PRE_ROOT36_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,36)
#define CCM_PRE_ROOT36_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,36)
#define CCM_PRE_ROOT36_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,36)
#define CCM_ACCESS_CTRL36                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,36)
#define CCM_ACCESS_CTRL_ROOT36_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,36)
#define CCM_ACCESS_CTRL_ROOT36_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,36)
#define CCM_ACCESS_CTRL_ROOT36_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,36)
#define CCM_TARGET_ROOT37                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,37)
#define CCM_TARGET_ROOT37_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,37)
#define CCM_TARGET_ROOT37_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,37)
#define CCM_TARGET_ROOT37_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,37)
#define CCM_MISC37                               CCM_MISC_REG(CCM_BASE_PTR,37)
#define CCM_MISC_ROOT37_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,37)
#define CCM_MISC_ROOT37_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,37)
#define CCM_MISC_ROOT37_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,37)
#define CCM_POST37                               CCM_POST_REG(CCM_BASE_PTR,37)
#define CCM_POST_ROOT37_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,37)
#define CCM_POST_ROOT37_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,37)
#define CCM_POST_ROOT37_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,37)
#define CCM_PRE37                                CCM_PRE_REG(CCM_BASE_PTR,37)
#define CCM_PRE_ROOT37_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,37)
#define CCM_PRE_ROOT37_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,37)
#define CCM_PRE_ROOT37_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,37)
#define CCM_ACCESS_CTRL37                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,37)
#define CCM_ACCESS_CTRL_ROOT37_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,37)
#define CCM_ACCESS_CTRL_ROOT37_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,37)
#define CCM_ACCESS_CTRL_ROOT37_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,37)
#define CCM_TARGET_ROOT38                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,38)
#define CCM_TARGET_ROOT38_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,38)
#define CCM_TARGET_ROOT38_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,38)
#define CCM_TARGET_ROOT38_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,38)
#define CCM_MISC38                               CCM_MISC_REG(CCM_BASE_PTR,38)
#define CCM_MISC_ROOT38_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,38)
#define CCM_MISC_ROOT38_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,38)
#define CCM_MISC_ROOT38_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,38)
#define CCM_POST38                               CCM_POST_REG(CCM_BASE_PTR,38)
#define CCM_POST_ROOT38_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,38)
#define CCM_POST_ROOT38_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,38)
#define CCM_POST_ROOT38_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,38)
#define CCM_PRE38                                CCM_PRE_REG(CCM_BASE_PTR,38)
#define CCM_PRE_ROOT38_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,38)
#define CCM_PRE_ROOT38_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,38)
#define CCM_PRE_ROOT38_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,38)
#define CCM_ACCESS_CTRL38                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,38)
#define CCM_ACCESS_CTRL_ROOT38_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,38)
#define CCM_ACCESS_CTRL_ROOT38_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,38)
#define CCM_ACCESS_CTRL_ROOT38_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,38)
#define CCM_TARGET_ROOT39                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,39)
#define CCM_TARGET_ROOT39_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,39)
#define CCM_TARGET_ROOT39_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,39)
#define CCM_TARGET_ROOT39_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,39)
#define CCM_MISC39                               CCM_MISC_REG(CCM_BASE_PTR,39)
#define CCM_MISC_ROOT39_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,39)
#define CCM_MISC_ROOT39_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,39)
#define CCM_MISC_ROOT39_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,39)
#define CCM_POST39                               CCM_POST_REG(CCM_BASE_PTR,39)
#define CCM_POST_ROOT39_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,39)
#define CCM_POST_ROOT39_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,39)
#define CCM_POST_ROOT39_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,39)
#define CCM_PRE39                                CCM_PRE_REG(CCM_BASE_PTR,39)
#define CCM_PRE_ROOT39_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,39)
#define CCM_PRE_ROOT39_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,39)
#define CCM_PRE_ROOT39_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,39)
#define CCM_ACCESS_CTRL39                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,39)
#define CCM_ACCESS_CTRL_ROOT39_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,39)
#define CCM_ACCESS_CTRL_ROOT39_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,39)
#define CCM_ACCESS_CTRL_ROOT39_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,39)
#define CCM_TARGET_ROOT40                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,40)
#define CCM_TARGET_ROOT40_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,40)
#define CCM_TARGET_ROOT40_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,40)
#define CCM_TARGET_ROOT40_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,40)
#define CCM_MISC40                               CCM_MISC_REG(CCM_BASE_PTR,40)
#define CCM_MISC_ROOT40_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,40)
#define CCM_MISC_ROOT40_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,40)
#define CCM_MISC_ROOT40_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,40)
#define CCM_POST40                               CCM_POST_REG(CCM_BASE_PTR,40)
#define CCM_POST_ROOT40_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,40)
#define CCM_POST_ROOT40_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,40)
#define CCM_POST_ROOT40_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,40)
#define CCM_PRE40                                CCM_PRE_REG(CCM_BASE_PTR,40)
#define CCM_PRE_ROOT40_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,40)
#define CCM_PRE_ROOT40_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,40)
#define CCM_PRE_ROOT40_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,40)
#define CCM_ACCESS_CTRL40                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,40)
#define CCM_ACCESS_CTRL_ROOT40_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,40)
#define CCM_ACCESS_CTRL_ROOT40_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,40)
#define CCM_ACCESS_CTRL_ROOT40_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,40)
#define CCM_TARGET_ROOT41                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,41)
#define CCM_TARGET_ROOT41_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,41)
#define CCM_TARGET_ROOT41_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,41)
#define CCM_TARGET_ROOT41_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,41)
#define CCM_MISC41                               CCM_MISC_REG(CCM_BASE_PTR,41)
#define CCM_MISC_ROOT41_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,41)
#define CCM_MISC_ROOT41_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,41)
#define CCM_MISC_ROOT41_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,41)
#define CCM_POST41                               CCM_POST_REG(CCM_BASE_PTR,41)
#define CCM_POST_ROOT41_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,41)
#define CCM_POST_ROOT41_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,41)
#define CCM_POST_ROOT41_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,41)
#define CCM_PRE41                                CCM_PRE_REG(CCM_BASE_PTR,41)
#define CCM_PRE_ROOT41_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,41)
#define CCM_PRE_ROOT41_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,41)
#define CCM_PRE_ROOT41_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,41)
#define CCM_ACCESS_CTRL41                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,41)
#define CCM_ACCESS_CTRL_ROOT41_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,41)
#define CCM_ACCESS_CTRL_ROOT41_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,41)
#define CCM_ACCESS_CTRL_ROOT41_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,41)
#define CCM_TARGET_ROOT42                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,42)
#define CCM_TARGET_ROOT42_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,42)
#define CCM_TARGET_ROOT42_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,42)
#define CCM_TARGET_ROOT42_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,42)
#define CCM_MISC42                               CCM_MISC_REG(CCM_BASE_PTR,42)
#define CCM_MISC_ROOT42_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,42)
#define CCM_MISC_ROOT42_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,42)
#define CCM_MISC_ROOT42_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,42)
#define CCM_POST42                               CCM_POST_REG(CCM_BASE_PTR,42)
#define CCM_POST_ROOT42_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,42)
#define CCM_POST_ROOT42_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,42)
#define CCM_POST_ROOT42_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,42)
#define CCM_PRE42                                CCM_PRE_REG(CCM_BASE_PTR,42)
#define CCM_PRE_ROOT42_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,42)
#define CCM_PRE_ROOT42_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,42)
#define CCM_PRE_ROOT42_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,42)
#define CCM_ACCESS_CTRL42                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,42)
#define CCM_ACCESS_CTRL_ROOT42_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,42)
#define CCM_ACCESS_CTRL_ROOT42_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,42)
#define CCM_ACCESS_CTRL_ROOT42_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,42)
#define CCM_TARGET_ROOT43                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,43)
#define CCM_TARGET_ROOT43_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,43)
#define CCM_TARGET_ROOT43_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,43)
#define CCM_TARGET_ROOT43_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,43)
#define CCM_MISC43                               CCM_MISC_REG(CCM_BASE_PTR,43)
#define CCM_MISC_ROOT43_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,43)
#define CCM_MISC_ROOT43_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,43)
#define CCM_MISC_ROOT43_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,43)
#define CCM_POST43                               CCM_POST_REG(CCM_BASE_PTR,43)
#define CCM_POST_ROOT43_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,43)
#define CCM_POST_ROOT43_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,43)
#define CCM_POST_ROOT43_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,43)
#define CCM_PRE43                                CCM_PRE_REG(CCM_BASE_PTR,43)
#define CCM_PRE_ROOT43_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,43)
#define CCM_PRE_ROOT43_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,43)
#define CCM_PRE_ROOT43_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,43)
#define CCM_ACCESS_CTRL43                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,43)
#define CCM_ACCESS_CTRL_ROOT43_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,43)
#define CCM_ACCESS_CTRL_ROOT43_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,43)
#define CCM_ACCESS_CTRL_ROOT43_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,43)
#define CCM_TARGET_ROOT44                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,44)
#define CCM_TARGET_ROOT44_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,44)
#define CCM_TARGET_ROOT44_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,44)
#define CCM_TARGET_ROOT44_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,44)
#define CCM_MISC44                               CCM_MISC_REG(CCM_BASE_PTR,44)
#define CCM_MISC_ROOT44_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,44)
#define CCM_MISC_ROOT44_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,44)
#define CCM_MISC_ROOT44_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,44)
#define CCM_POST44                               CCM_POST_REG(CCM_BASE_PTR,44)
#define CCM_POST_ROOT44_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,44)
#define CCM_POST_ROOT44_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,44)
#define CCM_POST_ROOT44_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,44)
#define CCM_PRE44                                CCM_PRE_REG(CCM_BASE_PTR,44)
#define CCM_PRE_ROOT44_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,44)
#define CCM_PRE_ROOT44_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,44)
#define CCM_PRE_ROOT44_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,44)
#define CCM_ACCESS_CTRL44                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,44)
#define CCM_ACCESS_CTRL_ROOT44_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,44)
#define CCM_ACCESS_CTRL_ROOT44_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,44)
#define CCM_ACCESS_CTRL_ROOT44_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,44)
#define CCM_TARGET_ROOT45                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,45)
#define CCM_TARGET_ROOT45_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,45)
#define CCM_TARGET_ROOT45_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,45)
#define CCM_TARGET_ROOT45_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,45)
#define CCM_MISC45                               CCM_MISC_REG(CCM_BASE_PTR,45)
#define CCM_MISC_ROOT45_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,45)
#define CCM_MISC_ROOT45_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,45)
#define CCM_MISC_ROOT45_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,45)
#define CCM_POST45                               CCM_POST_REG(CCM_BASE_PTR,45)
#define CCM_POST_ROOT45_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,45)
#define CCM_POST_ROOT45_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,45)
#define CCM_POST_ROOT45_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,45)
#define CCM_PRE45                                CCM_PRE_REG(CCM_BASE_PTR,45)
#define CCM_PRE_ROOT45_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,45)
#define CCM_PRE_ROOT45_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,45)
#define CCM_PRE_ROOT45_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,45)
#define CCM_ACCESS_CTRL45                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,45)
#define CCM_ACCESS_CTRL_ROOT45_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,45)
#define CCM_ACCESS_CTRL_ROOT45_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,45)
#define CCM_ACCESS_CTRL_ROOT45_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,45)
#define CCM_TARGET_ROOT46                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,46)
#define CCM_TARGET_ROOT46_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,46)
#define CCM_TARGET_ROOT46_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,46)
#define CCM_TARGET_ROOT46_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,46)
#define CCM_MISC46                               CCM_MISC_REG(CCM_BASE_PTR,46)
#define CCM_MISC_ROOT46_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,46)
#define CCM_MISC_ROOT46_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,46)
#define CCM_MISC_ROOT46_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,46)
#define CCM_POST46                               CCM_POST_REG(CCM_BASE_PTR,46)
#define CCM_POST_ROOT46_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,46)
#define CCM_POST_ROOT46_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,46)
#define CCM_POST_ROOT46_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,46)
#define CCM_PRE46                                CCM_PRE_REG(CCM_BASE_PTR,46)
#define CCM_PRE_ROOT46_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,46)
#define CCM_PRE_ROOT46_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,46)
#define CCM_PRE_ROOT46_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,46)
#define CCM_ACCESS_CTRL46                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,46)
#define CCM_ACCESS_CTRL_ROOT46_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,46)
#define CCM_ACCESS_CTRL_ROOT46_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,46)
#define CCM_ACCESS_CTRL_ROOT46_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,46)
#define CCM_TARGET_ROOT47                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,47)
#define CCM_TARGET_ROOT47_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,47)
#define CCM_TARGET_ROOT47_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,47)
#define CCM_TARGET_ROOT47_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,47)
#define CCM_MISC47                               CCM_MISC_REG(CCM_BASE_PTR,47)
#define CCM_MISC_ROOT47_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,47)
#define CCM_MISC_ROOT47_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,47)
#define CCM_MISC_ROOT47_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,47)
#define CCM_POST47                               CCM_POST_REG(CCM_BASE_PTR,47)
#define CCM_POST_ROOT47_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,47)
#define CCM_POST_ROOT47_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,47)
#define CCM_POST_ROOT47_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,47)
#define CCM_PRE47                                CCM_PRE_REG(CCM_BASE_PTR,47)
#define CCM_PRE_ROOT47_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,47)
#define CCM_PRE_ROOT47_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,47)
#define CCM_PRE_ROOT47_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,47)
#define CCM_ACCESS_CTRL47                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,47)
#define CCM_ACCESS_CTRL_ROOT47_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,47)
#define CCM_ACCESS_CTRL_ROOT47_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,47)
#define CCM_ACCESS_CTRL_ROOT47_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,47)
#define CCM_TARGET_ROOT48                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,48)
#define CCM_TARGET_ROOT48_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,48)
#define CCM_TARGET_ROOT48_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,48)
#define CCM_TARGET_ROOT48_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,48)
#define CCM_MISC48                               CCM_MISC_REG(CCM_BASE_PTR,48)
#define CCM_MISC_ROOT48_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,48)
#define CCM_MISC_ROOT48_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,48)
#define CCM_MISC_ROOT48_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,48)
#define CCM_POST48                               CCM_POST_REG(CCM_BASE_PTR,48)
#define CCM_POST_ROOT48_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,48)
#define CCM_POST_ROOT48_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,48)
#define CCM_POST_ROOT48_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,48)
#define CCM_PRE48                                CCM_PRE_REG(CCM_BASE_PTR,48)
#define CCM_PRE_ROOT48_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,48)
#define CCM_PRE_ROOT48_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,48)
#define CCM_PRE_ROOT48_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,48)
#define CCM_ACCESS_CTRL48                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,48)
#define CCM_ACCESS_CTRL_ROOT48_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,48)
#define CCM_ACCESS_CTRL_ROOT48_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,48)
#define CCM_ACCESS_CTRL_ROOT48_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,48)
#define CCM_TARGET_ROOT49                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,49)
#define CCM_TARGET_ROOT49_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,49)
#define CCM_TARGET_ROOT49_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,49)
#define CCM_TARGET_ROOT49_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,49)
#define CCM_MISC49                               CCM_MISC_REG(CCM_BASE_PTR,49)
#define CCM_MISC_ROOT49_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,49)
#define CCM_MISC_ROOT49_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,49)
#define CCM_MISC_ROOT49_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,49)
#define CCM_POST49                               CCM_POST_REG(CCM_BASE_PTR,49)
#define CCM_POST_ROOT49_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,49)
#define CCM_POST_ROOT49_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,49)
#define CCM_POST_ROOT49_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,49)
#define CCM_PRE49                                CCM_PRE_REG(CCM_BASE_PTR,49)
#define CCM_PRE_ROOT49_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,49)
#define CCM_PRE_ROOT49_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,49)
#define CCM_PRE_ROOT49_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,49)
#define CCM_ACCESS_CTRL49                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,49)
#define CCM_ACCESS_CTRL_ROOT49_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,49)
#define CCM_ACCESS_CTRL_ROOT49_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,49)
#define CCM_ACCESS_CTRL_ROOT49_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,49)
#define CCM_TARGET_ROOT50                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,50)
#define CCM_TARGET_ROOT50_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,50)
#define CCM_TARGET_ROOT50_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,50)
#define CCM_TARGET_ROOT50_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,50)
#define CCM_MISC50                               CCM_MISC_REG(CCM_BASE_PTR,50)
#define CCM_MISC_ROOT50_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,50)
#define CCM_MISC_ROOT50_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,50)
#define CCM_MISC_ROOT50_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,50)
#define CCM_POST50                               CCM_POST_REG(CCM_BASE_PTR,50)
#define CCM_POST_ROOT50_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,50)
#define CCM_POST_ROOT50_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,50)
#define CCM_POST_ROOT50_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,50)
#define CCM_PRE50                                CCM_PRE_REG(CCM_BASE_PTR,50)
#define CCM_PRE_ROOT50_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,50)
#define CCM_PRE_ROOT50_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,50)
#define CCM_PRE_ROOT50_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,50)
#define CCM_ACCESS_CTRL50                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,50)
#define CCM_ACCESS_CTRL_ROOT50_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,50)
#define CCM_ACCESS_CTRL_ROOT50_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,50)
#define CCM_ACCESS_CTRL_ROOT50_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,50)
#define CCM_TARGET_ROOT51                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,51)
#define CCM_TARGET_ROOT51_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,51)
#define CCM_TARGET_ROOT51_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,51)
#define CCM_TARGET_ROOT51_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,51)
#define CCM_MISC51                               CCM_MISC_REG(CCM_BASE_PTR,51)
#define CCM_MISC_ROOT51_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,51)
#define CCM_MISC_ROOT51_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,51)
#define CCM_MISC_ROOT51_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,51)
#define CCM_POST51                               CCM_POST_REG(CCM_BASE_PTR,51)
#define CCM_POST_ROOT51_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,51)
#define CCM_POST_ROOT51_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,51)
#define CCM_POST_ROOT51_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,51)
#define CCM_PRE51                                CCM_PRE_REG(CCM_BASE_PTR,51)
#define CCM_PRE_ROOT51_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,51)
#define CCM_PRE_ROOT51_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,51)
#define CCM_PRE_ROOT51_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,51)
#define CCM_ACCESS_CTRL51                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,51)
#define CCM_ACCESS_CTRL_ROOT51_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,51)
#define CCM_ACCESS_CTRL_ROOT51_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,51)
#define CCM_ACCESS_CTRL_ROOT51_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,51)
#define CCM_TARGET_ROOT52                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,52)
#define CCM_TARGET_ROOT52_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,52)
#define CCM_TARGET_ROOT52_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,52)
#define CCM_TARGET_ROOT52_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,52)
#define CCM_MISC52                               CCM_MISC_REG(CCM_BASE_PTR,52)
#define CCM_MISC_ROOT52_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,52)
#define CCM_MISC_ROOT52_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,52)
#define CCM_MISC_ROOT52_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,52)
#define CCM_POST52                               CCM_POST_REG(CCM_BASE_PTR,52)
#define CCM_POST_ROOT52_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,52)
#define CCM_POST_ROOT52_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,52)
#define CCM_POST_ROOT52_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,52)
#define CCM_PRE52                                CCM_PRE_REG(CCM_BASE_PTR,52)
#define CCM_PRE_ROOT52_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,52)
#define CCM_PRE_ROOT52_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,52)
#define CCM_PRE_ROOT52_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,52)
#define CCM_ACCESS_CTRL52                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,52)
#define CCM_ACCESS_CTRL_ROOT52_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,52)
#define CCM_ACCESS_CTRL_ROOT52_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,52)
#define CCM_ACCESS_CTRL_ROOT52_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,52)
#define CCM_TARGET_ROOT53                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,53)
#define CCM_TARGET_ROOT53_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,53)
#define CCM_TARGET_ROOT53_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,53)
#define CCM_TARGET_ROOT53_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,53)
#define CCM_MISC53                               CCM_MISC_REG(CCM_BASE_PTR,53)
#define CCM_MISC_ROOT53_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,53)
#define CCM_MISC_ROOT53_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,53)
#define CCM_MISC_ROOT53_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,53)
#define CCM_POST53                               CCM_POST_REG(CCM_BASE_PTR,53)
#define CCM_POST_ROOT53_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,53)
#define CCM_POST_ROOT53_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,53)
#define CCM_POST_ROOT53_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,53)
#define CCM_PRE53                                CCM_PRE_REG(CCM_BASE_PTR,53)
#define CCM_PRE_ROOT53_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,53)
#define CCM_PRE_ROOT53_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,53)
#define CCM_PRE_ROOT53_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,53)
#define CCM_ACCESS_CTRL53                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,53)
#define CCM_ACCESS_CTRL_ROOT53_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,53)
#define CCM_ACCESS_CTRL_ROOT53_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,53)
#define CCM_ACCESS_CTRL_ROOT53_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,53)
#define CCM_TARGET_ROOT54                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,54)
#define CCM_TARGET_ROOT54_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,54)
#define CCM_TARGET_ROOT54_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,54)
#define CCM_TARGET_ROOT54_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,54)
#define CCM_MISC54                               CCM_MISC_REG(CCM_BASE_PTR,54)
#define CCM_MISC_ROOT54_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,54)
#define CCM_MISC_ROOT54_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,54)
#define CCM_MISC_ROOT54_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,54)
#define CCM_POST54                               CCM_POST_REG(CCM_BASE_PTR,54)
#define CCM_POST_ROOT54_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,54)
#define CCM_POST_ROOT54_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,54)
#define CCM_POST_ROOT54_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,54)
#define CCM_PRE54                                CCM_PRE_REG(CCM_BASE_PTR,54)
#define CCM_PRE_ROOT54_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,54)
#define CCM_PRE_ROOT54_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,54)
#define CCM_PRE_ROOT54_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,54)
#define CCM_ACCESS_CTRL54                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,54)
#define CCM_ACCESS_CTRL_ROOT54_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,54)
#define CCM_ACCESS_CTRL_ROOT54_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,54)
#define CCM_ACCESS_CTRL_ROOT54_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,54)
#define CCM_TARGET_ROOT55                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,55)
#define CCM_TARGET_ROOT55_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,55)
#define CCM_TARGET_ROOT55_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,55)
#define CCM_TARGET_ROOT55_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,55)
#define CCM_MISC55                               CCM_MISC_REG(CCM_BASE_PTR,55)
#define CCM_MISC_ROOT55_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,55)
#define CCM_MISC_ROOT55_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,55)
#define CCM_MISC_ROOT55_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,55)
#define CCM_POST55                               CCM_POST_REG(CCM_BASE_PTR,55)
#define CCM_POST_ROOT55_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,55)
#define CCM_POST_ROOT55_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,55)
#define CCM_POST_ROOT55_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,55)
#define CCM_PRE55                                CCM_PRE_REG(CCM_BASE_PTR,55)
#define CCM_PRE_ROOT55_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,55)
#define CCM_PRE_ROOT55_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,55)
#define CCM_PRE_ROOT55_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,55)
#define CCM_ACCESS_CTRL55                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,55)
#define CCM_ACCESS_CTRL_ROOT55_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,55)
#define CCM_ACCESS_CTRL_ROOT55_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,55)
#define CCM_ACCESS_CTRL_ROOT55_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,55)
#define CCM_TARGET_ROOT56                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,56)
#define CCM_TARGET_ROOT56_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,56)
#define CCM_TARGET_ROOT56_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,56)
#define CCM_TARGET_ROOT56_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,56)
#define CCM_MISC56                               CCM_MISC_REG(CCM_BASE_PTR,56)
#define CCM_MISC_ROOT56_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,56)
#define CCM_MISC_ROOT56_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,56)
#define CCM_MISC_ROOT56_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,56)
#define CCM_POST56                               CCM_POST_REG(CCM_BASE_PTR,56)
#define CCM_POST_ROOT56_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,56)
#define CCM_POST_ROOT56_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,56)
#define CCM_POST_ROOT56_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,56)
#define CCM_PRE56                                CCM_PRE_REG(CCM_BASE_PTR,56)
#define CCM_PRE_ROOT56_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,56)
#define CCM_PRE_ROOT56_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,56)
#define CCM_PRE_ROOT56_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,56)
#define CCM_ACCESS_CTRL56                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,56)
#define CCM_ACCESS_CTRL_ROOT56_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,56)
#define CCM_ACCESS_CTRL_ROOT56_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,56)
#define CCM_ACCESS_CTRL_ROOT56_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,56)
#define CCM_TARGET_ROOT57                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,57)
#define CCM_TARGET_ROOT57_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,57)
#define CCM_TARGET_ROOT57_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,57)
#define CCM_TARGET_ROOT57_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,57)
#define CCM_MISC57                               CCM_MISC_REG(CCM_BASE_PTR,57)
#define CCM_MISC_ROOT57_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,57)
#define CCM_MISC_ROOT57_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,57)
#define CCM_MISC_ROOT57_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,57)
#define CCM_POST57                               CCM_POST_REG(CCM_BASE_PTR,57)
#define CCM_POST_ROOT57_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,57)
#define CCM_POST_ROOT57_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,57)
#define CCM_POST_ROOT57_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,57)
#define CCM_PRE57                                CCM_PRE_REG(CCM_BASE_PTR,57)
#define CCM_PRE_ROOT57_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,57)
#define CCM_PRE_ROOT57_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,57)
#define CCM_PRE_ROOT57_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,57)
#define CCM_ACCESS_CTRL57                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,57)
#define CCM_ACCESS_CTRL_ROOT57_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,57)
#define CCM_ACCESS_CTRL_ROOT57_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,57)
#define CCM_ACCESS_CTRL_ROOT57_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,57)
#define CCM_TARGET_ROOT58                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,58)
#define CCM_TARGET_ROOT58_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,58)
#define CCM_TARGET_ROOT58_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,58)
#define CCM_TARGET_ROOT58_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,58)
#define CCM_MISC58                               CCM_MISC_REG(CCM_BASE_PTR,58)
#define CCM_MISC_ROOT58_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,58)
#define CCM_MISC_ROOT58_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,58)
#define CCM_MISC_ROOT58_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,58)
#define CCM_POST58                               CCM_POST_REG(CCM_BASE_PTR,58)
#define CCM_POST_ROOT58_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,58)
#define CCM_POST_ROOT58_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,58)
#define CCM_POST_ROOT58_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,58)
#define CCM_PRE58                                CCM_PRE_REG(CCM_BASE_PTR,58)
#define CCM_PRE_ROOT58_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,58)
#define CCM_PRE_ROOT58_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,58)
#define CCM_PRE_ROOT58_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,58)
#define CCM_ACCESS_CTRL58                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,58)
#define CCM_ACCESS_CTRL_ROOT58_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,58)
#define CCM_ACCESS_CTRL_ROOT58_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,58)
#define CCM_ACCESS_CTRL_ROOT58_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,58)
#define CCM_TARGET_ROOT59                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,59)
#define CCM_TARGET_ROOT59_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,59)
#define CCM_TARGET_ROOT59_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,59)
#define CCM_TARGET_ROOT59_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,59)
#define CCM_MISC59                               CCM_MISC_REG(CCM_BASE_PTR,59)
#define CCM_MISC_ROOT59_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,59)
#define CCM_MISC_ROOT59_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,59)
#define CCM_MISC_ROOT59_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,59)
#define CCM_POST59                               CCM_POST_REG(CCM_BASE_PTR,59)
#define CCM_POST_ROOT59_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,59)
#define CCM_POST_ROOT59_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,59)
#define CCM_POST_ROOT59_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,59)
#define CCM_PRE59                                CCM_PRE_REG(CCM_BASE_PTR,59)
#define CCM_PRE_ROOT59_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,59)
#define CCM_PRE_ROOT59_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,59)
#define CCM_PRE_ROOT59_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,59)
#define CCM_ACCESS_CTRL59                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,59)
#define CCM_ACCESS_CTRL_ROOT59_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,59)
#define CCM_ACCESS_CTRL_ROOT59_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,59)
#define CCM_ACCESS_CTRL_ROOT59_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,59)
#define CCM_TARGET_ROOT60                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,60)
#define CCM_TARGET_ROOT60_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,60)
#define CCM_TARGET_ROOT60_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,60)
#define CCM_TARGET_ROOT60_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,60)
#define CCM_MISC60                               CCM_MISC_REG(CCM_BASE_PTR,60)
#define CCM_MISC_ROOT60_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,60)
#define CCM_MISC_ROOT60_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,60)
#define CCM_MISC_ROOT60_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,60)
#define CCM_POST60                               CCM_POST_REG(CCM_BASE_PTR,60)
#define CCM_POST_ROOT60_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,60)
#define CCM_POST_ROOT60_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,60)
#define CCM_POST_ROOT60_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,60)
#define CCM_PRE60                                CCM_PRE_REG(CCM_BASE_PTR,60)
#define CCM_PRE_ROOT60_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,60)
#define CCM_PRE_ROOT60_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,60)
#define CCM_PRE_ROOT60_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,60)
#define CCM_ACCESS_CTRL60                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,60)
#define CCM_ACCESS_CTRL_ROOT60_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,60)
#define CCM_ACCESS_CTRL_ROOT60_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,60)
#define CCM_ACCESS_CTRL_ROOT60_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,60)
#define CCM_TARGET_ROOT61                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,61)
#define CCM_TARGET_ROOT61_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,61)
#define CCM_TARGET_ROOT61_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,61)
#define CCM_TARGET_ROOT61_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,61)
#define CCM_MISC61                               CCM_MISC_REG(CCM_BASE_PTR,61)
#define CCM_MISC_ROOT61_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,61)
#define CCM_MISC_ROOT61_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,61)
#define CCM_MISC_ROOT61_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,61)
#define CCM_POST61                               CCM_POST_REG(CCM_BASE_PTR,61)
#define CCM_POST_ROOT61_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,61)
#define CCM_POST_ROOT61_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,61)
#define CCM_POST_ROOT61_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,61)
#define CCM_PRE61                                CCM_PRE_REG(CCM_BASE_PTR,61)
#define CCM_PRE_ROOT61_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,61)
#define CCM_PRE_ROOT61_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,61)
#define CCM_PRE_ROOT61_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,61)
#define CCM_ACCESS_CTRL61                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,61)
#define CCM_ACCESS_CTRL_ROOT61_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,61)
#define CCM_ACCESS_CTRL_ROOT61_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,61)
#define CCM_ACCESS_CTRL_ROOT61_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,61)
#define CCM_TARGET_ROOT62                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,62)
#define CCM_TARGET_ROOT62_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,62)
#define CCM_TARGET_ROOT62_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,62)
#define CCM_TARGET_ROOT62_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,62)
#define CCM_MISC62                               CCM_MISC_REG(CCM_BASE_PTR,62)
#define CCM_MISC_ROOT62_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,62)
#define CCM_MISC_ROOT62_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,62)
#define CCM_MISC_ROOT62_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,62)
#define CCM_POST62                               CCM_POST_REG(CCM_BASE_PTR,62)
#define CCM_POST_ROOT62_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,62)
#define CCM_POST_ROOT62_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,62)
#define CCM_POST_ROOT62_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,62)
#define CCM_PRE62                                CCM_PRE_REG(CCM_BASE_PTR,62)
#define CCM_PRE_ROOT62_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,62)
#define CCM_PRE_ROOT62_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,62)
#define CCM_PRE_ROOT62_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,62)
#define CCM_ACCESS_CTRL62                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,62)
#define CCM_ACCESS_CTRL_ROOT62_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,62)
#define CCM_ACCESS_CTRL_ROOT62_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,62)
#define CCM_ACCESS_CTRL_ROOT62_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,62)
#define CCM_TARGET_ROOT63                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,63)
#define CCM_TARGET_ROOT63_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,63)
#define CCM_TARGET_ROOT63_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,63)
#define CCM_TARGET_ROOT63_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,63)
#define CCM_MISC63                               CCM_MISC_REG(CCM_BASE_PTR,63)
#define CCM_MISC_ROOT63_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,63)
#define CCM_MISC_ROOT63_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,63)
#define CCM_MISC_ROOT63_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,63)
#define CCM_POST63                               CCM_POST_REG(CCM_BASE_PTR,63)
#define CCM_POST_ROOT63_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,63)
#define CCM_POST_ROOT63_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,63)
#define CCM_POST_ROOT63_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,63)
#define CCM_PRE63                                CCM_PRE_REG(CCM_BASE_PTR,63)
#define CCM_PRE_ROOT63_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,63)
#define CCM_PRE_ROOT63_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,63)
#define CCM_PRE_ROOT63_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,63)
#define CCM_ACCESS_CTRL63                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,63)
#define CCM_ACCESS_CTRL_ROOT63_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,63)
#define CCM_ACCESS_CTRL_ROOT63_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,63)
#define CCM_ACCESS_CTRL_ROOT63_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,63)
#define CCM_TARGET_ROOT64                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,64)
#define CCM_TARGET_ROOT64_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,64)
#define CCM_TARGET_ROOT64_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,64)
#define CCM_TARGET_ROOT64_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,64)
#define CCM_MISC64                               CCM_MISC_REG(CCM_BASE_PTR,64)
#define CCM_MISC_ROOT64_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,64)
#define CCM_MISC_ROOT64_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,64)
#define CCM_MISC_ROOT64_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,64)
#define CCM_POST64                               CCM_POST_REG(CCM_BASE_PTR,64)
#define CCM_POST_ROOT64_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,64)
#define CCM_POST_ROOT64_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,64)
#define CCM_POST_ROOT64_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,64)
#define CCM_PRE64                                CCM_PRE_REG(CCM_BASE_PTR,64)
#define CCM_PRE_ROOT64_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,64)
#define CCM_PRE_ROOT64_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,64)
#define CCM_PRE_ROOT64_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,64)
#define CCM_ACCESS_CTRL64                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,64)
#define CCM_ACCESS_CTRL_ROOT64_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,64)
#define CCM_ACCESS_CTRL_ROOT64_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,64)
#define CCM_ACCESS_CTRL_ROOT64_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,64)
#define CCM_TARGET_ROOT65                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,65)
#define CCM_TARGET_ROOT65_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,65)
#define CCM_TARGET_ROOT65_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,65)
#define CCM_TARGET_ROOT65_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,65)
#define CCM_MISC65                               CCM_MISC_REG(CCM_BASE_PTR,65)
#define CCM_MISC_ROOT65_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,65)
#define CCM_MISC_ROOT65_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,65)
#define CCM_MISC_ROOT65_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,65)
#define CCM_POST65                               CCM_POST_REG(CCM_BASE_PTR,65)
#define CCM_POST_ROOT65_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,65)
#define CCM_POST_ROOT65_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,65)
#define CCM_POST_ROOT65_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,65)
#define CCM_PRE65                                CCM_PRE_REG(CCM_BASE_PTR,65)
#define CCM_PRE_ROOT65_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,65)
#define CCM_PRE_ROOT65_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,65)
#define CCM_PRE_ROOT65_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,65)
#define CCM_ACCESS_CTRL65                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,65)
#define CCM_ACCESS_CTRL_ROOT65_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,65)
#define CCM_ACCESS_CTRL_ROOT65_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,65)
#define CCM_ACCESS_CTRL_ROOT65_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,65)
#define CCM_TARGET_ROOT66                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,66)
#define CCM_TARGET_ROOT66_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,66)
#define CCM_TARGET_ROOT66_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,66)
#define CCM_TARGET_ROOT66_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,66)
#define CCM_MISC66                               CCM_MISC_REG(CCM_BASE_PTR,66)
#define CCM_MISC_ROOT66_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,66)
#define CCM_MISC_ROOT66_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,66)
#define CCM_MISC_ROOT66_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,66)
#define CCM_POST66                               CCM_POST_REG(CCM_BASE_PTR,66)
#define CCM_POST_ROOT66_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,66)
#define CCM_POST_ROOT66_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,66)
#define CCM_POST_ROOT66_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,66)
#define CCM_PRE66                                CCM_PRE_REG(CCM_BASE_PTR,66)
#define CCM_PRE_ROOT66_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,66)
#define CCM_PRE_ROOT66_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,66)
#define CCM_PRE_ROOT66_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,66)
#define CCM_ACCESS_CTRL66                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,66)
#define CCM_ACCESS_CTRL_ROOT66_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,66)
#define CCM_ACCESS_CTRL_ROOT66_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,66)
#define CCM_ACCESS_CTRL_ROOT66_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,66)
#define CCM_TARGET_ROOT67                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,67)
#define CCM_TARGET_ROOT67_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,67)
#define CCM_TARGET_ROOT67_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,67)
#define CCM_TARGET_ROOT67_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,67)
#define CCM_MISC67                               CCM_MISC_REG(CCM_BASE_PTR,67)
#define CCM_MISC_ROOT67_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,67)
#define CCM_MISC_ROOT67_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,67)
#define CCM_MISC_ROOT67_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,67)
#define CCM_POST67                               CCM_POST_REG(CCM_BASE_PTR,67)
#define CCM_POST_ROOT67_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,67)
#define CCM_POST_ROOT67_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,67)
#define CCM_POST_ROOT67_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,67)
#define CCM_PRE67                                CCM_PRE_REG(CCM_BASE_PTR,67)
#define CCM_PRE_ROOT67_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,67)
#define CCM_PRE_ROOT67_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,67)
#define CCM_PRE_ROOT67_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,67)
#define CCM_ACCESS_CTRL67                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,67)
#define CCM_ACCESS_CTRL_ROOT67_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,67)
#define CCM_ACCESS_CTRL_ROOT67_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,67)
#define CCM_ACCESS_CTRL_ROOT67_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,67)
#define CCM_TARGET_ROOT68                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,68)
#define CCM_TARGET_ROOT68_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,68)
#define CCM_TARGET_ROOT68_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,68)
#define CCM_TARGET_ROOT68_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,68)
#define CCM_MISC68                               CCM_MISC_REG(CCM_BASE_PTR,68)
#define CCM_MISC_ROOT68_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,68)
#define CCM_MISC_ROOT68_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,68)
#define CCM_MISC_ROOT68_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,68)
#define CCM_POST68                               CCM_POST_REG(CCM_BASE_PTR,68)
#define CCM_POST_ROOT68_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,68)
#define CCM_POST_ROOT68_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,68)
#define CCM_POST_ROOT68_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,68)
#define CCM_PRE68                                CCM_PRE_REG(CCM_BASE_PTR,68)
#define CCM_PRE_ROOT68_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,68)
#define CCM_PRE_ROOT68_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,68)
#define CCM_PRE_ROOT68_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,68)
#define CCM_ACCESS_CTRL68                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,68)
#define CCM_ACCESS_CTRL_ROOT68_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,68)
#define CCM_ACCESS_CTRL_ROOT68_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,68)
#define CCM_ACCESS_CTRL_ROOT68_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,68)
#define CCM_TARGET_ROOT69                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,69)
#define CCM_TARGET_ROOT69_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,69)
#define CCM_TARGET_ROOT69_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,69)
#define CCM_TARGET_ROOT69_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,69)
#define CCM_MISC69                               CCM_MISC_REG(CCM_BASE_PTR,69)
#define CCM_MISC_ROOT69_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,69)
#define CCM_MISC_ROOT69_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,69)
#define CCM_MISC_ROOT69_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,69)
#define CCM_POST69                               CCM_POST_REG(CCM_BASE_PTR,69)
#define CCM_POST_ROOT69_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,69)
#define CCM_POST_ROOT69_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,69)
#define CCM_POST_ROOT69_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,69)
#define CCM_PRE69                                CCM_PRE_REG(CCM_BASE_PTR,69)
#define CCM_PRE_ROOT69_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,69)
#define CCM_PRE_ROOT69_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,69)
#define CCM_PRE_ROOT69_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,69)
#define CCM_ACCESS_CTRL69                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,69)
#define CCM_ACCESS_CTRL_ROOT69_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,69)
#define CCM_ACCESS_CTRL_ROOT69_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,69)
#define CCM_ACCESS_CTRL_ROOT69_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,69)
#define CCM_TARGET_ROOT70                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,70)
#define CCM_TARGET_ROOT70_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,70)
#define CCM_TARGET_ROOT70_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,70)
#define CCM_TARGET_ROOT70_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,70)
#define CCM_MISC70                               CCM_MISC_REG(CCM_BASE_PTR,70)
#define CCM_MISC_ROOT70_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,70)
#define CCM_MISC_ROOT70_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,70)
#define CCM_MISC_ROOT70_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,70)
#define CCM_POST70                               CCM_POST_REG(CCM_BASE_PTR,70)
#define CCM_POST_ROOT70_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,70)
#define CCM_POST_ROOT70_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,70)
#define CCM_POST_ROOT70_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,70)
#define CCM_PRE70                                CCM_PRE_REG(CCM_BASE_PTR,70)
#define CCM_PRE_ROOT70_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,70)
#define CCM_PRE_ROOT70_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,70)
#define CCM_PRE_ROOT70_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,70)
#define CCM_ACCESS_CTRL70                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,70)
#define CCM_ACCESS_CTRL_ROOT70_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,70)
#define CCM_ACCESS_CTRL_ROOT70_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,70)
#define CCM_ACCESS_CTRL_ROOT70_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,70)
#define CCM_TARGET_ROOT71                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,71)
#define CCM_TARGET_ROOT71_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,71)
#define CCM_TARGET_ROOT71_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,71)
#define CCM_TARGET_ROOT71_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,71)
#define CCM_MISC71                               CCM_MISC_REG(CCM_BASE_PTR,71)
#define CCM_MISC_ROOT71_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,71)
#define CCM_MISC_ROOT71_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,71)
#define CCM_MISC_ROOT71_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,71)
#define CCM_POST71                               CCM_POST_REG(CCM_BASE_PTR,71)
#define CCM_POST_ROOT71_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,71)
#define CCM_POST_ROOT71_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,71)
#define CCM_POST_ROOT71_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,71)
#define CCM_PRE71                                CCM_PRE_REG(CCM_BASE_PTR,71)
#define CCM_PRE_ROOT71_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,71)
#define CCM_PRE_ROOT71_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,71)
#define CCM_PRE_ROOT71_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,71)
#define CCM_ACCESS_CTRL71                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,71)
#define CCM_ACCESS_CTRL_ROOT71_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,71)
#define CCM_ACCESS_CTRL_ROOT71_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,71)
#define CCM_ACCESS_CTRL_ROOT71_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,71)
#define CCM_TARGET_ROOT72                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,72)
#define CCM_TARGET_ROOT72_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,72)
#define CCM_TARGET_ROOT72_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,72)
#define CCM_TARGET_ROOT72_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,72)
#define CCM_MISC72                               CCM_MISC_REG(CCM_BASE_PTR,72)
#define CCM_MISC_ROOT72_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,72)
#define CCM_MISC_ROOT72_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,72)
#define CCM_MISC_ROOT72_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,72)
#define CCM_POST72                               CCM_POST_REG(CCM_BASE_PTR,72)
#define CCM_POST_ROOT72_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,72)
#define CCM_POST_ROOT72_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,72)
#define CCM_POST_ROOT72_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,72)
#define CCM_PRE72                                CCM_PRE_REG(CCM_BASE_PTR,72)
#define CCM_PRE_ROOT72_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,72)
#define CCM_PRE_ROOT72_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,72)
#define CCM_PRE_ROOT72_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,72)
#define CCM_ACCESS_CTRL72                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,72)
#define CCM_ACCESS_CTRL_ROOT72_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,72)
#define CCM_ACCESS_CTRL_ROOT72_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,72)
#define CCM_ACCESS_CTRL_ROOT72_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,72)
#define CCM_TARGET_ROOT73                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,73)
#define CCM_TARGET_ROOT73_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,73)
#define CCM_TARGET_ROOT73_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,73)
#define CCM_TARGET_ROOT73_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,73)
#define CCM_MISC73                               CCM_MISC_REG(CCM_BASE_PTR,73)
#define CCM_MISC_ROOT73_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,73)
#define CCM_MISC_ROOT73_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,73)
#define CCM_MISC_ROOT73_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,73)
#define CCM_POST73                               CCM_POST_REG(CCM_BASE_PTR,73)
#define CCM_POST_ROOT73_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,73)
#define CCM_POST_ROOT73_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,73)
#define CCM_POST_ROOT73_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,73)
#define CCM_PRE73                                CCM_PRE_REG(CCM_BASE_PTR,73)
#define CCM_PRE_ROOT73_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,73)
#define CCM_PRE_ROOT73_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,73)
#define CCM_PRE_ROOT73_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,73)
#define CCM_ACCESS_CTRL73                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,73)
#define CCM_ACCESS_CTRL_ROOT73_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,73)
#define CCM_ACCESS_CTRL_ROOT73_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,73)
#define CCM_ACCESS_CTRL_ROOT73_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,73)
#define CCM_TARGET_ROOT74                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,74)
#define CCM_TARGET_ROOT74_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,74)
#define CCM_TARGET_ROOT74_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,74)
#define CCM_TARGET_ROOT74_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,74)
#define CCM_MISC74                               CCM_MISC_REG(CCM_BASE_PTR,74)
#define CCM_MISC_ROOT74_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,74)
#define CCM_MISC_ROOT74_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,74)
#define CCM_MISC_ROOT74_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,74)
#define CCM_POST74                               CCM_POST_REG(CCM_BASE_PTR,74)
#define CCM_POST_ROOT74_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,74)
#define CCM_POST_ROOT74_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,74)
#define CCM_POST_ROOT74_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,74)
#define CCM_PRE74                                CCM_PRE_REG(CCM_BASE_PTR,74)
#define CCM_PRE_ROOT74_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,74)
#define CCM_PRE_ROOT74_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,74)
#define CCM_PRE_ROOT74_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,74)
#define CCM_ACCESS_CTRL74                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,74)
#define CCM_ACCESS_CTRL_ROOT74_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,74)
#define CCM_ACCESS_CTRL_ROOT74_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,74)
#define CCM_ACCESS_CTRL_ROOT74_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,74)
#define CCM_TARGET_ROOT75                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,75)
#define CCM_TARGET_ROOT75_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,75)
#define CCM_TARGET_ROOT75_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,75)
#define CCM_TARGET_ROOT75_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,75)
#define CCM_MISC75                               CCM_MISC_REG(CCM_BASE_PTR,75)
#define CCM_MISC_ROOT75_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,75)
#define CCM_MISC_ROOT75_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,75)
#define CCM_MISC_ROOT75_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,75)
#define CCM_POST75                               CCM_POST_REG(CCM_BASE_PTR,75)
#define CCM_POST_ROOT75_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,75)
#define CCM_POST_ROOT75_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,75)
#define CCM_POST_ROOT75_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,75)
#define CCM_PRE75                                CCM_PRE_REG(CCM_BASE_PTR,75)
#define CCM_PRE_ROOT75_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,75)
#define CCM_PRE_ROOT75_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,75)
#define CCM_PRE_ROOT75_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,75)
#define CCM_ACCESS_CTRL75                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,75)
#define CCM_ACCESS_CTRL_ROOT75_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,75)
#define CCM_ACCESS_CTRL_ROOT75_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,75)
#define CCM_ACCESS_CTRL_ROOT75_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,75)
#define CCM_TARGET_ROOT76                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,76)
#define CCM_TARGET_ROOT76_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,76)
#define CCM_TARGET_ROOT76_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,76)
#define CCM_TARGET_ROOT76_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,76)
#define CCM_MISC76                               CCM_MISC_REG(CCM_BASE_PTR,76)
#define CCM_MISC_ROOT76_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,76)
#define CCM_MISC_ROOT76_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,76)
#define CCM_MISC_ROOT76_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,76)
#define CCM_POST76                               CCM_POST_REG(CCM_BASE_PTR,76)
#define CCM_POST_ROOT76_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,76)
#define CCM_POST_ROOT76_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,76)
#define CCM_POST_ROOT76_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,76)
#define CCM_PRE76                                CCM_PRE_REG(CCM_BASE_PTR,76)
#define CCM_PRE_ROOT76_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,76)
#define CCM_PRE_ROOT76_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,76)
#define CCM_PRE_ROOT76_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,76)
#define CCM_ACCESS_CTRL76                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,76)
#define CCM_ACCESS_CTRL_ROOT76_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,76)
#define CCM_ACCESS_CTRL_ROOT76_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,76)
#define CCM_ACCESS_CTRL_ROOT76_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,76)
#define CCM_TARGET_ROOT77                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,77)
#define CCM_TARGET_ROOT77_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,77)
#define CCM_TARGET_ROOT77_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,77)
#define CCM_TARGET_ROOT77_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,77)
#define CCM_MISC77                               CCM_MISC_REG(CCM_BASE_PTR,77)
#define CCM_MISC_ROOT77_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,77)
#define CCM_MISC_ROOT77_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,77)
#define CCM_MISC_ROOT77_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,77)
#define CCM_POST77                               CCM_POST_REG(CCM_BASE_PTR,77)
#define CCM_POST_ROOT77_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,77)
#define CCM_POST_ROOT77_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,77)
#define CCM_POST_ROOT77_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,77)
#define CCM_PRE77                                CCM_PRE_REG(CCM_BASE_PTR,77)
#define CCM_PRE_ROOT77_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,77)
#define CCM_PRE_ROOT77_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,77)
#define CCM_PRE_ROOT77_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,77)
#define CCM_ACCESS_CTRL77                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,77)
#define CCM_ACCESS_CTRL_ROOT77_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,77)
#define CCM_ACCESS_CTRL_ROOT77_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,77)
#define CCM_ACCESS_CTRL_ROOT77_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,77)
#define CCM_TARGET_ROOT78                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,78)
#define CCM_TARGET_ROOT78_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,78)
#define CCM_TARGET_ROOT78_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,78)
#define CCM_TARGET_ROOT78_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,78)
#define CCM_MISC78                               CCM_MISC_REG(CCM_BASE_PTR,78)
#define CCM_MISC_ROOT78_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,78)
#define CCM_MISC_ROOT78_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,78)
#define CCM_MISC_ROOT78_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,78)
#define CCM_POST78                               CCM_POST_REG(CCM_BASE_PTR,78)
#define CCM_POST_ROOT78_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,78)
#define CCM_POST_ROOT78_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,78)
#define CCM_POST_ROOT78_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,78)
#define CCM_PRE78                                CCM_PRE_REG(CCM_BASE_PTR,78)
#define CCM_PRE_ROOT78_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,78)
#define CCM_PRE_ROOT78_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,78)
#define CCM_PRE_ROOT78_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,78)
#define CCM_ACCESS_CTRL78                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,78)
#define CCM_ACCESS_CTRL_ROOT78_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,78)
#define CCM_ACCESS_CTRL_ROOT78_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,78)
#define CCM_ACCESS_CTRL_ROOT78_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,78)
#define CCM_TARGET_ROOT79                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,79)
#define CCM_TARGET_ROOT79_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,79)
#define CCM_TARGET_ROOT79_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,79)
#define CCM_TARGET_ROOT79_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,79)
#define CCM_MISC79                               CCM_MISC_REG(CCM_BASE_PTR,79)
#define CCM_MISC_ROOT79_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,79)
#define CCM_MISC_ROOT79_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,79)
#define CCM_MISC_ROOT79_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,79)
#define CCM_POST79                               CCM_POST_REG(CCM_BASE_PTR,79)
#define CCM_POST_ROOT79_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,79)
#define CCM_POST_ROOT79_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,79)
#define CCM_POST_ROOT79_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,79)
#define CCM_PRE79                                CCM_PRE_REG(CCM_BASE_PTR,79)
#define CCM_PRE_ROOT79_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,79)
#define CCM_PRE_ROOT79_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,79)
#define CCM_PRE_ROOT79_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,79)
#define CCM_ACCESS_CTRL79                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,79)
#define CCM_ACCESS_CTRL_ROOT79_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,79)
#define CCM_ACCESS_CTRL_ROOT79_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,79)
#define CCM_ACCESS_CTRL_ROOT79_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,79)
#define CCM_TARGET_ROOT80                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,80)
#define CCM_TARGET_ROOT80_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,80)
#define CCM_TARGET_ROOT80_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,80)
#define CCM_TARGET_ROOT80_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,80)
#define CCM_MISC80                               CCM_MISC_REG(CCM_BASE_PTR,80)
#define CCM_MISC_ROOT80_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,80)
#define CCM_MISC_ROOT80_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,80)
#define CCM_MISC_ROOT80_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,80)
#define CCM_POST80                               CCM_POST_REG(CCM_BASE_PTR,80)
#define CCM_POST_ROOT80_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,80)
#define CCM_POST_ROOT80_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,80)
#define CCM_POST_ROOT80_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,80)
#define CCM_PRE80                                CCM_PRE_REG(CCM_BASE_PTR,80)
#define CCM_PRE_ROOT80_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,80)
#define CCM_PRE_ROOT80_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,80)
#define CCM_PRE_ROOT80_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,80)
#define CCM_ACCESS_CTRL80                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,80)
#define CCM_ACCESS_CTRL_ROOT80_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,80)
#define CCM_ACCESS_CTRL_ROOT80_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,80)
#define CCM_ACCESS_CTRL_ROOT80_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,80)
#define CCM_TARGET_ROOT81                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,81)
#define CCM_TARGET_ROOT81_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,81)
#define CCM_TARGET_ROOT81_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,81)
#define CCM_TARGET_ROOT81_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,81)
#define CCM_MISC81                               CCM_MISC_REG(CCM_BASE_PTR,81)
#define CCM_MISC_ROOT81_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,81)
#define CCM_MISC_ROOT81_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,81)
#define CCM_MISC_ROOT81_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,81)
#define CCM_POST81                               CCM_POST_REG(CCM_BASE_PTR,81)
#define CCM_POST_ROOT81_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,81)
#define CCM_POST_ROOT81_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,81)
#define CCM_POST_ROOT81_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,81)
#define CCM_PRE81                                CCM_PRE_REG(CCM_BASE_PTR,81)
#define CCM_PRE_ROOT81_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,81)
#define CCM_PRE_ROOT81_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,81)
#define CCM_PRE_ROOT81_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,81)
#define CCM_ACCESS_CTRL81                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,81)
#define CCM_ACCESS_CTRL_ROOT81_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,81)
#define CCM_ACCESS_CTRL_ROOT81_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,81)
#define CCM_ACCESS_CTRL_ROOT81_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,81)
#define CCM_TARGET_ROOT82                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,82)
#define CCM_TARGET_ROOT82_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,82)
#define CCM_TARGET_ROOT82_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,82)
#define CCM_TARGET_ROOT82_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,82)
#define CCM_MISC82                               CCM_MISC_REG(CCM_BASE_PTR,82)
#define CCM_MISC_ROOT82_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,82)
#define CCM_MISC_ROOT82_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,82)
#define CCM_MISC_ROOT82_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,82)
#define CCM_POST82                               CCM_POST_REG(CCM_BASE_PTR,82)
#define CCM_POST_ROOT82_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,82)
#define CCM_POST_ROOT82_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,82)
#define CCM_POST_ROOT82_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,82)
#define CCM_PRE82                                CCM_PRE_REG(CCM_BASE_PTR,82)
#define CCM_PRE_ROOT82_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,82)
#define CCM_PRE_ROOT82_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,82)
#define CCM_PRE_ROOT82_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,82)
#define CCM_ACCESS_CTRL82                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,82)
#define CCM_ACCESS_CTRL_ROOT82_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,82)
#define CCM_ACCESS_CTRL_ROOT82_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,82)
#define CCM_ACCESS_CTRL_ROOT82_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,82)
#define CCM_TARGET_ROOT83                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,83)
#define CCM_TARGET_ROOT83_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,83)
#define CCM_TARGET_ROOT83_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,83)
#define CCM_TARGET_ROOT83_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,83)
#define CCM_MISC83                               CCM_MISC_REG(CCM_BASE_PTR,83)
#define CCM_MISC_ROOT83_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,83)
#define CCM_MISC_ROOT83_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,83)
#define CCM_MISC_ROOT83_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,83)
#define CCM_POST83                               CCM_POST_REG(CCM_BASE_PTR,83)
#define CCM_POST_ROOT83_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,83)
#define CCM_POST_ROOT83_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,83)
#define CCM_POST_ROOT83_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,83)
#define CCM_PRE83                                CCM_PRE_REG(CCM_BASE_PTR,83)
#define CCM_PRE_ROOT83_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,83)
#define CCM_PRE_ROOT83_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,83)
#define CCM_PRE_ROOT83_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,83)
#define CCM_ACCESS_CTRL83                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,83)
#define CCM_ACCESS_CTRL_ROOT83_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,83)
#define CCM_ACCESS_CTRL_ROOT83_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,83)
#define CCM_ACCESS_CTRL_ROOT83_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,83)
#define CCM_TARGET_ROOT84                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,84)
#define CCM_TARGET_ROOT84_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,84)
#define CCM_TARGET_ROOT84_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,84)
#define CCM_TARGET_ROOT84_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,84)
#define CCM_MISC84                               CCM_MISC_REG(CCM_BASE_PTR,84)
#define CCM_MISC_ROOT84_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,84)
#define CCM_MISC_ROOT84_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,84)
#define CCM_MISC_ROOT84_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,84)
#define CCM_POST84                               CCM_POST_REG(CCM_BASE_PTR,84)
#define CCM_POST_ROOT84_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,84)
#define CCM_POST_ROOT84_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,84)
#define CCM_POST_ROOT84_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,84)
#define CCM_PRE84                                CCM_PRE_REG(CCM_BASE_PTR,84)
#define CCM_PRE_ROOT84_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,84)
#define CCM_PRE_ROOT84_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,84)
#define CCM_PRE_ROOT84_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,84)
#define CCM_ACCESS_CTRL84                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,84)
#define CCM_ACCESS_CTRL_ROOT84_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,84)
#define CCM_ACCESS_CTRL_ROOT84_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,84)
#define CCM_ACCESS_CTRL_ROOT84_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,84)
#define CCM_TARGET_ROOT85                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,85)
#define CCM_TARGET_ROOT85_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,85)
#define CCM_TARGET_ROOT85_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,85)
#define CCM_TARGET_ROOT85_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,85)
#define CCM_MISC85                               CCM_MISC_REG(CCM_BASE_PTR,85)
#define CCM_MISC_ROOT85_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,85)
#define CCM_MISC_ROOT85_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,85)
#define CCM_MISC_ROOT85_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,85)
#define CCM_POST85                               CCM_POST_REG(CCM_BASE_PTR,85)
#define CCM_POST_ROOT85_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,85)
#define CCM_POST_ROOT85_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,85)
#define CCM_POST_ROOT85_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,85)
#define CCM_PRE85                                CCM_PRE_REG(CCM_BASE_PTR,85)
#define CCM_PRE_ROOT85_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,85)
#define CCM_PRE_ROOT85_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,85)
#define CCM_PRE_ROOT85_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,85)
#define CCM_ACCESS_CTRL85                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,85)
#define CCM_ACCESS_CTRL_ROOT85_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,85)
#define CCM_ACCESS_CTRL_ROOT85_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,85)
#define CCM_ACCESS_CTRL_ROOT85_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,85)
#define CCM_TARGET_ROOT86                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,86)
#define CCM_TARGET_ROOT86_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,86)
#define CCM_TARGET_ROOT86_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,86)
#define CCM_TARGET_ROOT86_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,86)
#define CCM_MISC86                               CCM_MISC_REG(CCM_BASE_PTR,86)
#define CCM_MISC_ROOT86_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,86)
#define CCM_MISC_ROOT86_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,86)
#define CCM_MISC_ROOT86_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,86)
#define CCM_POST86                               CCM_POST_REG(CCM_BASE_PTR,86)
#define CCM_POST_ROOT86_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,86)
#define CCM_POST_ROOT86_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,86)
#define CCM_POST_ROOT86_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,86)
#define CCM_PRE86                                CCM_PRE_REG(CCM_BASE_PTR,86)
#define CCM_PRE_ROOT86_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,86)
#define CCM_PRE_ROOT86_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,86)
#define CCM_PRE_ROOT86_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,86)
#define CCM_ACCESS_CTRL86                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,86)
#define CCM_ACCESS_CTRL_ROOT86_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,86)
#define CCM_ACCESS_CTRL_ROOT86_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,86)
#define CCM_ACCESS_CTRL_ROOT86_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,86)
#define CCM_TARGET_ROOT87                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,87)
#define CCM_TARGET_ROOT87_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,87)
#define CCM_TARGET_ROOT87_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,87)
#define CCM_TARGET_ROOT87_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,87)
#define CCM_MISC87                               CCM_MISC_REG(CCM_BASE_PTR,87)
#define CCM_MISC_ROOT87_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,87)
#define CCM_MISC_ROOT87_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,87)
#define CCM_MISC_ROOT87_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,87)
#define CCM_POST87                               CCM_POST_REG(CCM_BASE_PTR,87)
#define CCM_POST_ROOT87_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,87)
#define CCM_POST_ROOT87_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,87)
#define CCM_POST_ROOT87_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,87)
#define CCM_PRE87                                CCM_PRE_REG(CCM_BASE_PTR,87)
#define CCM_PRE_ROOT87_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,87)
#define CCM_PRE_ROOT87_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,87)
#define CCM_PRE_ROOT87_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,87)
#define CCM_ACCESS_CTRL87                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,87)
#define CCM_ACCESS_CTRL_ROOT87_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,87)
#define CCM_ACCESS_CTRL_ROOT87_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,87)
#define CCM_ACCESS_CTRL_ROOT87_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,87)
#define CCM_TARGET_ROOT88                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,88)
#define CCM_TARGET_ROOT88_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,88)
#define CCM_TARGET_ROOT88_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,88)
#define CCM_TARGET_ROOT88_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,88)
#define CCM_MISC88                               CCM_MISC_REG(CCM_BASE_PTR,88)
#define CCM_MISC_ROOT88_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,88)
#define CCM_MISC_ROOT88_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,88)
#define CCM_MISC_ROOT88_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,88)
#define CCM_POST88                               CCM_POST_REG(CCM_BASE_PTR,88)
#define CCM_POST_ROOT88_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,88)
#define CCM_POST_ROOT88_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,88)
#define CCM_POST_ROOT88_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,88)
#define CCM_PRE88                                CCM_PRE_REG(CCM_BASE_PTR,88)
#define CCM_PRE_ROOT88_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,88)
#define CCM_PRE_ROOT88_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,88)
#define CCM_PRE_ROOT88_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,88)
#define CCM_ACCESS_CTRL88                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,88)
#define CCM_ACCESS_CTRL_ROOT88_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,88)
#define CCM_ACCESS_CTRL_ROOT88_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,88)
#define CCM_ACCESS_CTRL_ROOT88_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,88)
#define CCM_TARGET_ROOT89                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,89)
#define CCM_TARGET_ROOT89_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,89)
#define CCM_TARGET_ROOT89_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,89)
#define CCM_TARGET_ROOT89_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,89)
#define CCM_MISC89                               CCM_MISC_REG(CCM_BASE_PTR,89)
#define CCM_MISC_ROOT89_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,89)
#define CCM_MISC_ROOT89_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,89)
#define CCM_MISC_ROOT89_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,89)
#define CCM_POST89                               CCM_POST_REG(CCM_BASE_PTR,89)
#define CCM_POST_ROOT89_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,89)
#define CCM_POST_ROOT89_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,89)
#define CCM_POST_ROOT89_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,89)
#define CCM_PRE89                                CCM_PRE_REG(CCM_BASE_PTR,89)
#define CCM_PRE_ROOT89_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,89)
#define CCM_PRE_ROOT89_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,89)
#define CCM_PRE_ROOT89_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,89)
#define CCM_ACCESS_CTRL89                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,89)
#define CCM_ACCESS_CTRL_ROOT89_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,89)
#define CCM_ACCESS_CTRL_ROOT89_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,89)
#define CCM_ACCESS_CTRL_ROOT89_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,89)
#define CCM_TARGET_ROOT90                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,90)
#define CCM_TARGET_ROOT90_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,90)
#define CCM_TARGET_ROOT90_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,90)
#define CCM_TARGET_ROOT90_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,90)
#define CCM_MISC90                               CCM_MISC_REG(CCM_BASE_PTR,90)
#define CCM_MISC_ROOT90_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,90)
#define CCM_MISC_ROOT90_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,90)
#define CCM_MISC_ROOT90_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,90)
#define CCM_POST90                               CCM_POST_REG(CCM_BASE_PTR,90)
#define CCM_POST_ROOT90_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,90)
#define CCM_POST_ROOT90_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,90)
#define CCM_POST_ROOT90_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,90)
#define CCM_PRE90                                CCM_PRE_REG(CCM_BASE_PTR,90)
#define CCM_PRE_ROOT90_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,90)
#define CCM_PRE_ROOT90_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,90)
#define CCM_PRE_ROOT90_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,90)
#define CCM_ACCESS_CTRL90                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,90)
#define CCM_ACCESS_CTRL_ROOT90_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,90)
#define CCM_ACCESS_CTRL_ROOT90_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,90)
#define CCM_ACCESS_CTRL_ROOT90_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,90)
#define CCM_TARGET_ROOT91                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,91)
#define CCM_TARGET_ROOT91_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,91)
#define CCM_TARGET_ROOT91_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,91)
#define CCM_TARGET_ROOT91_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,91)
#define CCM_MISC91                               CCM_MISC_REG(CCM_BASE_PTR,91)
#define CCM_MISC_ROOT91_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,91)
#define CCM_MISC_ROOT91_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,91)
#define CCM_MISC_ROOT91_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,91)
#define CCM_POST91                               CCM_POST_REG(CCM_BASE_PTR,91)
#define CCM_POST_ROOT91_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,91)
#define CCM_POST_ROOT91_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,91)
#define CCM_POST_ROOT91_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,91)
#define CCM_PRE91                                CCM_PRE_REG(CCM_BASE_PTR,91)
#define CCM_PRE_ROOT91_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,91)
#define CCM_PRE_ROOT91_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,91)
#define CCM_PRE_ROOT91_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,91)
#define CCM_ACCESS_CTRL91                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,91)
#define CCM_ACCESS_CTRL_ROOT91_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,91)
#define CCM_ACCESS_CTRL_ROOT91_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,91)
#define CCM_ACCESS_CTRL_ROOT91_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,91)
#define CCM_TARGET_ROOT92                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,92)
#define CCM_TARGET_ROOT92_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,92)
#define CCM_TARGET_ROOT92_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,92)
#define CCM_TARGET_ROOT92_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,92)
#define CCM_MISC92                               CCM_MISC_REG(CCM_BASE_PTR,92)
#define CCM_MISC_ROOT92_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,92)
#define CCM_MISC_ROOT92_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,92)
#define CCM_MISC_ROOT92_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,92)
#define CCM_POST92                               CCM_POST_REG(CCM_BASE_PTR,92)
#define CCM_POST_ROOT92_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,92)
#define CCM_POST_ROOT92_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,92)
#define CCM_POST_ROOT92_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,92)
#define CCM_PRE92                                CCM_PRE_REG(CCM_BASE_PTR,92)
#define CCM_PRE_ROOT92_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,92)
#define CCM_PRE_ROOT92_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,92)
#define CCM_PRE_ROOT92_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,92)
#define CCM_ACCESS_CTRL92                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,92)
#define CCM_ACCESS_CTRL_ROOT92_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,92)
#define CCM_ACCESS_CTRL_ROOT92_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,92)
#define CCM_ACCESS_CTRL_ROOT92_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,92)
#define CCM_TARGET_ROOT93                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,93)
#define CCM_TARGET_ROOT93_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,93)
#define CCM_TARGET_ROOT93_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,93)
#define CCM_TARGET_ROOT93_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,93)
#define CCM_MISC93                               CCM_MISC_REG(CCM_BASE_PTR,93)
#define CCM_MISC_ROOT93_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,93)
#define CCM_MISC_ROOT93_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,93)
#define CCM_MISC_ROOT93_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,93)
#define CCM_POST93                               CCM_POST_REG(CCM_BASE_PTR,93)
#define CCM_POST_ROOT93_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,93)
#define CCM_POST_ROOT93_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,93)
#define CCM_POST_ROOT93_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,93)
#define CCM_PRE93                                CCM_PRE_REG(CCM_BASE_PTR,93)
#define CCM_PRE_ROOT93_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,93)
#define CCM_PRE_ROOT93_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,93)
#define CCM_PRE_ROOT93_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,93)
#define CCM_ACCESS_CTRL93                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,93)
#define CCM_ACCESS_CTRL_ROOT93_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,93)
#define CCM_ACCESS_CTRL_ROOT93_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,93)
#define CCM_ACCESS_CTRL_ROOT93_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,93)
#define CCM_TARGET_ROOT94                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,94)
#define CCM_TARGET_ROOT94_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,94)
#define CCM_TARGET_ROOT94_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,94)
#define CCM_TARGET_ROOT94_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,94)
#define CCM_MISC94                               CCM_MISC_REG(CCM_BASE_PTR,94)
#define CCM_MISC_ROOT94_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,94)
#define CCM_MISC_ROOT94_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,94)
#define CCM_MISC_ROOT94_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,94)
#define CCM_POST94                               CCM_POST_REG(CCM_BASE_PTR,94)
#define CCM_POST_ROOT94_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,94)
#define CCM_POST_ROOT94_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,94)
#define CCM_POST_ROOT94_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,94)
#define CCM_PRE94                                CCM_PRE_REG(CCM_BASE_PTR,94)
#define CCM_PRE_ROOT94_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,94)
#define CCM_PRE_ROOT94_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,94)
#define CCM_PRE_ROOT94_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,94)
#define CCM_ACCESS_CTRL94                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,94)
#define CCM_ACCESS_CTRL_ROOT94_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,94)
#define CCM_ACCESS_CTRL_ROOT94_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,94)
#define CCM_ACCESS_CTRL_ROOT94_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,94)
#define CCM_TARGET_ROOT95                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,95)
#define CCM_TARGET_ROOT95_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,95)
#define CCM_TARGET_ROOT95_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,95)
#define CCM_TARGET_ROOT95_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,95)
#define CCM_MISC95                               CCM_MISC_REG(CCM_BASE_PTR,95)
#define CCM_MISC_ROOT95_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,95)
#define CCM_MISC_ROOT95_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,95)
#define CCM_MISC_ROOT95_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,95)
#define CCM_POST95                               CCM_POST_REG(CCM_BASE_PTR,95)
#define CCM_POST_ROOT95_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,95)
#define CCM_POST_ROOT95_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,95)
#define CCM_POST_ROOT95_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,95)
#define CCM_PRE95                                CCM_PRE_REG(CCM_BASE_PTR,95)
#define CCM_PRE_ROOT95_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,95)
#define CCM_PRE_ROOT95_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,95)
#define CCM_PRE_ROOT95_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,95)
#define CCM_ACCESS_CTRL95                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,95)
#define CCM_ACCESS_CTRL_ROOT95_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,95)
#define CCM_ACCESS_CTRL_ROOT95_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,95)
#define CCM_ACCESS_CTRL_ROOT95_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,95)
#define CCM_TARGET_ROOT96                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,96)
#define CCM_TARGET_ROOT96_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,96)
#define CCM_TARGET_ROOT96_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,96)
#define CCM_TARGET_ROOT96_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,96)
#define CCM_MISC96                               CCM_MISC_REG(CCM_BASE_PTR,96)
#define CCM_MISC_ROOT96_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,96)
#define CCM_MISC_ROOT96_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,96)
#define CCM_MISC_ROOT96_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,96)
#define CCM_POST96                               CCM_POST_REG(CCM_BASE_PTR,96)
#define CCM_POST_ROOT96_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,96)
#define CCM_POST_ROOT96_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,96)
#define CCM_POST_ROOT96_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,96)
#define CCM_PRE96                                CCM_PRE_REG(CCM_BASE_PTR,96)
#define CCM_PRE_ROOT96_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,96)
#define CCM_PRE_ROOT96_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,96)
#define CCM_PRE_ROOT96_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,96)
#define CCM_ACCESS_CTRL96                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,96)
#define CCM_ACCESS_CTRL_ROOT96_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,96)
#define CCM_ACCESS_CTRL_ROOT96_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,96)
#define CCM_ACCESS_CTRL_ROOT96_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,96)
#define CCM_TARGET_ROOT97                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,97)
#define CCM_TARGET_ROOT97_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,97)
#define CCM_TARGET_ROOT97_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,97)
#define CCM_TARGET_ROOT97_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,97)
#define CCM_MISC97                               CCM_MISC_REG(CCM_BASE_PTR,97)
#define CCM_MISC_ROOT97_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,97)
#define CCM_MISC_ROOT97_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,97)
#define CCM_MISC_ROOT97_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,97)
#define CCM_POST97                               CCM_POST_REG(CCM_BASE_PTR,97)
#define CCM_POST_ROOT97_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,97)
#define CCM_POST_ROOT97_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,97)
#define CCM_POST_ROOT97_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,97)
#define CCM_PRE97                                CCM_PRE_REG(CCM_BASE_PTR,97)
#define CCM_PRE_ROOT97_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,97)
#define CCM_PRE_ROOT97_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,97)
#define CCM_PRE_ROOT97_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,97)
#define CCM_ACCESS_CTRL97                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,97)
#define CCM_ACCESS_CTRL_ROOT97_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,97)
#define CCM_ACCESS_CTRL_ROOT97_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,97)
#define CCM_ACCESS_CTRL_ROOT97_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,97)
#define CCM_TARGET_ROOT98                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,98)
#define CCM_TARGET_ROOT98_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,98)
#define CCM_TARGET_ROOT98_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,98)
#define CCM_TARGET_ROOT98_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,98)
#define CCM_MISC98                               CCM_MISC_REG(CCM_BASE_PTR,98)
#define CCM_MISC_ROOT98_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,98)
#define CCM_MISC_ROOT98_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,98)
#define CCM_MISC_ROOT98_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,98)
#define CCM_POST98                               CCM_POST_REG(CCM_BASE_PTR,98)
#define CCM_POST_ROOT98_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,98)
#define CCM_POST_ROOT98_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,98)
#define CCM_POST_ROOT98_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,98)
#define CCM_PRE98                                CCM_PRE_REG(CCM_BASE_PTR,98)
#define CCM_PRE_ROOT98_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,98)
#define CCM_PRE_ROOT98_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,98)
#define CCM_PRE_ROOT98_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,98)
#define CCM_ACCESS_CTRL98                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,98)
#define CCM_ACCESS_CTRL_ROOT98_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,98)
#define CCM_ACCESS_CTRL_ROOT98_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,98)
#define CCM_ACCESS_CTRL_ROOT98_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,98)
#define CCM_TARGET_ROOT99                        CCM_TARGET_ROOT_REG(CCM_BASE_PTR,99)
#define CCM_TARGET_ROOT99_SET                    CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,99)
#define CCM_TARGET_ROOT99_CLR                    CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,99)
#define CCM_TARGET_ROOT99_TOG                    CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,99)
#define CCM_MISC99                               CCM_MISC_REG(CCM_BASE_PTR,99)
#define CCM_MISC_ROOT99_SET                      CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,99)
#define CCM_MISC_ROOT99_CLR                      CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,99)
#define CCM_MISC_ROOT99_TOG                      CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,99)
#define CCM_POST99                               CCM_POST_REG(CCM_BASE_PTR,99)
#define CCM_POST_ROOT99_SET                      CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,99)
#define CCM_POST_ROOT99_CLR                      CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,99)
#define CCM_POST_ROOT99_TOG                      CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,99)
#define CCM_PRE99                                CCM_PRE_REG(CCM_BASE_PTR,99)
#define CCM_PRE_ROOT99_SET                       CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,99)
#define CCM_PRE_ROOT99_CLR                       CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,99)
#define CCM_PRE_ROOT99_TOG                       CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,99)
#define CCM_ACCESS_CTRL99                        CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,99)
#define CCM_ACCESS_CTRL_ROOT99_SET               CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,99)
#define CCM_ACCESS_CTRL_ROOT99_CLR               CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,99)
#define CCM_ACCESS_CTRL_ROOT99_TOG               CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,99)
#define CCM_TARGET_ROOT100                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,100)
#define CCM_TARGET_ROOT100_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,100)
#define CCM_TARGET_ROOT100_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,100)
#define CCM_TARGET_ROOT100_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,100)
#define CCM_MISC100                              CCM_MISC_REG(CCM_BASE_PTR,100)
#define CCM_MISC_ROOT100_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,100)
#define CCM_MISC_ROOT100_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,100)
#define CCM_MISC_ROOT100_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,100)
#define CCM_POST100                              CCM_POST_REG(CCM_BASE_PTR,100)
#define CCM_POST_ROOT100_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,100)
#define CCM_POST_ROOT100_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,100)
#define CCM_POST_ROOT100_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,100)
#define CCM_PRE100                               CCM_PRE_REG(CCM_BASE_PTR,100)
#define CCM_PRE_ROOT100_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,100)
#define CCM_PRE_ROOT100_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,100)
#define CCM_PRE_ROOT100_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,100)
#define CCM_ACCESS_CTRL100                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,100)
#define CCM_ACCESS_CTRL_ROOT100_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,100)
#define CCM_ACCESS_CTRL_ROOT100_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,100)
#define CCM_ACCESS_CTRL_ROOT100_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,100)
#define CCM_TARGET_ROOT101                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,101)
#define CCM_TARGET_ROOT101_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,101)
#define CCM_TARGET_ROOT101_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,101)
#define CCM_TARGET_ROOT101_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,101)
#define CCM_MISC101                              CCM_MISC_REG(CCM_BASE_PTR,101)
#define CCM_MISC_ROOT101_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,101)
#define CCM_MISC_ROOT101_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,101)
#define CCM_MISC_ROOT101_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,101)
#define CCM_POST101                              CCM_POST_REG(CCM_BASE_PTR,101)
#define CCM_POST_ROOT101_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,101)
#define CCM_POST_ROOT101_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,101)
#define CCM_POST_ROOT101_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,101)
#define CCM_PRE101                               CCM_PRE_REG(CCM_BASE_PTR,101)
#define CCM_PRE_ROOT101_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,101)
#define CCM_PRE_ROOT101_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,101)
#define CCM_PRE_ROOT101_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,101)
#define CCM_ACCESS_CTRL101                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,101)
#define CCM_ACCESS_CTRL_ROOT101_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,101)
#define CCM_ACCESS_CTRL_ROOT101_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,101)
#define CCM_ACCESS_CTRL_ROOT101_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,101)
#define CCM_TARGET_ROOT102                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,102)
#define CCM_TARGET_ROOT102_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,102)
#define CCM_TARGET_ROOT102_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,102)
#define CCM_TARGET_ROOT102_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,102)
#define CCM_MISC102                              CCM_MISC_REG(CCM_BASE_PTR,102)
#define CCM_MISC_ROOT102_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,102)
#define CCM_MISC_ROOT102_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,102)
#define CCM_MISC_ROOT102_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,102)
#define CCM_POST102                              CCM_POST_REG(CCM_BASE_PTR,102)
#define CCM_POST_ROOT102_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,102)
#define CCM_POST_ROOT102_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,102)
#define CCM_POST_ROOT102_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,102)
#define CCM_PRE102                               CCM_PRE_REG(CCM_BASE_PTR,102)
#define CCM_PRE_ROOT102_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,102)
#define CCM_PRE_ROOT102_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,102)
#define CCM_PRE_ROOT102_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,102)
#define CCM_ACCESS_CTRL102                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,102)
#define CCM_ACCESS_CTRL_ROOT102_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,102)
#define CCM_ACCESS_CTRL_ROOT102_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,102)
#define CCM_ACCESS_CTRL_ROOT102_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,102)
#define CCM_TARGET_ROOT103                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,103)
#define CCM_TARGET_ROOT103_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,103)
#define CCM_TARGET_ROOT103_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,103)
#define CCM_TARGET_ROOT103_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,103)
#define CCM_MISC103                              CCM_MISC_REG(CCM_BASE_PTR,103)
#define CCM_MISC_ROOT103_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,103)
#define CCM_MISC_ROOT103_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,103)
#define CCM_MISC_ROOT103_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,103)
#define CCM_POST103                              CCM_POST_REG(CCM_BASE_PTR,103)
#define CCM_POST_ROOT103_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,103)
#define CCM_POST_ROOT103_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,103)
#define CCM_POST_ROOT103_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,103)
#define CCM_PRE103                               CCM_PRE_REG(CCM_BASE_PTR,103)
#define CCM_PRE_ROOT103_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,103)
#define CCM_PRE_ROOT103_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,103)
#define CCM_PRE_ROOT103_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,103)
#define CCM_ACCESS_CTRL103                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,103)
#define CCM_ACCESS_CTRL_ROOT103_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,103)
#define CCM_ACCESS_CTRL_ROOT103_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,103)
#define CCM_ACCESS_CTRL_ROOT103_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,103)
#define CCM_TARGET_ROOT104                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,104)
#define CCM_TARGET_ROOT104_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,104)
#define CCM_TARGET_ROOT104_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,104)
#define CCM_TARGET_ROOT104_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,104)
#define CCM_MISC104                              CCM_MISC_REG(CCM_BASE_PTR,104)
#define CCM_MISC_ROOT104_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,104)
#define CCM_MISC_ROOT104_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,104)
#define CCM_MISC_ROOT104_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,104)
#define CCM_POST104                              CCM_POST_REG(CCM_BASE_PTR,104)
#define CCM_POST_ROOT104_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,104)
#define CCM_POST_ROOT104_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,104)
#define CCM_POST_ROOT104_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,104)
#define CCM_PRE104                               CCM_PRE_REG(CCM_BASE_PTR,104)
#define CCM_PRE_ROOT104_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,104)
#define CCM_PRE_ROOT104_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,104)
#define CCM_PRE_ROOT104_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,104)
#define CCM_ACCESS_CTRL104                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,104)
#define CCM_ACCESS_CTRL_ROOT104_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,104)
#define CCM_ACCESS_CTRL_ROOT104_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,104)
#define CCM_ACCESS_CTRL_ROOT104_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,104)
#define CCM_TARGET_ROOT105                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,105)
#define CCM_TARGET_ROOT105_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,105)
#define CCM_TARGET_ROOT105_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,105)
#define CCM_TARGET_ROOT105_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,105)
#define CCM_MISC105                              CCM_MISC_REG(CCM_BASE_PTR,105)
#define CCM_MISC_ROOT105_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,105)
#define CCM_MISC_ROOT105_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,105)
#define CCM_MISC_ROOT105_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,105)
#define CCM_POST105                              CCM_POST_REG(CCM_BASE_PTR,105)
#define CCM_POST_ROOT105_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,105)
#define CCM_POST_ROOT105_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,105)
#define CCM_POST_ROOT105_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,105)
#define CCM_PRE105                               CCM_PRE_REG(CCM_BASE_PTR,105)
#define CCM_PRE_ROOT105_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,105)
#define CCM_PRE_ROOT105_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,105)
#define CCM_PRE_ROOT105_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,105)
#define CCM_ACCESS_CTRL105                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,105)
#define CCM_ACCESS_CTRL_ROOT105_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,105)
#define CCM_ACCESS_CTRL_ROOT105_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,105)
#define CCM_ACCESS_CTRL_ROOT105_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,105)
#define CCM_TARGET_ROOT106                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,106)
#define CCM_TARGET_ROOT106_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,106)
#define CCM_TARGET_ROOT106_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,106)
#define CCM_TARGET_ROOT106_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,106)
#define CCM_MISC106                              CCM_MISC_REG(CCM_BASE_PTR,106)
#define CCM_MISC_ROOT106_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,106)
#define CCM_MISC_ROOT106_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,106)
#define CCM_MISC_ROOT106_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,106)
#define CCM_POST106                              CCM_POST_REG(CCM_BASE_PTR,106)
#define CCM_POST_ROOT106_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,106)
#define CCM_POST_ROOT106_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,106)
#define CCM_POST_ROOT106_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,106)
#define CCM_PRE106                               CCM_PRE_REG(CCM_BASE_PTR,106)
#define CCM_PRE_ROOT106_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,106)
#define CCM_PRE_ROOT106_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,106)
#define CCM_PRE_ROOT106_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,106)
#define CCM_ACCESS_CTRL106                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,106)
#define CCM_ACCESS_CTRL_ROOT106_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,106)
#define CCM_ACCESS_CTRL_ROOT106_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,106)
#define CCM_ACCESS_CTRL_ROOT106_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,106)
#define CCM_TARGET_ROOT107                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,107)
#define CCM_TARGET_ROOT107_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,107)
#define CCM_TARGET_ROOT107_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,107)
#define CCM_TARGET_ROOT107_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,107)
#define CCM_MISC107                              CCM_MISC_REG(CCM_BASE_PTR,107)
#define CCM_MISC_ROOT107_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,107)
#define CCM_MISC_ROOT107_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,107)
#define CCM_MISC_ROOT107_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,107)
#define CCM_POST107                              CCM_POST_REG(CCM_BASE_PTR,107)
#define CCM_POST_ROOT107_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,107)
#define CCM_POST_ROOT107_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,107)
#define CCM_POST_ROOT107_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,107)
#define CCM_PRE107                               CCM_PRE_REG(CCM_BASE_PTR,107)
#define CCM_PRE_ROOT107_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,107)
#define CCM_PRE_ROOT107_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,107)
#define CCM_PRE_ROOT107_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,107)
#define CCM_ACCESS_CTRL107                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,107)
#define CCM_ACCESS_CTRL_ROOT107_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,107)
#define CCM_ACCESS_CTRL_ROOT107_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,107)
#define CCM_ACCESS_CTRL_ROOT107_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,107)
#define CCM_TARGET_ROOT108                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,108)
#define CCM_TARGET_ROOT108_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,108)
#define CCM_TARGET_ROOT108_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,108)
#define CCM_TARGET_ROOT108_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,108)
#define CCM_MISC108                              CCM_MISC_REG(CCM_BASE_PTR,108)
#define CCM_MISC_ROOT108_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,108)
#define CCM_MISC_ROOT108_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,108)
#define CCM_MISC_ROOT108_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,108)
#define CCM_POST108                              CCM_POST_REG(CCM_BASE_PTR,108)
#define CCM_POST_ROOT108_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,108)
#define CCM_POST_ROOT108_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,108)
#define CCM_POST_ROOT108_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,108)
#define CCM_PRE108                               CCM_PRE_REG(CCM_BASE_PTR,108)
#define CCM_PRE_ROOT108_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,108)
#define CCM_PRE_ROOT108_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,108)
#define CCM_PRE_ROOT108_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,108)
#define CCM_ACCESS_CTRL108                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,108)
#define CCM_ACCESS_CTRL_ROOT108_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,108)
#define CCM_ACCESS_CTRL_ROOT108_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,108)
#define CCM_ACCESS_CTRL_ROOT108_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,108)
#define CCM_TARGET_ROOT109                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,109)
#define CCM_TARGET_ROOT109_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,109)
#define CCM_TARGET_ROOT109_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,109)
#define CCM_TARGET_ROOT109_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,109)
#define CCM_MISC109                              CCM_MISC_REG(CCM_BASE_PTR,109)
#define CCM_MISC_ROOT109_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,109)
#define CCM_MISC_ROOT109_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,109)
#define CCM_MISC_ROOT109_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,109)
#define CCM_POST109                              CCM_POST_REG(CCM_BASE_PTR,109)
#define CCM_POST_ROOT109_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,109)
#define CCM_POST_ROOT109_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,109)
#define CCM_POST_ROOT109_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,109)
#define CCM_PRE109                               CCM_PRE_REG(CCM_BASE_PTR,109)
#define CCM_PRE_ROOT109_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,109)
#define CCM_PRE_ROOT109_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,109)
#define CCM_PRE_ROOT109_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,109)
#define CCM_ACCESS_CTRL109                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,109)
#define CCM_ACCESS_CTRL_ROOT109_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,109)
#define CCM_ACCESS_CTRL_ROOT109_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,109)
#define CCM_ACCESS_CTRL_ROOT109_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,109)
#define CCM_TARGET_ROOT110                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,110)
#define CCM_TARGET_ROOT110_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,110)
#define CCM_TARGET_ROOT110_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,110)
#define CCM_TARGET_ROOT110_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,110)
#define CCM_MISC110                              CCM_MISC_REG(CCM_BASE_PTR,110)
#define CCM_MISC_ROOT110_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,110)
#define CCM_MISC_ROOT110_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,110)
#define CCM_MISC_ROOT110_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,110)
#define CCM_POST110                              CCM_POST_REG(CCM_BASE_PTR,110)
#define CCM_POST_ROOT110_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,110)
#define CCM_POST_ROOT110_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,110)
#define CCM_POST_ROOT110_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,110)
#define CCM_PRE110                               CCM_PRE_REG(CCM_BASE_PTR,110)
#define CCM_PRE_ROOT110_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,110)
#define CCM_PRE_ROOT110_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,110)
#define CCM_PRE_ROOT110_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,110)
#define CCM_ACCESS_CTRL110                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,110)
#define CCM_ACCESS_CTRL_ROOT110_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,110)
#define CCM_ACCESS_CTRL_ROOT110_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,110)
#define CCM_ACCESS_CTRL_ROOT110_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,110)
#define CCM_TARGET_ROOT111                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,111)
#define CCM_TARGET_ROOT111_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,111)
#define CCM_TARGET_ROOT111_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,111)
#define CCM_TARGET_ROOT111_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,111)
#define CCM_MISC111                              CCM_MISC_REG(CCM_BASE_PTR,111)
#define CCM_MISC_ROOT111_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,111)
#define CCM_MISC_ROOT111_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,111)
#define CCM_MISC_ROOT111_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,111)
#define CCM_POST111                              CCM_POST_REG(CCM_BASE_PTR,111)
#define CCM_POST_ROOT111_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,111)
#define CCM_POST_ROOT111_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,111)
#define CCM_POST_ROOT111_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,111)
#define CCM_PRE111                               CCM_PRE_REG(CCM_BASE_PTR,111)
#define CCM_PRE_ROOT111_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,111)
#define CCM_PRE_ROOT111_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,111)
#define CCM_PRE_ROOT111_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,111)
#define CCM_ACCESS_CTRL111                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,111)
#define CCM_ACCESS_CTRL_ROOT111_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,111)
#define CCM_ACCESS_CTRL_ROOT111_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,111)
#define CCM_ACCESS_CTRL_ROOT111_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,111)
#define CCM_TARGET_ROOT112                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,112)
#define CCM_TARGET_ROOT112_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,112)
#define CCM_TARGET_ROOT112_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,112)
#define CCM_TARGET_ROOT112_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,112)
#define CCM_MISC112                              CCM_MISC_REG(CCM_BASE_PTR,112)
#define CCM_MISC_ROOT112_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,112)
#define CCM_MISC_ROOT112_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,112)
#define CCM_MISC_ROOT112_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,112)
#define CCM_POST112                              CCM_POST_REG(CCM_BASE_PTR,112)
#define CCM_POST_ROOT112_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,112)
#define CCM_POST_ROOT112_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,112)
#define CCM_POST_ROOT112_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,112)
#define CCM_PRE112                               CCM_PRE_REG(CCM_BASE_PTR,112)
#define CCM_PRE_ROOT112_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,112)
#define CCM_PRE_ROOT112_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,112)
#define CCM_PRE_ROOT112_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,112)
#define CCM_ACCESS_CTRL112                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,112)
#define CCM_ACCESS_CTRL_ROOT112_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,112)
#define CCM_ACCESS_CTRL_ROOT112_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,112)
#define CCM_ACCESS_CTRL_ROOT112_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,112)
#define CCM_TARGET_ROOT113                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,113)
#define CCM_TARGET_ROOT113_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,113)
#define CCM_TARGET_ROOT113_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,113)
#define CCM_TARGET_ROOT113_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,113)
#define CCM_MISC113                              CCM_MISC_REG(CCM_BASE_PTR,113)
#define CCM_MISC_ROOT113_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,113)
#define CCM_MISC_ROOT113_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,113)
#define CCM_MISC_ROOT113_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,113)
#define CCM_POST113                              CCM_POST_REG(CCM_BASE_PTR,113)
#define CCM_POST_ROOT113_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,113)
#define CCM_POST_ROOT113_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,113)
#define CCM_POST_ROOT113_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,113)
#define CCM_PRE113                               CCM_PRE_REG(CCM_BASE_PTR,113)
#define CCM_PRE_ROOT113_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,113)
#define CCM_PRE_ROOT113_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,113)
#define CCM_PRE_ROOT113_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,113)
#define CCM_ACCESS_CTRL113                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,113)
#define CCM_ACCESS_CTRL_ROOT113_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,113)
#define CCM_ACCESS_CTRL_ROOT113_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,113)
#define CCM_ACCESS_CTRL_ROOT113_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,113)
#define CCM_TARGET_ROOT114                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,114)
#define CCM_TARGET_ROOT114_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,114)
#define CCM_TARGET_ROOT114_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,114)
#define CCM_TARGET_ROOT114_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,114)
#define CCM_MISC114                              CCM_MISC_REG(CCM_BASE_PTR,114)
#define CCM_MISC_ROOT114_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,114)
#define CCM_MISC_ROOT114_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,114)
#define CCM_MISC_ROOT114_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,114)
#define CCM_POST114                              CCM_POST_REG(CCM_BASE_PTR,114)
#define CCM_POST_ROOT114_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,114)
#define CCM_POST_ROOT114_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,114)
#define CCM_POST_ROOT114_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,114)
#define CCM_PRE114                               CCM_PRE_REG(CCM_BASE_PTR,114)
#define CCM_PRE_ROOT114_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,114)
#define CCM_PRE_ROOT114_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,114)
#define CCM_PRE_ROOT114_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,114)
#define CCM_ACCESS_CTRL114                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,114)
#define CCM_ACCESS_CTRL_ROOT114_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,114)
#define CCM_ACCESS_CTRL_ROOT114_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,114)
#define CCM_ACCESS_CTRL_ROOT114_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,114)
#define CCM_TARGET_ROOT115                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,115)
#define CCM_TARGET_ROOT115_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,115)
#define CCM_TARGET_ROOT115_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,115)
#define CCM_TARGET_ROOT115_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,115)
#define CCM_MISC115                              CCM_MISC_REG(CCM_BASE_PTR,115)
#define CCM_MISC_ROOT115_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,115)
#define CCM_MISC_ROOT115_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,115)
#define CCM_MISC_ROOT115_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,115)
#define CCM_POST115                              CCM_POST_REG(CCM_BASE_PTR,115)
#define CCM_POST_ROOT115_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,115)
#define CCM_POST_ROOT115_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,115)
#define CCM_POST_ROOT115_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,115)
#define CCM_PRE115                               CCM_PRE_REG(CCM_BASE_PTR,115)
#define CCM_PRE_ROOT115_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,115)
#define CCM_PRE_ROOT115_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,115)
#define CCM_PRE_ROOT115_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,115)
#define CCM_ACCESS_CTRL115                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,115)
#define CCM_ACCESS_CTRL_ROOT115_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,115)
#define CCM_ACCESS_CTRL_ROOT115_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,115)
#define CCM_ACCESS_CTRL_ROOT115_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,115)
#define CCM_TARGET_ROOT116                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,116)
#define CCM_TARGET_ROOT116_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,116)
#define CCM_TARGET_ROOT116_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,116)
#define CCM_TARGET_ROOT116_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,116)
#define CCM_MISC116                              CCM_MISC_REG(CCM_BASE_PTR,116)
#define CCM_MISC_ROOT116_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,116)
#define CCM_MISC_ROOT116_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,116)
#define CCM_MISC_ROOT116_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,116)
#define CCM_POST116                              CCM_POST_REG(CCM_BASE_PTR,116)
#define CCM_POST_ROOT116_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,116)
#define CCM_POST_ROOT116_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,116)
#define CCM_POST_ROOT116_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,116)
#define CCM_PRE116                               CCM_PRE_REG(CCM_BASE_PTR,116)
#define CCM_PRE_ROOT116_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,116)
#define CCM_PRE_ROOT116_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,116)
#define CCM_PRE_ROOT116_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,116)
#define CCM_ACCESS_CTRL116                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,116)
#define CCM_ACCESS_CTRL_ROOT116_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,116)
#define CCM_ACCESS_CTRL_ROOT116_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,116)
#define CCM_ACCESS_CTRL_ROOT116_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,116)
#define CCM_TARGET_ROOT117                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,117)
#define CCM_TARGET_ROOT117_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,117)
#define CCM_TARGET_ROOT117_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,117)
#define CCM_TARGET_ROOT117_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,117)
#define CCM_MISC117                              CCM_MISC_REG(CCM_BASE_PTR,117)
#define CCM_MISC_ROOT117_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,117)
#define CCM_MISC_ROOT117_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,117)
#define CCM_MISC_ROOT117_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,117)
#define CCM_POST117                              CCM_POST_REG(CCM_BASE_PTR,117)
#define CCM_POST_ROOT117_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,117)
#define CCM_POST_ROOT117_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,117)
#define CCM_POST_ROOT117_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,117)
#define CCM_PRE117                               CCM_PRE_REG(CCM_BASE_PTR,117)
#define CCM_PRE_ROOT117_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,117)
#define CCM_PRE_ROOT117_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,117)
#define CCM_PRE_ROOT117_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,117)
#define CCM_ACCESS_CTRL117                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,117)
#define CCM_ACCESS_CTRL_ROOT117_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,117)
#define CCM_ACCESS_CTRL_ROOT117_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,117)
#define CCM_ACCESS_CTRL_ROOT117_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,117)
#define CCM_TARGET_ROOT118                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,118)
#define CCM_TARGET_ROOT118_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,118)
#define CCM_TARGET_ROOT118_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,118)
#define CCM_TARGET_ROOT118_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,118)
#define CCM_MISC118                              CCM_MISC_REG(CCM_BASE_PTR,118)
#define CCM_MISC_ROOT118_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,118)
#define CCM_MISC_ROOT118_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,118)
#define CCM_MISC_ROOT118_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,118)
#define CCM_POST118                              CCM_POST_REG(CCM_BASE_PTR,118)
#define CCM_POST_ROOT118_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,118)
#define CCM_POST_ROOT118_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,118)
#define CCM_POST_ROOT118_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,118)
#define CCM_PRE118                               CCM_PRE_REG(CCM_BASE_PTR,118)
#define CCM_PRE_ROOT118_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,118)
#define CCM_PRE_ROOT118_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,118)
#define CCM_PRE_ROOT118_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,118)
#define CCM_ACCESS_CTRL118                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,118)
#define CCM_ACCESS_CTRL_ROOT118_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,118)
#define CCM_ACCESS_CTRL_ROOT118_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,118)
#define CCM_ACCESS_CTRL_ROOT118_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,118)
#define CCM_TARGET_ROOT119                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,119)
#define CCM_TARGET_ROOT119_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,119)
#define CCM_TARGET_ROOT119_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,119)
#define CCM_TARGET_ROOT119_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,119)
#define CCM_MISC119                              CCM_MISC_REG(CCM_BASE_PTR,119)
#define CCM_MISC_ROOT119_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,119)
#define CCM_MISC_ROOT119_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,119)
#define CCM_MISC_ROOT119_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,119)
#define CCM_POST119                              CCM_POST_REG(CCM_BASE_PTR,119)
#define CCM_POST_ROOT119_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,119)
#define CCM_POST_ROOT119_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,119)
#define CCM_POST_ROOT119_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,119)
#define CCM_PRE119                               CCM_PRE_REG(CCM_BASE_PTR,119)
#define CCM_PRE_ROOT119_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,119)
#define CCM_PRE_ROOT119_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,119)
#define CCM_PRE_ROOT119_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,119)
#define CCM_ACCESS_CTRL119                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,119)
#define CCM_ACCESS_CTRL_ROOT119_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,119)
#define CCM_ACCESS_CTRL_ROOT119_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,119)
#define CCM_ACCESS_CTRL_ROOT119_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,119)
#define CCM_TARGET_ROOT120                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,120)
#define CCM_TARGET_ROOT120_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,120)
#define CCM_TARGET_ROOT120_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,120)
#define CCM_TARGET_ROOT120_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,120)
#define CCM_MISC120                              CCM_MISC_REG(CCM_BASE_PTR,120)
#define CCM_MISC_ROOT120_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,120)
#define CCM_MISC_ROOT120_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,120)
#define CCM_MISC_ROOT120_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,120)
#define CCM_POST120                              CCM_POST_REG(CCM_BASE_PTR,120)
#define CCM_POST_ROOT120_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,120)
#define CCM_POST_ROOT120_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,120)
#define CCM_POST_ROOT120_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,120)
#define CCM_PRE120                               CCM_PRE_REG(CCM_BASE_PTR,120)
#define CCM_PRE_ROOT120_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,120)
#define CCM_PRE_ROOT120_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,120)
#define CCM_PRE_ROOT120_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,120)
#define CCM_ACCESS_CTRL120                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,120)
#define CCM_ACCESS_CTRL_ROOT120_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,120)
#define CCM_ACCESS_CTRL_ROOT120_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,120)
#define CCM_ACCESS_CTRL_ROOT120_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,120)
#define CCM_TARGET_ROOT121                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,121)
#define CCM_TARGET_ROOT121_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,121)
#define CCM_TARGET_ROOT121_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,121)
#define CCM_TARGET_ROOT121_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,121)
#define CCM_MISC121                              CCM_MISC_REG(CCM_BASE_PTR,121)
#define CCM_MISC_ROOT121_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,121)
#define CCM_MISC_ROOT121_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,121)
#define CCM_MISC_ROOT121_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,121)
#define CCM_POST121                              CCM_POST_REG(CCM_BASE_PTR,121)
#define CCM_POST_ROOT121_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,121)
#define CCM_POST_ROOT121_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,121)
#define CCM_POST_ROOT121_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,121)
#define CCM_PRE121                               CCM_PRE_REG(CCM_BASE_PTR,121)
#define CCM_PRE_ROOT121_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,121)
#define CCM_PRE_ROOT121_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,121)
#define CCM_PRE_ROOT121_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,121)
#define CCM_ACCESS_CTRL121                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,121)
#define CCM_ACCESS_CTRL_ROOT121_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,121)
#define CCM_ACCESS_CTRL_ROOT121_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,121)
#define CCM_ACCESS_CTRL_ROOT121_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,121)
#define CCM_TARGET_ROOT122                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,122)
#define CCM_TARGET_ROOT122_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,122)
#define CCM_TARGET_ROOT122_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,122)
#define CCM_TARGET_ROOT122_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,122)
#define CCM_MISC122                              CCM_MISC_REG(CCM_BASE_PTR,122)
#define CCM_MISC_ROOT122_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,122)
#define CCM_MISC_ROOT122_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,122)
#define CCM_MISC_ROOT122_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,122)
#define CCM_POST122                              CCM_POST_REG(CCM_BASE_PTR,122)
#define CCM_POST_ROOT122_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,122)
#define CCM_POST_ROOT122_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,122)
#define CCM_POST_ROOT122_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,122)
#define CCM_PRE122                               CCM_PRE_REG(CCM_BASE_PTR,122)
#define CCM_PRE_ROOT122_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,122)
#define CCM_PRE_ROOT122_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,122)
#define CCM_PRE_ROOT122_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,122)
#define CCM_ACCESS_CTRL122                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,122)
#define CCM_ACCESS_CTRL_ROOT122_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,122)
#define CCM_ACCESS_CTRL_ROOT122_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,122)
#define CCM_ACCESS_CTRL_ROOT122_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,122)
#define CCM_TARGET_ROOT123                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,123)
#define CCM_TARGET_ROOT123_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,123)
#define CCM_TARGET_ROOT123_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,123)
#define CCM_TARGET_ROOT123_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,123)
#define CCM_MISC123                              CCM_MISC_REG(CCM_BASE_PTR,123)
#define CCM_MISC_ROOT123_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,123)
#define CCM_MISC_ROOT123_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,123)
#define CCM_MISC_ROOT123_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,123)
#define CCM_POST123                              CCM_POST_REG(CCM_BASE_PTR,123)
#define CCM_POST_ROOT123_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,123)
#define CCM_POST_ROOT123_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,123)
#define CCM_POST_ROOT123_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,123)
#define CCM_PRE123                               CCM_PRE_REG(CCM_BASE_PTR,123)
#define CCM_PRE_ROOT123_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,123)
#define CCM_PRE_ROOT123_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,123)
#define CCM_PRE_ROOT123_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,123)
#define CCM_ACCESS_CTRL123                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,123)
#define CCM_ACCESS_CTRL_ROOT123_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,123)
#define CCM_ACCESS_CTRL_ROOT123_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,123)
#define CCM_ACCESS_CTRL_ROOT123_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,123)
#define CCM_TARGET_ROOT124                       CCM_TARGET_ROOT_REG(CCM_BASE_PTR,124)
#define CCM_TARGET_ROOT124_SET                   CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,124)
#define CCM_TARGET_ROOT124_CLR                   CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,124)
#define CCM_TARGET_ROOT124_TOG                   CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,124)
#define CCM_MISC124                              CCM_MISC_REG(CCM_BASE_PTR,124)
#define CCM_MISC_ROOT124_SET                     CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,124)
#define CCM_MISC_ROOT124_CLR                     CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,124)
#define CCM_MISC_ROOT124_TOG                     CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,124)
#define CCM_POST124                              CCM_POST_REG(CCM_BASE_PTR,124)
#define CCM_POST_ROOT124_SET                     CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,124)
#define CCM_POST_ROOT124_CLR                     CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,124)
#define CCM_POST_ROOT124_TOG                     CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,124)
#define CCM_PRE124                               CCM_PRE_REG(CCM_BASE_PTR,124)
#define CCM_PRE_ROOT124_SET                      CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,124)
#define CCM_PRE_ROOT124_CLR                      CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,124)
#define CCM_PRE_ROOT124_TOG                      CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,124)
#define CCM_ACCESS_CTRL124                       CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,124)
#define CCM_ACCESS_CTRL_ROOT124_SET              CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,124)
#define CCM_ACCESS_CTRL_ROOT124_CLR              CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,124)
#define CCM_ACCESS_CTRL_ROOT124_TOG              CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,124)

/* CCM - Register array accessors */
#define CCM_PLL_CTRL(index)                      CCM_PLL_CTRL_REG(CCM_BASE_PTR,index)
#define CCM_PLL_CTRL_SET(index)                  CCM_PLL_CTRL_SET_REG(CCM_BASE_PTR,index)
#define CCM_PLL_CTRL_CLR(index)                  CCM_PLL_CTRL_CLR_REG(CCM_BASE_PTR,index)
#define CCM_PLL_CTRL_TOG(index)                  CCM_PLL_CTRL_TOG_REG(CCM_BASE_PTR,index)
#define CCM_CCGR(index)                          CCM_CCGR_REG(CCM_BASE_PTR,index)
#define CCM_CCGR_SET(index)                      CCM_CCGR_SET_REG(CCM_BASE_PTR,index)
#define CCM_CCGR_CLR(index)                      CCM_CCGR_CLR_REG(CCM_BASE_PTR,index)
#define CCM_CCGR_TOG(index)                      CCM_CCGR_TOG_REG(CCM_BASE_PTR,index)
#define CCM_TARGET_ROOT(index)                   CCM_TARGET_ROOT_REG(CCM_BASE_PTR,index)
#define CCM_TARGET_ROOT_SET(index)               CCM_TARGET_ROOT_SET_REG(CCM_BASE_PTR,index)
#define CCM_TARGET_ROOT_CLR(index)               CCM_TARGET_ROOT_CLR_REG(CCM_BASE_PTR,index)
#define CCM_TARGET_ROOT_TOG(index)               CCM_TARGET_ROOT_TOG_REG(CCM_BASE_PTR,index)
#define CCM_MISC(index)                          CCM_MISC_REG(CCM_BASE_PTR,index)
#define CCM_MISC_ROOT_SET(index)                 CCM_MISC_ROOT_SET_REG(CCM_BASE_PTR,index)
#define CCM_MISC_ROOT_CLR(index)                 CCM_MISC_ROOT_CLR_REG(CCM_BASE_PTR,index)
#define CCM_MISC_ROOT_TOG(index)                 CCM_MISC_ROOT_TOG_REG(CCM_BASE_PTR,index)
#define CCM_POST(index)                          CCM_POST_REG(CCM_BASE_PTR,index)
#define CCM_POST_ROOT_SET(index)                 CCM_POST_ROOT_SET_REG(CCM_BASE_PTR,index)
#define CCM_POST_ROOT_CLR(index)                 CCM_POST_ROOT_CLR_REG(CCM_BASE_PTR,index)
#define CCM_POST_ROOT_TOG(index)                 CCM_POST_ROOT_TOG_REG(CCM_BASE_PTR,index)
#define CCM_PRE(index)                           CCM_PRE_REG(CCM_BASE_PTR,index)
#define CCM_PRE_ROOT_SET(index)                  CCM_PRE_ROOT_SET_REG(CCM_BASE_PTR,index)
#define CCM_PRE_ROOT_CLR(index)                  CCM_PRE_ROOT_CLR_REG(CCM_BASE_PTR,index)
#define CCM_PRE_ROOT_TOG(index)                  CCM_PRE_ROOT_TOG_REG(CCM_BASE_PTR,index)
#define CCM_ACCESS_CTRL(index)                   CCM_ACCESS_CTRL_REG(CCM_BASE_PTR,index)
#define CCM_ACCESS_CTRL_ROOT_SET(index)          CCM_ACCESS_CTRL_ROOT_SET_REG(CCM_BASE_PTR,index)
#define CCM_ACCESS_CTRL_ROOT_CLR(index)          CCM_ACCESS_CTRL_ROOT_CLR_REG(CCM_BASE_PTR,index)
#define CCM_ACCESS_CTRL_ROOT_TOG(index)          CCM_ACCESS_CTRL_ROOT_TOG_REG(CCM_BASE_PTR,index)

/*!
 * @}
 */ /* end of group CCM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group CCM_Peripheral */


/* ----------------------------------------------------------------------------
   -- CCM_ANALOG
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CCM_ANALOG_Peripheral CCM_ANALOG
 * @{
 */

/** CCM_ANALOG - Peripheral register structure */
typedef struct CCM_ANALOG_MemMap {
  uint32_t PLL_ARM;                                /**< Anadig ARM PLL control Register, offset: 0x0 */
  uint32_t PLL_ARM_SET;                            /**< Anadig ARM PLL control Register, offset: 0x4 */
  uint32_t PLL_ARM_CLR;                            /**< Anadig ARM PLL control Register, offset: 0x8 */
  uint32_t PLL_ARM_TOG;                            /**< Anadig ARM PLL control Register, offset: 0xC */
  uint32_t PLL_DDR;                                /**< Anadig DDR PLL Control Register, offset: 0x10 */
  uint32_t PLL_DDR_SET;                            /**< Anadig DDR PLL Control Register, offset: 0x14 */
  uint32_t PLL_DDR_CLR;                            /**< Anadig DDR PLL Control Register, offset: 0x18 */
  uint32_t PLL_DDR_TOG;                            /**< Anadig DDR PLL Control Register, offset: 0x1C */
  uint32_t PLL_DDR_SS;                             /**< DDR PLL Spread Spectrum Register., offset: 0x20 */
  uint8_t RESERVED_0[12];
  uint32_t PLL_DDR_NUM;                            /**< Numerator of DDR PLL Fractional Loop Divider Register, offset: 0x30 */
  uint8_t RESERVED_1[12];
  uint32_t PLL_DDR_DENOM;                          /**< Denominator of DDR PLL Fractional Loop Divider Register, offset: 0x40 */
  uint8_t RESERVED_2[12];
  uint32_t PLL_480;                                /**< Anadig 480MHz PLL Control Register, offset: 0x50 */
  uint32_t PLL_480_SET;                            /**< Anadig 480MHz PLL Control Register, offset: 0x54 */
  uint32_t PLL_480_CLR;                            /**< Anadig 480MHz PLL Control Register, offset: 0x58 */
  uint32_t PLL_480_TOG;                            /**< Anadig 480MHz PLL Control Register, offset: 0x5C */
  uint32_t PFD_480A;                               /**< 480MHz Clock Phase Fractional Divider Control Register A, offset: 0x60 */
  uint32_t PFD_480A_SET;                           /**< 480MHz Clock Phase Fractional Divider Control Register A, offset: 0x64 */
  uint32_t PFD_480A_CLR;                           /**< 480MHz Clock Phase Fractional Divider Control Register A, offset: 0x68 */
  uint32_t PFD_480A_TOG;                           /**< 480MHz Clock Phase Fractional Divider Control Register A, offset: 0x6C */
  uint32_t PFD_480B;                               /**< 480MHz Clock Phase Fractional Divider Control Register B, offset: 0x70 */
  uint32_t PFD_480B_SET;                           /**< 480MHz Clock Phase Fractional Divider Control Register B, offset: 0x74 */
  uint32_t PFD_480B_CLR;                           /**< 480MHz Clock Phase Fractional Divider Control Register B, offset: 0x78 */
  uint32_t PFD_480B_TOG;                           /**< 480MHz Clock Phase Fractional Divider Control Register B, offset: 0x7C */
  uint32_t PLL_ENET;                               /**< Anadig ENET PLL Control Register, offset: 0x80 */
  uint32_t PLL_ENET_SET;                           /**< Anadig ENET PLL Control Register, offset: 0x84 */
  uint32_t PLL_ENET_CLR;                           /**< Anadig ENET PLL Control Register, offset: 0x88 */
  uint32_t PLL_ENET_TOG;                           /**< Anadig ENET PLL Control Register, offset: 0x8C */
  uint32_t PLL_AUDIO;                              /**< Anadig Audio PLL control Register, offset: 0x90 */
  uint32_t PLL_AUDIO_SET;                          /**< Anadig Audio PLL control Register, offset: 0x94 */
  uint32_t PLL_AUDIO_CLR;                          /**< Anadig Audio PLL control Register, offset: 0x98 */
  uint32_t PLL_AUDIO_TOG;                          /**< Anadig Audio PLL control Register, offset: 0x9C */
  uint32_t PLL_AUDIO_SS;                           /**< Audio PLL Spread Spectrum Register., offset: 0xA0 */
  uint8_t RESERVED_3[12];
  uint32_t PLL_AUDIO_NUM;                          /**< Numerator of Audio PLL Fractional Loop Divider Register, offset: 0xB0 */
  uint8_t RESERVED_4[12];
  uint32_t PLL_AUDIO_DENOM;                        /**< Denominator of Audio PLL Fractional Loop Divider Register, offset: 0xC0 */
  uint8_t RESERVED_5[12];
  uint32_t PLL_VIDEO;                              /**< Anadig Video PLL control Register, offset: 0xD0 */
  uint32_t PLL_VIDEO_SET;                          /**< Anadig Video PLL control Register, offset: 0xD4 */
  uint32_t PLL_VIDEO_CLR;                          /**< Anadig Video PLL control Register, offset: 0xD8 */
  uint32_t PLL_VIDEO_TOG;                          /**< Anadig Video PLL control Register, offset: 0xDC */
  uint32_t PLL_VIDEO_SS;                           /**< Video PLL Spread Spectrum Register., offset: 0xE0 */
  uint8_t RESERVED_6[12];
  uint32_t PLL_VIDEO_NUM;                          /**< Numerator of Video PLL Fractional Loop Divider Register, offset: 0xF0 */
  uint8_t RESERVED_7[12];
  uint32_t PLL_VIDEO_DENOM;                        /**< Denominator of Video PLL Fractional Loop Divider Register, offset: 0x100 */
  uint8_t RESERVED_8[12];
  uint32_t CLK_MISC0;                              /**< Miscellaneous0 Analog Clock Control and Status Register, offset: 0x110 */
  uint32_t CLK_MISC0_SET;                          /**< Miscellaneous0 Analog Clock Control and Status Register, offset: 0x114 */
  uint32_t CLK_MISC0_CLR;                          /**< Miscellaneous0 Analog Clock Control and Status Register, offset: 0x118 */
  uint32_t CLK_MISC0_TOG;                          /**< Miscellaneous0 Analog Clock Control and Status Register, offset: 0x11C */
} volatile *CCM_ANALOG_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- CCM_ANALOG - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CCM_ANALOG_Register_Accessor_Macros CCM_ANALOG - Register accessor macros
 * @{
 */


/* CCM_ANALOG - Register accessors */
#define CCM_ANALOG_PLL_ARM_REG(base)             ((base)->PLL_ARM)
#define CCM_ANALOG_PLL_ARM_SET_REG(base)         ((base)->PLL_ARM_SET)
#define CCM_ANALOG_PLL_ARM_CLR_REG(base)         ((base)->PLL_ARM_CLR)
#define CCM_ANALOG_PLL_ARM_TOG_REG(base)         ((base)->PLL_ARM_TOG)
#define CCM_ANALOG_PLL_DDR_REG(base)             ((base)->PLL_DDR)
#define CCM_ANALOG_PLL_DDR_SET_REG(base)         ((base)->PLL_DDR_SET)
#define CCM_ANALOG_PLL_DDR_CLR_REG(base)         ((base)->PLL_DDR_CLR)
#define CCM_ANALOG_PLL_DDR_TOG_REG(base)         ((base)->PLL_DDR_TOG)
#define CCM_ANALOG_PLL_DDR_SS_REG(base)          ((base)->PLL_DDR_SS)
#define CCM_ANALOG_PLL_DDR_NUM_REG(base)         ((base)->PLL_DDR_NUM)
#define CCM_ANALOG_PLL_DDR_DENOM_REG(base)       ((base)->PLL_DDR_DENOM)
#define CCM_ANALOG_PLL_480_REG(base)             ((base)->PLL_480)
#define CCM_ANALOG_PLL_480_SET_REG(base)         ((base)->PLL_480_SET)
#define CCM_ANALOG_PLL_480_CLR_REG(base)         ((base)->PLL_480_CLR)
#define CCM_ANALOG_PLL_480_TOG_REG(base)         ((base)->PLL_480_TOG)
#define CCM_ANALOG_PFD_480A_REG(base)            ((base)->PFD_480A)
#define CCM_ANALOG_PFD_480A_SET_REG(base)        ((base)->PFD_480A_SET)
#define CCM_ANALOG_PFD_480A_CLR_REG(base)        ((base)->PFD_480A_CLR)
#define CCM_ANALOG_PFD_480A_TOG_REG(base)        ((base)->PFD_480A_TOG)
#define CCM_ANALOG_PFD_480B_REG(base)            ((base)->PFD_480B)
#define CCM_ANALOG_PFD_480B_SET_REG(base)        ((base)->PFD_480B_SET)
#define CCM_ANALOG_PFD_480B_CLR_REG(base)        ((base)->PFD_480B_CLR)
#define CCM_ANALOG_PFD_480B_TOG_REG(base)        ((base)->PFD_480B_TOG)
#define CCM_ANALOG_PLL_ENET_REG(base)            ((base)->PLL_ENET)
#define CCM_ANALOG_PLL_ENET_SET_REG(base)        ((base)->PLL_ENET_SET)
#define CCM_ANALOG_PLL_ENET_CLR_REG(base)        ((base)->PLL_ENET_CLR)
#define CCM_ANALOG_PLL_ENET_TOG_REG(base)        ((base)->PLL_ENET_TOG)
#define CCM_ANALOG_PLL_AUDIO_REG(base)           ((base)->PLL_AUDIO)
#define CCM_ANALOG_PLL_AUDIO_SET_REG(base)       ((base)->PLL_AUDIO_SET)
#define CCM_ANALOG_PLL_AUDIO_CLR_REG(base)       ((base)->PLL_AUDIO_CLR)
#define CCM_ANALOG_PLL_AUDIO_TOG_REG(base)       ((base)->PLL_AUDIO_TOG)
#define CCM_ANALOG_PLL_AUDIO_SS_REG(base)        ((base)->PLL_AUDIO_SS)
#define CCM_ANALOG_PLL_AUDIO_NUM_REG(base)       ((base)->PLL_AUDIO_NUM)
#define CCM_ANALOG_PLL_AUDIO_DENOM_REG(base)     ((base)->PLL_AUDIO_DENOM)
#define CCM_ANALOG_PLL_VIDEO_REG(base)           ((base)->PLL_VIDEO)
#define CCM_ANALOG_PLL_VIDEO_SET_REG(base)       ((base)->PLL_VIDEO_SET)
#define CCM_ANALOG_PLL_VIDEO_CLR_REG(base)       ((base)->PLL_VIDEO_CLR)
#define CCM_ANALOG_PLL_VIDEO_TOG_REG(base)       ((base)->PLL_VIDEO_TOG)
#define CCM_ANALOG_PLL_VIDEO_SS_REG(base)        ((base)->PLL_VIDEO_SS)
#define CCM_ANALOG_PLL_VIDEO_NUM_REG(base)       ((base)->PLL_VIDEO_NUM)
#define CCM_ANALOG_PLL_VIDEO_DENOM_REG(base)     ((base)->PLL_VIDEO_DENOM)
#define CCM_ANALOG_CLK_MISC0_REG(base)           ((base)->CLK_MISC0)
#define CCM_ANALOG_CLK_MISC0_SET_REG(base)       ((base)->CLK_MISC0_SET)
#define CCM_ANALOG_CLK_MISC0_CLR_REG(base)       ((base)->CLK_MISC0_CLR)
#define CCM_ANALOG_CLK_MISC0_TOG_REG(base)       ((base)->CLK_MISC0_TOG)

/*!
 * @}
 */ /* end of group CCM_ANALOG_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- CCM_ANALOG Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CCM_ANALOG_Register_Masks CCM_ANALOG Register Masks
 * @{
 */

/*! @name PLL_ARM - Anadig ARM PLL control Register */
#define CCM_ANALOG_PLL_ARM_DIV_SELECT_MASK       (0x7FU)
#define CCM_ANALOG_PLL_ARM_DIV_SELECT_SHIFT      (0U)
#define CCM_ANALOG_PLL_ARM_DIV_SELECT(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_ARM_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_ARM_HALF_LF_MASK          (0x80U)
#define CCM_ANALOG_PLL_ARM_HALF_LF_SHIFT         (7U)
#define CCM_ANALOG_PLL_ARM_DOUBLE_LF_MASK        (0x100U)
#define CCM_ANALOG_PLL_ARM_DOUBLE_LF_SHIFT       (8U)
#define CCM_ANALOG_PLL_ARM_HALF_CP_MASK          (0x200U)
#define CCM_ANALOG_PLL_ARM_HALF_CP_SHIFT         (9U)
#define CCM_ANALOG_PLL_ARM_DOUBLE_CP_MASK        (0x400U)
#define CCM_ANALOG_PLL_ARM_DOUBLE_CP_SHIFT       (10U)
#define CCM_ANALOG_PLL_ARM_HOLD_RING_OFF_MASK    (0x800U)
#define CCM_ANALOG_PLL_ARM_HOLD_RING_OFF_SHIFT   (11U)
#define CCM_ANALOG_PLL_ARM_POWERDOWN_MASK        (0x1000U)
#define CCM_ANALOG_PLL_ARM_POWERDOWN_SHIFT       (12U)
#define CCM_ANALOG_PLL_ARM_ENABLE_CLK_MASK       (0x2000U)
#define CCM_ANALOG_PLL_ARM_ENABLE_CLK_SHIFT      (13U)
#define CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC_MASK   (0xC000U)
#define CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC_SHIFT  (14U)
#define CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_ARM_BYPASS_MASK           (0x10000U)
#define CCM_ANALOG_PLL_ARM_BYPASS_SHIFT          (16U)
#define CCM_ANALOG_PLL_ARM_LVDS_SEL_MASK         (0x20000U)
#define CCM_ANALOG_PLL_ARM_LVDS_SEL_SHIFT        (17U)
#define CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL_MASK   (0x40000U)
#define CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL_SHIFT  (18U)
#define CCM_ANALOG_PLL_ARM_PLL_SEL_MASK          (0x80000U)
#define CCM_ANALOG_PLL_ARM_PLL_SEL_SHIFT         (19U)
#define CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE_MASK (0x100000U)
#define CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE_SHIFT (20U)
#define CCM_ANALOG_PLL_ARM_RSVD0_MASK            (0x7FE00000U)
#define CCM_ANALOG_PLL_ARM_RSVD0_SHIFT           (21U)
#define CCM_ANALOG_PLL_ARM_RSVD0(x)              (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_RSVD0_SHIFT)) & CCM_ANALOG_PLL_ARM_RSVD0_MASK)
#define CCM_ANALOG_PLL_ARM_LOCK_MASK             (0x80000000U)
#define CCM_ANALOG_PLL_ARM_LOCK_SHIFT            (31U)

/*! @name PLL_ARM_SET - Anadig ARM PLL control Register */
#define CCM_ANALOG_PLL_ARM_SET_DIV_SELECT_MASK   (0x7FU)
#define CCM_ANALOG_PLL_ARM_SET_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_ARM_SET_DIV_SELECT(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_SET_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_ARM_SET_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_ARM_SET_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_ARM_SET_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_ARM_SET_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_ARM_SET_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_ARM_SET_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_ARM_SET_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_ARM_SET_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_ARM_SET_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_ARM_SET_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_ARM_SET_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_ARM_SET_POWERDOWN_MASK    (0x1000U)
#define CCM_ANALOG_PLL_ARM_SET_POWERDOWN_SHIFT   (12U)
#define CCM_ANALOG_PLL_ARM_SET_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_ARM_SET_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_ARM_SET_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_ARM_SET_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_ARM_SET_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_SET_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_ARM_SET_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_ARM_SET_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_ARM_SET_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_ARM_SET_LVDS_SEL_MASK     (0x20000U)
#define CCM_ANALOG_PLL_ARM_SET_LVDS_SEL_SHIFT    (17U)
#define CCM_ANALOG_PLL_ARM_SET_LVDS_24MHZ_SEL_MASK (0x40000U)
#define CCM_ANALOG_PLL_ARM_SET_LVDS_24MHZ_SEL_SHIFT (18U)
#define CCM_ANALOG_PLL_ARM_SET_PLL_SEL_MASK      (0x80000U)
#define CCM_ANALOG_PLL_ARM_SET_PLL_SEL_SHIFT     (19U)
#define CCM_ANALOG_PLL_ARM_SET_PLL_ARM_OVERRIDE_MASK (0x100000U)
#define CCM_ANALOG_PLL_ARM_SET_PLL_ARM_OVERRIDE_SHIFT (20U)
#define CCM_ANALOG_PLL_ARM_SET_RSVD0_MASK        (0x7FE00000U)
#define CCM_ANALOG_PLL_ARM_SET_RSVD0_SHIFT       (21U)
#define CCM_ANALOG_PLL_ARM_SET_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_SET_RSVD0_SHIFT)) & CCM_ANALOG_PLL_ARM_SET_RSVD0_MASK)
#define CCM_ANALOG_PLL_ARM_SET_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_ARM_SET_LOCK_SHIFT        (31U)

/*! @name PLL_ARM_CLR - Anadig ARM PLL control Register */
#define CCM_ANALOG_PLL_ARM_CLR_DIV_SELECT_MASK   (0x7FU)
#define CCM_ANALOG_PLL_ARM_CLR_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_ARM_CLR_DIV_SELECT(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_CLR_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_ARM_CLR_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_ARM_CLR_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_ARM_CLR_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_ARM_CLR_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_ARM_CLR_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_ARM_CLR_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_ARM_CLR_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_ARM_CLR_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_ARM_CLR_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_ARM_CLR_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_ARM_CLR_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_ARM_CLR_POWERDOWN_MASK    (0x1000U)
#define CCM_ANALOG_PLL_ARM_CLR_POWERDOWN_SHIFT   (12U)
#define CCM_ANALOG_PLL_ARM_CLR_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_ARM_CLR_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_ARM_CLR_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_ARM_CLR_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_ARM_CLR_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_CLR_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_ARM_CLR_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_ARM_CLR_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_ARM_CLR_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_ARM_CLR_LVDS_SEL_MASK     (0x20000U)
#define CCM_ANALOG_PLL_ARM_CLR_LVDS_SEL_SHIFT    (17U)
#define CCM_ANALOG_PLL_ARM_CLR_LVDS_24MHZ_SEL_MASK (0x40000U)
#define CCM_ANALOG_PLL_ARM_CLR_LVDS_24MHZ_SEL_SHIFT (18U)
#define CCM_ANALOG_PLL_ARM_CLR_PLL_SEL_MASK      (0x80000U)
#define CCM_ANALOG_PLL_ARM_CLR_PLL_SEL_SHIFT     (19U)
#define CCM_ANALOG_PLL_ARM_CLR_PLL_ARM_OVERRIDE_MASK (0x100000U)
#define CCM_ANALOG_PLL_ARM_CLR_PLL_ARM_OVERRIDE_SHIFT (20U)
#define CCM_ANALOG_PLL_ARM_CLR_RSVD0_MASK        (0x7FE00000U)
#define CCM_ANALOG_PLL_ARM_CLR_RSVD0_SHIFT       (21U)
#define CCM_ANALOG_PLL_ARM_CLR_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_CLR_RSVD0_SHIFT)) & CCM_ANALOG_PLL_ARM_CLR_RSVD0_MASK)
#define CCM_ANALOG_PLL_ARM_CLR_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_ARM_CLR_LOCK_SHIFT        (31U)

/*! @name PLL_ARM_TOG - Anadig ARM PLL control Register */
#define CCM_ANALOG_PLL_ARM_TOG_DIV_SELECT_MASK   (0x7FU)
#define CCM_ANALOG_PLL_ARM_TOG_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_ARM_TOG_DIV_SELECT(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_TOG_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_ARM_TOG_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_ARM_TOG_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_ARM_TOG_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_ARM_TOG_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_ARM_TOG_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_ARM_TOG_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_ARM_TOG_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_ARM_TOG_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_ARM_TOG_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_ARM_TOG_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_ARM_TOG_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_ARM_TOG_POWERDOWN_MASK    (0x1000U)
#define CCM_ANALOG_PLL_ARM_TOG_POWERDOWN_SHIFT   (12U)
#define CCM_ANALOG_PLL_ARM_TOG_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_ARM_TOG_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_ARM_TOG_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_ARM_TOG_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_ARM_TOG_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_TOG_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_ARM_TOG_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_ARM_TOG_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_ARM_TOG_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_ARM_TOG_LVDS_SEL_MASK     (0x20000U)
#define CCM_ANALOG_PLL_ARM_TOG_LVDS_SEL_SHIFT    (17U)
#define CCM_ANALOG_PLL_ARM_TOG_LVDS_24MHZ_SEL_MASK (0x40000U)
#define CCM_ANALOG_PLL_ARM_TOG_LVDS_24MHZ_SEL_SHIFT (18U)
#define CCM_ANALOG_PLL_ARM_TOG_PLL_SEL_MASK      (0x80000U)
#define CCM_ANALOG_PLL_ARM_TOG_PLL_SEL_SHIFT     (19U)
#define CCM_ANALOG_PLL_ARM_TOG_PLL_ARM_OVERRIDE_MASK (0x100000U)
#define CCM_ANALOG_PLL_ARM_TOG_PLL_ARM_OVERRIDE_SHIFT (20U)
#define CCM_ANALOG_PLL_ARM_TOG_RSVD0_MASK        (0x7FE00000U)
#define CCM_ANALOG_PLL_ARM_TOG_RSVD0_SHIFT       (21U)
#define CCM_ANALOG_PLL_ARM_TOG_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ARM_TOG_RSVD0_SHIFT)) & CCM_ANALOG_PLL_ARM_TOG_RSVD0_MASK)
#define CCM_ANALOG_PLL_ARM_TOG_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_ARM_TOG_LOCK_SHIFT        (31U)

/*! @name PLL_DDR - Anadig DDR PLL Control Register */
#define CCM_ANALOG_PLL_DDR_DIV_SELECT_MASK       (0x7FU)
#define CCM_ANALOG_PLL_DDR_DIV_SELECT_SHIFT      (0U)
#define CCM_ANALOG_PLL_DDR_DIV_SELECT(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_DDR_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_DDR_HALF_LF_MASK          (0x80U)
#define CCM_ANALOG_PLL_DDR_HALF_LF_SHIFT         (7U)
#define CCM_ANALOG_PLL_DDR_DOUBLE_LF_MASK        (0x100U)
#define CCM_ANALOG_PLL_DDR_DOUBLE_LF_SHIFT       (8U)
#define CCM_ANALOG_PLL_DDR_HALF_CP_MASK          (0x200U)
#define CCM_ANALOG_PLL_DDR_HALF_CP_SHIFT         (9U)
#define CCM_ANALOG_PLL_DDR_DOUBLE_CP_MASK        (0x400U)
#define CCM_ANALOG_PLL_DDR_DOUBLE_CP_SHIFT       (10U)
#define CCM_ANALOG_PLL_DDR_HOLD_RING_OFF_MASK    (0x800U)
#define CCM_ANALOG_PLL_DDR_HOLD_RING_OFF_SHIFT   (11U)
#define CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK_MASK  (0x1000U)
#define CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK_SHIFT (12U)
#define CCM_ANALOG_PLL_DDR_ENABLE_CLK_MASK       (0x2000U)
#define CCM_ANALOG_PLL_DDR_ENABLE_CLK_SHIFT      (13U)
#define CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC_MASK   (0xC000U)
#define CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC_SHIFT  (14U)
#define CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_DDR_BYPASS_MASK           (0x10000U)
#define CCM_ANALOG_PLL_DDR_BYPASS_SHIFT          (16U)
#define CCM_ANALOG_PLL_DDR_DITHER_ENABLE_MASK    (0x20000U)
#define CCM_ANALOG_PLL_DDR_DITHER_ENABLE_SHIFT   (17U)
#define CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN_MASK    (0x40000U)
#define CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN_SHIFT   (18U)
#define CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE_MASK (0x80000U)
#define CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE_SHIFT (19U)
#define CCM_ANALOG_PLL_DDR_POWERDOWN_MASK        (0x100000U)
#define CCM_ANALOG_PLL_DDR_POWERDOWN_SHIFT       (20U)
#define CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT_MASK  (0x600000U)
#define CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT_SHIFT (21U)
#define CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT(x)    (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_DDR_RSVD1_MASK            (0x7F800000U)
#define CCM_ANALOG_PLL_DDR_RSVD1_SHIFT           (23U)
#define CCM_ANALOG_PLL_DDR_RSVD1(x)              (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_RSVD1_SHIFT)) & CCM_ANALOG_PLL_DDR_RSVD1_MASK)
#define CCM_ANALOG_PLL_DDR_LOCK_MASK             (0x80000000U)
#define CCM_ANALOG_PLL_DDR_LOCK_SHIFT            (31U)

/*! @name PLL_DDR_SET - Anadig DDR PLL Control Register */
#define CCM_ANALOG_PLL_DDR_SET_DIV_SELECT_MASK   (0x7FU)
#define CCM_ANALOG_PLL_DDR_SET_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_DDR_SET_DIV_SELECT(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_SET_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_DDR_SET_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_DDR_SET_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_DDR_SET_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_DDR_SET_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_DDR_SET_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_DDR_SET_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_DDR_SET_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_DDR_SET_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_DDR_SET_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_DDR_SET_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_DDR_SET_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_DDR_SET_DIV2_ENABLE_CLK_MASK (0x1000U)
#define CCM_ANALOG_PLL_DDR_SET_DIV2_ENABLE_CLK_SHIFT (12U)
#define CCM_ANALOG_PLL_DDR_SET_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_DDR_SET_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_DDR_SET_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_DDR_SET_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_DDR_SET_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_SET_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_DDR_SET_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_DDR_SET_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_DDR_SET_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_DDR_SET_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_DDR_SET_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_DDR_SET_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_DDR_SET_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_DDR_SET_PLL_DDR_OVERRIDE_MASK (0x80000U)
#define CCM_ANALOG_PLL_DDR_SET_PLL_DDR_OVERRIDE_SHIFT (19U)
#define CCM_ANALOG_PLL_DDR_SET_POWERDOWN_MASK    (0x100000U)
#define CCM_ANALOG_PLL_DDR_SET_POWERDOWN_SHIFT   (20U)
#define CCM_ANALOG_PLL_DDR_SET_TEST_DIV_SELECT_MASK (0x600000U)
#define CCM_ANALOG_PLL_DDR_SET_TEST_DIV_SELECT_SHIFT (21U)
#define CCM_ANALOG_PLL_DDR_SET_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_SET_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_DDR_SET_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_DDR_SET_RSVD1_MASK        (0x7F800000U)
#define CCM_ANALOG_PLL_DDR_SET_RSVD1_SHIFT       (23U)
#define CCM_ANALOG_PLL_DDR_SET_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_SET_RSVD1_SHIFT)) & CCM_ANALOG_PLL_DDR_SET_RSVD1_MASK)
#define CCM_ANALOG_PLL_DDR_SET_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_DDR_SET_LOCK_SHIFT        (31U)

/*! @name PLL_DDR_CLR - Anadig DDR PLL Control Register */
#define CCM_ANALOG_PLL_DDR_CLR_DIV_SELECT_MASK   (0x7FU)
#define CCM_ANALOG_PLL_DDR_CLR_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_DDR_CLR_DIV_SELECT(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_CLR_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_DDR_CLR_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_DDR_CLR_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_DDR_CLR_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_DDR_CLR_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_DDR_CLR_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_DDR_CLR_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_DDR_CLR_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_DDR_CLR_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_DDR_CLR_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_DDR_CLR_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_DDR_CLR_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_DDR_CLR_DIV2_ENABLE_CLK_MASK (0x1000U)
#define CCM_ANALOG_PLL_DDR_CLR_DIV2_ENABLE_CLK_SHIFT (12U)
#define CCM_ANALOG_PLL_DDR_CLR_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_DDR_CLR_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_DDR_CLR_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_DDR_CLR_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_DDR_CLR_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_CLR_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_DDR_CLR_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_DDR_CLR_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_DDR_CLR_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_DDR_CLR_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_DDR_CLR_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_DDR_CLR_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_DDR_CLR_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_DDR_CLR_PLL_DDR_OVERRIDE_MASK (0x80000U)
#define CCM_ANALOG_PLL_DDR_CLR_PLL_DDR_OVERRIDE_SHIFT (19U)
#define CCM_ANALOG_PLL_DDR_CLR_POWERDOWN_MASK    (0x100000U)
#define CCM_ANALOG_PLL_DDR_CLR_POWERDOWN_SHIFT   (20U)
#define CCM_ANALOG_PLL_DDR_CLR_TEST_DIV_SELECT_MASK (0x600000U)
#define CCM_ANALOG_PLL_DDR_CLR_TEST_DIV_SELECT_SHIFT (21U)
#define CCM_ANALOG_PLL_DDR_CLR_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_CLR_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_DDR_CLR_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_DDR_CLR_RSVD1_MASK        (0x7F800000U)
#define CCM_ANALOG_PLL_DDR_CLR_RSVD1_SHIFT       (23U)
#define CCM_ANALOG_PLL_DDR_CLR_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_CLR_RSVD1_SHIFT)) & CCM_ANALOG_PLL_DDR_CLR_RSVD1_MASK)
#define CCM_ANALOG_PLL_DDR_CLR_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_DDR_CLR_LOCK_SHIFT        (31U)

/*! @name PLL_DDR_TOG - Anadig DDR PLL Control Register */
#define CCM_ANALOG_PLL_DDR_TOG_DIV_SELECT_MASK   (0x7FU)
#define CCM_ANALOG_PLL_DDR_TOG_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_DDR_TOG_DIV_SELECT(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_TOG_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_DDR_TOG_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_DDR_TOG_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_DDR_TOG_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_DDR_TOG_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_DDR_TOG_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_DDR_TOG_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_DDR_TOG_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_DDR_TOG_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_DDR_TOG_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_DDR_TOG_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_DDR_TOG_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_DDR_TOG_DIV2_ENABLE_CLK_MASK (0x1000U)
#define CCM_ANALOG_PLL_DDR_TOG_DIV2_ENABLE_CLK_SHIFT (12U)
#define CCM_ANALOG_PLL_DDR_TOG_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_DDR_TOG_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_DDR_TOG_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_DDR_TOG_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_DDR_TOG_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_TOG_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_DDR_TOG_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_DDR_TOG_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_DDR_TOG_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_DDR_TOG_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_DDR_TOG_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_DDR_TOG_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_DDR_TOG_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_DDR_TOG_PLL_DDR_OVERRIDE_MASK (0x80000U)
#define CCM_ANALOG_PLL_DDR_TOG_PLL_DDR_OVERRIDE_SHIFT (19U)
#define CCM_ANALOG_PLL_DDR_TOG_POWERDOWN_MASK    (0x100000U)
#define CCM_ANALOG_PLL_DDR_TOG_POWERDOWN_SHIFT   (20U)
#define CCM_ANALOG_PLL_DDR_TOG_TEST_DIV_SELECT_MASK (0x600000U)
#define CCM_ANALOG_PLL_DDR_TOG_TEST_DIV_SELECT_SHIFT (21U)
#define CCM_ANALOG_PLL_DDR_TOG_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_TOG_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_DDR_TOG_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_DDR_TOG_RSVD1_MASK        (0x7F800000U)
#define CCM_ANALOG_PLL_DDR_TOG_RSVD1_SHIFT       (23U)
#define CCM_ANALOG_PLL_DDR_TOG_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_TOG_RSVD1_SHIFT)) & CCM_ANALOG_PLL_DDR_TOG_RSVD1_MASK)
#define CCM_ANALOG_PLL_DDR_TOG_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_DDR_TOG_LOCK_SHIFT        (31U)

/*! @name PLL_DDR_SS - DDR PLL Spread Spectrum Register. */
#define CCM_ANALOG_PLL_DDR_SS_STEP_MASK          (0x7FFFU)
#define CCM_ANALOG_PLL_DDR_SS_STEP_SHIFT         (0U)
#define CCM_ANALOG_PLL_DDR_SS_STEP(x)            (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_SS_STEP_SHIFT)) & CCM_ANALOG_PLL_DDR_SS_STEP_MASK)
#define CCM_ANALOG_PLL_DDR_SS_ENABLE_MASK        (0x8000U)
#define CCM_ANALOG_PLL_DDR_SS_ENABLE_SHIFT       (15U)
#define CCM_ANALOG_PLL_DDR_SS_STOP_MASK          (0xFFFF0000U)
#define CCM_ANALOG_PLL_DDR_SS_STOP_SHIFT         (16U)
#define CCM_ANALOG_PLL_DDR_SS_STOP(x)            (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_SS_STOP_SHIFT)) & CCM_ANALOG_PLL_DDR_SS_STOP_MASK)

/*! @name PLL_DDR_NUM - Numerator of DDR PLL Fractional Loop Divider Register */
#define CCM_ANALOG_PLL_DDR_NUM_A_MASK            (0x3FFFFFFFU)
#define CCM_ANALOG_PLL_DDR_NUM_A_SHIFT           (0U)
#define CCM_ANALOG_PLL_DDR_NUM_A(x)              (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_NUM_A_SHIFT)) & CCM_ANALOG_PLL_DDR_NUM_A_MASK)
#define CCM_ANALOG_PLL_DDR_NUM_RSVD0_MASK        (0xC0000000U)
#define CCM_ANALOG_PLL_DDR_NUM_RSVD0_SHIFT       (30U)
#define CCM_ANALOG_PLL_DDR_NUM_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_NUM_RSVD0_SHIFT)) & CCM_ANALOG_PLL_DDR_NUM_RSVD0_MASK)

/*! @name PLL_DDR_DENOM - Denominator of DDR PLL Fractional Loop Divider Register */
#define CCM_ANALOG_PLL_DDR_DENOM_B_MASK          (0x3FFFFFFFU)
#define CCM_ANALOG_PLL_DDR_DENOM_B_SHIFT         (0U)
#define CCM_ANALOG_PLL_DDR_DENOM_B(x)            (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_DENOM_B_SHIFT)) & CCM_ANALOG_PLL_DDR_DENOM_B_MASK)
#define CCM_ANALOG_PLL_DDR_DENOM_RSVD0_MASK      (0xC0000000U)
#define CCM_ANALOG_PLL_DDR_DENOM_RSVD0_SHIFT     (30U)
#define CCM_ANALOG_PLL_DDR_DENOM_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_DDR_DENOM_RSVD0_SHIFT)) & CCM_ANALOG_PLL_DDR_DENOM_RSVD0_MASK)

/*! @name PLL_480 - Anadig 480MHz PLL Control Register */
#define CCM_ANALOG_PLL_480_DIV_SELECT_MASK       (0x1U)
#define CCM_ANALOG_PLL_480_DIV_SELECT_SHIFT      (0U)
#define CCM_ANALOG_PLL_480_RSVD0_MASK            (0xEU)
#define CCM_ANALOG_PLL_480_RSVD0_SHIFT           (1U)
#define CCM_ANALOG_PLL_480_RSVD0(x)              (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_RSVD0_SHIFT)) & CCM_ANALOG_PLL_480_RSVD0_MASK)
#define CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE_MASK (0x10U)
#define CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE_SHIFT (4U)
#define CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE_MASK (0x20U)
#define CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE_SHIFT (5U)
#define CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE_MASK (0x40U)
#define CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE_SHIFT (6U)
#define CCM_ANALOG_PLL_480_HALF_LF_MASK          (0x80U)
#define CCM_ANALOG_PLL_480_HALF_LF_SHIFT         (7U)
#define CCM_ANALOG_PLL_480_DOUBLE_LF_MASK        (0x100U)
#define CCM_ANALOG_PLL_480_DOUBLE_LF_SHIFT       (8U)
#define CCM_ANALOG_PLL_480_HALF_CP_MASK          (0x200U)
#define CCM_ANALOG_PLL_480_HALF_CP_SHIFT         (9U)
#define CCM_ANALOG_PLL_480_DOUBLE_CP_MASK        (0x400U)
#define CCM_ANALOG_PLL_480_DOUBLE_CP_SHIFT       (10U)
#define CCM_ANALOG_PLL_480_HOLD_RING_OFF_MASK    (0x800U)
#define CCM_ANALOG_PLL_480_HOLD_RING_OFF_SHIFT   (11U)
#define CCM_ANALOG_PLL_480_POWERDOWN_MASK        (0x1000U)
#define CCM_ANALOG_PLL_480_POWERDOWN_SHIFT       (12U)
#define CCM_ANALOG_PLL_480_ENABLE_CLK_MASK       (0x2000U)
#define CCM_ANALOG_PLL_480_ENABLE_CLK_SHIFT      (13U)
#define CCM_ANALOG_PLL_480_BYPASS_CLK_SRC_MASK   (0xC000U)
#define CCM_ANALOG_PLL_480_BYPASS_CLK_SRC_SHIFT  (14U)
#define CCM_ANALOG_PLL_480_BYPASS_CLK_SRC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_480_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_480_BYPASS_MASK           (0x10000U)
#define CCM_ANALOG_PLL_480_BYPASS_SHIFT          (16U)
#define CCM_ANALOG_PLL_480_PLL_480_OVERRIDE_MASK (0x20000U)
#define CCM_ANALOG_PLL_480_PLL_480_OVERRIDE_SHIFT (17U)
#define CCM_ANALOG_PLL_480_PFD0_OVERRIDE_MASK    (0x40000U)
#define CCM_ANALOG_PLL_480_PFD0_OVERRIDE_SHIFT   (18U)
#define CCM_ANALOG_PLL_480_PFD1_OVERRIDE_MASK    (0x80000U)
#define CCM_ANALOG_PLL_480_PFD1_OVERRIDE_SHIFT   (19U)
#define CCM_ANALOG_PLL_480_PFD2_OVERRIDE_MASK    (0x100000U)
#define CCM_ANALOG_PLL_480_PFD2_OVERRIDE_SHIFT   (20U)
#define CCM_ANALOG_PLL_480_PFD3_OVERRIDE_MASK    (0x200000U)
#define CCM_ANALOG_PLL_480_PFD3_OVERRIDE_SHIFT   (21U)
#define CCM_ANALOG_PLL_480_PFD4_OVERRIDE_MASK    (0x400000U)
#define CCM_ANALOG_PLL_480_PFD4_OVERRIDE_SHIFT   (22U)
#define CCM_ANALOG_PLL_480_PFD5_OVERRIDE_MASK    (0x800000U)
#define CCM_ANALOG_PLL_480_PFD5_OVERRIDE_SHIFT   (23U)
#define CCM_ANALOG_PLL_480_PFD6_OVERRIDE_MASK    (0x1000000U)
#define CCM_ANALOG_PLL_480_PFD6_OVERRIDE_SHIFT   (24U)
#define CCM_ANALOG_PLL_480_PFD7_OVERRIDE_MASK    (0x2000000U)
#define CCM_ANALOG_PLL_480_PFD7_OVERRIDE_SHIFT   (25U)
#define CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE_MASK (0x4000000U)
#define CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE_SHIFT (26U)
#define CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE_MASK (0x8000000U)
#define CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE_SHIFT (27U)
#define CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE_MASK (0x10000000U)
#define CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE_SHIFT (28U)
#define CCM_ANALOG_PLL_480_RSVD1_MASK            (0x60000000U)
#define CCM_ANALOG_PLL_480_RSVD1_SHIFT           (29U)
#define CCM_ANALOG_PLL_480_RSVD1(x)              (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_RSVD1_SHIFT)) & CCM_ANALOG_PLL_480_RSVD1_MASK)
#define CCM_ANALOG_PLL_480_LOCK_MASK             (0x80000000U)
#define CCM_ANALOG_PLL_480_LOCK_SHIFT            (31U)

/*! @name PLL_480_SET - Anadig 480MHz PLL Control Register */
#define CCM_ANALOG_PLL_480_SET_DIV_SELECT_MASK   (0x1U)
#define CCM_ANALOG_PLL_480_SET_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_480_SET_RSVD0_MASK        (0xEU)
#define CCM_ANALOG_PLL_480_SET_RSVD0_SHIFT       (1U)
#define CCM_ANALOG_PLL_480_SET_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_SET_RSVD0_SHIFT)) & CCM_ANALOG_PLL_480_SET_RSVD0_MASK)
#define CCM_ANALOG_PLL_480_SET_MAIN_DIV1_CLKGATE_MASK (0x10U)
#define CCM_ANALOG_PLL_480_SET_MAIN_DIV1_CLKGATE_SHIFT (4U)
#define CCM_ANALOG_PLL_480_SET_MAIN_DIV2_CLKGATE_MASK (0x20U)
#define CCM_ANALOG_PLL_480_SET_MAIN_DIV2_CLKGATE_SHIFT (5U)
#define CCM_ANALOG_PLL_480_SET_MAIN_DIV4_CLKGATE_MASK (0x40U)
#define CCM_ANALOG_PLL_480_SET_MAIN_DIV4_CLKGATE_SHIFT (6U)
#define CCM_ANALOG_PLL_480_SET_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_480_SET_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_480_SET_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_480_SET_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_480_SET_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_480_SET_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_480_SET_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_480_SET_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_480_SET_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_480_SET_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_480_SET_POWERDOWN_MASK    (0x1000U)
#define CCM_ANALOG_PLL_480_SET_POWERDOWN_SHIFT   (12U)
#define CCM_ANALOG_PLL_480_SET_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_480_SET_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_480_SET_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_480_SET_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_480_SET_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_SET_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_480_SET_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_480_SET_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_480_SET_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_480_SET_PLL_480_OVERRIDE_MASK (0x20000U)
#define CCM_ANALOG_PLL_480_SET_PLL_480_OVERRIDE_SHIFT (17U)
#define CCM_ANALOG_PLL_480_SET_PFD0_OVERRIDE_MASK (0x40000U)
#define CCM_ANALOG_PLL_480_SET_PFD0_OVERRIDE_SHIFT (18U)
#define CCM_ANALOG_PLL_480_SET_PFD1_OVERRIDE_MASK (0x80000U)
#define CCM_ANALOG_PLL_480_SET_PFD1_OVERRIDE_SHIFT (19U)
#define CCM_ANALOG_PLL_480_SET_PFD2_OVERRIDE_MASK (0x100000U)
#define CCM_ANALOG_PLL_480_SET_PFD2_OVERRIDE_SHIFT (20U)
#define CCM_ANALOG_PLL_480_SET_PFD3_OVERRIDE_MASK (0x200000U)
#define CCM_ANALOG_PLL_480_SET_PFD3_OVERRIDE_SHIFT (21U)
#define CCM_ANALOG_PLL_480_SET_PFD4_OVERRIDE_MASK (0x400000U)
#define CCM_ANALOG_PLL_480_SET_PFD4_OVERRIDE_SHIFT (22U)
#define CCM_ANALOG_PLL_480_SET_PFD5_OVERRIDE_MASK (0x800000U)
#define CCM_ANALOG_PLL_480_SET_PFD5_OVERRIDE_SHIFT (23U)
#define CCM_ANALOG_PLL_480_SET_PFD6_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_480_SET_PFD6_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_480_SET_PFD7_OVERRIDE_MASK (0x2000000U)
#define CCM_ANALOG_PLL_480_SET_PFD7_OVERRIDE_SHIFT (25U)
#define CCM_ANALOG_PLL_480_SET_PFD0_DIV2_CLKGATE_MASK (0x4000000U)
#define CCM_ANALOG_PLL_480_SET_PFD0_DIV2_CLKGATE_SHIFT (26U)
#define CCM_ANALOG_PLL_480_SET_PFD1_DIV2_CLKGATE_MASK (0x8000000U)
#define CCM_ANALOG_PLL_480_SET_PFD1_DIV2_CLKGATE_SHIFT (27U)
#define CCM_ANALOG_PLL_480_SET_PFD2_DIV2_CLKGATE_MASK (0x10000000U)
#define CCM_ANALOG_PLL_480_SET_PFD2_DIV2_CLKGATE_SHIFT (28U)
#define CCM_ANALOG_PLL_480_SET_RSVD1_MASK        (0x60000000U)
#define CCM_ANALOG_PLL_480_SET_RSVD1_SHIFT       (29U)
#define CCM_ANALOG_PLL_480_SET_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_SET_RSVD1_SHIFT)) & CCM_ANALOG_PLL_480_SET_RSVD1_MASK)
#define CCM_ANALOG_PLL_480_SET_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_480_SET_LOCK_SHIFT        (31U)

/*! @name PLL_480_CLR - Anadig 480MHz PLL Control Register */
#define CCM_ANALOG_PLL_480_CLR_DIV_SELECT_MASK   (0x1U)
#define CCM_ANALOG_PLL_480_CLR_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_480_CLR_RSVD0_MASK        (0xEU)
#define CCM_ANALOG_PLL_480_CLR_RSVD0_SHIFT       (1U)
#define CCM_ANALOG_PLL_480_CLR_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_CLR_RSVD0_SHIFT)) & CCM_ANALOG_PLL_480_CLR_RSVD0_MASK)
#define CCM_ANALOG_PLL_480_CLR_MAIN_DIV1_CLKGATE_MASK (0x10U)
#define CCM_ANALOG_PLL_480_CLR_MAIN_DIV1_CLKGATE_SHIFT (4U)
#define CCM_ANALOG_PLL_480_CLR_MAIN_DIV2_CLKGATE_MASK (0x20U)
#define CCM_ANALOG_PLL_480_CLR_MAIN_DIV2_CLKGATE_SHIFT (5U)
#define CCM_ANALOG_PLL_480_CLR_MAIN_DIV4_CLKGATE_MASK (0x40U)
#define CCM_ANALOG_PLL_480_CLR_MAIN_DIV4_CLKGATE_SHIFT (6U)
#define CCM_ANALOG_PLL_480_CLR_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_480_CLR_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_480_CLR_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_480_CLR_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_480_CLR_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_480_CLR_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_480_CLR_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_480_CLR_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_480_CLR_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_480_CLR_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_480_CLR_POWERDOWN_MASK    (0x1000U)
#define CCM_ANALOG_PLL_480_CLR_POWERDOWN_SHIFT   (12U)
#define CCM_ANALOG_PLL_480_CLR_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_480_CLR_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_480_CLR_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_480_CLR_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_480_CLR_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_CLR_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_480_CLR_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_480_CLR_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_480_CLR_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_480_CLR_PLL_480_OVERRIDE_MASK (0x20000U)
#define CCM_ANALOG_PLL_480_CLR_PLL_480_OVERRIDE_SHIFT (17U)
#define CCM_ANALOG_PLL_480_CLR_PFD0_OVERRIDE_MASK (0x40000U)
#define CCM_ANALOG_PLL_480_CLR_PFD0_OVERRIDE_SHIFT (18U)
#define CCM_ANALOG_PLL_480_CLR_PFD1_OVERRIDE_MASK (0x80000U)
#define CCM_ANALOG_PLL_480_CLR_PFD1_OVERRIDE_SHIFT (19U)
#define CCM_ANALOG_PLL_480_CLR_PFD2_OVERRIDE_MASK (0x100000U)
#define CCM_ANALOG_PLL_480_CLR_PFD2_OVERRIDE_SHIFT (20U)
#define CCM_ANALOG_PLL_480_CLR_PFD3_OVERRIDE_MASK (0x200000U)
#define CCM_ANALOG_PLL_480_CLR_PFD3_OVERRIDE_SHIFT (21U)
#define CCM_ANALOG_PLL_480_CLR_PFD4_OVERRIDE_MASK (0x400000U)
#define CCM_ANALOG_PLL_480_CLR_PFD4_OVERRIDE_SHIFT (22U)
#define CCM_ANALOG_PLL_480_CLR_PFD5_OVERRIDE_MASK (0x800000U)
#define CCM_ANALOG_PLL_480_CLR_PFD5_OVERRIDE_SHIFT (23U)
#define CCM_ANALOG_PLL_480_CLR_PFD6_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_480_CLR_PFD6_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_480_CLR_PFD7_OVERRIDE_MASK (0x2000000U)
#define CCM_ANALOG_PLL_480_CLR_PFD7_OVERRIDE_SHIFT (25U)
#define CCM_ANALOG_PLL_480_CLR_PFD0_DIV2_CLKGATE_MASK (0x4000000U)
#define CCM_ANALOG_PLL_480_CLR_PFD0_DIV2_CLKGATE_SHIFT (26U)
#define CCM_ANALOG_PLL_480_CLR_PFD1_DIV2_CLKGATE_MASK (0x8000000U)
#define CCM_ANALOG_PLL_480_CLR_PFD1_DIV2_CLKGATE_SHIFT (27U)
#define CCM_ANALOG_PLL_480_CLR_PFD2_DIV2_CLKGATE_MASK (0x10000000U)
#define CCM_ANALOG_PLL_480_CLR_PFD2_DIV2_CLKGATE_SHIFT (28U)
#define CCM_ANALOG_PLL_480_CLR_RSVD1_MASK        (0x60000000U)
#define CCM_ANALOG_PLL_480_CLR_RSVD1_SHIFT       (29U)
#define CCM_ANALOG_PLL_480_CLR_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_CLR_RSVD1_SHIFT)) & CCM_ANALOG_PLL_480_CLR_RSVD1_MASK)
#define CCM_ANALOG_PLL_480_CLR_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_480_CLR_LOCK_SHIFT        (31U)

/*! @name PLL_480_TOG - Anadig 480MHz PLL Control Register */
#define CCM_ANALOG_PLL_480_TOG_DIV_SELECT_MASK   (0x1U)
#define CCM_ANALOG_PLL_480_TOG_DIV_SELECT_SHIFT  (0U)
#define CCM_ANALOG_PLL_480_TOG_RSVD0_MASK        (0xEU)
#define CCM_ANALOG_PLL_480_TOG_RSVD0_SHIFT       (1U)
#define CCM_ANALOG_PLL_480_TOG_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_TOG_RSVD0_SHIFT)) & CCM_ANALOG_PLL_480_TOG_RSVD0_MASK)
#define CCM_ANALOG_PLL_480_TOG_MAIN_DIV1_CLKGATE_MASK (0x10U)
#define CCM_ANALOG_PLL_480_TOG_MAIN_DIV1_CLKGATE_SHIFT (4U)
#define CCM_ANALOG_PLL_480_TOG_MAIN_DIV2_CLKGATE_MASK (0x20U)
#define CCM_ANALOG_PLL_480_TOG_MAIN_DIV2_CLKGATE_SHIFT (5U)
#define CCM_ANALOG_PLL_480_TOG_MAIN_DIV4_CLKGATE_MASK (0x40U)
#define CCM_ANALOG_PLL_480_TOG_MAIN_DIV4_CLKGATE_SHIFT (6U)
#define CCM_ANALOG_PLL_480_TOG_HALF_LF_MASK      (0x80U)
#define CCM_ANALOG_PLL_480_TOG_HALF_LF_SHIFT     (7U)
#define CCM_ANALOG_PLL_480_TOG_DOUBLE_LF_MASK    (0x100U)
#define CCM_ANALOG_PLL_480_TOG_DOUBLE_LF_SHIFT   (8U)
#define CCM_ANALOG_PLL_480_TOG_HALF_CP_MASK      (0x200U)
#define CCM_ANALOG_PLL_480_TOG_HALF_CP_SHIFT     (9U)
#define CCM_ANALOG_PLL_480_TOG_DOUBLE_CP_MASK    (0x400U)
#define CCM_ANALOG_PLL_480_TOG_DOUBLE_CP_SHIFT   (10U)
#define CCM_ANALOG_PLL_480_TOG_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_480_TOG_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_480_TOG_POWERDOWN_MASK    (0x1000U)
#define CCM_ANALOG_PLL_480_TOG_POWERDOWN_SHIFT   (12U)
#define CCM_ANALOG_PLL_480_TOG_ENABLE_CLK_MASK   (0x2000U)
#define CCM_ANALOG_PLL_480_TOG_ENABLE_CLK_SHIFT  (13U)
#define CCM_ANALOG_PLL_480_TOG_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_480_TOG_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_480_TOG_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_TOG_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_480_TOG_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_480_TOG_BYPASS_MASK       (0x10000U)
#define CCM_ANALOG_PLL_480_TOG_BYPASS_SHIFT      (16U)
#define CCM_ANALOG_PLL_480_TOG_PLL_480_OVERRIDE_MASK (0x20000U)
#define CCM_ANALOG_PLL_480_TOG_PLL_480_OVERRIDE_SHIFT (17U)
#define CCM_ANALOG_PLL_480_TOG_PFD0_OVERRIDE_MASK (0x40000U)
#define CCM_ANALOG_PLL_480_TOG_PFD0_OVERRIDE_SHIFT (18U)
#define CCM_ANALOG_PLL_480_TOG_PFD1_OVERRIDE_MASK (0x80000U)
#define CCM_ANALOG_PLL_480_TOG_PFD1_OVERRIDE_SHIFT (19U)
#define CCM_ANALOG_PLL_480_TOG_PFD2_OVERRIDE_MASK (0x100000U)
#define CCM_ANALOG_PLL_480_TOG_PFD2_OVERRIDE_SHIFT (20U)
#define CCM_ANALOG_PLL_480_TOG_PFD3_OVERRIDE_MASK (0x200000U)
#define CCM_ANALOG_PLL_480_TOG_PFD3_OVERRIDE_SHIFT (21U)
#define CCM_ANALOG_PLL_480_TOG_PFD4_OVERRIDE_MASK (0x400000U)
#define CCM_ANALOG_PLL_480_TOG_PFD4_OVERRIDE_SHIFT (22U)
#define CCM_ANALOG_PLL_480_TOG_PFD5_OVERRIDE_MASK (0x800000U)
#define CCM_ANALOG_PLL_480_TOG_PFD5_OVERRIDE_SHIFT (23U)
#define CCM_ANALOG_PLL_480_TOG_PFD6_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_480_TOG_PFD6_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_480_TOG_PFD7_OVERRIDE_MASK (0x2000000U)
#define CCM_ANALOG_PLL_480_TOG_PFD7_OVERRIDE_SHIFT (25U)
#define CCM_ANALOG_PLL_480_TOG_PFD0_DIV2_CLKGATE_MASK (0x4000000U)
#define CCM_ANALOG_PLL_480_TOG_PFD0_DIV2_CLKGATE_SHIFT (26U)
#define CCM_ANALOG_PLL_480_TOG_PFD1_DIV2_CLKGATE_MASK (0x8000000U)
#define CCM_ANALOG_PLL_480_TOG_PFD1_DIV2_CLKGATE_SHIFT (27U)
#define CCM_ANALOG_PLL_480_TOG_PFD2_DIV2_CLKGATE_MASK (0x10000000U)
#define CCM_ANALOG_PLL_480_TOG_PFD2_DIV2_CLKGATE_SHIFT (28U)
#define CCM_ANALOG_PLL_480_TOG_RSVD1_MASK        (0x60000000U)
#define CCM_ANALOG_PLL_480_TOG_RSVD1_SHIFT       (29U)
#define CCM_ANALOG_PLL_480_TOG_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_480_TOG_RSVD1_SHIFT)) & CCM_ANALOG_PLL_480_TOG_RSVD1_MASK)
#define CCM_ANALOG_PLL_480_TOG_LOCK_MASK         (0x80000000U)
#define CCM_ANALOG_PLL_480_TOG_LOCK_SHIFT        (31U)

/*! @name PFD_480A - 480MHz Clock Phase Fractional Divider Control Register A */
#define CCM_ANALOG_PFD_480A_PFD0_FRAC_MASK       (0x3FU)
#define CCM_ANALOG_PFD_480A_PFD0_FRAC_SHIFT      (0U)
#define CCM_ANALOG_PFD_480A_PFD0_FRAC(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_PFD0_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_PFD0_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_PFD0_STABLE_MASK     (0x40U)
#define CCM_ANALOG_PFD_480A_PFD0_STABLE_SHIFT    (6U)
#define CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE_MASK (0x80U)
#define CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE_SHIFT (7U)
#define CCM_ANALOG_PFD_480A_PFD1_FRAC_MASK       (0x3F00U)
#define CCM_ANALOG_PFD_480A_PFD1_FRAC_SHIFT      (8U)
#define CCM_ANALOG_PFD_480A_PFD1_FRAC(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_PFD1_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_PFD1_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_PFD1_STABLE_MASK     (0x4000U)
#define CCM_ANALOG_PFD_480A_PFD1_STABLE_SHIFT    (14U)
#define CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE_MASK (0x8000U)
#define CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE_SHIFT (15U)
#define CCM_ANALOG_PFD_480A_PFD2_FRAC_MASK       (0x3F0000U)
#define CCM_ANALOG_PFD_480A_PFD2_FRAC_SHIFT      (16U)
#define CCM_ANALOG_PFD_480A_PFD2_FRAC(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_PFD2_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_PFD2_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_PFD2_STABLE_MASK     (0x400000U)
#define CCM_ANALOG_PFD_480A_PFD2_STABLE_SHIFT    (22U)
#define CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE_MASK (0x800000U)
#define CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE_SHIFT (23U)
#define CCM_ANALOG_PFD_480A_PFD3_FRAC_MASK       (0x3F000000U)
#define CCM_ANALOG_PFD_480A_PFD3_FRAC_SHIFT      (24U)
#define CCM_ANALOG_PFD_480A_PFD3_FRAC(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_PFD3_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_PFD3_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_PFD3_STABLE_MASK     (0x40000000U)
#define CCM_ANALOG_PFD_480A_PFD3_STABLE_SHIFT    (30U)
#define CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE_MASK (0x80000000U)
#define CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE_SHIFT (31U)

/*! @name PFD_480A_SET - 480MHz Clock Phase Fractional Divider Control Register A */
#define CCM_ANALOG_PFD_480A_SET_PFD0_FRAC_MASK   (0x3FU)
#define CCM_ANALOG_PFD_480A_SET_PFD0_FRAC_SHIFT  (0U)
#define CCM_ANALOG_PFD_480A_SET_PFD0_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_SET_PFD0_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_SET_PFD0_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_SET_PFD0_STABLE_MASK (0x40U)
#define CCM_ANALOG_PFD_480A_SET_PFD0_STABLE_SHIFT (6U)
#define CCM_ANALOG_PFD_480A_SET_PFD0_DIV1_CLKGATE_MASK (0x80U)
#define CCM_ANALOG_PFD_480A_SET_PFD0_DIV1_CLKGATE_SHIFT (7U)
#define CCM_ANALOG_PFD_480A_SET_PFD1_FRAC_MASK   (0x3F00U)
#define CCM_ANALOG_PFD_480A_SET_PFD1_FRAC_SHIFT  (8U)
#define CCM_ANALOG_PFD_480A_SET_PFD1_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_SET_PFD1_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_SET_PFD1_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_SET_PFD1_STABLE_MASK (0x4000U)
#define CCM_ANALOG_PFD_480A_SET_PFD1_STABLE_SHIFT (14U)
#define CCM_ANALOG_PFD_480A_SET_PFD1_DIV1_CLKGATE_MASK (0x8000U)
#define CCM_ANALOG_PFD_480A_SET_PFD1_DIV1_CLKGATE_SHIFT (15U)
#define CCM_ANALOG_PFD_480A_SET_PFD2_FRAC_MASK   (0x3F0000U)
#define CCM_ANALOG_PFD_480A_SET_PFD2_FRAC_SHIFT  (16U)
#define CCM_ANALOG_PFD_480A_SET_PFD2_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_SET_PFD2_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_SET_PFD2_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_SET_PFD2_STABLE_MASK (0x400000U)
#define CCM_ANALOG_PFD_480A_SET_PFD2_STABLE_SHIFT (22U)
#define CCM_ANALOG_PFD_480A_SET_PFD2_DIV1_CLKGATE_MASK (0x800000U)
#define CCM_ANALOG_PFD_480A_SET_PFD2_DIV1_CLKGATE_SHIFT (23U)
#define CCM_ANALOG_PFD_480A_SET_PFD3_FRAC_MASK   (0x3F000000U)
#define CCM_ANALOG_PFD_480A_SET_PFD3_FRAC_SHIFT  (24U)
#define CCM_ANALOG_PFD_480A_SET_PFD3_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_SET_PFD3_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_SET_PFD3_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_SET_PFD3_STABLE_MASK (0x40000000U)
#define CCM_ANALOG_PFD_480A_SET_PFD3_STABLE_SHIFT (30U)
#define CCM_ANALOG_PFD_480A_SET_PFD3_DIV1_CLKGATE_MASK (0x80000000U)
#define CCM_ANALOG_PFD_480A_SET_PFD3_DIV1_CLKGATE_SHIFT (31U)

/*! @name PFD_480A_CLR - 480MHz Clock Phase Fractional Divider Control Register A */
#define CCM_ANALOG_PFD_480A_CLR_PFD0_FRAC_MASK   (0x3FU)
#define CCM_ANALOG_PFD_480A_CLR_PFD0_FRAC_SHIFT  (0U)
#define CCM_ANALOG_PFD_480A_CLR_PFD0_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_CLR_PFD0_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_CLR_PFD0_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_CLR_PFD0_STABLE_MASK (0x40U)
#define CCM_ANALOG_PFD_480A_CLR_PFD0_STABLE_SHIFT (6U)
#define CCM_ANALOG_PFD_480A_CLR_PFD0_DIV1_CLKGATE_MASK (0x80U)
#define CCM_ANALOG_PFD_480A_CLR_PFD0_DIV1_CLKGATE_SHIFT (7U)
#define CCM_ANALOG_PFD_480A_CLR_PFD1_FRAC_MASK   (0x3F00U)
#define CCM_ANALOG_PFD_480A_CLR_PFD1_FRAC_SHIFT  (8U)
#define CCM_ANALOG_PFD_480A_CLR_PFD1_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_CLR_PFD1_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_CLR_PFD1_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_CLR_PFD1_STABLE_MASK (0x4000U)
#define CCM_ANALOG_PFD_480A_CLR_PFD1_STABLE_SHIFT (14U)
#define CCM_ANALOG_PFD_480A_CLR_PFD1_DIV1_CLKGATE_MASK (0x8000U)
#define CCM_ANALOG_PFD_480A_CLR_PFD1_DIV1_CLKGATE_SHIFT (15U)
#define CCM_ANALOG_PFD_480A_CLR_PFD2_FRAC_MASK   (0x3F0000U)
#define CCM_ANALOG_PFD_480A_CLR_PFD2_FRAC_SHIFT  (16U)
#define CCM_ANALOG_PFD_480A_CLR_PFD2_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_CLR_PFD2_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_CLR_PFD2_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_CLR_PFD2_STABLE_MASK (0x400000U)
#define CCM_ANALOG_PFD_480A_CLR_PFD2_STABLE_SHIFT (22U)
#define CCM_ANALOG_PFD_480A_CLR_PFD2_DIV1_CLKGATE_MASK (0x800000U)
#define CCM_ANALOG_PFD_480A_CLR_PFD2_DIV1_CLKGATE_SHIFT (23U)
#define CCM_ANALOG_PFD_480A_CLR_PFD3_FRAC_MASK   (0x3F000000U)
#define CCM_ANALOG_PFD_480A_CLR_PFD3_FRAC_SHIFT  (24U)
#define CCM_ANALOG_PFD_480A_CLR_PFD3_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_CLR_PFD3_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_CLR_PFD3_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_CLR_PFD3_STABLE_MASK (0x40000000U)
#define CCM_ANALOG_PFD_480A_CLR_PFD3_STABLE_SHIFT (30U)
#define CCM_ANALOG_PFD_480A_CLR_PFD3_DIV1_CLKGATE_MASK (0x80000000U)
#define CCM_ANALOG_PFD_480A_CLR_PFD3_DIV1_CLKGATE_SHIFT (31U)

/*! @name PFD_480A_TOG - 480MHz Clock Phase Fractional Divider Control Register A */
#define CCM_ANALOG_PFD_480A_TOG_PFD0_FRAC_MASK   (0x3FU)
#define CCM_ANALOG_PFD_480A_TOG_PFD0_FRAC_SHIFT  (0U)
#define CCM_ANALOG_PFD_480A_TOG_PFD0_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_TOG_PFD0_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_TOG_PFD0_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_TOG_PFD0_STABLE_MASK (0x40U)
#define CCM_ANALOG_PFD_480A_TOG_PFD0_STABLE_SHIFT (6U)
#define CCM_ANALOG_PFD_480A_TOG_PFD0_DIV1_CLKGATE_MASK (0x80U)
#define CCM_ANALOG_PFD_480A_TOG_PFD0_DIV1_CLKGATE_SHIFT (7U)
#define CCM_ANALOG_PFD_480A_TOG_PFD1_FRAC_MASK   (0x3F00U)
#define CCM_ANALOG_PFD_480A_TOG_PFD1_FRAC_SHIFT  (8U)
#define CCM_ANALOG_PFD_480A_TOG_PFD1_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_TOG_PFD1_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_TOG_PFD1_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_TOG_PFD1_STABLE_MASK (0x4000U)
#define CCM_ANALOG_PFD_480A_TOG_PFD1_STABLE_SHIFT (14U)
#define CCM_ANALOG_PFD_480A_TOG_PFD1_DIV1_CLKGATE_MASK (0x8000U)
#define CCM_ANALOG_PFD_480A_TOG_PFD1_DIV1_CLKGATE_SHIFT (15U)
#define CCM_ANALOG_PFD_480A_TOG_PFD2_FRAC_MASK   (0x3F0000U)
#define CCM_ANALOG_PFD_480A_TOG_PFD2_FRAC_SHIFT  (16U)
#define CCM_ANALOG_PFD_480A_TOG_PFD2_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_TOG_PFD2_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_TOG_PFD2_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_TOG_PFD2_STABLE_MASK (0x400000U)
#define CCM_ANALOG_PFD_480A_TOG_PFD2_STABLE_SHIFT (22U)
#define CCM_ANALOG_PFD_480A_TOG_PFD2_DIV1_CLKGATE_MASK (0x800000U)
#define CCM_ANALOG_PFD_480A_TOG_PFD2_DIV1_CLKGATE_SHIFT (23U)
#define CCM_ANALOG_PFD_480A_TOG_PFD3_FRAC_MASK   (0x3F000000U)
#define CCM_ANALOG_PFD_480A_TOG_PFD3_FRAC_SHIFT  (24U)
#define CCM_ANALOG_PFD_480A_TOG_PFD3_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480A_TOG_PFD3_FRAC_SHIFT)) & CCM_ANALOG_PFD_480A_TOG_PFD3_FRAC_MASK)
#define CCM_ANALOG_PFD_480A_TOG_PFD3_STABLE_MASK (0x40000000U)
#define CCM_ANALOG_PFD_480A_TOG_PFD3_STABLE_SHIFT (30U)
#define CCM_ANALOG_PFD_480A_TOG_PFD3_DIV1_CLKGATE_MASK (0x80000000U)
#define CCM_ANALOG_PFD_480A_TOG_PFD3_DIV1_CLKGATE_SHIFT (31U)

/*! @name PFD_480B - 480MHz Clock Phase Fractional Divider Control Register B */
#define CCM_ANALOG_PFD_480B_PFD4_FRAC_MASK       (0x3FU)
#define CCM_ANALOG_PFD_480B_PFD4_FRAC_SHIFT      (0U)
#define CCM_ANALOG_PFD_480B_PFD4_FRAC(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_PFD4_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_PFD4_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_PFD4_STABLE_MASK     (0x40U)
#define CCM_ANALOG_PFD_480B_PFD4_STABLE_SHIFT    (6U)
#define CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE_MASK (0x80U)
#define CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE_SHIFT (7U)
#define CCM_ANALOG_PFD_480B_PFD5_FRAC_MASK       (0x3F00U)
#define CCM_ANALOG_PFD_480B_PFD5_FRAC_SHIFT      (8U)
#define CCM_ANALOG_PFD_480B_PFD5_FRAC(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_PFD5_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_PFD5_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_PFD5_STABLE_MASK     (0x4000U)
#define CCM_ANALOG_PFD_480B_PFD5_STABLE_SHIFT    (14U)
#define CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE_MASK (0x8000U)
#define CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE_SHIFT (15U)
#define CCM_ANALOG_PFD_480B_PFD6_FRAC_MASK       (0x3F0000U)
#define CCM_ANALOG_PFD_480B_PFD6_FRAC_SHIFT      (16U)
#define CCM_ANALOG_PFD_480B_PFD6_FRAC(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_PFD6_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_PFD6_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_PFD6_STABLE_MASK     (0x400000U)
#define CCM_ANALOG_PFD_480B_PFD6_STABLE_SHIFT    (22U)
#define CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE_MASK (0x800000U)
#define CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE_SHIFT (23U)
#define CCM_ANALOG_PFD_480B_PFD7_FRAC_MASK       (0x3F000000U)
#define CCM_ANALOG_PFD_480B_PFD7_FRAC_SHIFT      (24U)
#define CCM_ANALOG_PFD_480B_PFD7_FRAC(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_PFD7_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_PFD7_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_PFD7_STABLE_MASK     (0x40000000U)
#define CCM_ANALOG_PFD_480B_PFD7_STABLE_SHIFT    (30U)
#define CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE_MASK (0x80000000U)
#define CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE_SHIFT (31U)

/*! @name PFD_480B_SET - 480MHz Clock Phase Fractional Divider Control Register B */
#define CCM_ANALOG_PFD_480B_SET_PFD4_FRAC_MASK   (0x3FU)
#define CCM_ANALOG_PFD_480B_SET_PFD4_FRAC_SHIFT  (0U)
#define CCM_ANALOG_PFD_480B_SET_PFD4_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_SET_PFD4_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_SET_PFD4_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_SET_PFD4_STABLE_MASK (0x40U)
#define CCM_ANALOG_PFD_480B_SET_PFD4_STABLE_SHIFT (6U)
#define CCM_ANALOG_PFD_480B_SET_PFD4_DIV1_CLKGATE_MASK (0x80U)
#define CCM_ANALOG_PFD_480B_SET_PFD4_DIV1_CLKGATE_SHIFT (7U)
#define CCM_ANALOG_PFD_480B_SET_PFD5_FRAC_MASK   (0x3F00U)
#define CCM_ANALOG_PFD_480B_SET_PFD5_FRAC_SHIFT  (8U)
#define CCM_ANALOG_PFD_480B_SET_PFD5_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_SET_PFD5_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_SET_PFD5_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_SET_PFD5_STABLE_MASK (0x4000U)
#define CCM_ANALOG_PFD_480B_SET_PFD5_STABLE_SHIFT (14U)
#define CCM_ANALOG_PFD_480B_SET_PFD5_DIV1_CLKGATE_MASK (0x8000U)
#define CCM_ANALOG_PFD_480B_SET_PFD5_DIV1_CLKGATE_SHIFT (15U)
#define CCM_ANALOG_PFD_480B_SET_PFD6_FRAC_MASK   (0x3F0000U)
#define CCM_ANALOG_PFD_480B_SET_PFD6_FRAC_SHIFT  (16U)
#define CCM_ANALOG_PFD_480B_SET_PFD6_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_SET_PFD6_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_SET_PFD6_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_SET_PFD6_STABLE_MASK (0x400000U)
#define CCM_ANALOG_PFD_480B_SET_PFD6_STABLE_SHIFT (22U)
#define CCM_ANALOG_PFD_480B_SET_PFD6_DIV1_CLKGATE_MASK (0x800000U)
#define CCM_ANALOG_PFD_480B_SET_PFD6_DIV1_CLKGATE_SHIFT (23U)
#define CCM_ANALOG_PFD_480B_SET_PFD7_FRAC_MASK   (0x3F000000U)
#define CCM_ANALOG_PFD_480B_SET_PFD7_FRAC_SHIFT  (24U)
#define CCM_ANALOG_PFD_480B_SET_PFD7_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_SET_PFD7_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_SET_PFD7_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_SET_PFD7_STABLE_MASK (0x40000000U)
#define CCM_ANALOG_PFD_480B_SET_PFD7_STABLE_SHIFT (30U)
#define CCM_ANALOG_PFD_480B_SET_PFD7_DIV1_CLKGATE_MASK (0x80000000U)
#define CCM_ANALOG_PFD_480B_SET_PFD7_DIV1_CLKGATE_SHIFT (31U)

/*! @name PFD_480B_CLR - 480MHz Clock Phase Fractional Divider Control Register B */
#define CCM_ANALOG_PFD_480B_CLR_PFD4_FRAC_MASK   (0x3FU)
#define CCM_ANALOG_PFD_480B_CLR_PFD4_FRAC_SHIFT  (0U)
#define CCM_ANALOG_PFD_480B_CLR_PFD4_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_CLR_PFD4_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_CLR_PFD4_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_CLR_PFD4_STABLE_MASK (0x40U)
#define CCM_ANALOG_PFD_480B_CLR_PFD4_STABLE_SHIFT (6U)
#define CCM_ANALOG_PFD_480B_CLR_PFD4_DIV1_CLKGATE_MASK (0x80U)
#define CCM_ANALOG_PFD_480B_CLR_PFD4_DIV1_CLKGATE_SHIFT (7U)
#define CCM_ANALOG_PFD_480B_CLR_PFD5_FRAC_MASK   (0x3F00U)
#define CCM_ANALOG_PFD_480B_CLR_PFD5_FRAC_SHIFT  (8U)
#define CCM_ANALOG_PFD_480B_CLR_PFD5_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_CLR_PFD5_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_CLR_PFD5_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_CLR_PFD5_STABLE_MASK (0x4000U)
#define CCM_ANALOG_PFD_480B_CLR_PFD5_STABLE_SHIFT (14U)
#define CCM_ANALOG_PFD_480B_CLR_PFD5_DIV1_CLKGATE_MASK (0x8000U)
#define CCM_ANALOG_PFD_480B_CLR_PFD5_DIV1_CLKGATE_SHIFT (15U)
#define CCM_ANALOG_PFD_480B_CLR_PFD6_FRAC_MASK   (0x3F0000U)
#define CCM_ANALOG_PFD_480B_CLR_PFD6_FRAC_SHIFT  (16U)
#define CCM_ANALOG_PFD_480B_CLR_PFD6_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_CLR_PFD6_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_CLR_PFD6_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_CLR_PFD6_STABLE_MASK (0x400000U)
#define CCM_ANALOG_PFD_480B_CLR_PFD6_STABLE_SHIFT (22U)
#define CCM_ANALOG_PFD_480B_CLR_PFD6_DIV1_CLKGATE_MASK (0x800000U)
#define CCM_ANALOG_PFD_480B_CLR_PFD6_DIV1_CLKGATE_SHIFT (23U)
#define CCM_ANALOG_PFD_480B_CLR_PFD7_FRAC_MASK   (0x3F000000U)
#define CCM_ANALOG_PFD_480B_CLR_PFD7_FRAC_SHIFT  (24U)
#define CCM_ANALOG_PFD_480B_CLR_PFD7_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_CLR_PFD7_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_CLR_PFD7_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_CLR_PFD7_STABLE_MASK (0x40000000U)
#define CCM_ANALOG_PFD_480B_CLR_PFD7_STABLE_SHIFT (30U)
#define CCM_ANALOG_PFD_480B_CLR_PFD7_DIV1_CLKGATE_MASK (0x80000000U)
#define CCM_ANALOG_PFD_480B_CLR_PFD7_DIV1_CLKGATE_SHIFT (31U)

/*! @name PFD_480B_TOG - 480MHz Clock Phase Fractional Divider Control Register B */
#define CCM_ANALOG_PFD_480B_TOG_PFD4_FRAC_MASK   (0x3FU)
#define CCM_ANALOG_PFD_480B_TOG_PFD4_FRAC_SHIFT  (0U)
#define CCM_ANALOG_PFD_480B_TOG_PFD4_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_TOG_PFD4_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_TOG_PFD4_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_TOG_PFD4_STABLE_MASK (0x40U)
#define CCM_ANALOG_PFD_480B_TOG_PFD4_STABLE_SHIFT (6U)
#define CCM_ANALOG_PFD_480B_TOG_PFD4_DIV1_CLKGATE_MASK (0x80U)
#define CCM_ANALOG_PFD_480B_TOG_PFD4_DIV1_CLKGATE_SHIFT (7U)
#define CCM_ANALOG_PFD_480B_TOG_PFD5_FRAC_MASK   (0x3F00U)
#define CCM_ANALOG_PFD_480B_TOG_PFD5_FRAC_SHIFT  (8U)
#define CCM_ANALOG_PFD_480B_TOG_PFD5_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_TOG_PFD5_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_TOG_PFD5_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_TOG_PFD5_STABLE_MASK (0x4000U)
#define CCM_ANALOG_PFD_480B_TOG_PFD5_STABLE_SHIFT (14U)
#define CCM_ANALOG_PFD_480B_TOG_PFD5_DIV1_CLKGATE_MASK (0x8000U)
#define CCM_ANALOG_PFD_480B_TOG_PFD5_DIV1_CLKGATE_SHIFT (15U)
#define CCM_ANALOG_PFD_480B_TOG_PFD6_FRAC_MASK   (0x3F0000U)
#define CCM_ANALOG_PFD_480B_TOG_PFD6_FRAC_SHIFT  (16U)
#define CCM_ANALOG_PFD_480B_TOG_PFD6_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_TOG_PFD6_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_TOG_PFD6_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_TOG_PFD6_STABLE_MASK (0x400000U)
#define CCM_ANALOG_PFD_480B_TOG_PFD6_STABLE_SHIFT (22U)
#define CCM_ANALOG_PFD_480B_TOG_PFD6_DIV1_CLKGATE_MASK (0x800000U)
#define CCM_ANALOG_PFD_480B_TOG_PFD6_DIV1_CLKGATE_SHIFT (23U)
#define CCM_ANALOG_PFD_480B_TOG_PFD7_FRAC_MASK   (0x3F000000U)
#define CCM_ANALOG_PFD_480B_TOG_PFD7_FRAC_SHIFT  (24U)
#define CCM_ANALOG_PFD_480B_TOG_PFD7_FRAC(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PFD_480B_TOG_PFD7_FRAC_SHIFT)) & CCM_ANALOG_PFD_480B_TOG_PFD7_FRAC_MASK)
#define CCM_ANALOG_PFD_480B_TOG_PFD7_STABLE_MASK (0x40000000U)
#define CCM_ANALOG_PFD_480B_TOG_PFD7_STABLE_SHIFT (30U)
#define CCM_ANALOG_PFD_480B_TOG_PFD7_DIV1_CLKGATE_MASK (0x80000000U)
#define CCM_ANALOG_PFD_480B_TOG_PFD7_DIV1_CLKGATE_SHIFT (31U)

/*! @name PLL_ENET - Anadig ENET PLL Control Register */
#define CCM_ANALOG_PLL_ENET_HALF_LF_MASK         (0x1U)
#define CCM_ANALOG_PLL_ENET_HALF_LF_SHIFT        (0U)
#define CCM_ANALOG_PLL_ENET_DOUBLE_LF_MASK       (0x2U)
#define CCM_ANALOG_PLL_ENET_DOUBLE_LF_SHIFT      (1U)
#define CCM_ANALOG_PLL_ENET_HALF_CP_MASK         (0x4U)
#define CCM_ANALOG_PLL_ENET_HALF_CP_SHIFT        (2U)
#define CCM_ANALOG_PLL_ENET_DOUBLE_CP_MASK       (0x8U)
#define CCM_ANALOG_PLL_ENET_DOUBLE_CP_SHIFT      (3U)
#define CCM_ANALOG_PLL_ENET_HOLD_RING_OFF_MASK   (0x10U)
#define CCM_ANALOG_PLL_ENET_HOLD_RING_OFF_SHIFT  (4U)
#define CCM_ANALOG_PLL_ENET_POWERDOWN_MASK       (0x20U)
#define CCM_ANALOG_PLL_ENET_POWERDOWN_SHIFT      (5U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ_MASK (0x40U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ_SHIFT (6U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ_MASK (0x80U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ_SHIFT (7U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ_MASK (0x100U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ_SHIFT (8U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ_MASK (0x200U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ_SHIFT (9U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ_MASK (0x400U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ_SHIFT (10U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ_MASK (0x800U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ_SHIFT (11U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ_MASK (0x1000U)
#define CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ_SHIFT (12U)
#define CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE_MASK (0x2000U)
#define CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE_SHIFT (13U)
#define CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC_MASK  (0xC000U)
#define CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(x)    (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_ENET_BYPASS_MASK          (0x10000U)
#define CCM_ANALOG_PLL_ENET_BYPASS_SHIFT         (16U)
#define CCM_ANALOG_PLL_ENET_DITHER_ENABLE_MASK   (0x20000U)
#define CCM_ANALOG_PLL_ENET_DITHER_ENABLE_SHIFT  (17U)
#define CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN_MASK   (0x40000U)
#define CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN_SHIFT  (18U)
#define CCM_ANALOG_PLL_ENET_RSVD1_MASK           (0x7FF80000U)
#define CCM_ANALOG_PLL_ENET_RSVD1_SHIFT          (19U)
#define CCM_ANALOG_PLL_ENET_RSVD1(x)             (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ENET_RSVD1_SHIFT)) & CCM_ANALOG_PLL_ENET_RSVD1_MASK)
#define CCM_ANALOG_PLL_ENET_LOCK_MASK            (0x80000000U)
#define CCM_ANALOG_PLL_ENET_LOCK_SHIFT           (31U)

/*! @name PLL_ENET_SET - Anadig ENET PLL Control Register */
#define CCM_ANALOG_PLL_ENET_SET_HALF_LF_MASK     (0x1U)
#define CCM_ANALOG_PLL_ENET_SET_HALF_LF_SHIFT    (0U)
#define CCM_ANALOG_PLL_ENET_SET_DOUBLE_LF_MASK   (0x2U)
#define CCM_ANALOG_PLL_ENET_SET_DOUBLE_LF_SHIFT  (1U)
#define CCM_ANALOG_PLL_ENET_SET_HALF_CP_MASK     (0x4U)
#define CCM_ANALOG_PLL_ENET_SET_HALF_CP_SHIFT    (2U)
#define CCM_ANALOG_PLL_ENET_SET_DOUBLE_CP_MASK   (0x8U)
#define CCM_ANALOG_PLL_ENET_SET_DOUBLE_CP_SHIFT  (3U)
#define CCM_ANALOG_PLL_ENET_SET_HOLD_RING_OFF_MASK (0x10U)
#define CCM_ANALOG_PLL_ENET_SET_HOLD_RING_OFF_SHIFT (4U)
#define CCM_ANALOG_PLL_ENET_SET_POWERDOWN_MASK   (0x20U)
#define CCM_ANALOG_PLL_ENET_SET_POWERDOWN_SHIFT  (5U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_25MHZ_MASK (0x40U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_25MHZ_SHIFT (6U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_40MHZ_MASK (0x80U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_40MHZ_SHIFT (7U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_50MHZ_MASK (0x100U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_50MHZ_SHIFT (8U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_100MHZ_MASK (0x200U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_100MHZ_SHIFT (9U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_125MHZ_MASK (0x400U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_125MHZ_SHIFT (10U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_250MHZ_MASK (0x800U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_250MHZ_SHIFT (11U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_500MHZ_MASK (0x1000U)
#define CCM_ANALOG_PLL_ENET_SET_ENABLE_CLK_500MHZ_SHIFT (12U)
#define CCM_ANALOG_PLL_ENET_SET_PLL_ENET_OVERRIDE_MASK (0x2000U)
#define CCM_ANALOG_PLL_ENET_SET_PLL_ENET_OVERRIDE_SHIFT (13U)
#define CCM_ANALOG_PLL_ENET_SET_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_ENET_SET_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_ENET_SET_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ENET_SET_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_ENET_SET_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_ENET_SET_BYPASS_MASK      (0x10000U)
#define CCM_ANALOG_PLL_ENET_SET_BYPASS_SHIFT     (16U)
#define CCM_ANALOG_PLL_ENET_SET_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_ENET_SET_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_ENET_SET_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_ENET_SET_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_ENET_SET_RSVD1_MASK       (0x7FF80000U)
#define CCM_ANALOG_PLL_ENET_SET_RSVD1_SHIFT      (19U)
#define CCM_ANALOG_PLL_ENET_SET_RSVD1(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ENET_SET_RSVD1_SHIFT)) & CCM_ANALOG_PLL_ENET_SET_RSVD1_MASK)
#define CCM_ANALOG_PLL_ENET_SET_LOCK_MASK        (0x80000000U)
#define CCM_ANALOG_PLL_ENET_SET_LOCK_SHIFT       (31U)

/*! @name PLL_ENET_CLR - Anadig ENET PLL Control Register */
#define CCM_ANALOG_PLL_ENET_CLR_HALF_LF_MASK     (0x1U)
#define CCM_ANALOG_PLL_ENET_CLR_HALF_LF_SHIFT    (0U)
#define CCM_ANALOG_PLL_ENET_CLR_DOUBLE_LF_MASK   (0x2U)
#define CCM_ANALOG_PLL_ENET_CLR_DOUBLE_LF_SHIFT  (1U)
#define CCM_ANALOG_PLL_ENET_CLR_HALF_CP_MASK     (0x4U)
#define CCM_ANALOG_PLL_ENET_CLR_HALF_CP_SHIFT    (2U)
#define CCM_ANALOG_PLL_ENET_CLR_DOUBLE_CP_MASK   (0x8U)
#define CCM_ANALOG_PLL_ENET_CLR_DOUBLE_CP_SHIFT  (3U)
#define CCM_ANALOG_PLL_ENET_CLR_HOLD_RING_OFF_MASK (0x10U)
#define CCM_ANALOG_PLL_ENET_CLR_HOLD_RING_OFF_SHIFT (4U)
#define CCM_ANALOG_PLL_ENET_CLR_POWERDOWN_MASK   (0x20U)
#define CCM_ANALOG_PLL_ENET_CLR_POWERDOWN_SHIFT  (5U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_25MHZ_MASK (0x40U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_25MHZ_SHIFT (6U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_40MHZ_MASK (0x80U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_40MHZ_SHIFT (7U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_50MHZ_MASK (0x100U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_50MHZ_SHIFT (8U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_100MHZ_MASK (0x200U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_100MHZ_SHIFT (9U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_125MHZ_MASK (0x400U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_125MHZ_SHIFT (10U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_250MHZ_MASK (0x800U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_250MHZ_SHIFT (11U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_500MHZ_MASK (0x1000U)
#define CCM_ANALOG_PLL_ENET_CLR_ENABLE_CLK_500MHZ_SHIFT (12U)
#define CCM_ANALOG_PLL_ENET_CLR_PLL_ENET_OVERRIDE_MASK (0x2000U)
#define CCM_ANALOG_PLL_ENET_CLR_PLL_ENET_OVERRIDE_SHIFT (13U)
#define CCM_ANALOG_PLL_ENET_CLR_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_ENET_CLR_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_ENET_CLR_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ENET_CLR_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_ENET_CLR_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_ENET_CLR_BYPASS_MASK      (0x10000U)
#define CCM_ANALOG_PLL_ENET_CLR_BYPASS_SHIFT     (16U)
#define CCM_ANALOG_PLL_ENET_CLR_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_ENET_CLR_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_ENET_CLR_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_ENET_CLR_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_ENET_CLR_RSVD1_MASK       (0x7FF80000U)
#define CCM_ANALOG_PLL_ENET_CLR_RSVD1_SHIFT      (19U)
#define CCM_ANALOG_PLL_ENET_CLR_RSVD1(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ENET_CLR_RSVD1_SHIFT)) & CCM_ANALOG_PLL_ENET_CLR_RSVD1_MASK)
#define CCM_ANALOG_PLL_ENET_CLR_LOCK_MASK        (0x80000000U)
#define CCM_ANALOG_PLL_ENET_CLR_LOCK_SHIFT       (31U)

/*! @name PLL_ENET_TOG - Anadig ENET PLL Control Register */
#define CCM_ANALOG_PLL_ENET_TOG_HALF_LF_MASK     (0x1U)
#define CCM_ANALOG_PLL_ENET_TOG_HALF_LF_SHIFT    (0U)
#define CCM_ANALOG_PLL_ENET_TOG_DOUBLE_LF_MASK   (0x2U)
#define CCM_ANALOG_PLL_ENET_TOG_DOUBLE_LF_SHIFT  (1U)
#define CCM_ANALOG_PLL_ENET_TOG_HALF_CP_MASK     (0x4U)
#define CCM_ANALOG_PLL_ENET_TOG_HALF_CP_SHIFT    (2U)
#define CCM_ANALOG_PLL_ENET_TOG_DOUBLE_CP_MASK   (0x8U)
#define CCM_ANALOG_PLL_ENET_TOG_DOUBLE_CP_SHIFT  (3U)
#define CCM_ANALOG_PLL_ENET_TOG_HOLD_RING_OFF_MASK (0x10U)
#define CCM_ANALOG_PLL_ENET_TOG_HOLD_RING_OFF_SHIFT (4U)
#define CCM_ANALOG_PLL_ENET_TOG_POWERDOWN_MASK   (0x20U)
#define CCM_ANALOG_PLL_ENET_TOG_POWERDOWN_SHIFT  (5U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_25MHZ_MASK (0x40U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_25MHZ_SHIFT (6U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_40MHZ_MASK (0x80U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_40MHZ_SHIFT (7U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_50MHZ_MASK (0x100U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_50MHZ_SHIFT (8U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_100MHZ_MASK (0x200U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_100MHZ_SHIFT (9U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_125MHZ_MASK (0x400U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_125MHZ_SHIFT (10U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_250MHZ_MASK (0x800U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_250MHZ_SHIFT (11U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_500MHZ_MASK (0x1000U)
#define CCM_ANALOG_PLL_ENET_TOG_ENABLE_CLK_500MHZ_SHIFT (12U)
#define CCM_ANALOG_PLL_ENET_TOG_PLL_ENET_OVERRIDE_MASK (0x2000U)
#define CCM_ANALOG_PLL_ENET_TOG_PLL_ENET_OVERRIDE_SHIFT (13U)
#define CCM_ANALOG_PLL_ENET_TOG_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_ENET_TOG_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_ENET_TOG_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ENET_TOG_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_ENET_TOG_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_ENET_TOG_BYPASS_MASK      (0x10000U)
#define CCM_ANALOG_PLL_ENET_TOG_BYPASS_SHIFT     (16U)
#define CCM_ANALOG_PLL_ENET_TOG_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_ENET_TOG_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_ENET_TOG_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_ENET_TOG_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_ENET_TOG_RSVD1_MASK       (0x7FF80000U)
#define CCM_ANALOG_PLL_ENET_TOG_RSVD1_SHIFT      (19U)
#define CCM_ANALOG_PLL_ENET_TOG_RSVD1(x)         (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_ENET_TOG_RSVD1_SHIFT)) & CCM_ANALOG_PLL_ENET_TOG_RSVD1_MASK)
#define CCM_ANALOG_PLL_ENET_TOG_LOCK_MASK        (0x80000000U)
#define CCM_ANALOG_PLL_ENET_TOG_LOCK_SHIFT       (31U)

/*! @name PLL_AUDIO - Anadig Audio PLL control Register */
#define CCM_ANALOG_PLL_AUDIO_DIV_SELECT_MASK     (0x7FU)
#define CCM_ANALOG_PLL_AUDIO_DIV_SELECT_SHIFT    (0U)
#define CCM_ANALOG_PLL_AUDIO_DIV_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_AUDIO_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_AUDIO_HALF_LF_MASK        (0x80U)
#define CCM_ANALOG_PLL_AUDIO_HALF_LF_SHIFT       (7U)
#define CCM_ANALOG_PLL_AUDIO_DOUBLE_LF_MASK      (0x100U)
#define CCM_ANALOG_PLL_AUDIO_DOUBLE_LF_SHIFT     (8U)
#define CCM_ANALOG_PLL_AUDIO_HALF_CP_MASK        (0x200U)
#define CCM_ANALOG_PLL_AUDIO_HALF_CP_SHIFT       (9U)
#define CCM_ANALOG_PLL_AUDIO_DOUBLE_CP_MASK      (0x400U)
#define CCM_ANALOG_PLL_AUDIO_DOUBLE_CP_SHIFT     (10U)
#define CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF_MASK  (0x800U)
#define CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_AUDIO_POWERDOWN_MASK      (0x1000U)
#define CCM_ANALOG_PLL_AUDIO_POWERDOWN_SHIFT     (12U)
#define CCM_ANALOG_PLL_AUDIO_ENABLE_CLK_MASK     (0x2000U)
#define CCM_ANALOG_PLL_AUDIO_ENABLE_CLK_SHIFT    (13U)
#define CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(x)   (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_AUDIO_BYPASS_MASK         (0x10000U)
#define CCM_ANALOG_PLL_AUDIO_BYPASS_SHIFT        (16U)
#define CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE_MASK  (0x20000U)
#define CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN_MASK  (0x40000U)
#define CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT_MASK (0x180000U)
#define CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT_SHIFT (19U)
#define CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT(x)  (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_AUDIO_RSVD0_MASK          (0x200000U)
#define CCM_ANALOG_PLL_AUDIO_RSVD0_SHIFT         (21U)
#define CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL_MASK   (0xC00000U)
#define CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL_SHIFT  (22U)
#define CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL_SHIFT)) & CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL_MASK)
#define CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_AUDIO_RSVD1_MASK          (0x7E000000U)
#define CCM_ANALOG_PLL_AUDIO_RSVD1_SHIFT         (25U)
#define CCM_ANALOG_PLL_AUDIO_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_RSVD1_SHIFT)) & CCM_ANALOG_PLL_AUDIO_RSVD1_MASK)
#define CCM_ANALOG_PLL_AUDIO_LOCK_MASK           (0x80000000U)
#define CCM_ANALOG_PLL_AUDIO_LOCK_SHIFT          (31U)

/*! @name PLL_AUDIO_SET - Anadig Audio PLL control Register */
#define CCM_ANALOG_PLL_AUDIO_SET_DIV_SELECT_MASK (0x7FU)
#define CCM_ANALOG_PLL_AUDIO_SET_DIV_SELECT_SHIFT (0U)
#define CCM_ANALOG_PLL_AUDIO_SET_DIV_SELECT(x)   (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_SET_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_AUDIO_SET_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_AUDIO_SET_HALF_LF_MASK    (0x80U)
#define CCM_ANALOG_PLL_AUDIO_SET_HALF_LF_SHIFT   (7U)
#define CCM_ANALOG_PLL_AUDIO_SET_DOUBLE_LF_MASK  (0x100U)
#define CCM_ANALOG_PLL_AUDIO_SET_DOUBLE_LF_SHIFT (8U)
#define CCM_ANALOG_PLL_AUDIO_SET_HALF_CP_MASK    (0x200U)
#define CCM_ANALOG_PLL_AUDIO_SET_HALF_CP_SHIFT   (9U)
#define CCM_ANALOG_PLL_AUDIO_SET_DOUBLE_CP_MASK  (0x400U)
#define CCM_ANALOG_PLL_AUDIO_SET_DOUBLE_CP_SHIFT (10U)
#define CCM_ANALOG_PLL_AUDIO_SET_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_AUDIO_SET_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_AUDIO_SET_POWERDOWN_MASK  (0x1000U)
#define CCM_ANALOG_PLL_AUDIO_SET_POWERDOWN_SHIFT (12U)
#define CCM_ANALOG_PLL_AUDIO_SET_ENABLE_CLK_MASK (0x2000U)
#define CCM_ANALOG_PLL_AUDIO_SET_ENABLE_CLK_SHIFT (13U)
#define CCM_ANALOG_PLL_AUDIO_SET_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_AUDIO_SET_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_AUDIO_SET_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_SET_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_AUDIO_SET_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_AUDIO_SET_BYPASS_MASK     (0x10000U)
#define CCM_ANALOG_PLL_AUDIO_SET_BYPASS_SHIFT    (16U)
#define CCM_ANALOG_PLL_AUDIO_SET_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_AUDIO_SET_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_AUDIO_SET_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_AUDIO_SET_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_AUDIO_SET_TEST_DIV_SELECT_MASK (0x180000U)
#define CCM_ANALOG_PLL_AUDIO_SET_TEST_DIV_SELECT_SHIFT (19U)
#define CCM_ANALOG_PLL_AUDIO_SET_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_SET_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_AUDIO_SET_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_AUDIO_SET_RSVD0_MASK      (0x200000U)
#define CCM_ANALOG_PLL_AUDIO_SET_RSVD0_SHIFT     (21U)
#define CCM_ANALOG_PLL_AUDIO_SET_POST_DIV_SEL_MASK (0xC00000U)
#define CCM_ANALOG_PLL_AUDIO_SET_POST_DIV_SEL_SHIFT (22U)
#define CCM_ANALOG_PLL_AUDIO_SET_POST_DIV_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_SET_POST_DIV_SEL_SHIFT)) & CCM_ANALOG_PLL_AUDIO_SET_POST_DIV_SEL_MASK)
#define CCM_ANALOG_PLL_AUDIO_SET_PLL_AUDIO_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_AUDIO_SET_PLL_AUDIO_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_AUDIO_SET_RSVD1_MASK      (0x7E000000U)
#define CCM_ANALOG_PLL_AUDIO_SET_RSVD1_SHIFT     (25U)
#define CCM_ANALOG_PLL_AUDIO_SET_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_SET_RSVD1_SHIFT)) & CCM_ANALOG_PLL_AUDIO_SET_RSVD1_MASK)
#define CCM_ANALOG_PLL_AUDIO_SET_LOCK_MASK       (0x80000000U)
#define CCM_ANALOG_PLL_AUDIO_SET_LOCK_SHIFT      (31U)

/*! @name PLL_AUDIO_CLR - Anadig Audio PLL control Register */
#define CCM_ANALOG_PLL_AUDIO_CLR_DIV_SELECT_MASK (0x7FU)
#define CCM_ANALOG_PLL_AUDIO_CLR_DIV_SELECT_SHIFT (0U)
#define CCM_ANALOG_PLL_AUDIO_CLR_DIV_SELECT(x)   (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_CLR_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_AUDIO_CLR_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_AUDIO_CLR_HALF_LF_MASK    (0x80U)
#define CCM_ANALOG_PLL_AUDIO_CLR_HALF_LF_SHIFT   (7U)
#define CCM_ANALOG_PLL_AUDIO_CLR_DOUBLE_LF_MASK  (0x100U)
#define CCM_ANALOG_PLL_AUDIO_CLR_DOUBLE_LF_SHIFT (8U)
#define CCM_ANALOG_PLL_AUDIO_CLR_HALF_CP_MASK    (0x200U)
#define CCM_ANALOG_PLL_AUDIO_CLR_HALF_CP_SHIFT   (9U)
#define CCM_ANALOG_PLL_AUDIO_CLR_DOUBLE_CP_MASK  (0x400U)
#define CCM_ANALOG_PLL_AUDIO_CLR_DOUBLE_CP_SHIFT (10U)
#define CCM_ANALOG_PLL_AUDIO_CLR_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_AUDIO_CLR_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_AUDIO_CLR_POWERDOWN_MASK  (0x1000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_POWERDOWN_SHIFT (12U)
#define CCM_ANALOG_PLL_AUDIO_CLR_ENABLE_CLK_MASK (0x2000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_ENABLE_CLK_SHIFT (13U)
#define CCM_ANALOG_PLL_AUDIO_CLR_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_AUDIO_CLR_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_CLR_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_AUDIO_CLR_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_AUDIO_CLR_BYPASS_MASK     (0x10000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_BYPASS_SHIFT    (16U)
#define CCM_ANALOG_PLL_AUDIO_CLR_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_AUDIO_CLR_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_AUDIO_CLR_TEST_DIV_SELECT_MASK (0x180000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_TEST_DIV_SELECT_SHIFT (19U)
#define CCM_ANALOG_PLL_AUDIO_CLR_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_CLR_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_AUDIO_CLR_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_AUDIO_CLR_RSVD0_MASK      (0x200000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_RSVD0_SHIFT     (21U)
#define CCM_ANALOG_PLL_AUDIO_CLR_POST_DIV_SEL_MASK (0xC00000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_POST_DIV_SEL_SHIFT (22U)
#define CCM_ANALOG_PLL_AUDIO_CLR_POST_DIV_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_CLR_POST_DIV_SEL_SHIFT)) & CCM_ANALOG_PLL_AUDIO_CLR_POST_DIV_SEL_MASK)
#define CCM_ANALOG_PLL_AUDIO_CLR_PLL_AUDIO_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_PLL_AUDIO_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_AUDIO_CLR_RSVD1_MASK      (0x7E000000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_RSVD1_SHIFT     (25U)
#define CCM_ANALOG_PLL_AUDIO_CLR_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_CLR_RSVD1_SHIFT)) & CCM_ANALOG_PLL_AUDIO_CLR_RSVD1_MASK)
#define CCM_ANALOG_PLL_AUDIO_CLR_LOCK_MASK       (0x80000000U)
#define CCM_ANALOG_PLL_AUDIO_CLR_LOCK_SHIFT      (31U)

/*! @name PLL_AUDIO_TOG - Anadig Audio PLL control Register */
#define CCM_ANALOG_PLL_AUDIO_TOG_DIV_SELECT_MASK (0x7FU)
#define CCM_ANALOG_PLL_AUDIO_TOG_DIV_SELECT_SHIFT (0U)
#define CCM_ANALOG_PLL_AUDIO_TOG_DIV_SELECT(x)   (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_TOG_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_AUDIO_TOG_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_AUDIO_TOG_HALF_LF_MASK    (0x80U)
#define CCM_ANALOG_PLL_AUDIO_TOG_HALF_LF_SHIFT   (7U)
#define CCM_ANALOG_PLL_AUDIO_TOG_DOUBLE_LF_MASK  (0x100U)
#define CCM_ANALOG_PLL_AUDIO_TOG_DOUBLE_LF_SHIFT (8U)
#define CCM_ANALOG_PLL_AUDIO_TOG_HALF_CP_MASK    (0x200U)
#define CCM_ANALOG_PLL_AUDIO_TOG_HALF_CP_SHIFT   (9U)
#define CCM_ANALOG_PLL_AUDIO_TOG_DOUBLE_CP_MASK  (0x400U)
#define CCM_ANALOG_PLL_AUDIO_TOG_DOUBLE_CP_SHIFT (10U)
#define CCM_ANALOG_PLL_AUDIO_TOG_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_AUDIO_TOG_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_AUDIO_TOG_POWERDOWN_MASK  (0x1000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_POWERDOWN_SHIFT (12U)
#define CCM_ANALOG_PLL_AUDIO_TOG_ENABLE_CLK_MASK (0x2000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_ENABLE_CLK_SHIFT (13U)
#define CCM_ANALOG_PLL_AUDIO_TOG_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_AUDIO_TOG_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_TOG_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_AUDIO_TOG_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_AUDIO_TOG_BYPASS_MASK     (0x10000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_BYPASS_SHIFT    (16U)
#define CCM_ANALOG_PLL_AUDIO_TOG_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_AUDIO_TOG_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_AUDIO_TOG_TEST_DIV_SELECT_MASK (0x180000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_TEST_DIV_SELECT_SHIFT (19U)
#define CCM_ANALOG_PLL_AUDIO_TOG_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_TOG_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_AUDIO_TOG_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_AUDIO_TOG_RSVD0_MASK      (0x200000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_RSVD0_SHIFT     (21U)
#define CCM_ANALOG_PLL_AUDIO_TOG_POST_DIV_SEL_MASK (0xC00000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_POST_DIV_SEL_SHIFT (22U)
#define CCM_ANALOG_PLL_AUDIO_TOG_POST_DIV_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_TOG_POST_DIV_SEL_SHIFT)) & CCM_ANALOG_PLL_AUDIO_TOG_POST_DIV_SEL_MASK)
#define CCM_ANALOG_PLL_AUDIO_TOG_PLL_AUDIO_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_PLL_AUDIO_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_AUDIO_TOG_RSVD1_MASK      (0x7E000000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_RSVD1_SHIFT     (25U)
#define CCM_ANALOG_PLL_AUDIO_TOG_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_TOG_RSVD1_SHIFT)) & CCM_ANALOG_PLL_AUDIO_TOG_RSVD1_MASK)
#define CCM_ANALOG_PLL_AUDIO_TOG_LOCK_MASK       (0x80000000U)
#define CCM_ANALOG_PLL_AUDIO_TOG_LOCK_SHIFT      (31U)

/*! @name PLL_AUDIO_SS - Audio PLL Spread Spectrum Register. */
#define CCM_ANALOG_PLL_AUDIO_SS_STEP_MASK        (0x7FFFU)
#define CCM_ANALOG_PLL_AUDIO_SS_STEP_SHIFT       (0U)
#define CCM_ANALOG_PLL_AUDIO_SS_STEP(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_SS_STEP_SHIFT)) & CCM_ANALOG_PLL_AUDIO_SS_STEP_MASK)
#define CCM_ANALOG_PLL_AUDIO_SS_ENABLE_MASK      (0x8000U)
#define CCM_ANALOG_PLL_AUDIO_SS_ENABLE_SHIFT     (15U)
#define CCM_ANALOG_PLL_AUDIO_SS_STOP_MASK        (0xFFFF0000U)
#define CCM_ANALOG_PLL_AUDIO_SS_STOP_SHIFT       (16U)
#define CCM_ANALOG_PLL_AUDIO_SS_STOP(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_SS_STOP_SHIFT)) & CCM_ANALOG_PLL_AUDIO_SS_STOP_MASK)

/*! @name PLL_AUDIO_NUM - Numerator of Audio PLL Fractional Loop Divider Register */
#define CCM_ANALOG_PLL_AUDIO_NUM_A_MASK          (0x3FFFFFFFU)
#define CCM_ANALOG_PLL_AUDIO_NUM_A_SHIFT         (0U)
#define CCM_ANALOG_PLL_AUDIO_NUM_A(x)            (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_NUM_A_SHIFT)) & CCM_ANALOG_PLL_AUDIO_NUM_A_MASK)
#define CCM_ANALOG_PLL_AUDIO_NUM_RSVD0_MASK      (0xC0000000U)
#define CCM_ANALOG_PLL_AUDIO_NUM_RSVD0_SHIFT     (30U)
#define CCM_ANALOG_PLL_AUDIO_NUM_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_NUM_RSVD0_SHIFT)) & CCM_ANALOG_PLL_AUDIO_NUM_RSVD0_MASK)

/*! @name PLL_AUDIO_DENOM - Denominator of Audio PLL Fractional Loop Divider Register */
#define CCM_ANALOG_PLL_AUDIO_DENOM_B_MASK        (0x3FFFFFFFU)
#define CCM_ANALOG_PLL_AUDIO_DENOM_B_SHIFT       (0U)
#define CCM_ANALOG_PLL_AUDIO_DENOM_B(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_DENOM_B_SHIFT)) & CCM_ANALOG_PLL_AUDIO_DENOM_B_MASK)
#define CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0_MASK    (0xC0000000U)
#define CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0_SHIFT   (30U)
#define CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0(x)      (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0_SHIFT)) & CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0_MASK)

/*! @name PLL_VIDEO - Anadig Video PLL control Register */
#define CCM_ANALOG_PLL_VIDEO_DIV_SELECT_MASK     (0x7FU)
#define CCM_ANALOG_PLL_VIDEO_DIV_SELECT_SHIFT    (0U)
#define CCM_ANALOG_PLL_VIDEO_DIV_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_VIDEO_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_VIDEO_HALF_LF_MASK        (0x80U)
#define CCM_ANALOG_PLL_VIDEO_HALF_LF_SHIFT       (7U)
#define CCM_ANALOG_PLL_VIDEO_DOUBLE_LF_MASK      (0x100U)
#define CCM_ANALOG_PLL_VIDEO_DOUBLE_LF_SHIFT     (8U)
#define CCM_ANALOG_PLL_VIDEO_HALF_CP_MASK        (0x200U)
#define CCM_ANALOG_PLL_VIDEO_HALF_CP_SHIFT       (9U)
#define CCM_ANALOG_PLL_VIDEO_DOUBLE_CP_MASK      (0x400U)
#define CCM_ANALOG_PLL_VIDEO_DOUBLE_CP_SHIFT     (10U)
#define CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF_MASK  (0x800U)
#define CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_VIDEO_POWERDOWN_MASK      (0x1000U)
#define CCM_ANALOG_PLL_VIDEO_POWERDOWN_SHIFT     (12U)
#define CCM_ANALOG_PLL_VIDEO_ENABLE_CLK_MASK     (0x2000U)
#define CCM_ANALOG_PLL_VIDEO_ENABLE_CLK_SHIFT    (13U)
#define CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(x)   (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_VIDEO_BYPASS_MASK         (0x10000U)
#define CCM_ANALOG_PLL_VIDEO_BYPASS_SHIFT        (16U)
#define CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE_MASK  (0x20000U)
#define CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN_MASK  (0x40000U)
#define CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT_MASK (0x180000U)
#define CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT_SHIFT (19U)
#define CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT(x)  (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_VIDEO_RSVD0_MASK          (0x200000U)
#define CCM_ANALOG_PLL_VIDEO_RSVD0_SHIFT         (21U)
#define CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL_MASK   (0xC00000U)
#define CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL_SHIFT  (22U)
#define CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL(x)     (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL_SHIFT)) & CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL_MASK)
#define CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_VIDEO_RSVD1_MASK          (0x7E000000U)
#define CCM_ANALOG_PLL_VIDEO_RSVD1_SHIFT         (25U)
#define CCM_ANALOG_PLL_VIDEO_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_RSVD1_SHIFT)) & CCM_ANALOG_PLL_VIDEO_RSVD1_MASK)
#define CCM_ANALOG_PLL_VIDEO_LOCK_MASK           (0x80000000U)
#define CCM_ANALOG_PLL_VIDEO_LOCK_SHIFT          (31U)

/*! @name PLL_VIDEO_SET - Anadig Video PLL control Register */
#define CCM_ANALOG_PLL_VIDEO_SET_DIV_SELECT_MASK (0x7FU)
#define CCM_ANALOG_PLL_VIDEO_SET_DIV_SELECT_SHIFT (0U)
#define CCM_ANALOG_PLL_VIDEO_SET_DIV_SELECT(x)   (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_SET_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_VIDEO_SET_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_VIDEO_SET_HALF_LF_MASK    (0x80U)
#define CCM_ANALOG_PLL_VIDEO_SET_HALF_LF_SHIFT   (7U)
#define CCM_ANALOG_PLL_VIDEO_SET_DOUBLE_LF_MASK  (0x100U)
#define CCM_ANALOG_PLL_VIDEO_SET_DOUBLE_LF_SHIFT (8U)
#define CCM_ANALOG_PLL_VIDEO_SET_HALF_CP_MASK    (0x200U)
#define CCM_ANALOG_PLL_VIDEO_SET_HALF_CP_SHIFT   (9U)
#define CCM_ANALOG_PLL_VIDEO_SET_DOUBLE_CP_MASK  (0x400U)
#define CCM_ANALOG_PLL_VIDEO_SET_DOUBLE_CP_SHIFT (10U)
#define CCM_ANALOG_PLL_VIDEO_SET_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_VIDEO_SET_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_VIDEO_SET_POWERDOWN_MASK  (0x1000U)
#define CCM_ANALOG_PLL_VIDEO_SET_POWERDOWN_SHIFT (12U)
#define CCM_ANALOG_PLL_VIDEO_SET_ENABLE_CLK_MASK (0x2000U)
#define CCM_ANALOG_PLL_VIDEO_SET_ENABLE_CLK_SHIFT (13U)
#define CCM_ANALOG_PLL_VIDEO_SET_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_VIDEO_SET_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_VIDEO_SET_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_SET_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_VIDEO_SET_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_VIDEO_SET_BYPASS_MASK     (0x10000U)
#define CCM_ANALOG_PLL_VIDEO_SET_BYPASS_SHIFT    (16U)
#define CCM_ANALOG_PLL_VIDEO_SET_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_VIDEO_SET_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_VIDEO_SET_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_VIDEO_SET_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_VIDEO_SET_TEST_DIV_SELECT_MASK (0x180000U)
#define CCM_ANALOG_PLL_VIDEO_SET_TEST_DIV_SELECT_SHIFT (19U)
#define CCM_ANALOG_PLL_VIDEO_SET_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_SET_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_VIDEO_SET_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_VIDEO_SET_RSVD0_MASK      (0x200000U)
#define CCM_ANALOG_PLL_VIDEO_SET_RSVD0_SHIFT     (21U)
#define CCM_ANALOG_PLL_VIDEO_SET_POST_DIV_SEL_MASK (0xC00000U)
#define CCM_ANALOG_PLL_VIDEO_SET_POST_DIV_SEL_SHIFT (22U)
#define CCM_ANALOG_PLL_VIDEO_SET_POST_DIV_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_SET_POST_DIV_SEL_SHIFT)) & CCM_ANALOG_PLL_VIDEO_SET_POST_DIV_SEL_MASK)
#define CCM_ANALOG_PLL_VIDEO_SET_PLL_VIDEO_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_VIDEO_SET_PLL_VIDEO_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_VIDEO_SET_RSVD1_MASK      (0x7E000000U)
#define CCM_ANALOG_PLL_VIDEO_SET_RSVD1_SHIFT     (25U)
#define CCM_ANALOG_PLL_VIDEO_SET_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_SET_RSVD1_SHIFT)) & CCM_ANALOG_PLL_VIDEO_SET_RSVD1_MASK)
#define CCM_ANALOG_PLL_VIDEO_SET_LOCK_MASK       (0x80000000U)
#define CCM_ANALOG_PLL_VIDEO_SET_LOCK_SHIFT      (31U)

/*! @name PLL_VIDEO_CLR - Anadig Video PLL control Register */
#define CCM_ANALOG_PLL_VIDEO_CLR_DIV_SELECT_MASK (0x7FU)
#define CCM_ANALOG_PLL_VIDEO_CLR_DIV_SELECT_SHIFT (0U)
#define CCM_ANALOG_PLL_VIDEO_CLR_DIV_SELECT(x)   (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_CLR_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_VIDEO_CLR_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_VIDEO_CLR_HALF_LF_MASK    (0x80U)
#define CCM_ANALOG_PLL_VIDEO_CLR_HALF_LF_SHIFT   (7U)
#define CCM_ANALOG_PLL_VIDEO_CLR_DOUBLE_LF_MASK  (0x100U)
#define CCM_ANALOG_PLL_VIDEO_CLR_DOUBLE_LF_SHIFT (8U)
#define CCM_ANALOG_PLL_VIDEO_CLR_HALF_CP_MASK    (0x200U)
#define CCM_ANALOG_PLL_VIDEO_CLR_HALF_CP_SHIFT   (9U)
#define CCM_ANALOG_PLL_VIDEO_CLR_DOUBLE_CP_MASK  (0x400U)
#define CCM_ANALOG_PLL_VIDEO_CLR_DOUBLE_CP_SHIFT (10U)
#define CCM_ANALOG_PLL_VIDEO_CLR_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_VIDEO_CLR_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_VIDEO_CLR_POWERDOWN_MASK  (0x1000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_POWERDOWN_SHIFT (12U)
#define CCM_ANALOG_PLL_VIDEO_CLR_ENABLE_CLK_MASK (0x2000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_ENABLE_CLK_SHIFT (13U)
#define CCM_ANALOG_PLL_VIDEO_CLR_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_VIDEO_CLR_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_CLR_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_VIDEO_CLR_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_VIDEO_CLR_BYPASS_MASK     (0x10000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_BYPASS_SHIFT    (16U)
#define CCM_ANALOG_PLL_VIDEO_CLR_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_VIDEO_CLR_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_VIDEO_CLR_TEST_DIV_SELECT_MASK (0x180000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_TEST_DIV_SELECT_SHIFT (19U)
#define CCM_ANALOG_PLL_VIDEO_CLR_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_CLR_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_VIDEO_CLR_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_VIDEO_CLR_RSVD0_MASK      (0x200000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_RSVD0_SHIFT     (21U)
#define CCM_ANALOG_PLL_VIDEO_CLR_POST_DIV_SEL_MASK (0xC00000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_POST_DIV_SEL_SHIFT (22U)
#define CCM_ANALOG_PLL_VIDEO_CLR_POST_DIV_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_CLR_POST_DIV_SEL_SHIFT)) & CCM_ANALOG_PLL_VIDEO_CLR_POST_DIV_SEL_MASK)
#define CCM_ANALOG_PLL_VIDEO_CLR_PLL_VIDEO_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_PLL_VIDEO_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_VIDEO_CLR_RSVD1_MASK      (0x7E000000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_RSVD1_SHIFT     (25U)
#define CCM_ANALOG_PLL_VIDEO_CLR_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_CLR_RSVD1_SHIFT)) & CCM_ANALOG_PLL_VIDEO_CLR_RSVD1_MASK)
#define CCM_ANALOG_PLL_VIDEO_CLR_LOCK_MASK       (0x80000000U)
#define CCM_ANALOG_PLL_VIDEO_CLR_LOCK_SHIFT      (31U)

/*! @name PLL_VIDEO_TOG - Anadig Video PLL control Register */
#define CCM_ANALOG_PLL_VIDEO_TOG_DIV_SELECT_MASK (0x7FU)
#define CCM_ANALOG_PLL_VIDEO_TOG_DIV_SELECT_SHIFT (0U)
#define CCM_ANALOG_PLL_VIDEO_TOG_DIV_SELECT(x)   (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_TOG_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_VIDEO_TOG_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_VIDEO_TOG_HALF_LF_MASK    (0x80U)
#define CCM_ANALOG_PLL_VIDEO_TOG_HALF_LF_SHIFT   (7U)
#define CCM_ANALOG_PLL_VIDEO_TOG_DOUBLE_LF_MASK  (0x100U)
#define CCM_ANALOG_PLL_VIDEO_TOG_DOUBLE_LF_SHIFT (8U)
#define CCM_ANALOG_PLL_VIDEO_TOG_HALF_CP_MASK    (0x200U)
#define CCM_ANALOG_PLL_VIDEO_TOG_HALF_CP_SHIFT   (9U)
#define CCM_ANALOG_PLL_VIDEO_TOG_DOUBLE_CP_MASK  (0x400U)
#define CCM_ANALOG_PLL_VIDEO_TOG_DOUBLE_CP_SHIFT (10U)
#define CCM_ANALOG_PLL_VIDEO_TOG_HOLD_RING_OFF_MASK (0x800U)
#define CCM_ANALOG_PLL_VIDEO_TOG_HOLD_RING_OFF_SHIFT (11U)
#define CCM_ANALOG_PLL_VIDEO_TOG_POWERDOWN_MASK  (0x1000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_POWERDOWN_SHIFT (12U)
#define CCM_ANALOG_PLL_VIDEO_TOG_ENABLE_CLK_MASK (0x2000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_ENABLE_CLK_SHIFT (13U)
#define CCM_ANALOG_PLL_VIDEO_TOG_BYPASS_CLK_SRC_MASK (0xC000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_BYPASS_CLK_SRC_SHIFT (14U)
#define CCM_ANALOG_PLL_VIDEO_TOG_BYPASS_CLK_SRC(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_TOG_BYPASS_CLK_SRC_SHIFT)) & CCM_ANALOG_PLL_VIDEO_TOG_BYPASS_CLK_SRC_MASK)
#define CCM_ANALOG_PLL_VIDEO_TOG_BYPASS_MASK     (0x10000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_BYPASS_SHIFT    (16U)
#define CCM_ANALOG_PLL_VIDEO_TOG_DITHER_ENABLE_MASK (0x20000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_DITHER_ENABLE_SHIFT (17U)
#define CCM_ANALOG_PLL_VIDEO_TOG_PFD_OFFSET_EN_MASK (0x40000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_PFD_OFFSET_EN_SHIFT (18U)
#define CCM_ANALOG_PLL_VIDEO_TOG_TEST_DIV_SELECT_MASK (0x180000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_TEST_DIV_SELECT_SHIFT (19U)
#define CCM_ANALOG_PLL_VIDEO_TOG_TEST_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_TOG_TEST_DIV_SELECT_SHIFT)) & CCM_ANALOG_PLL_VIDEO_TOG_TEST_DIV_SELECT_MASK)
#define CCM_ANALOG_PLL_VIDEO_TOG_RSVD0_MASK      (0x200000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_RSVD0_SHIFT     (21U)
#define CCM_ANALOG_PLL_VIDEO_TOG_POST_DIV_SEL_MASK (0xC00000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_POST_DIV_SEL_SHIFT (22U)
#define CCM_ANALOG_PLL_VIDEO_TOG_POST_DIV_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_TOG_POST_DIV_SEL_SHIFT)) & CCM_ANALOG_PLL_VIDEO_TOG_POST_DIV_SEL_MASK)
#define CCM_ANALOG_PLL_VIDEO_TOG_PLL_VIDEO_OVERRIDE_MASK (0x1000000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_PLL_VIDEO_OVERRIDE_SHIFT (24U)
#define CCM_ANALOG_PLL_VIDEO_TOG_RSVD1_MASK      (0x7E000000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_RSVD1_SHIFT     (25U)
#define CCM_ANALOG_PLL_VIDEO_TOG_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_TOG_RSVD1_SHIFT)) & CCM_ANALOG_PLL_VIDEO_TOG_RSVD1_MASK)
#define CCM_ANALOG_PLL_VIDEO_TOG_LOCK_MASK       (0x80000000U)
#define CCM_ANALOG_PLL_VIDEO_TOG_LOCK_SHIFT      (31U)

/*! @name PLL_VIDEO_SS - Video PLL Spread Spectrum Register. */
#define CCM_ANALOG_PLL_VIDEO_SS_STEP_MASK        (0x7FFFU)
#define CCM_ANALOG_PLL_VIDEO_SS_STEP_SHIFT       (0U)
#define CCM_ANALOG_PLL_VIDEO_SS_STEP(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_SS_STEP_SHIFT)) & CCM_ANALOG_PLL_VIDEO_SS_STEP_MASK)
#define CCM_ANALOG_PLL_VIDEO_SS_ENABLE_MASK      (0x8000U)
#define CCM_ANALOG_PLL_VIDEO_SS_ENABLE_SHIFT     (15U)
#define CCM_ANALOG_PLL_VIDEO_SS_STOP_MASK        (0xFFFF0000U)
#define CCM_ANALOG_PLL_VIDEO_SS_STOP_SHIFT       (16U)
#define CCM_ANALOG_PLL_VIDEO_SS_STOP(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_SS_STOP_SHIFT)) & CCM_ANALOG_PLL_VIDEO_SS_STOP_MASK)

/*! @name PLL_VIDEO_NUM - Numerator of Video PLL Fractional Loop Divider Register */
#define CCM_ANALOG_PLL_VIDEO_NUM_A_MASK          (0x3FFFFFFFU)
#define CCM_ANALOG_PLL_VIDEO_NUM_A_SHIFT         (0U)
#define CCM_ANALOG_PLL_VIDEO_NUM_A(x)            (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_NUM_A_SHIFT)) & CCM_ANALOG_PLL_VIDEO_NUM_A_MASK)
#define CCM_ANALOG_PLL_VIDEO_NUM_RSVD0_MASK      (0xC0000000U)
#define CCM_ANALOG_PLL_VIDEO_NUM_RSVD0_SHIFT     (30U)
#define CCM_ANALOG_PLL_VIDEO_NUM_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_NUM_RSVD0_SHIFT)) & CCM_ANALOG_PLL_VIDEO_NUM_RSVD0_MASK)

/*! @name PLL_VIDEO_DENOM - Denominator of Video PLL Fractional Loop Divider Register */
#define CCM_ANALOG_PLL_VIDEO_DENOM_B_MASK        (0x3FFFFFFFU)
#define CCM_ANALOG_PLL_VIDEO_DENOM_B_SHIFT       (0U)
#define CCM_ANALOG_PLL_VIDEO_DENOM_B(x)          (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_DENOM_B_SHIFT)) & CCM_ANALOG_PLL_VIDEO_DENOM_B_MASK)
#define CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0_MASK    (0xC0000000U)
#define CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0_SHIFT   (30U)
#define CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0(x)      (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0_SHIFT)) & CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0_MASK)

/*! @name CLK_MISC0 - Miscellaneous0 Analog Clock Control and Status Register */
#define CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL_MASK  (0x1FU)
#define CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL_SHIFT (0U)
#define CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL(x)    (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL_SHIFT)) & CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL_MASK)
#define CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN_MASK  (0x20U)
#define CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN_SHIFT (5U)
#define CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN_MASK  (0x40U)
#define CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN_SHIFT (6U)
#define CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV_MASK   (0x80U)
#define CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV_SHIFT  (7U)
#define CCM_ANALOG_CLK_MISC0_RSVD0_MASK          (0xFFFFFF00U)
#define CCM_ANALOG_CLK_MISC0_RSVD0_SHIFT         (8U)
#define CCM_ANALOG_CLK_MISC0_RSVD0(x)            (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_CLK_MISC0_RSVD0_SHIFT)) & CCM_ANALOG_CLK_MISC0_RSVD0_MASK)

/*! @name CLK_MISC0_SET - Miscellaneous0 Analog Clock Control and Status Register */
#define CCM_ANALOG_CLK_MISC0_SET_LVDS1_CLK_SEL_MASK (0x1FU)
#define CCM_ANALOG_CLK_MISC0_SET_LVDS1_CLK_SEL_SHIFT (0U)
#define CCM_ANALOG_CLK_MISC0_SET_LVDS1_CLK_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_CLK_MISC0_SET_LVDS1_CLK_SEL_SHIFT)) & CCM_ANALOG_CLK_MISC0_SET_LVDS1_CLK_SEL_MASK)
#define CCM_ANALOG_CLK_MISC0_SET_LVDSCLK1_OBEN_MASK (0x20U)
#define CCM_ANALOG_CLK_MISC0_SET_LVDSCLK1_OBEN_SHIFT (5U)
#define CCM_ANALOG_CLK_MISC0_SET_LVDSCLK1_IBEN_MASK (0x40U)
#define CCM_ANALOG_CLK_MISC0_SET_LVDSCLK1_IBEN_SHIFT (6U)
#define CCM_ANALOG_CLK_MISC0_SET_ACLK2_PREDIV_MASK (0x80U)
#define CCM_ANALOG_CLK_MISC0_SET_ACLK2_PREDIV_SHIFT (7U)
#define CCM_ANALOG_CLK_MISC0_SET_RSVD0_MASK      (0xFFFFFF00U)
#define CCM_ANALOG_CLK_MISC0_SET_RSVD0_SHIFT     (8U)
#define CCM_ANALOG_CLK_MISC0_SET_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_CLK_MISC0_SET_RSVD0_SHIFT)) & CCM_ANALOG_CLK_MISC0_SET_RSVD0_MASK)

/*! @name CLK_MISC0_CLR - Miscellaneous0 Analog Clock Control and Status Register */
#define CCM_ANALOG_CLK_MISC0_CLR_LVDS1_CLK_SEL_MASK (0x1FU)
#define CCM_ANALOG_CLK_MISC0_CLR_LVDS1_CLK_SEL_SHIFT (0U)
#define CCM_ANALOG_CLK_MISC0_CLR_LVDS1_CLK_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_CLK_MISC0_CLR_LVDS1_CLK_SEL_SHIFT)) & CCM_ANALOG_CLK_MISC0_CLR_LVDS1_CLK_SEL_MASK)
#define CCM_ANALOG_CLK_MISC0_CLR_LVDSCLK1_OBEN_MASK (0x20U)
#define CCM_ANALOG_CLK_MISC0_CLR_LVDSCLK1_OBEN_SHIFT (5U)
#define CCM_ANALOG_CLK_MISC0_CLR_LVDSCLK1_IBEN_MASK (0x40U)
#define CCM_ANALOG_CLK_MISC0_CLR_LVDSCLK1_IBEN_SHIFT (6U)
#define CCM_ANALOG_CLK_MISC0_CLR_ACLK2_PREDIV_MASK (0x80U)
#define CCM_ANALOG_CLK_MISC0_CLR_ACLK2_PREDIV_SHIFT (7U)
#define CCM_ANALOG_CLK_MISC0_CLR_RSVD0_MASK      (0xFFFFFF00U)
#define CCM_ANALOG_CLK_MISC0_CLR_RSVD0_SHIFT     (8U)
#define CCM_ANALOG_CLK_MISC0_CLR_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_CLK_MISC0_CLR_RSVD0_SHIFT)) & CCM_ANALOG_CLK_MISC0_CLR_RSVD0_MASK)

/*! @name CLK_MISC0_TOG - Miscellaneous0 Analog Clock Control and Status Register */
#define CCM_ANALOG_CLK_MISC0_TOG_LVDS1_CLK_SEL_MASK (0x1FU)
#define CCM_ANALOG_CLK_MISC0_TOG_LVDS1_CLK_SEL_SHIFT (0U)
#define CCM_ANALOG_CLK_MISC0_TOG_LVDS1_CLK_SEL(x) (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_CLK_MISC0_TOG_LVDS1_CLK_SEL_SHIFT)) & CCM_ANALOG_CLK_MISC0_TOG_LVDS1_CLK_SEL_MASK)
#define CCM_ANALOG_CLK_MISC0_TOG_LVDSCLK1_OBEN_MASK (0x20U)
#define CCM_ANALOG_CLK_MISC0_TOG_LVDSCLK1_OBEN_SHIFT (5U)
#define CCM_ANALOG_CLK_MISC0_TOG_LVDSCLK1_IBEN_MASK (0x40U)
#define CCM_ANALOG_CLK_MISC0_TOG_LVDSCLK1_IBEN_SHIFT (6U)
#define CCM_ANALOG_CLK_MISC0_TOG_ACLK2_PREDIV_MASK (0x80U)
#define CCM_ANALOG_CLK_MISC0_TOG_ACLK2_PREDIV_SHIFT (7U)
#define CCM_ANALOG_CLK_MISC0_TOG_RSVD0_MASK      (0xFFFFFF00U)
#define CCM_ANALOG_CLK_MISC0_TOG_RSVD0_SHIFT     (8U)
#define CCM_ANALOG_CLK_MISC0_TOG_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << CCM_ANALOG_CLK_MISC0_TOG_RSVD0_SHIFT)) & CCM_ANALOG_CLK_MISC0_TOG_RSVD0_MASK)


/*!
 * @}
 */ /* end of group CCM_ANALOG_Register_Masks */


/* CCM_ANALOG - Peripheral instance base addresses */
/** Peripheral CCM_ANALOG base pointer */
#define CCM_ANALOG_BASE_PTR                      ((CCM_ANALOG_MemMapPtr)0x30360060u)
/** Array initializer of CCM_ANALOG peripheral base pointers */
#define CCM_ANALOG_BASE_PTRS                     { CCM_ANALOG_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- CCM_ANALOG - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CCM_ANALOG_Register_Accessor_Macros CCM_ANALOG - Register accessor macros
 * @{
 */


/* CCM_ANALOG - Register instance definitions */
/* CCM_ANALOG */
#define CCM_ANALOG_PLL_ARM                       CCM_ANALOG_PLL_ARM_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_ARM_SET                   CCM_ANALOG_PLL_ARM_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_ARM_CLR                   CCM_ANALOG_PLL_ARM_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_ARM_TOG                   CCM_ANALOG_PLL_ARM_TOG_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_DDR                       CCM_ANALOG_PLL_DDR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_DDR_SET                   CCM_ANALOG_PLL_DDR_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_DDR_CLR                   CCM_ANALOG_PLL_DDR_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_DDR_TOG                   CCM_ANALOG_PLL_DDR_TOG_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_DDR_SS                    CCM_ANALOG_PLL_DDR_SS_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_DDR_NUM                   CCM_ANALOG_PLL_DDR_NUM_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_DDR_DENOM                 CCM_ANALOG_PLL_DDR_DENOM_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_480                       CCM_ANALOG_PLL_480_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_480_SET                   CCM_ANALOG_PLL_480_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_480_CLR                   CCM_ANALOG_PLL_480_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_480_TOG                   CCM_ANALOG_PLL_480_TOG_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PFD_480A                      CCM_ANALOG_PFD_480A_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PFD_480A_SET                  CCM_ANALOG_PFD_480A_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PFD_480A_CLR                  CCM_ANALOG_PFD_480A_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PFD_480A_TOG                  CCM_ANALOG_PFD_480A_TOG_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PFD_480B                      CCM_ANALOG_PFD_480B_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PFD_480B_SET                  CCM_ANALOG_PFD_480B_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PFD_480B_CLR                  CCM_ANALOG_PFD_480B_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PFD_480B_TOG                  CCM_ANALOG_PFD_480B_TOG_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_ENET                      CCM_ANALOG_PLL_ENET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_ENET_SET                  CCM_ANALOG_PLL_ENET_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_ENET_CLR                  CCM_ANALOG_PLL_ENET_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_ENET_TOG                  CCM_ANALOG_PLL_ENET_TOG_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_AUDIO                     CCM_ANALOG_PLL_AUDIO_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_AUDIO_SET                 CCM_ANALOG_PLL_AUDIO_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_AUDIO_CLR                 CCM_ANALOG_PLL_AUDIO_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_AUDIO_TOG                 CCM_ANALOG_PLL_AUDIO_TOG_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_AUDIO_SS                  CCM_ANALOG_PLL_AUDIO_SS_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_AUDIO_NUM                 CCM_ANALOG_PLL_AUDIO_NUM_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_AUDIO_DENOM               CCM_ANALOG_PLL_AUDIO_DENOM_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_VIDEO                     CCM_ANALOG_PLL_VIDEO_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_VIDEO_SET                 CCM_ANALOG_PLL_VIDEO_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_VIDEO_CLR                 CCM_ANALOG_PLL_VIDEO_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_VIDEO_TOG                 CCM_ANALOG_PLL_VIDEO_TOG_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_VIDEO_SS                  CCM_ANALOG_PLL_VIDEO_SS_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_VIDEO_NUM                 CCM_ANALOG_PLL_VIDEO_NUM_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_PLL_VIDEO_DENOM               CCM_ANALOG_PLL_VIDEO_DENOM_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_CLK_MISC0                     CCM_ANALOG_CLK_MISC0_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_CLK_MISC0_SET                 CCM_ANALOG_CLK_MISC0_SET_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_CLK_MISC0_CLR                 CCM_ANALOG_CLK_MISC0_CLR_REG(CCM_ANALOG_BASE_PTR)
#define CCM_ANALOG_CLK_MISC0_TOG                 CCM_ANALOG_CLK_MISC0_TOG_REG(CCM_ANALOG_BASE_PTR)

/*!
 * @}
 */ /* end of group CCM_ANALOG_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group CCM_ANALOG_Peripheral */


/* ----------------------------------------------------------------------------
   -- CSI
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CSI_Peripheral CSI
 * @{
 */

/** CSI - Peripheral register structure */
typedef struct CSI_MemMap {
  uint32_t CSICR1;                                 /**< CSI Control Register 1, offset: 0x0 */
  uint32_t CSICR2;                                 /**< CSI Control Register 2, offset: 0x4 */
  uint32_t CSICR3;                                 /**< CSI Control Register 3, offset: 0x8 */
  uint32_t CSISTATFIFO;                            /**< CSI Statistic FIFO Register, offset: 0xC */
  uint32_t CSIRFIFO;                               /**< CSI RX FIFO Register, offset: 0x10 */
  uint32_t CSIRXCNT;                               /**< CSI RX Count Register, offset: 0x14 */
  uint32_t CSISR;                                  /**< CSI Status Register, offset: 0x18 */
  uint8_t RESERVED_0[4];
  uint32_t CSIDMASA_STATFIFO;                      /**< CSI DMA Start Address Register - for STATFIFO, offset: 0x20 */
  uint32_t CSIDMATS_STATFIFO;                      /**< CSI DMA Transfer Size Register - for STATFIFO, offset: 0x24 */
  uint32_t CSIDMASA_FB1;                           /**< CSI DMA Start Address Register - for Frame Buffer1, offset: 0x28 */
  uint32_t CSIDMASA_FB2;                           /**< CSI DMA Transfer Size Register - for Frame Buffer2, offset: 0x2C */
  uint32_t CSIFBUF_PARA;                           /**< CSI Frame Buffer Parameter Register, offset: 0x30 */
  uint32_t CSIIMAG_PARA;                           /**< CSI Image Parameter Register, offset: 0x34 */
  uint8_t RESERVED_1[16];
  uint32_t CSICR18;                                /**< CSI Control Register 18, offset: 0x48 */
} volatile *CSI_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- CSI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CSI_Register_Accessor_Macros CSI - Register accessor macros
 * @{
 */


/* CSI - Register accessors */
#define CSI_CSICR1_REG(base)                     ((base)->CSICR1)
#define CSI_CSICR2_REG(base)                     ((base)->CSICR2)
#define CSI_CSICR3_REG(base)                     ((base)->CSICR3)
#define CSI_CSISTATFIFO_REG(base)                ((base)->CSISTATFIFO)
#define CSI_CSIRFIFO_REG(base)                   ((base)->CSIRFIFO)
#define CSI_CSIRXCNT_REG(base)                   ((base)->CSIRXCNT)
#define CSI_CSISR_REG(base)                      ((base)->CSISR)
#define CSI_CSIDMASA_STATFIFO_REG(base)          ((base)->CSIDMASA_STATFIFO)
#define CSI_CSIDMATS_STATFIFO_REG(base)          ((base)->CSIDMATS_STATFIFO)
#define CSI_CSIDMASA_FB1_REG(base)               ((base)->CSIDMASA_FB1)
#define CSI_CSIDMASA_FB2_REG(base)               ((base)->CSIDMASA_FB2)
#define CSI_CSIFBUF_PARA_REG(base)               ((base)->CSIFBUF_PARA)
#define CSI_CSIIMAG_PARA_REG(base)               ((base)->CSIIMAG_PARA)
#define CSI_CSICR18_REG(base)                    ((base)->CSICR18)

/*!
 * @}
 */ /* end of group CSI_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- CSI Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CSI_Register_Masks CSI Register Masks
 * @{
 */

/*! @name CSICR1 - CSI Control Register 1 */
#define CSI_CSICR1_PIXEL_BIT_MASK                (0x1U)
#define CSI_CSICR1_PIXEL_BIT_SHIFT               (0U)
#define CSI_CSICR1_REDGE_MASK                    (0x2U)
#define CSI_CSICR1_REDGE_SHIFT                   (1U)
#define CSI_CSICR1_INV_PCLK_MASK                 (0x4U)
#define CSI_CSICR1_INV_PCLK_SHIFT                (2U)
#define CSI_CSICR1_INV_DATA_MASK                 (0x8U)
#define CSI_CSICR1_INV_DATA_SHIFT                (3U)
#define CSI_CSICR1_GCLK_MODE_MASK                (0x10U)
#define CSI_CSICR1_GCLK_MODE_SHIFT               (4U)
#define CSI_CSICR1_CLR_RXFIFO_MASK               (0x20U)
#define CSI_CSICR1_CLR_RXFIFO_SHIFT              (5U)
#define CSI_CSICR1_CLR_STATFIFO_MASK             (0x40U)
#define CSI_CSICR1_CLR_STATFIFO_SHIFT            (6U)
#define CSI_CSICR1_PACK_DIR_MASK                 (0x80U)
#define CSI_CSICR1_PACK_DIR_SHIFT                (7U)
#define CSI_CSICR1_FCC_MASK                      (0x100U)
#define CSI_CSICR1_FCC_SHIFT                     (8U)
#define CSI_CSICR1_CCIR_EN_MASK                  (0x400U)
#define CSI_CSICR1_CCIR_EN_SHIFT                 (10U)
#define CSI_CSICR1_HSYNC_POL_MASK                (0x800U)
#define CSI_CSICR1_HSYNC_POL_SHIFT               (11U)
#define CSI_CSICR1_SOF_INTEN_MASK                (0x10000U)
#define CSI_CSICR1_SOF_INTEN_SHIFT               (16U)
#define CSI_CSICR1_SOF_POL_MASK                  (0x20000U)
#define CSI_CSICR1_SOF_POL_SHIFT                 (17U)
#define CSI_CSICR1_RXFF_INTEN_MASK               (0x40000U)
#define CSI_CSICR1_RXFF_INTEN_SHIFT              (18U)
#define CSI_CSICR1_FB1_DMA_DONE_INTEN_MASK       (0x80000U)
#define CSI_CSICR1_FB1_DMA_DONE_INTEN_SHIFT      (19U)
#define CSI_CSICR1_FB2_DMA_DONE_INTEN_MASK       (0x100000U)
#define CSI_CSICR1_FB2_DMA_DONE_INTEN_SHIFT      (20U)
#define CSI_CSICR1_STATFF_INTEN_MASK             (0x200000U)
#define CSI_CSICR1_STATFF_INTEN_SHIFT            (21U)
#define CSI_CSICR1_SFF_DMA_DONE_INTEN_MASK       (0x400000U)
#define CSI_CSICR1_SFF_DMA_DONE_INTEN_SHIFT      (22U)
#define CSI_CSICR1_RF_OR_INTEN_MASK              (0x1000000U)
#define CSI_CSICR1_RF_OR_INTEN_SHIFT             (24U)
#define CSI_CSICR1_SF_OR_INTEN_MASK              (0x2000000U)
#define CSI_CSICR1_SF_OR_INTEN_SHIFT             (25U)
#define CSI_CSICR1_COF_INT_EN_MASK               (0x4000000U)
#define CSI_CSICR1_COF_INT_EN_SHIFT              (26U)
#define CSI_CSICR1_VIDEO_MODE_MASK               (0x8000000U)
#define CSI_CSICR1_VIDEO_MODE_SHIFT              (27U)
#define CSI_CSICR1_PrP_IF_EN_MASK                (0x10000000U)
#define CSI_CSICR1_PrP_IF_EN_SHIFT               (28U)
#define CSI_CSICR1_EOF_INT_EN_MASK               (0x20000000U)
#define CSI_CSICR1_EOF_INT_EN_SHIFT              (29U)
#define CSI_CSICR1_EXT_VSYNC_MASK                (0x40000000U)
#define CSI_CSICR1_EXT_VSYNC_SHIFT               (30U)
#define CSI_CSICR1_SWAP16_EN_MASK                (0x80000000U)
#define CSI_CSICR1_SWAP16_EN_SHIFT               (31U)

/*! @name CSICR2 - CSI Control Register 2 */
#define CSI_CSICR2_HSC_MASK                      (0xFFU)
#define CSI_CSICR2_HSC_SHIFT                     (0U)
#define CSI_CSICR2_HSC(x)                        (((uint32_t)(((uint32_t)(x)) << CSI_CSICR2_HSC_SHIFT)) & CSI_CSICR2_HSC_MASK)
#define CSI_CSICR2_VSC_MASK                      (0xFF00U)
#define CSI_CSICR2_VSC_SHIFT                     (8U)
#define CSI_CSICR2_VSC(x)                        (((uint32_t)(((uint32_t)(x)) << CSI_CSICR2_VSC_SHIFT)) & CSI_CSICR2_VSC_MASK)
#define CSI_CSICR2_LVRM_MASK                     (0x70000U)
#define CSI_CSICR2_LVRM_SHIFT                    (16U)
#define CSI_CSICR2_LVRM(x)                       (((uint32_t)(((uint32_t)(x)) << CSI_CSICR2_LVRM_SHIFT)) & CSI_CSICR2_LVRM_MASK)
#define CSI_CSICR2_BTS_MASK                      (0x180000U)
#define CSI_CSICR2_BTS_SHIFT                     (19U)
#define CSI_CSICR2_BTS(x)                        (((uint32_t)(((uint32_t)(x)) << CSI_CSICR2_BTS_SHIFT)) & CSI_CSICR2_BTS_MASK)
#define CSI_CSICR2_SCE_MASK                      (0x800000U)
#define CSI_CSICR2_SCE_SHIFT                     (23U)
#define CSI_CSICR2_AFS_MASK                      (0x3000000U)
#define CSI_CSICR2_AFS_SHIFT                     (24U)
#define CSI_CSICR2_AFS(x)                        (((uint32_t)(((uint32_t)(x)) << CSI_CSICR2_AFS_SHIFT)) & CSI_CSICR2_AFS_MASK)
#define CSI_CSICR2_DRM_MASK                      (0x4000000U)
#define CSI_CSICR2_DRM_SHIFT                     (26U)
#define CSI_CSICR2_DMA_BURST_TYPE_SFF_MASK       (0x30000000U)
#define CSI_CSICR2_DMA_BURST_TYPE_SFF_SHIFT      (28U)
#define CSI_CSICR2_DMA_BURST_TYPE_SFF(x)         (((uint32_t)(((uint32_t)(x)) << CSI_CSICR2_DMA_BURST_TYPE_SFF_SHIFT)) & CSI_CSICR2_DMA_BURST_TYPE_SFF_MASK)
#define CSI_CSICR2_DMA_BURST_TYPE_RFF_MASK       (0xC0000000U)
#define CSI_CSICR2_DMA_BURST_TYPE_RFF_SHIFT      (30U)
#define CSI_CSICR2_DMA_BURST_TYPE_RFF(x)         (((uint32_t)(((uint32_t)(x)) << CSI_CSICR2_DMA_BURST_TYPE_RFF_SHIFT)) & CSI_CSICR2_DMA_BURST_TYPE_RFF_MASK)

/*! @name CSICR3 - CSI Control Register 3 */
#define CSI_CSICR3_ECC_AUTO_EN_MASK              (0x1U)
#define CSI_CSICR3_ECC_AUTO_EN_SHIFT             (0U)
#define CSI_CSICR3_ECC_INT_EN_MASK               (0x2U)
#define CSI_CSICR3_ECC_INT_EN_SHIFT              (1U)
#define CSI_CSICR3_ZERO_PACK_EN_MASK             (0x4U)
#define CSI_CSICR3_ZERO_PACK_EN_SHIFT            (2U)
#define CSI_CSICR3_TWO_8BIT_SENSOR_MASK          (0x8U)
#define CSI_CSICR3_TWO_8BIT_SENSOR_SHIFT         (3U)
#define CSI_CSICR3_RxFF_LEVEL_MASK               (0x70U)
#define CSI_CSICR3_RxFF_LEVEL_SHIFT              (4U)
#define CSI_CSICR3_RxFF_LEVEL(x)                 (((uint32_t)(((uint32_t)(x)) << CSI_CSICR3_RxFF_LEVEL_SHIFT)) & CSI_CSICR3_RxFF_LEVEL_MASK)
#define CSI_CSICR3_HRESP_ERR_EN_MASK             (0x80U)
#define CSI_CSICR3_HRESP_ERR_EN_SHIFT            (7U)
#define CSI_CSICR3_STATFF_LEVEL_MASK             (0x700U)
#define CSI_CSICR3_STATFF_LEVEL_SHIFT            (8U)
#define CSI_CSICR3_STATFF_LEVEL(x)               (((uint32_t)(((uint32_t)(x)) << CSI_CSICR3_STATFF_LEVEL_SHIFT)) & CSI_CSICR3_STATFF_LEVEL_MASK)
#define CSI_CSICR3_DMA_REQ_EN_SFF_MASK           (0x800U)
#define CSI_CSICR3_DMA_REQ_EN_SFF_SHIFT          (11U)
#define CSI_CSICR3_DMA_REQ_EN_RFF_MASK           (0x1000U)
#define CSI_CSICR3_DMA_REQ_EN_RFF_SHIFT          (12U)
#define CSI_CSICR3_DMA_REFLASH_SFF_MASK          (0x2000U)
#define CSI_CSICR3_DMA_REFLASH_SFF_SHIFT         (13U)
#define CSI_CSICR3_DMA_REFLASH_RFF_MASK          (0x4000U)
#define CSI_CSICR3_DMA_REFLASH_RFF_SHIFT         (14U)
#define CSI_CSICR3_FRMCNT_RST_MASK               (0x8000U)
#define CSI_CSICR3_FRMCNT_RST_SHIFT              (15U)
#define CSI_CSICR3_FRMCNT_MASK                   (0xFFFF0000U)
#define CSI_CSICR3_FRMCNT_SHIFT                  (16U)
#define CSI_CSICR3_FRMCNT(x)                     (((uint32_t)(((uint32_t)(x)) << CSI_CSICR3_FRMCNT_SHIFT)) & CSI_CSICR3_FRMCNT_MASK)

/*! @name CSISTATFIFO - CSI Statistic FIFO Register */
#define CSI_CSISTATFIFO_STAT_MASK                (0xFFFFFFFFU)
#define CSI_CSISTATFIFO_STAT_SHIFT               (0U)
#define CSI_CSISTATFIFO_STAT(x)                  (((uint32_t)(((uint32_t)(x)) << CSI_CSISTATFIFO_STAT_SHIFT)) & CSI_CSISTATFIFO_STAT_MASK)

/*! @name CSIRFIFO - CSI RX FIFO Register */
#define CSI_CSIRFIFO_IMAGE_MASK                  (0xFFFFFFFFU)
#define CSI_CSIRFIFO_IMAGE_SHIFT                 (0U)
#define CSI_CSIRFIFO_IMAGE(x)                    (((uint32_t)(((uint32_t)(x)) << CSI_CSIRFIFO_IMAGE_SHIFT)) & CSI_CSIRFIFO_IMAGE_MASK)

/*! @name CSIRXCNT - CSI RX Count Register */
#define CSI_CSIRXCNT_RXCNT_MASK                  (0x3FFFFFU)
#define CSI_CSIRXCNT_RXCNT_SHIFT                 (0U)
#define CSI_CSIRXCNT_RXCNT(x)                    (((uint32_t)(((uint32_t)(x)) << CSI_CSIRXCNT_RXCNT_SHIFT)) & CSI_CSIRXCNT_RXCNT_MASK)

/*! @name CSISR - CSI Status Register */
#define CSI_CSISR_DRDY_MASK                      (0x1U)
#define CSI_CSISR_DRDY_SHIFT                     (0U)
#define CSI_CSISR_ECC_INT_MASK                   (0x2U)
#define CSI_CSISR_ECC_INT_SHIFT                  (1U)
#define CSI_CSISR_HRESP_ERR_INT_MASK             (0x80U)
#define CSI_CSISR_HRESP_ERR_INT_SHIFT            (7U)
#define CSI_CSISR_COF_INT_MASK                   (0x2000U)
#define CSI_CSISR_COF_INT_SHIFT                  (13U)
#define CSI_CSISR_F1_INT_MASK                    (0x4000U)
#define CSI_CSISR_F1_INT_SHIFT                   (14U)
#define CSI_CSISR_F2_INT_MASK                    (0x8000U)
#define CSI_CSISR_F2_INT_SHIFT                   (15U)
#define CSI_CSISR_SOF_INT_MASK                   (0x10000U)
#define CSI_CSISR_SOF_INT_SHIFT                  (16U)
#define CSI_CSISR_EOF_INT_MASK                   (0x20000U)
#define CSI_CSISR_EOF_INT_SHIFT                  (17U)
#define CSI_CSISR_RxFF_INT_MASK                  (0x40000U)
#define CSI_CSISR_RxFF_INT_SHIFT                 (18U)
#define CSI_CSISR_DMA_TSF_DONE_FB1_MASK          (0x80000U)
#define CSI_CSISR_DMA_TSF_DONE_FB1_SHIFT         (19U)
#define CSI_CSISR_DMA_TSF_DONE_FB2_MASK          (0x100000U)
#define CSI_CSISR_DMA_TSF_DONE_FB2_SHIFT         (20U)
#define CSI_CSISR_STATFF_INT_MASK                (0x200000U)
#define CSI_CSISR_STATFF_INT_SHIFT               (21U)
#define CSI_CSISR_DMA_TSF_DONE_SFF_MASK          (0x400000U)
#define CSI_CSISR_DMA_TSF_DONE_SFF_SHIFT         (22U)
#define CSI_CSISR_RF_OR_INT_MASK                 (0x1000000U)
#define CSI_CSISR_RF_OR_INT_SHIFT                (24U)
#define CSI_CSISR_SF_OR_INT_MASK                 (0x2000000U)
#define CSI_CSISR_SF_OR_INT_SHIFT                (25U)
#define CSI_CSISR_DMA_FIELD1_DONE_MASK           (0x4000000U)
#define CSI_CSISR_DMA_FIELD1_DONE_SHIFT          (26U)
#define CSI_CSISR_DMA_FIELD0_DONE_MASK           (0x8000000U)
#define CSI_CSISR_DMA_FIELD0_DONE_SHIFT          (27U)
#define CSI_CSISR_BASEADDR_CHHANGE_ERROR_MASK    (0x10000000U)
#define CSI_CSISR_BASEADDR_CHHANGE_ERROR_SHIFT   (28U)

/*! @name CSIDMASA_STATFIFO - CSI DMA Start Address Register - for STATFIFO */
#define CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF_MASK (0xFFFFFFFCU)
#define CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF_SHIFT (2U)
#define CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(x) (((uint32_t)(((uint32_t)(x)) << CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF_SHIFT)) & CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF_MASK)

/*! @name CSIDMATS_STATFIFO - CSI DMA Transfer Size Register - for STATFIFO */
#define CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF_MASK (0xFFFFFFFFU)
#define CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF_SHIFT (0U)
#define CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF(x) (((uint32_t)(((uint32_t)(x)) << CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF_SHIFT)) & CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF_MASK)

/*! @name CSIDMASA_FB1 - CSI DMA Start Address Register - for Frame Buffer1 */
#define CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1_MASK (0xFFFFFFFCU)
#define CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1_SHIFT (2U)
#define CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(x)   (((uint32_t)(((uint32_t)(x)) << CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1_SHIFT)) & CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1_MASK)

/*! @name CSIDMASA_FB2 - CSI DMA Transfer Size Register - for Frame Buffer2 */
#define CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2_MASK (0xFFFFFFFCU)
#define CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2_SHIFT (2U)
#define CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(x)   (((uint32_t)(((uint32_t)(x)) << CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2_SHIFT)) & CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2_MASK)

/*! @name CSIFBUF_PARA - CSI Frame Buffer Parameter Register */
#define CSI_CSIFBUF_PARA_FBUF_STRIDE_MASK        (0xFFFFU)
#define CSI_CSIFBUF_PARA_FBUF_STRIDE_SHIFT       (0U)
#define CSI_CSIFBUF_PARA_FBUF_STRIDE(x)          (((uint32_t)(((uint32_t)(x)) << CSI_CSIFBUF_PARA_FBUF_STRIDE_SHIFT)) & CSI_CSIFBUF_PARA_FBUF_STRIDE_MASK)
#define CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE_MASK (0xFFFF0000U)
#define CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE_SHIFT (16U)
#define CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE(x)   (((uint32_t)(((uint32_t)(x)) << CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE_SHIFT)) & CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE_MASK)

/*! @name CSIIMAG_PARA - CSI Image Parameter Register */
#define CSI_CSIIMAG_PARA_IMAGE_HEIGHT_MASK       (0xFFFFU)
#define CSI_CSIIMAG_PARA_IMAGE_HEIGHT_SHIFT      (0U)
#define CSI_CSIIMAG_PARA_IMAGE_HEIGHT(x)         (((uint32_t)(((uint32_t)(x)) << CSI_CSIIMAG_PARA_IMAGE_HEIGHT_SHIFT)) & CSI_CSIIMAG_PARA_IMAGE_HEIGHT_MASK)
#define CSI_CSIIMAG_PARA_IMAGE_WIDTH_MASK        (0xFFFF0000U)
#define CSI_CSIIMAG_PARA_IMAGE_WIDTH_SHIFT       (16U)
#define CSI_CSIIMAG_PARA_IMAGE_WIDTH(x)          (((uint32_t)(((uint32_t)(x)) << CSI_CSIIMAG_PARA_IMAGE_WIDTH_SHIFT)) & CSI_CSIIMAG_PARA_IMAGE_WIDTH_MASK)

/*! @name CSICR18 - CSI Control Register 18 */
#define CSI_CSICR18_DEINTERLACE_EN_MASK          (0x4U)
#define CSI_CSICR18_DEINTERLACE_EN_SHIFT         (2U)
#define CSI_CSICR18_PARALLEL24_EN_MASK           (0x8U)
#define CSI_CSICR18_PARALLEL24_EN_SHIFT          (3U)
#define CSI_CSICR18_BASEADDR_SWITCH_EN_MASK      (0x10U)
#define CSI_CSICR18_BASEADDR_SWITCH_EN_SHIFT     (4U)
#define CSI_CSICR18_BASEADDR_SWITCH_SEL_MASK     (0x20U)
#define CSI_CSICR18_BASEADDR_SWITCH_SEL_SHIFT    (5U)
#define CSI_CSICR18_FIELD0_DONE_IE_MASK          (0x40U)
#define CSI_CSICR18_FIELD0_DONE_IE_SHIFT         (6U)
#define CSI_CSICR18_DMA_FIELD1_DONE_IE_MASK      (0x80U)
#define CSI_CSICR18_DMA_FIELD1_DONE_IE_SHIFT     (7U)
#define CSI_CSICR18_LAST_DMA_REQ_SEL_MASK        (0x100U)
#define CSI_CSICR18_LAST_DMA_REQ_SEL_SHIFT       (8U)
#define CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE_MASK (0x200U)
#define CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE_SHIFT (9U)
#define CSI_CSICR18_RGB888A_FORMAT_SEL_MASK      (0x400U)
#define CSI_CSICR18_RGB888A_FORMAT_SEL_SHIFT     (10U)
#define CSI_CSICR18_AHB_HPROT_MASK               (0xF000U)
#define CSI_CSICR18_AHB_HPROT_SHIFT              (12U)
#define CSI_CSICR18_AHB_HPROT(x)                 (((uint32_t)(((uint32_t)(x)) << CSI_CSICR18_AHB_HPROT_SHIFT)) & CSI_CSICR18_AHB_HPROT_MASK)
#define CSI_CSICR18_CSI_LCDIF_BUFFER_LINES_MASK  (0x30000U)
#define CSI_CSICR18_CSI_LCDIF_BUFFER_LINES_SHIFT (16U)
#define CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(x)    (((uint32_t)(((uint32_t)(x)) << CSI_CSICR18_CSI_LCDIF_BUFFER_LINES_SHIFT)) & CSI_CSICR18_CSI_LCDIF_BUFFER_LINES_MASK)
#define CSI_CSICR18_MASK_OPTION_MASK             (0xC0000U)
#define CSI_CSICR18_MASK_OPTION_SHIFT            (18U)
#define CSI_CSICR18_MASK_OPTION(x)               (((uint32_t)(((uint32_t)(x)) << CSI_CSICR18_MASK_OPTION_SHIFT)) & CSI_CSICR18_MASK_OPTION_MASK)
#define CSI_CSICR18_MIPI_DOUBLE_CMPNT_MASK       (0x100000U)
#define CSI_CSICR18_MIPI_DOUBLE_CMPNT_SHIFT      (20U)
#define CSI_CSICR18_MIPI_YU_SWAP_MASK            (0x200000U)
#define CSI_CSICR18_MIPI_YU_SWAP_SHIFT           (21U)
#define CSI_CSICR18_DATA_FROM_MIPI_MASK          (0x400000U)
#define CSI_CSICR18_DATA_FROM_MIPI_SHIFT         (22U)
#define CSI_CSICR18_LINE_STRIDE_EN_MASK          (0x1000000U)
#define CSI_CSICR18_LINE_STRIDE_EN_SHIFT         (24U)
#define CSI_CSICR18_MIPI_DATA_FORMAT_MASK        (0x7E000000U)
#define CSI_CSICR18_MIPI_DATA_FORMAT_SHIFT       (25U)
#define CSI_CSICR18_MIPI_DATA_FORMAT(x)          (((uint32_t)(((uint32_t)(x)) << CSI_CSICR18_MIPI_DATA_FORMAT_SHIFT)) & CSI_CSICR18_MIPI_DATA_FORMAT_MASK)
#define CSI_CSICR18_CSI_ENABLE_MASK              (0x80000000U)
#define CSI_CSICR18_CSI_ENABLE_SHIFT             (31U)


/*!
 * @}
 */ /* end of group CSI_Register_Masks */


/* CSI - Peripheral instance base addresses */
/** Peripheral CSI base pointer */
#define CSI_BASE_PTR                             ((CSI_MemMapPtr)0x30710000u)
/** Array initializer of CSI peripheral base pointers */
#define CSI_BASE_PTRS                            { CSI_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- CSI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CSI_Register_Accessor_Macros CSI - Register accessor macros
 * @{
 */


/* CSI - Register instance definitions */
/* CSI */
#define CSI_CSICR1                               CSI_CSICR1_REG(CSI_BASE_PTR)
#define CSI_CSICR2                               CSI_CSICR2_REG(CSI_BASE_PTR)
#define CSI_CSICR3                               CSI_CSICR3_REG(CSI_BASE_PTR)
#define CSI_CSISTATFIFO                          CSI_CSISTATFIFO_REG(CSI_BASE_PTR)
#define CSI_CSIRFIFO                             CSI_CSIRFIFO_REG(CSI_BASE_PTR)
#define CSI_CSIRXCNT                             CSI_CSIRXCNT_REG(CSI_BASE_PTR)
#define CSI_CSISR                                CSI_CSISR_REG(CSI_BASE_PTR)
#define CSI_CSIDMASA_STATFIFO                    CSI_CSIDMASA_STATFIFO_REG(CSI_BASE_PTR)
#define CSI_CSIDMATS_STATFIFO                    CSI_CSIDMATS_STATFIFO_REG(CSI_BASE_PTR)
#define CSI_CSIDMASA_FB1                         CSI_CSIDMASA_FB1_REG(CSI_BASE_PTR)
#define CSI_CSIDMASA_FB2                         CSI_CSIDMASA_FB2_REG(CSI_BASE_PTR)
#define CSI_CSIFBUF_PARA                         CSI_CSIFBUF_PARA_REG(CSI_BASE_PTR)
#define CSI_CSIIMAG_PARA                         CSI_CSIIMAG_PARA_REG(CSI_BASE_PTR)
#define CSI_CSICR18                              CSI_CSICR18_REG(CSI_BASE_PTR)

/*!
 * @}
 */ /* end of group CSI_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group CSI_Peripheral */


/* ----------------------------------------------------------------------------
   -- DDRC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDRC_Peripheral DDRC
 * @{
 */

/** DDRC - Peripheral register structure */
typedef struct DDRC_MemMap {
  uint32_t MSTR;                                   /**< Master Register, offset: 0x0 */
  uint32_t STAT;                                   /**< Operating Mode Status Register, offset: 0x4 */
  uint8_t RESERVED_0[8];
  uint32_t MRCTRL0;                                /**< Mode Register Read / Write Control Register 0, offset: 0x10 */
  uint32_t MRCTRL1;                                /**< Mode Register Read / Write Control Register 1, offset: 0x14 */
  uint32_t MRSTAT;                                 /**< Mode Register Read / Write Status Register, offset: 0x18 */
  uint8_t RESERVED_1[4];
  uint32_t DERATEEN;                               /**< Temperature Derate Enable Register, offset: 0x20 */
  uint32_t DERATEINT;                              /**< Temperature Derate Interval Register, offset: 0x24 */
  uint8_t RESERVED_2[8];
  uint32_t PWRCTL;                                 /**< Low Power Control Register, offset: 0x30 */
  uint32_t PWRTMG;                                 /**< Low Power Timing Register, offset: 0x34 */
  uint32_t HWLPCTL;                                /**< Hardware Low Power Control Register, offset: 0x38 */
  uint8_t RESERVED_3[20];
  uint32_t RFSHCTL0;                               /**< Refresh Control Register 0, offset: 0x50 */
  uint32_t RFSHCTL1;                               /**< Refresh Control Register 1, offset: 0x54 */
  uint8_t RESERVED_4[8];
  uint32_t RFSHCTL3;                               /**< Refresh Control Register 0, offset: 0x60 */
  uint32_t RFSHTMG;                                /**< Refresh Timing Register, offset: 0x64 */
  uint8_t RESERVED_5[104];
  uint32_t INIT0;                                  /**< SDRAM Initialization Register 0, offset: 0xD0 */
  uint32_t INIT1;                                  /**< SDRAM Initialization Register 1, offset: 0xD4 */
  uint32_t INIT2;                                  /**< SDRAM Initialization Register 2, offset: 0xD8 */
  uint32_t INIT3;                                  /**< SDRAM Initialization Register 3, offset: 0xDC */
  uint32_t INIT4;                                  /**< SDRAM Initialization Register 4, offset: 0xE0 */
  uint32_t INIT5;                                  /**< SDRAM Initialization Register 5, offset: 0xE4 */
  uint8_t RESERVED_6[12];
  uint32_t RANKCTL;                                /**< Rank Control Register, offset: 0xF4 */
  uint8_t RESERVED_7[8];
  uint32_t DRAMTMG0;                               /**< SDRAM Timing Register 0, offset: 0x100 */
  uint32_t DRAMTMG1;                               /**< SDRAM Timing Register 1, offset: 0x104 */
  uint32_t DRAMTMG2;                               /**< SDRAM Timing Register 2, offset: 0x108 */
  uint32_t DRAMTMG3;                               /**< SDRAM Timing Register 3, offset: 0x10C */
  uint32_t DRAMTMG4;                               /**< SDRAM Timing Register 4, offset: 0x110 */
  uint32_t DRAMTMG5;                               /**< SDRAM Timing Register5, offset: 0x114 */
  uint32_t DRAMTMG6;                               /**< SDRAM Timing Register 6, offset: 0x118 */
  uint32_t DRAMTMG7;                               /**< SDRAM Timing Register 7, offset: 0x11C */
  uint32_t DRAMTMG8;                               /**< SDRAM Timing Register 8, offset: 0x120 */
  uint8_t RESERVED_8[92];
  uint32_t ZQCTL0;                                 /**< ZQ Control Register 0, offset: 0x180 */
  uint32_t ZQCTL1;                                 /**< ZQ Control Register 1, offset: 0x184 */
  uint32_t ZQCTL2;                                 /**< ZQ Control Register 2, offset: 0x188 */
  uint32_t ZQSTAT;                                 /**< ZQ Status Register, offset: 0x18C */
  uint32_t DFITMG0;                                /**< DFI Timing Register 0, offset: 0x190 */
  uint32_t DFITMG1;                                /**< DFI Timing Register 1, offset: 0x194 */
  uint32_t DFILPCFG0;                              /**< DFI Low Power Configuration Register 0, offset: 0x198 */
  uint8_t RESERVED_9[4];
  uint32_t DFIUPD0;                                /**< DFI Update Register 0, offset: 0x1A0 */
  uint32_t DFIUPD1;                                /**< DFI Update Register 1, offset: 0x1A4 */
  uint32_t DFIUPD2;                                /**< DFI Update Register 2, offset: 0x1A8 */
  uint32_t DFIUPD3;                                /**< DFI Update Register 3, offset: 0x1AC */
  uint32_t DFIMISC;                                /**< DFI Miscellaneous Control Register, offset: 0x1B0 */
  uint8_t RESERVED_10[76];
  uint32_t ADDRMAP0;                               /**< Address Map Register 0, offset: 0x200 */
  uint32_t ADDRMAP1;                               /**< Address Map Register 1, offset: 0x204 */
  uint32_t ADDRMAP2;                               /**< Address Map Register 2, offset: 0x208 */
  uint32_t ADDRMAP3;                               /**< Address Map Register 3, offset: 0x20C */
  uint32_t ADDRMAP4;                               /**< Address Map Register 4, offset: 0x210 */
  uint32_t ADDRMAP5;                               /**< Address Map Register 5, offset: 0x214 */
  uint32_t ADDRMAP6;                               /**< Address Map Register 6, offset: 0x218 */
  uint8_t RESERVED_11[36];
  uint32_t ODTCFG;                                 /**< ODT Configuration Register, offset: 0x240 */
  uint32_t ODTMAP;                                 /**< ODT / Rank Map Register, offset: 0x244 */
  uint8_t RESERVED_12[8];
  uint32_t SCHED;                                  /**< Scheduler Control Register, offset: 0x250 */
  uint32_t SCHED1;                                 /**< Scheduler Control Register 1, offset: 0x254 */
  uint8_t RESERVED_13[4];
  uint32_t PERFHPR1;                               /**< High Priority Read CAM Register 1, offset: 0x25C */
  uint8_t RESERVED_14[4];
  uint32_t PERFLPR1;                               /**< Low Priority Read CAM Register 1, offset: 0x264 */
  uint8_t RESERVED_15[4];
  uint32_t PERFWR1;                                /**< Write CAM Register 1, offset: 0x26C */
  uint8_t RESERVED_16[4];
  uint32_t PERFVPR1;                               /**< Variable Priority Read CAM Register 1, offset: 0x274 */
  uint32_t PERFVPW1;                               /**< Variable Priority Write CAM Register 1, offset: 0x278 */
  uint8_t RESERVED_17[132];
  uint32_t DBG0;                                   /**< Debug Register 0, offset: 0x300 */
  uint32_t DBG1;                                   /**< Debug Register 1, offset: 0x304 */
  uint32_t DBGCAM;                                 /**< CAM Debug Register, offset: 0x308 */
  uint32_t DBGCMD;                                 /**< Command Debug Register, offset: 0x30C */
  uint32_t DBGSTAT;                                /**< Status Debug Register, offset: 0x310 */
  uint8_t RESERVED_18[12];
  uint32_t SWCTL;                                  /**< Software Register Programming Control Enable, offset: 0x320 */
  uint32_t SWSTAT;                                 /**< Software Register Programming Control Status, offset: 0x324 */
} volatile *DDRC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- DDRC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDRC_Register_Accessor_Macros DDRC - Register accessor macros
 * @{
 */


/* DDRC - Register accessors */
#define DDRC_MSTR_REG(base)                      ((base)->MSTR)
#define DDRC_STAT_REG(base)                      ((base)->STAT)
#define DDRC_MRCTRL0_REG(base)                   ((base)->MRCTRL0)
#define DDRC_MRCTRL1_REG(base)                   ((base)->MRCTRL1)
#define DDRC_MRSTAT_REG(base)                    ((base)->MRSTAT)
#define DDRC_DERATEEN_REG(base)                  ((base)->DERATEEN)
#define DDRC_DERATEINT_REG(base)                 ((base)->DERATEINT)
#define DDRC_PWRCTL_REG(base)                    ((base)->PWRCTL)
#define DDRC_PWRTMG_REG(base)                    ((base)->PWRTMG)
#define DDRC_HWLPCTL_REG(base)                   ((base)->HWLPCTL)
#define DDRC_RFSHCTL0_REG(base)                  ((base)->RFSHCTL0)
#define DDRC_RFSHCTL1_REG(base)                  ((base)->RFSHCTL1)
#define DDRC_RFSHCTL3_REG(base)                  ((base)->RFSHCTL3)
#define DDRC_RFSHTMG_REG(base)                   ((base)->RFSHTMG)
#define DDRC_INIT0_REG(base)                     ((base)->INIT0)
#define DDRC_INIT1_REG(base)                     ((base)->INIT1)
#define DDRC_INIT2_REG(base)                     ((base)->INIT2)
#define DDRC_INIT3_REG(base)                     ((base)->INIT3)
#define DDRC_INIT4_REG(base)                     ((base)->INIT4)
#define DDRC_INIT5_REG(base)                     ((base)->INIT5)
#define DDRC_RANKCTL_REG(base)                   ((base)->RANKCTL)
#define DDRC_DRAMTMG0_REG(base)                  ((base)->DRAMTMG0)
#define DDRC_DRAMTMG1_REG(base)                  ((base)->DRAMTMG1)
#define DDRC_DRAMTMG2_REG(base)                  ((base)->DRAMTMG2)
#define DDRC_DRAMTMG3_REG(base)                  ((base)->DRAMTMG3)
#define DDRC_DRAMTMG4_REG(base)                  ((base)->DRAMTMG4)
#define DDRC_DRAMTMG5_REG(base)                  ((base)->DRAMTMG5)
#define DDRC_DRAMTMG6_REG(base)                  ((base)->DRAMTMG6)
#define DDRC_DRAMTMG7_REG(base)                  ((base)->DRAMTMG7)
#define DDRC_DRAMTMG8_REG(base)                  ((base)->DRAMTMG8)
#define DDRC_ZQCTL0_REG(base)                    ((base)->ZQCTL0)
#define DDRC_ZQCTL1_REG(base)                    ((base)->ZQCTL1)
#define DDRC_ZQCTL2_REG(base)                    ((base)->ZQCTL2)
#define DDRC_ZQSTAT_REG(base)                    ((base)->ZQSTAT)
#define DDRC_DFITMG0_REG(base)                   ((base)->DFITMG0)
#define DDRC_DFITMG1_REG(base)                   ((base)->DFITMG1)
#define DDRC_DFILPCFG0_REG(base)                 ((base)->DFILPCFG0)
#define DDRC_DFIUPD0_REG(base)                   ((base)->DFIUPD0)
#define DDRC_DFIUPD1_REG(base)                   ((base)->DFIUPD1)
#define DDRC_DFIUPD2_REG(base)                   ((base)->DFIUPD2)
#define DDRC_DFIUPD3_REG(base)                   ((base)->DFIUPD3)
#define DDRC_DFIMISC_REG(base)                   ((base)->DFIMISC)
#define DDRC_ADDRMAP0_REG(base)                  ((base)->ADDRMAP0)
#define DDRC_ADDRMAP1_REG(base)                  ((base)->ADDRMAP1)
#define DDRC_ADDRMAP2_REG(base)                  ((base)->ADDRMAP2)
#define DDRC_ADDRMAP3_REG(base)                  ((base)->ADDRMAP3)
#define DDRC_ADDRMAP4_REG(base)                  ((base)->ADDRMAP4)
#define DDRC_ADDRMAP5_REG(base)                  ((base)->ADDRMAP5)
#define DDRC_ADDRMAP6_REG(base)                  ((base)->ADDRMAP6)
#define DDRC_ODTCFG_REG(base)                    ((base)->ODTCFG)
#define DDRC_ODTMAP_REG(base)                    ((base)->ODTMAP)
#define DDRC_SCHED_REG(base)                     ((base)->SCHED)
#define DDRC_SCHED1_REG(base)                    ((base)->SCHED1)
#define DDRC_PERFHPR1_REG(base)                  ((base)->PERFHPR1)
#define DDRC_PERFLPR1_REG(base)                  ((base)->PERFLPR1)
#define DDRC_PERFWR1_REG(base)                   ((base)->PERFWR1)
#define DDRC_PERFVPR1_REG(base)                  ((base)->PERFVPR1)
#define DDRC_PERFVPW1_REG(base)                  ((base)->PERFVPW1)
#define DDRC_DBG0_REG(base)                      ((base)->DBG0)
#define DDRC_DBG1_REG(base)                      ((base)->DBG1)
#define DDRC_DBGCAM_REG(base)                    ((base)->DBGCAM)
#define DDRC_DBGCMD_REG(base)                    ((base)->DBGCMD)
#define DDRC_DBGSTAT_REG(base)                   ((base)->DBGSTAT)
#define DDRC_SWCTL_REG(base)                     ((base)->SWCTL)
#define DDRC_SWSTAT_REG(base)                    ((base)->SWSTAT)

/*!
 * @}
 */ /* end of group DDRC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- DDRC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDRC_Register_Masks DDRC Register Masks
 * @{
 */

/*! @name MSTR - Master Register */
#define DDRC_MSTR_DDR3_MASK                      (0x1U)
#define DDRC_MSTR_DDR3_SHIFT                     (0U)
#define DDRC_MSTR_LPDDR2_MASK                    (0x4U)
#define DDRC_MSTR_LPDDR2_SHIFT                   (2U)
#define DDRC_MSTR_LPDDR3_MASK                    (0x8U)
#define DDRC_MSTR_LPDDR3_SHIFT                   (3U)
#define DDRC_MSTR_BURST_MODE_MASK                (0x100U)
#define DDRC_MSTR_BURST_MODE_SHIFT               (8U)
#define DDRC_MSTR_BURSTCHOP_MASK                 (0x200U)
#define DDRC_MSTR_BURSTCHOP_SHIFT                (9U)
#define DDRC_MSTR_DATA_BUS_WIDTH_MASK            (0x3000U)
#define DDRC_MSTR_DATA_BUS_WIDTH_SHIFT           (12U)
#define DDRC_MSTR_DATA_BUS_WIDTH(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_MSTR_DATA_BUS_WIDTH_SHIFT)) & DDRC_MSTR_DATA_BUS_WIDTH_MASK)
#define DDRC_MSTR_DLL_OFF_MODE_MASK              (0x8000U)
#define DDRC_MSTR_DLL_OFF_MODE_SHIFT             (15U)
#define DDRC_MSTR_BURST_RDWR_MASK                (0xF0000U)
#define DDRC_MSTR_BURST_RDWR_SHIFT               (16U)
#define DDRC_MSTR_BURST_RDWR(x)                  (((uint32_t)(((uint32_t)(x)) << DDRC_MSTR_BURST_RDWR_SHIFT)) & DDRC_MSTR_BURST_RDWR_MASK)
#define DDRC_MSTR_ACTIVE_RANKS_MASK              (0xF000000U)
#define DDRC_MSTR_ACTIVE_RANKS_SHIFT             (24U)
#define DDRC_MSTR_ACTIVE_RANKS(x)                (((uint32_t)(((uint32_t)(x)) << DDRC_MSTR_ACTIVE_RANKS_SHIFT)) & DDRC_MSTR_ACTIVE_RANKS_MASK)

/*! @name STAT - Operating Mode Status Register */
#define DDRC_STAT_OPERATING_MODE_MASK            (0x7U)
#define DDRC_STAT_OPERATING_MODE_SHIFT           (0U)
#define DDRC_STAT_OPERATING_MODE(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_STAT_OPERATING_MODE_SHIFT)) & DDRC_STAT_OPERATING_MODE_MASK)
#define DDRC_STAT_SELFREF_TYPE_MASK              (0x30U)
#define DDRC_STAT_SELFREF_TYPE_SHIFT             (4U)
#define DDRC_STAT_SELFREF_TYPE(x)                (((uint32_t)(((uint32_t)(x)) << DDRC_STAT_SELFREF_TYPE_SHIFT)) & DDRC_STAT_SELFREF_TYPE_MASK)
#define DDRC_STAT_SELFREF_STATE_MASK             (0x300U)
#define DDRC_STAT_SELFREF_STATE_SHIFT            (8U)
#define DDRC_STAT_SELFREF_STATE(x)               (((uint32_t)(((uint32_t)(x)) << DDRC_STAT_SELFREF_STATE_SHIFT)) & DDRC_STAT_SELFREF_STATE_MASK)

/*! @name MRCTRL0 - Mode Register Read / Write Control Register 0 */
#define DDRC_MRCTRL0_MR_TYPE_MASK                (0x1U)
#define DDRC_MRCTRL0_MR_TYPE_SHIFT               (0U)
#define DDRC_MRCTRL0_MR_RANK_MASK                (0xF0U)
#define DDRC_MRCTRL0_MR_RANK_SHIFT               (4U)
#define DDRC_MRCTRL0_MR_RANK(x)                  (((uint32_t)(((uint32_t)(x)) << DDRC_MRCTRL0_MR_RANK_SHIFT)) & DDRC_MRCTRL0_MR_RANK_MASK)
#define DDRC_MRCTRL0_MR_ADDR_MASK                (0xF000U)
#define DDRC_MRCTRL0_MR_ADDR_SHIFT               (12U)
#define DDRC_MRCTRL0_MR_ADDR(x)                  (((uint32_t)(((uint32_t)(x)) << DDRC_MRCTRL0_MR_ADDR_SHIFT)) & DDRC_MRCTRL0_MR_ADDR_MASK)
#define DDRC_MRCTRL0_MR_WR_MASK                  (0x80000000U)
#define DDRC_MRCTRL0_MR_WR_SHIFT                 (31U)

/*! @name MRCTRL1 - Mode Register Read / Write Control Register 1 */
#define DDRC_MRCTRL1_MR_DATA_MASK                (0x3FFFFU)
#define DDRC_MRCTRL1_MR_DATA_SHIFT               (0U)
#define DDRC_MRCTRL1_MR_DATA(x)                  (((uint32_t)(((uint32_t)(x)) << DDRC_MRCTRL1_MR_DATA_SHIFT)) & DDRC_MRCTRL1_MR_DATA_MASK)

/*! @name MRSTAT - Mode Register Read / Write Status Register */
#define DDRC_MRSTAT_MR_WR_BUSY_MASK              (0x1U)
#define DDRC_MRSTAT_MR_WR_BUSY_SHIFT             (0U)

/*! @name DERATEEN - Temperature Derate Enable Register */
#define DDRC_DERATEEN_DERATE_ENABLE_MASK         (0x1U)
#define DDRC_DERATEEN_DERATE_ENABLE_SHIFT        (0U)
#define DDRC_DERATEEN_DERATE_VALUE_MASK          (0x2U)
#define DDRC_DERATEEN_DERATE_VALUE_SHIFT         (1U)
#define DDRC_DERATEEN_DERATE_BYTE_MASK           (0xF0U)
#define DDRC_DERATEEN_DERATE_BYTE_SHIFT          (4U)
#define DDRC_DERATEEN_DERATE_BYTE(x)             (((uint32_t)(((uint32_t)(x)) << DDRC_DERATEEN_DERATE_BYTE_SHIFT)) & DDRC_DERATEEN_DERATE_BYTE_MASK)

/*! @name DERATEINT - Temperature Derate Interval Register */
#define DDRC_DERATEINT_MR4_READ_INTERVAL_MASK    (0xFFFFFFFFU)
#define DDRC_DERATEINT_MR4_READ_INTERVAL_SHIFT   (0U)
#define DDRC_DERATEINT_MR4_READ_INTERVAL(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_DERATEINT_MR4_READ_INTERVAL_SHIFT)) & DDRC_DERATEINT_MR4_READ_INTERVAL_MASK)

/*! @name PWRCTL - Low Power Control Register */
#define DDRC_PWRCTL_SELFREF_EN_MASK              (0x1U)
#define DDRC_PWRCTL_SELFREF_EN_SHIFT             (0U)
#define DDRC_PWRCTL_POWERDOWN_EN_MASK            (0x2U)
#define DDRC_PWRCTL_POWERDOWN_EN_SHIFT           (1U)
#define DDRC_PWRCTL_DEEPPOWERDOWN_EN_MASK        (0x4U)
#define DDRC_PWRCTL_DEEPPOWERDOWN_EN_SHIFT       (2U)
#define DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE_MASK (0x8U)
#define DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE_SHIFT (3U)
#define DDRC_PWRCTL_SELFREF_SW_MASK              (0x20U)
#define DDRC_PWRCTL_SELFREF_SW_SHIFT             (5U)

/*! @name PWRTMG - Low Power Timing Register */
#define DDRC_PWRTMG_POWERDOWN_TO_X32_MASK        (0x1FU)
#define DDRC_PWRTMG_POWERDOWN_TO_X32_SHIFT       (0U)
#define DDRC_PWRTMG_POWERDOWN_TO_X32(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_PWRTMG_POWERDOWN_TO_X32_SHIFT)) & DDRC_PWRTMG_POWERDOWN_TO_X32_MASK)
#define DDRC_PWRTMG_T_DPD_X4096_MASK             (0xFF00U)
#define DDRC_PWRTMG_T_DPD_X4096_SHIFT            (8U)
#define DDRC_PWRTMG_T_DPD_X4096(x)               (((uint32_t)(((uint32_t)(x)) << DDRC_PWRTMG_T_DPD_X4096_SHIFT)) & DDRC_PWRTMG_T_DPD_X4096_MASK)
#define DDRC_PWRTMG_SELFREF_TO_X32_MASK          (0xFF0000U)
#define DDRC_PWRTMG_SELFREF_TO_X32_SHIFT         (16U)
#define DDRC_PWRTMG_SELFREF_TO_X32(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_PWRTMG_SELFREF_TO_X32_SHIFT)) & DDRC_PWRTMG_SELFREF_TO_X32_MASK)

/*! @name HWLPCTL - Hardware Low Power Control Register */
#define DDRC_HWLPCTL_HW_LP_EN_MASK               (0x1U)
#define DDRC_HWLPCTL_HW_LP_EN_SHIFT              (0U)
#define DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN_MASK     (0x2U)
#define DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN_SHIFT    (1U)
#define DDRC_HWLPCTL_HW_LP_IDLE_X32_MASK         (0xFFF0000U)
#define DDRC_HWLPCTL_HW_LP_IDLE_X32_SHIFT        (16U)
#define DDRC_HWLPCTL_HW_LP_IDLE_X32(x)           (((uint32_t)(((uint32_t)(x)) << DDRC_HWLPCTL_HW_LP_IDLE_X32_SHIFT)) & DDRC_HWLPCTL_HW_LP_IDLE_X32_MASK)

/*! @name RFSHCTL0 - Refresh Control Register 0 */
#define DDRC_RFSHCTL0_PER_BANK_REFRESH_MASK      (0x4U)
#define DDRC_RFSHCTL0_PER_BANK_REFRESH_SHIFT     (2U)
#define DDRC_RFSHCTL0_REFRESH_BURST_MASK         (0x1F0U)
#define DDRC_RFSHCTL0_REFRESH_BURST_SHIFT        (4U)
#define DDRC_RFSHCTL0_REFRESH_BURST(x)           (((uint32_t)(((uint32_t)(x)) << DDRC_RFSHCTL0_REFRESH_BURST_SHIFT)) & DDRC_RFSHCTL0_REFRESH_BURST_MASK)
#define DDRC_RFSHCTL0_REFRESH_TO_X32_MASK        (0x1F000U)
#define DDRC_RFSHCTL0_REFRESH_TO_X32_SHIFT       (12U)
#define DDRC_RFSHCTL0_REFRESH_TO_X32(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_RFSHCTL0_REFRESH_TO_X32_SHIFT)) & DDRC_RFSHCTL0_REFRESH_TO_X32_MASK)
#define DDRC_RFSHCTL0_REFRESH_MARGIN_MASK        (0xF00000U)
#define DDRC_RFSHCTL0_REFRESH_MARGIN_SHIFT       (20U)
#define DDRC_RFSHCTL0_REFRESH_MARGIN(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_RFSHCTL0_REFRESH_MARGIN_SHIFT)) & DDRC_RFSHCTL0_REFRESH_MARGIN_MASK)

/*! @name RFSHCTL1 - Refresh Control Register 1 */
#define DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32_MASK (0xFFFU)
#define DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32_SHIFT (0U)
#define DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32(x) (((uint32_t)(((uint32_t)(x)) << DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32_SHIFT)) & DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32_MASK)
#define DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32_MASK (0xFFF0000U)
#define DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32_SHIFT (16U)
#define DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32(x) (((uint32_t)(((uint32_t)(x)) << DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32_SHIFT)) & DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32_MASK)

/*! @name RFSHCTL3 - Refresh Control Register 0 */
#define DDRC_RFSHCTL3_DIS_AUTO_REFRESH_MASK      (0x1U)
#define DDRC_RFSHCTL3_DIS_AUTO_REFRESH_SHIFT     (0U)
#define DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL_MASK  (0x2U)
#define DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL_SHIFT (1U)

/*! @name RFSHTMG - Refresh Timing Register */
#define DDRC_RFSHTMG_T_RFC_MIN_MASK              (0x3FFU)
#define DDRC_RFSHTMG_T_RFC_MIN_SHIFT             (0U)
#define DDRC_RFSHTMG_T_RFC_MIN(x)                (((uint32_t)(((uint32_t)(x)) << DDRC_RFSHTMG_T_RFC_MIN_SHIFT)) & DDRC_RFSHTMG_T_RFC_MIN_MASK)
#define DDRC_RFSHTMG_T_RFC_NOM_X32_MASK          (0xFFF0000U)
#define DDRC_RFSHTMG_T_RFC_NOM_X32_SHIFT         (16U)
#define DDRC_RFSHTMG_T_RFC_NOM_X32(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_RFSHTMG_T_RFC_NOM_X32_SHIFT)) & DDRC_RFSHTMG_T_RFC_NOM_X32_MASK)

/*! @name INIT0 - SDRAM Initialization Register 0 */
#define DDRC_INIT0_PRE_CKE_X1024_MASK            (0x7FFU)
#define DDRC_INIT0_PRE_CKE_X1024_SHIFT           (0U)
#define DDRC_INIT0_PRE_CKE_X1024(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_INIT0_PRE_CKE_X1024_SHIFT)) & DDRC_INIT0_PRE_CKE_X1024_MASK)
#define DDRC_INIT0_POST_CKE_X1024_MASK           (0x3FF0000U)
#define DDRC_INIT0_POST_CKE_X1024_SHIFT          (16U)
#define DDRC_INIT0_POST_CKE_X1024(x)             (((uint32_t)(((uint32_t)(x)) << DDRC_INIT0_POST_CKE_X1024_SHIFT)) & DDRC_INIT0_POST_CKE_X1024_MASK)
#define DDRC_INIT0_SKIP_DRAM_INIT_MASK           (0xC0000000U)
#define DDRC_INIT0_SKIP_DRAM_INIT_SHIFT          (30U)
#define DDRC_INIT0_SKIP_DRAM_INIT(x)             (((uint32_t)(((uint32_t)(x)) << DDRC_INIT0_SKIP_DRAM_INIT_SHIFT)) & DDRC_INIT0_SKIP_DRAM_INIT_MASK)

/*! @name INIT1 - SDRAM Initialization Register 1 */
#define DDRC_INIT1_PRE_OCD_X32_MASK              (0xFU)
#define DDRC_INIT1_PRE_OCD_X32_SHIFT             (0U)
#define DDRC_INIT1_PRE_OCD_X32(x)                (((uint32_t)(((uint32_t)(x)) << DDRC_INIT1_PRE_OCD_X32_SHIFT)) & DDRC_INIT1_PRE_OCD_X32_MASK)
#define DDRC_INIT1_FINAL_WAIT_X32_MASK           (0x7F00U)
#define DDRC_INIT1_FINAL_WAIT_X32_SHIFT          (8U)
#define DDRC_INIT1_FINAL_WAIT_X32(x)             (((uint32_t)(((uint32_t)(x)) << DDRC_INIT1_FINAL_WAIT_X32_SHIFT)) & DDRC_INIT1_FINAL_WAIT_X32_MASK)
#define DDRC_INIT1_DRAM_RSTN_X1024_MASK          (0xFF0000U)
#define DDRC_INIT1_DRAM_RSTN_X1024_SHIFT         (16U)
#define DDRC_INIT1_DRAM_RSTN_X1024(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_INIT1_DRAM_RSTN_X1024_SHIFT)) & DDRC_INIT1_DRAM_RSTN_X1024_MASK)

/*! @name INIT2 - SDRAM Initialization Register 2 */
#define DDRC_INIT2_MIN_STABLE_CLOCK_X1_MASK      (0xFU)
#define DDRC_INIT2_MIN_STABLE_CLOCK_X1_SHIFT     (0U)
#define DDRC_INIT2_MIN_STABLE_CLOCK_X1(x)        (((uint32_t)(((uint32_t)(x)) << DDRC_INIT2_MIN_STABLE_CLOCK_X1_SHIFT)) & DDRC_INIT2_MIN_STABLE_CLOCK_X1_MASK)
#define DDRC_INIT2_IDLE_AFTER_RESET_X32_MASK     (0xFF00U)
#define DDRC_INIT2_IDLE_AFTER_RESET_X32_SHIFT    (8U)
#define DDRC_INIT2_IDLE_AFTER_RESET_X32(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_INIT2_IDLE_AFTER_RESET_X32_SHIFT)) & DDRC_INIT2_IDLE_AFTER_RESET_X32_MASK)

/*! @name INIT3 - SDRAM Initialization Register 3 */
#define DDRC_INIT3_EMR_MASK                      (0xFFFFU)
#define DDRC_INIT3_EMR_SHIFT                     (0U)
#define DDRC_INIT3_EMR(x)                        (((uint32_t)(((uint32_t)(x)) << DDRC_INIT3_EMR_SHIFT)) & DDRC_INIT3_EMR_MASK)
#define DDRC_INIT3_MR_MASK                       (0xFFFF0000U)
#define DDRC_INIT3_MR_SHIFT                      (16U)
#define DDRC_INIT3_MR(x)                         (((uint32_t)(((uint32_t)(x)) << DDRC_INIT3_MR_SHIFT)) & DDRC_INIT3_MR_MASK)

/*! @name INIT4 - SDRAM Initialization Register 4 */
#define DDRC_INIT4_EMR3_MASK                     (0xFFFFU)
#define DDRC_INIT4_EMR3_SHIFT                    (0U)
#define DDRC_INIT4_EMR3(x)                       (((uint32_t)(((uint32_t)(x)) << DDRC_INIT4_EMR3_SHIFT)) & DDRC_INIT4_EMR3_MASK)
#define DDRC_INIT4_EMR2_MASK                     (0xFFFF0000U)
#define DDRC_INIT4_EMR2_SHIFT                    (16U)
#define DDRC_INIT4_EMR2(x)                       (((uint32_t)(((uint32_t)(x)) << DDRC_INIT4_EMR2_SHIFT)) & DDRC_INIT4_EMR2_MASK)

/*! @name INIT5 - SDRAM Initialization Register 5 */
#define DDRC_INIT5_MAX_AUTO_INIT_X1024_MASK      (0x3FFU)
#define DDRC_INIT5_MAX_AUTO_INIT_X1024_SHIFT     (0U)
#define DDRC_INIT5_MAX_AUTO_INIT_X1024(x)        (((uint32_t)(((uint32_t)(x)) << DDRC_INIT5_MAX_AUTO_INIT_X1024_SHIFT)) & DDRC_INIT5_MAX_AUTO_INIT_X1024_MASK)
#define DDRC_INIT5_DEV_ZQINIT_X32_MASK           (0xFF0000U)
#define DDRC_INIT5_DEV_ZQINIT_X32_SHIFT          (16U)
#define DDRC_INIT5_DEV_ZQINIT_X32(x)             (((uint32_t)(((uint32_t)(x)) << DDRC_INIT5_DEV_ZQINIT_X32_SHIFT)) & DDRC_INIT5_DEV_ZQINIT_X32_MASK)

/*! @name RANKCTL - Rank Control Register */
#define DDRC_RANKCTL_DIFF_RANK_RD_GAP_MASK       (0xF0U)
#define DDRC_RANKCTL_DIFF_RANK_RD_GAP_SHIFT      (4U)
#define DDRC_RANKCTL_DIFF_RANK_RD_GAP(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_RANKCTL_DIFF_RANK_RD_GAP_SHIFT)) & DDRC_RANKCTL_DIFF_RANK_RD_GAP_MASK)
#define DDRC_RANKCTL_DIFF_RANK_WR_GAP_MASK       (0xF00U)
#define DDRC_RANKCTL_DIFF_RANK_WR_GAP_SHIFT      (8U)
#define DDRC_RANKCTL_DIFF_RANK_WR_GAP(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_RANKCTL_DIFF_RANK_WR_GAP_SHIFT)) & DDRC_RANKCTL_DIFF_RANK_WR_GAP_MASK)

/*! @name DRAMTMG0 - SDRAM Timing Register 0 */
#define DDRC_DRAMTMG0_T_RAS_MIN_MASK             (0x3FU)
#define DDRC_DRAMTMG0_T_RAS_MIN_SHIFT            (0U)
#define DDRC_DRAMTMG0_T_RAS_MIN(x)               (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG0_T_RAS_MIN_SHIFT)) & DDRC_DRAMTMG0_T_RAS_MIN_MASK)
#define DDRC_DRAMTMG0_T_RAS_MAX_MASK             (0x7F00U)
#define DDRC_DRAMTMG0_T_RAS_MAX_SHIFT            (8U)
#define DDRC_DRAMTMG0_T_RAS_MAX(x)               (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG0_T_RAS_MAX_SHIFT)) & DDRC_DRAMTMG0_T_RAS_MAX_MASK)
#define DDRC_DRAMTMG0_T_FAW_MASK                 (0x3F0000U)
#define DDRC_DRAMTMG0_T_FAW_SHIFT                (16U)
#define DDRC_DRAMTMG0_T_FAW(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG0_T_FAW_SHIFT)) & DDRC_DRAMTMG0_T_FAW_MASK)
#define DDRC_DRAMTMG0_WR2PRE_MASK                (0x7F000000U)
#define DDRC_DRAMTMG0_WR2PRE_SHIFT               (24U)
#define DDRC_DRAMTMG0_WR2PRE(x)                  (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG0_WR2PRE_SHIFT)) & DDRC_DRAMTMG0_WR2PRE_MASK)

/*! @name DRAMTMG1 - SDRAM Timing Register 1 */
#define DDRC_DRAMTMG1_T_RC_MASK                  (0x7FU)
#define DDRC_DRAMTMG1_T_RC_SHIFT                 (0U)
#define DDRC_DRAMTMG1_T_RC(x)                    (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG1_T_RC_SHIFT)) & DDRC_DRAMTMG1_T_RC_MASK)
#define DDRC_DRAMTMG1_RD2PRE_MASK                (0x1F00U)
#define DDRC_DRAMTMG1_RD2PRE_SHIFT               (8U)
#define DDRC_DRAMTMG1_RD2PRE(x)                  (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG1_RD2PRE_SHIFT)) & DDRC_DRAMTMG1_RD2PRE_MASK)
#define DDRC_DRAMTMG1_T_XP_MASK                  (0x1F0000U)
#define DDRC_DRAMTMG1_T_XP_SHIFT                 (16U)
#define DDRC_DRAMTMG1_T_XP(x)                    (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG1_T_XP_SHIFT)) & DDRC_DRAMTMG1_T_XP_MASK)

/*! @name DRAMTMG2 - SDRAM Timing Register 2 */
#define DDRC_DRAMTMG2_WR2RD_MASK                 (0x3FU)
#define DDRC_DRAMTMG2_WR2RD_SHIFT                (0U)
#define DDRC_DRAMTMG2_WR2RD(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG2_WR2RD_SHIFT)) & DDRC_DRAMTMG2_WR2RD_MASK)
#define DDRC_DRAMTMG2_RD2WR_MASK                 (0x3F00U)
#define DDRC_DRAMTMG2_RD2WR_SHIFT                (8U)
#define DDRC_DRAMTMG2_RD2WR(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG2_RD2WR_SHIFT)) & DDRC_DRAMTMG2_RD2WR_MASK)
#define DDRC_DRAMTMG2_READ_LATENCY_MASK          (0x3F0000U)
#define DDRC_DRAMTMG2_READ_LATENCY_SHIFT         (16U)
#define DDRC_DRAMTMG2_READ_LATENCY(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG2_READ_LATENCY_SHIFT)) & DDRC_DRAMTMG2_READ_LATENCY_MASK)
#define DDRC_DRAMTMG2_WRITE_LATENCY_MASK         (0x3F000000U)
#define DDRC_DRAMTMG2_WRITE_LATENCY_SHIFT        (24U)
#define DDRC_DRAMTMG2_WRITE_LATENCY(x)           (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG2_WRITE_LATENCY_SHIFT)) & DDRC_DRAMTMG2_WRITE_LATENCY_MASK)

/*! @name DRAMTMG3 - SDRAM Timing Register 3 */
#define DDRC_DRAMTMG3_T_MOD_MASK                 (0x3FFU)
#define DDRC_DRAMTMG3_T_MOD_SHIFT                (0U)
#define DDRC_DRAMTMG3_T_MOD(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG3_T_MOD_SHIFT)) & DDRC_DRAMTMG3_T_MOD_MASK)
#define DDRC_DRAMTMG3_T_MRD_MASK                 (0x3F000U)
#define DDRC_DRAMTMG3_T_MRD_SHIFT                (12U)
#define DDRC_DRAMTMG3_T_MRD(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG3_T_MRD_SHIFT)) & DDRC_DRAMTMG3_T_MRD_MASK)
#define DDRC_DRAMTMG3_T_MRW_MASK                 (0x3FF00000U)
#define DDRC_DRAMTMG3_T_MRW_SHIFT                (20U)
#define DDRC_DRAMTMG3_T_MRW(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG3_T_MRW_SHIFT)) & DDRC_DRAMTMG3_T_MRW_MASK)

/*! @name DRAMTMG4 - SDRAM Timing Register 4 */
#define DDRC_DRAMTMG4_T_RP_MASK                  (0x1FU)
#define DDRC_DRAMTMG4_T_RP_SHIFT                 (0U)
#define DDRC_DRAMTMG4_T_RP(x)                    (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG4_T_RP_SHIFT)) & DDRC_DRAMTMG4_T_RP_MASK)
#define DDRC_DRAMTMG4_T_RRD_MASK                 (0xF00U)
#define DDRC_DRAMTMG4_T_RRD_SHIFT                (8U)
#define DDRC_DRAMTMG4_T_RRD(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG4_T_RRD_SHIFT)) & DDRC_DRAMTMG4_T_RRD_MASK)
#define DDRC_DRAMTMG4_T_CCD_MASK                 (0xF0000U)
#define DDRC_DRAMTMG4_T_CCD_SHIFT                (16U)
#define DDRC_DRAMTMG4_T_CCD(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG4_T_CCD_SHIFT)) & DDRC_DRAMTMG4_T_CCD_MASK)
#define DDRC_DRAMTMG4_T_RCD_MASK                 (0x1F000000U)
#define DDRC_DRAMTMG4_T_RCD_SHIFT                (24U)
#define DDRC_DRAMTMG4_T_RCD(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG4_T_RCD_SHIFT)) & DDRC_DRAMTMG4_T_RCD_MASK)

/*! @name DRAMTMG5 - SDRAM Timing Register5 */
#define DDRC_DRAMTMG5_T_CKE_MASK                 (0x1FU)
#define DDRC_DRAMTMG5_T_CKE_SHIFT                (0U)
#define DDRC_DRAMTMG5_T_CKE(x)                   (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG5_T_CKE_SHIFT)) & DDRC_DRAMTMG5_T_CKE_MASK)
#define DDRC_DRAMTMG5_T_CKESR_MASK               (0x3F00U)
#define DDRC_DRAMTMG5_T_CKESR_SHIFT              (8U)
#define DDRC_DRAMTMG5_T_CKESR(x)                 (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG5_T_CKESR_SHIFT)) & DDRC_DRAMTMG5_T_CKESR_MASK)
#define DDRC_DRAMTMG5_T_CKSRE_MASK               (0xF0000U)
#define DDRC_DRAMTMG5_T_CKSRE_SHIFT              (16U)
#define DDRC_DRAMTMG5_T_CKSRE(x)                 (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG5_T_CKSRE_SHIFT)) & DDRC_DRAMTMG5_T_CKSRE_MASK)
#define DDRC_DRAMTMG5_T_CKSRX_MASK               (0xF000000U)
#define DDRC_DRAMTMG5_T_CKSRX_SHIFT              (24U)
#define DDRC_DRAMTMG5_T_CKSRX(x)                 (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG5_T_CKSRX_SHIFT)) & DDRC_DRAMTMG5_T_CKSRX_MASK)

/*! @name DRAMTMG6 - SDRAM Timing Register 6 */
#define DDRC_DRAMTMG6_T_CKCSX_MASK               (0xFU)
#define DDRC_DRAMTMG6_T_CKCSX_SHIFT              (0U)
#define DDRC_DRAMTMG6_T_CKCSX(x)                 (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG6_T_CKCSX_SHIFT)) & DDRC_DRAMTMG6_T_CKCSX_MASK)
#define DDRC_DRAMTMG6_T_CKDPDX_MASK              (0xF0000U)
#define DDRC_DRAMTMG6_T_CKDPDX_SHIFT             (16U)
#define DDRC_DRAMTMG6_T_CKDPDX(x)                (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG6_T_CKDPDX_SHIFT)) & DDRC_DRAMTMG6_T_CKDPDX_MASK)
#define DDRC_DRAMTMG6_T_CKDPDE_MASK              (0xF000000U)
#define DDRC_DRAMTMG6_T_CKDPDE_SHIFT             (24U)
#define DDRC_DRAMTMG6_T_CKDPDE(x)                (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG6_T_CKDPDE_SHIFT)) & DDRC_DRAMTMG6_T_CKDPDE_MASK)

/*! @name DRAMTMG7 - SDRAM Timing Register 7 */
#define DDRC_DRAMTMG7_T_CKPDX_MASK               (0xFU)
#define DDRC_DRAMTMG7_T_CKPDX_SHIFT              (0U)
#define DDRC_DRAMTMG7_T_CKPDX(x)                 (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG7_T_CKPDX_SHIFT)) & DDRC_DRAMTMG7_T_CKPDX_MASK)
#define DDRC_DRAMTMG7_T_CKPDE_MASK               (0xF00U)
#define DDRC_DRAMTMG7_T_CKPDE_SHIFT              (8U)
#define DDRC_DRAMTMG7_T_CKPDE(x)                 (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG7_T_CKPDE_SHIFT)) & DDRC_DRAMTMG7_T_CKPDE_MASK)

/*! @name DRAMTMG8 - SDRAM Timing Register 8 */
#define DDRC_DRAMTMG8_T_XS_X32_MASK              (0x7FU)
#define DDRC_DRAMTMG8_T_XS_X32_SHIFT             (0U)
#define DDRC_DRAMTMG8_T_XS_X32(x)                (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG8_T_XS_X32_SHIFT)) & DDRC_DRAMTMG8_T_XS_X32_MASK)
#define DDRC_DRAMTMG8_T_XS_DLL_X32_MASK          (0x7F00U)
#define DDRC_DRAMTMG8_T_XS_DLL_X32_SHIFT         (8U)
#define DDRC_DRAMTMG8_T_XS_DLL_X32(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_DRAMTMG8_T_XS_DLL_X32_SHIFT)) & DDRC_DRAMTMG8_T_XS_DLL_X32_MASK)

/*! @name ZQCTL0 - ZQ Control Register 0 */
#define DDRC_ZQCTL0_T_ZQ_SHORT_NOP_MASK          (0x3FFU)
#define DDRC_ZQCTL0_T_ZQ_SHORT_NOP_SHIFT         (0U)
#define DDRC_ZQCTL0_T_ZQ_SHORT_NOP(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_ZQCTL0_T_ZQ_SHORT_NOP_SHIFT)) & DDRC_ZQCTL0_T_ZQ_SHORT_NOP_MASK)
#define DDRC_ZQCTL0_T_ZQ_LONG_NOP_MASK           (0x3FF0000U)
#define DDRC_ZQCTL0_T_ZQ_LONG_NOP_SHIFT          (16U)
#define DDRC_ZQCTL0_T_ZQ_LONG_NOP(x)             (((uint32_t)(((uint32_t)(x)) << DDRC_ZQCTL0_T_ZQ_LONG_NOP_SHIFT)) & DDRC_ZQCTL0_T_ZQ_LONG_NOP_MASK)
#define DDRC_ZQCTL0_ZQ_RESISTOR_SHARED_MASK      (0x20000000U)
#define DDRC_ZQCTL0_ZQ_RESISTOR_SHARED_SHIFT     (29U)
#define DDRC_ZQCTL0_DIS_SRX_ZQCL_MASK            (0x40000000U)
#define DDRC_ZQCTL0_DIS_SRX_ZQCL_SHIFT           (30U)
#define DDRC_ZQCTL0_DIS_AUTO_ZQ_MASK             (0x80000000U)
#define DDRC_ZQCTL0_DIS_AUTO_ZQ_SHIFT            (31U)

/*! @name ZQCTL1 - ZQ Control Register 1 */
#define DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024_MASK (0xFFFFFU)
#define DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024_SHIFT (0U)
#define DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024(x) (((uint32_t)(((uint32_t)(x)) << DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024_SHIFT)) & DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024_MASK)
#define DDRC_ZQCTL1_T_ZQ_RESET_NOP_MASK          (0x3FF00000U)
#define DDRC_ZQCTL1_T_ZQ_RESET_NOP_SHIFT         (20U)
#define DDRC_ZQCTL1_T_ZQ_RESET_NOP(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_ZQCTL1_T_ZQ_RESET_NOP_SHIFT)) & DDRC_ZQCTL1_T_ZQ_RESET_NOP_MASK)

/*! @name ZQCTL2 - ZQ Control Register 2 */
#define DDRC_ZQCTL2_ZQ_RESET_MASK                (0x1U)
#define DDRC_ZQCTL2_ZQ_RESET_SHIFT               (0U)

/*! @name ZQSTAT - ZQ Status Register */
#define DDRC_ZQSTAT_ZQ_RESET_BUSY_MASK           (0x1U)
#define DDRC_ZQSTAT_ZQ_RESET_BUSY_SHIFT          (0U)

/*! @name DFITMG0 - DFI Timing Register 0 */
#define DDRC_DFITMG0_DFI_TPHY_WRLAT_MASK         (0x3FU)
#define DDRC_DFITMG0_DFI_TPHY_WRLAT_SHIFT        (0U)
#define DDRC_DFITMG0_DFI_TPHY_WRLAT(x)           (((uint32_t)(((uint32_t)(x)) << DDRC_DFITMG0_DFI_TPHY_WRLAT_SHIFT)) & DDRC_DFITMG0_DFI_TPHY_WRLAT_MASK)
#define DDRC_DFITMG0_DFI_TPHY_WRDATA_MASK        (0x3F00U)
#define DDRC_DFITMG0_DFI_TPHY_WRDATA_SHIFT       (8U)
#define DDRC_DFITMG0_DFI_TPHY_WRDATA(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_DFITMG0_DFI_TPHY_WRDATA_SHIFT)) & DDRC_DFITMG0_DFI_TPHY_WRDATA_MASK)
#define DDRC_DFITMG0_DFI_WRDATA_USE_SDR_MASK     (0x8000U)
#define DDRC_DFITMG0_DFI_WRDATA_USE_SDR_SHIFT    (15U)
#define DDRC_DFITMG0_DFI_T_RDDATA_EN_MASK        (0x3F0000U)
#define DDRC_DFITMG0_DFI_T_RDDATA_EN_SHIFT       (16U)
#define DDRC_DFITMG0_DFI_T_RDDATA_EN(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_DFITMG0_DFI_T_RDDATA_EN_SHIFT)) & DDRC_DFITMG0_DFI_T_RDDATA_EN_MASK)
#define DDRC_DFITMG0_DFI_RDDATA_USE_SDR_MASK     (0x800000U)
#define DDRC_DFITMG0_DFI_RDDATA_USE_SDR_SHIFT    (23U)
#define DDRC_DFITMG0_DFI_T_CTRL_DELAY_MASK       (0x1F000000U)
#define DDRC_DFITMG0_DFI_T_CTRL_DELAY_SHIFT      (24U)
#define DDRC_DFITMG0_DFI_T_CTRL_DELAY(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_DFITMG0_DFI_T_CTRL_DELAY_SHIFT)) & DDRC_DFITMG0_DFI_T_CTRL_DELAY_MASK)

/*! @name DFITMG1 - DFI Timing Register 1 */
#define DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE_MASK  (0xFU)
#define DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE_SHIFT (0U)
#define DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE_SHIFT)) & DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE_MASK)
#define DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE_MASK (0xF00U)
#define DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE_SHIFT (8U)
#define DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE(x)   (((uint32_t)(((uint32_t)(x)) << DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE_SHIFT)) & DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE_MASK)
#define DDRC_DFITMG1_DFI_T_WRDATA_DELAY_MASK     (0x1F0000U)
#define DDRC_DFITMG1_DFI_T_WRDATA_DELAY_SHIFT    (16U)
#define DDRC_DFITMG1_DFI_T_WRDATA_DELAY(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_DFITMG1_DFI_T_WRDATA_DELAY_SHIFT)) & DDRC_DFITMG1_DFI_T_WRDATA_DELAY_MASK)

/*! @name DFILPCFG0 - DFI Low Power Configuration Register 0 */
#define DDRC_DFILPCFG0_DFI_LP_EN_PD_MASK         (0x1U)
#define DDRC_DFILPCFG0_DFI_LP_EN_PD_SHIFT        (0U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD_MASK     (0xF0U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD_SHIFT    (4U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD_SHIFT)) & DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD_MASK)
#define DDRC_DFILPCFG0_DFI_LP_EN_SR_MASK         (0x100U)
#define DDRC_DFILPCFG0_DFI_LP_EN_SR_SHIFT        (8U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR_MASK     (0xF000U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR_SHIFT    (12U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR_SHIFT)) & DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR_MASK)
#define DDRC_DFILPCFG0_DFI_LP_EN_DPD_MASK        (0x10000U)
#define DDRC_DFILPCFG0_DFI_LP_EN_DPD_SHIFT       (16U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD_MASK    (0xF00000U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD_SHIFT   (20U)
#define DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD_SHIFT)) & DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD_MASK)
#define DDRC_DFILPCFG0_DFI_TLP_RESP_MASK         (0xF000000U)
#define DDRC_DFILPCFG0_DFI_TLP_RESP_SHIFT        (24U)
#define DDRC_DFILPCFG0_DFI_TLP_RESP(x)           (((uint32_t)(((uint32_t)(x)) << DDRC_DFILPCFG0_DFI_TLP_RESP_SHIFT)) & DDRC_DFILPCFG0_DFI_TLP_RESP_MASK)

/*! @name DFIUPD0 - DFI Update Register 0 */
#define DDRC_DFIUPD0_DFI_T_CTRLUP_MIN_MASK       (0x3FFU)
#define DDRC_DFIUPD0_DFI_T_CTRLUP_MIN_SHIFT      (0U)
#define DDRC_DFIUPD0_DFI_T_CTRLUP_MIN(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_DFIUPD0_DFI_T_CTRLUP_MIN_SHIFT)) & DDRC_DFIUPD0_DFI_T_CTRLUP_MIN_MASK)
#define DDRC_DFIUPD0_DFI_T_CTRLUP_MAX_MASK       (0x3FF0000U)
#define DDRC_DFIUPD0_DFI_T_CTRLUP_MAX_SHIFT      (16U)
#define DDRC_DFIUPD0_DFI_T_CTRLUP_MAX(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_DFIUPD0_DFI_T_CTRLUP_MAX_SHIFT)) & DDRC_DFIUPD0_DFI_T_CTRLUP_MAX_MASK)
#define DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX_MASK   (0x40000000U)
#define DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX_SHIFT  (30U)
#define DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_MASK       (0x80000000U)
#define DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SHIFT      (31U)

/*! @name DFIUPD1 - DFI Update Register 1 */
#define DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024_MASK (0xFFU)
#define DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024_SHIFT (0U)
#define DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024(x) (((uint32_t)(((uint32_t)(x)) << DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024_SHIFT)) & DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024_MASK)
#define DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024_MASK (0xFF0000U)
#define DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024_SHIFT (16U)
#define DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024(x) (((uint32_t)(((uint32_t)(x)) << DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024_SHIFT)) & DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024_MASK)

/*! @name DFIUPD2 - DFI Update Register 2 */
#define DDRC_DFIUPD2_DFI_PHYUPD_TYPE0_MASK       (0xFFFU)
#define DDRC_DFIUPD2_DFI_PHYUPD_TYPE0_SHIFT      (0U)
#define DDRC_DFIUPD2_DFI_PHYUPD_TYPE0(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_DFIUPD2_DFI_PHYUPD_TYPE0_SHIFT)) & DDRC_DFIUPD2_DFI_PHYUPD_TYPE0_MASK)
#define DDRC_DFIUPD2_DFI_PHYUPD_TYPE1_MASK       (0xFFF0000U)
#define DDRC_DFIUPD2_DFI_PHYUPD_TYPE1_SHIFT      (16U)
#define DDRC_DFIUPD2_DFI_PHYUPD_TYPE1(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_DFIUPD2_DFI_PHYUPD_TYPE1_SHIFT)) & DDRC_DFIUPD2_DFI_PHYUPD_TYPE1_MASK)
#define DDRC_DFIUPD2_DFI_PHYUPD_EN_MASK          (0x80000000U)
#define DDRC_DFIUPD2_DFI_PHYUPD_EN_SHIFT         (31U)

/*! @name DFIUPD3 - DFI Update Register 3 */
#define DDRC_DFIUPD3_DFI_PHYUPD_TYPE2_MASK       (0xFFFU)
#define DDRC_DFIUPD3_DFI_PHYUPD_TYPE2_SHIFT      (0U)
#define DDRC_DFIUPD3_DFI_PHYUPD_TYPE2(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_DFIUPD3_DFI_PHYUPD_TYPE2_SHIFT)) & DDRC_DFIUPD3_DFI_PHYUPD_TYPE2_MASK)
#define DDRC_DFIUPD3_DFI_PHYUPD_TYPE3_MASK       (0xFFF0000U)
#define DDRC_DFIUPD3_DFI_PHYUPD_TYPE3_SHIFT      (16U)
#define DDRC_DFIUPD3_DFI_PHYUPD_TYPE3(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_DFIUPD3_DFI_PHYUPD_TYPE3_SHIFT)) & DDRC_DFIUPD3_DFI_PHYUPD_TYPE3_MASK)

/*! @name DFIMISC - DFI Miscellaneous Control Register */
#define DDRC_DFIMISC_DFI_INIT_COMPLETE_EN_MASK   (0x1U)
#define DDRC_DFIMISC_DFI_INIT_COMPLETE_EN_SHIFT  (0U)

/*! @name ADDRMAP0 - Address Map Register 0 */
#define DDRC_ADDRMAP0_ADDRMAP_CS_BIT0_MASK       (0x1FU)
#define DDRC_ADDRMAP0_ADDRMAP_CS_BIT0_SHIFT      (0U)
#define DDRC_ADDRMAP0_ADDRMAP_CS_BIT0(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP0_ADDRMAP_CS_BIT0_SHIFT)) & DDRC_ADDRMAP0_ADDRMAP_CS_BIT0_MASK)
#define DDRC_ADDRMAP0_ADDRMAP_CS_BIT1_MASK       (0x1F00U)
#define DDRC_ADDRMAP0_ADDRMAP_CS_BIT1_SHIFT      (8U)
#define DDRC_ADDRMAP0_ADDRMAP_CS_BIT1(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP0_ADDRMAP_CS_BIT1_SHIFT)) & DDRC_ADDRMAP0_ADDRMAP_CS_BIT1_MASK)

/*! @name ADDRMAP1 - Address Map Register 1 */
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B0_MASK       (0x1FU)
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B0_SHIFT      (0U)
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B0(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP1_ADDRMAP_BANK_B0_SHIFT)) & DDRC_ADDRMAP1_ADDRMAP_BANK_B0_MASK)
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B1_MASK       (0x1F00U)
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B1_SHIFT      (8U)
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B1(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP1_ADDRMAP_BANK_B1_SHIFT)) & DDRC_ADDRMAP1_ADDRMAP_BANK_B1_MASK)
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B2_MASK       (0x1F0000U)
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B2_SHIFT      (16U)
#define DDRC_ADDRMAP1_ADDRMAP_BANK_B2(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP1_ADDRMAP_BANK_B2_SHIFT)) & DDRC_ADDRMAP1_ADDRMAP_BANK_B2_MASK)

/*! @name ADDRMAP2 - Address Map Register 2 */
#define DDRC_ADDRMAP2_ADDRMAP_COL_B2_MASK        (0xFU)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B2_SHIFT       (0U)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B2(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP2_ADDRMAP_COL_B2_SHIFT)) & DDRC_ADDRMAP2_ADDRMAP_COL_B2_MASK)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B3_MASK        (0xF00U)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B3_SHIFT       (8U)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B3(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP2_ADDRMAP_COL_B3_SHIFT)) & DDRC_ADDRMAP2_ADDRMAP_COL_B3_MASK)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B4_MASK        (0xF0000U)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B4_SHIFT       (16U)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B4(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP2_ADDRMAP_COL_B4_SHIFT)) & DDRC_ADDRMAP2_ADDRMAP_COL_B4_MASK)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B5_MASK        (0xF000000U)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B5_SHIFT       (24U)
#define DDRC_ADDRMAP2_ADDRMAP_COL_B5(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP2_ADDRMAP_COL_B5_SHIFT)) & DDRC_ADDRMAP2_ADDRMAP_COL_B5_MASK)

/*! @name ADDRMAP3 - Address Map Register 3 */
#define DDRC_ADDRMAP3_ADDRMAP_COL_B6_MASK        (0xFU)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B6_SHIFT       (0U)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B6(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP3_ADDRMAP_COL_B6_SHIFT)) & DDRC_ADDRMAP3_ADDRMAP_COL_B6_MASK)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B7_MASK        (0xF00U)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B7_SHIFT       (8U)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B7(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP3_ADDRMAP_COL_B7_SHIFT)) & DDRC_ADDRMAP3_ADDRMAP_COL_B7_MASK)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B8_MASK        (0xF0000U)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B8_SHIFT       (16U)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B8(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP3_ADDRMAP_COL_B8_SHIFT)) & DDRC_ADDRMAP3_ADDRMAP_COL_B8_MASK)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B9_MASK        (0xF000000U)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B9_SHIFT       (24U)
#define DDRC_ADDRMAP3_ADDRMAP_COL_B9(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP3_ADDRMAP_COL_B9_SHIFT)) & DDRC_ADDRMAP3_ADDRMAP_COL_B9_MASK)

/*! @name ADDRMAP4 - Address Map Register 4 */
#define DDRC_ADDRMAP4_ADDRMAP_COL_B10_MASK       (0xFU)
#define DDRC_ADDRMAP4_ADDRMAP_COL_B10_SHIFT      (0U)
#define DDRC_ADDRMAP4_ADDRMAP_COL_B10(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP4_ADDRMAP_COL_B10_SHIFT)) & DDRC_ADDRMAP4_ADDRMAP_COL_B10_MASK)
#define DDRC_ADDRMAP4_ADDRMAP_COL_B11_MASK       (0xF00U)
#define DDRC_ADDRMAP4_ADDRMAP_COL_B11_SHIFT      (8U)
#define DDRC_ADDRMAP4_ADDRMAP_COL_B11(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP4_ADDRMAP_COL_B11_SHIFT)) & DDRC_ADDRMAP4_ADDRMAP_COL_B11_MASK)

/*! @name ADDRMAP5 - Address Map Register 5 */
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B0_MASK        (0xFU)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B0_SHIFT       (0U)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B0(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP5_ADDRMAP_ROW_B0_SHIFT)) & DDRC_ADDRMAP5_ADDRMAP_ROW_B0_MASK)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B1_MASK        (0xF00U)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B1_SHIFT       (8U)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B1(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP5_ADDRMAP_ROW_B1_SHIFT)) & DDRC_ADDRMAP5_ADDRMAP_ROW_B1_MASK)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10_MASK     (0xF0000U)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10_SHIFT    (16U)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10_SHIFT)) & DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10_MASK)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B11_MASK       (0xF000000U)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B11_SHIFT      (24U)
#define DDRC_ADDRMAP5_ADDRMAP_ROW_B11(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP5_ADDRMAP_ROW_B11_SHIFT)) & DDRC_ADDRMAP5_ADDRMAP_ROW_B11_MASK)

/*! @name ADDRMAP6 - Address Map Register 6 */
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B12_MASK       (0xFU)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B12_SHIFT      (0U)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B12(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP6_ADDRMAP_ROW_B12_SHIFT)) & DDRC_ADDRMAP6_ADDRMAP_ROW_B12_MASK)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B13_MASK       (0xF00U)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B13_SHIFT      (8U)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B13(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP6_ADDRMAP_ROW_B13_SHIFT)) & DDRC_ADDRMAP6_ADDRMAP_ROW_B13_MASK)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B14_MASK       (0xF0000U)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B14_SHIFT      (16U)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B14(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP6_ADDRMAP_ROW_B14_SHIFT)) & DDRC_ADDRMAP6_ADDRMAP_ROW_B14_MASK)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B15_MASK       (0xF000000U)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B15_SHIFT      (24U)
#define DDRC_ADDRMAP6_ADDRMAP_ROW_B15(x)         (((uint32_t)(((uint32_t)(x)) << DDRC_ADDRMAP6_ADDRMAP_ROW_B15_SHIFT)) & DDRC_ADDRMAP6_ADDRMAP_ROW_B15_MASK)
#define DDRC_ADDRMAP6_LPDDR3_6GB_12GB_MASK       (0x80000000U)
#define DDRC_ADDRMAP6_LPDDR3_6GB_12GB_SHIFT      (31U)

/*! @name ODTCFG - ODT Configuration Register */
#define DDRC_ODTCFG_RD_ODT_DELAY_MASK            (0x7CU)
#define DDRC_ODTCFG_RD_ODT_DELAY_SHIFT           (2U)
#define DDRC_ODTCFG_RD_ODT_DELAY(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_ODTCFG_RD_ODT_DELAY_SHIFT)) & DDRC_ODTCFG_RD_ODT_DELAY_MASK)
#define DDRC_ODTCFG_RD_ODT_HOLD_MASK             (0xF00U)
#define DDRC_ODTCFG_RD_ODT_HOLD_SHIFT            (8U)
#define DDRC_ODTCFG_RD_ODT_HOLD(x)               (((uint32_t)(((uint32_t)(x)) << DDRC_ODTCFG_RD_ODT_HOLD_SHIFT)) & DDRC_ODTCFG_RD_ODT_HOLD_MASK)
#define DDRC_ODTCFG_WR_ODT_DELAY_MASK            (0x1F0000U)
#define DDRC_ODTCFG_WR_ODT_DELAY_SHIFT           (16U)
#define DDRC_ODTCFG_WR_ODT_DELAY(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_ODTCFG_WR_ODT_DELAY_SHIFT)) & DDRC_ODTCFG_WR_ODT_DELAY_MASK)
#define DDRC_ODTCFG_WR_ODT_HOLD_MASK             (0xF000000U)
#define DDRC_ODTCFG_WR_ODT_HOLD_SHIFT            (24U)
#define DDRC_ODTCFG_WR_ODT_HOLD(x)               (((uint32_t)(((uint32_t)(x)) << DDRC_ODTCFG_WR_ODT_HOLD_SHIFT)) & DDRC_ODTCFG_WR_ODT_HOLD_MASK)

/*! @name ODTMAP - ODT / Rank Map Register */
#define DDRC_ODTMAP_RANK0_WR_ODT_MASK            (0xFU)
#define DDRC_ODTMAP_RANK0_WR_ODT_SHIFT           (0U)
#define DDRC_ODTMAP_RANK0_WR_ODT(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_ODTMAP_RANK0_WR_ODT_SHIFT)) & DDRC_ODTMAP_RANK0_WR_ODT_MASK)
#define DDRC_ODTMAP_RANK0_RD_ODT_MASK            (0xF0U)
#define DDRC_ODTMAP_RANK0_RD_ODT_SHIFT           (4U)
#define DDRC_ODTMAP_RANK0_RD_ODT(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_ODTMAP_RANK0_RD_ODT_SHIFT)) & DDRC_ODTMAP_RANK0_RD_ODT_MASK)
#define DDRC_ODTMAP_RANK1_WR_ODT_MASK            (0xF00U)
#define DDRC_ODTMAP_RANK1_WR_ODT_SHIFT           (8U)
#define DDRC_ODTMAP_RANK1_WR_ODT(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_ODTMAP_RANK1_WR_ODT_SHIFT)) & DDRC_ODTMAP_RANK1_WR_ODT_MASK)
#define DDRC_ODTMAP_RANK1_RD_ODT_MASK            (0xF000U)
#define DDRC_ODTMAP_RANK1_RD_ODT_SHIFT           (12U)
#define DDRC_ODTMAP_RANK1_RD_ODT(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_ODTMAP_RANK1_RD_ODT_SHIFT)) & DDRC_ODTMAP_RANK1_RD_ODT_MASK)

/*! @name SCHED - Scheduler Control Register */
#define DDRC_SCHED_FORCE_LOW_PRI_N_MASK          (0x1U)
#define DDRC_SCHED_FORCE_LOW_PRI_N_SHIFT         (0U)
#define DDRC_SCHED_PREFER_WRITE_MASK             (0x2U)
#define DDRC_SCHED_PREFER_WRITE_SHIFT            (1U)
#define DDRC_SCHED_PAGECLOSE_MASK                (0x4U)
#define DDRC_SCHED_PAGECLOSE_SHIFT               (2U)
#define DDRC_SCHED_LPR_NUM_ENTRIES_MASK          (0x3F00U)
#define DDRC_SCHED_LPR_NUM_ENTRIES_SHIFT         (8U)
#define DDRC_SCHED_LPR_NUM_ENTRIES(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_SCHED_LPR_NUM_ENTRIES_SHIFT)) & DDRC_SCHED_LPR_NUM_ENTRIES_MASK)
#define DDRC_SCHED_RDWR_IDLE_GAP_MASK            (0x7F000000U)
#define DDRC_SCHED_RDWR_IDLE_GAP_SHIFT           (24U)
#define DDRC_SCHED_RDWR_IDLE_GAP(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_SCHED_RDWR_IDLE_GAP_SHIFT)) & DDRC_SCHED_RDWR_IDLE_GAP_MASK)

/*! @name SCHED1 - Scheduler Control Register 1 */
#define DDRC_SCHED1_PAGECLOSE_TIMER_MASK         (0xFFU)
#define DDRC_SCHED1_PAGECLOSE_TIMER_SHIFT        (0U)
#define DDRC_SCHED1_PAGECLOSE_TIMER(x)           (((uint32_t)(((uint32_t)(x)) << DDRC_SCHED1_PAGECLOSE_TIMER_SHIFT)) & DDRC_SCHED1_PAGECLOSE_TIMER_MASK)

/*! @name PERFHPR1 - High Priority Read CAM Register 1 */
#define DDRC_PERFHPR1_HPR_MAX_STARVE_MASK        (0xFFFFU)
#define DDRC_PERFHPR1_HPR_MAX_STARVE_SHIFT       (0U)
#define DDRC_PERFHPR1_HPR_MAX_STARVE(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_PERFHPR1_HPR_MAX_STARVE_SHIFT)) & DDRC_PERFHPR1_HPR_MAX_STARVE_MASK)
#define DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH_MASK   (0xFF000000U)
#define DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH_SHIFT  (24U)
#define DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH_SHIFT)) & DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH_MASK)

/*! @name PERFLPR1 - Low Priority Read CAM Register 1 */
#define DDRC_PERFLPR1_LPR_MAX_STARVE_MASK        (0xFFFFU)
#define DDRC_PERFLPR1_LPR_MAX_STARVE_SHIFT       (0U)
#define DDRC_PERFLPR1_LPR_MAX_STARVE(x)          (((uint32_t)(((uint32_t)(x)) << DDRC_PERFLPR1_LPR_MAX_STARVE_SHIFT)) & DDRC_PERFLPR1_LPR_MAX_STARVE_MASK)
#define DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH_MASK   (0xFF000000U)
#define DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH_SHIFT  (24U)
#define DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH_SHIFT)) & DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH_MASK)

/*! @name PERFWR1 - Write CAM Register 1 */
#define DDRC_PERFWR1_W_MAX_STARVE_MASK           (0xFFFFU)
#define DDRC_PERFWR1_W_MAX_STARVE_SHIFT          (0U)
#define DDRC_PERFWR1_W_MAX_STARVE(x)             (((uint32_t)(((uint32_t)(x)) << DDRC_PERFWR1_W_MAX_STARVE_SHIFT)) & DDRC_PERFWR1_W_MAX_STARVE_MASK)
#define DDRC_PERFWR1_W_XACT_RUN_LENGTH_MASK      (0xFF000000U)
#define DDRC_PERFWR1_W_XACT_RUN_LENGTH_SHIFT     (24U)
#define DDRC_PERFWR1_W_XACT_RUN_LENGTH(x)        (((uint32_t)(((uint32_t)(x)) << DDRC_PERFWR1_W_XACT_RUN_LENGTH_SHIFT)) & DDRC_PERFWR1_W_XACT_RUN_LENGTH_MASK)

/*! @name PERFVPR1 - Variable Priority Read CAM Register 1 */
#define DDRC_PERFVPR1_VPR_TIMEOUT_RANGE_MASK     (0x7FFU)
#define DDRC_PERFVPR1_VPR_TIMEOUT_RANGE_SHIFT    (0U)
#define DDRC_PERFVPR1_VPR_TIMEOUT_RANGE(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_PERFVPR1_VPR_TIMEOUT_RANGE_SHIFT)) & DDRC_PERFVPR1_VPR_TIMEOUT_RANGE_MASK)

/*! @name PERFVPW1 - Variable Priority Write CAM Register 1 */
#define DDRC_PERFVPW1_VPW_TIMEOUT_RANGE_MASK     (0x7FFU)
#define DDRC_PERFVPW1_VPW_TIMEOUT_RANGE_SHIFT    (0U)
#define DDRC_PERFVPW1_VPW_TIMEOUT_RANGE(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_PERFVPW1_VPW_TIMEOUT_RANGE_SHIFT)) & DDRC_PERFVPW1_VPW_TIMEOUT_RANGE_MASK)

/*! @name DBG0 - Debug Register 0 */
#define DDRC_DBG0_DIS_WC_MASK                    (0x1U)
#define DDRC_DBG0_DIS_WC_SHIFT                   (0U)
#define DDRC_DBG0_DIS_COLLISION_PAGE_OPT_MASK    (0x10U)
#define DDRC_DBG0_DIS_COLLISION_PAGE_OPT_SHIFT   (4U)

/*! @name DBG1 - Debug Register 1 */
#define DDRC_DBG1_DIS_DQ_MASK                    (0x1U)
#define DDRC_DBG1_DIS_DQ_SHIFT                   (0U)
#define DDRC_DBG1_DIS_HIF_MASK                   (0x2U)
#define DDRC_DBG1_DIS_HIF_SHIFT                  (1U)

/*! @name DBGCAM - CAM Debug Register */
#define DDRC_DBGCAM_DBG_HPR_Q_DEPTH_MASK         (0x7FU)
#define DDRC_DBGCAM_DBG_HPR_Q_DEPTH_SHIFT        (0U)
#define DDRC_DBGCAM_DBG_HPR_Q_DEPTH(x)           (((uint32_t)(((uint32_t)(x)) << DDRC_DBGCAM_DBG_HPR_Q_DEPTH_SHIFT)) & DDRC_DBGCAM_DBG_HPR_Q_DEPTH_MASK)
#define DDRC_DBGCAM_DBG_LPR_Q_DEPTH_MASK         (0x7F00U)
#define DDRC_DBGCAM_DBG_LPR_Q_DEPTH_SHIFT        (8U)
#define DDRC_DBGCAM_DBG_LPR_Q_DEPTH(x)           (((uint32_t)(((uint32_t)(x)) << DDRC_DBGCAM_DBG_LPR_Q_DEPTH_SHIFT)) & DDRC_DBGCAM_DBG_LPR_Q_DEPTH_MASK)
#define DDRC_DBGCAM_DBG_W_Q_DEPTH_MASK           (0x7F0000U)
#define DDRC_DBGCAM_DBG_W_Q_DEPTH_SHIFT          (16U)
#define DDRC_DBGCAM_DBG_W_Q_DEPTH(x)             (((uint32_t)(((uint32_t)(x)) << DDRC_DBGCAM_DBG_W_Q_DEPTH_SHIFT)) & DDRC_DBGCAM_DBG_W_Q_DEPTH_MASK)
#define DDRC_DBGCAM_DBG_STALL_MASK               (0x1000000U)
#define DDRC_DBGCAM_DBG_STALL_SHIFT              (24U)
#define DDRC_DBGCAM_DBG_RD_Q_EMPTY_MASK          (0x2000000U)
#define DDRC_DBGCAM_DBG_RD_Q_EMPTY_SHIFT         (25U)
#define DDRC_DBGCAM_DBG_WR_Q_EMPTY_MASK          (0x4000000U)
#define DDRC_DBGCAM_DBG_WR_Q_EMPTY_SHIFT         (26U)
#define DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY_MASK  (0x10000000U)
#define DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY_SHIFT (28U)
#define DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY_MASK  (0x20000000U)
#define DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY_SHIFT (29U)
#define DDRC_DBGCAM_DBG_STALL_WR_MASK            (0x40000000U)
#define DDRC_DBGCAM_DBG_STALL_WR_SHIFT           (30U)
#define DDRC_DBGCAM_DBG_STALL_RD_MASK            (0x80000000U)
#define DDRC_DBGCAM_DBG_STALL_RD_SHIFT           (31U)

/*! @name DBGCMD - Command Debug Register */
#define DDRC_DBGCMD_RANK0_REFRESH_MASK           (0x1U)
#define DDRC_DBGCMD_RANK0_REFRESH_SHIFT          (0U)
#define DDRC_DBGCMD_RANK1_REFRESH_MASK           (0x2U)
#define DDRC_DBGCMD_RANK1_REFRESH_SHIFT          (1U)
#define DDRC_DBGCMD_ZQ_CALIB_SHORT_MASK          (0x10U)
#define DDRC_DBGCMD_ZQ_CALIB_SHORT_SHIFT         (4U)
#define DDRC_DBGCMD_CTRLUPD_MASK                 (0x20U)
#define DDRC_DBGCMD_CTRLUPD_SHIFT                (5U)

/*! @name DBGSTAT - Status Debug Register */
#define DDRC_DBGSTAT_RANK0_REFRESH_BUSY_MASK     (0x1U)
#define DDRC_DBGSTAT_RANK0_REFRESH_BUSY_SHIFT    (0U)
#define DDRC_DBGSTAT_RANK1_REFRESH_BUSY_MASK     (0x2U)
#define DDRC_DBGSTAT_RANK1_REFRESH_BUSY_SHIFT    (1U)
#define DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY_MASK    (0x10U)
#define DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY_SHIFT   (4U)
#define DDRC_DBGSTAT_CTRLUPD_BUSY_MASK           (0x20U)
#define DDRC_DBGSTAT_CTRLUPD_BUSY_SHIFT          (5U)

/*! @name SWCTL - Software Register Programming Control Enable */
#define DDRC_SWCTL_SW_DONE_MASK                  (0x1U)
#define DDRC_SWCTL_SW_DONE_SHIFT                 (0U)

/*! @name SWSTAT - Software Register Programming Control Status */
#define DDRC_SWSTAT_SW_DONE_ACK_MASK             (0x1U)
#define DDRC_SWSTAT_SW_DONE_ACK_SHIFT            (0U)


/*!
 * @}
 */ /* end of group DDRC_Register_Masks */


/* DDRC - Peripheral instance base addresses */
/** Peripheral DDRC base pointer */
#define DDRC_BASE_PTR                            ((DDRC_MemMapPtr)0x307A0000u)
/** Array initializer of DDRC peripheral base pointers */
#define DDRC_BASE_PTRS                           { DDRC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- DDRC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDRC_Register_Accessor_Macros DDRC - Register accessor macros
 * @{
 */


/* DDRC - Register instance definitions */
/* DDRC */
#define DDRC_MSTR                                DDRC_MSTR_REG(DDRC_BASE_PTR)
#define DDRC_STAT                                DDRC_STAT_REG(DDRC_BASE_PTR)
#define DDRC_MRCTRL0                             DDRC_MRCTRL0_REG(DDRC_BASE_PTR)
#define DDRC_MRCTRL1                             DDRC_MRCTRL1_REG(DDRC_BASE_PTR)
#define DDRC_MRSTAT                              DDRC_MRSTAT_REG(DDRC_BASE_PTR)
#define DDRC_DERATEEN                            DDRC_DERATEEN_REG(DDRC_BASE_PTR)
#define DDRC_DERATEINT                           DDRC_DERATEINT_REG(DDRC_BASE_PTR)
#define DDRC_PWRCTL                              DDRC_PWRCTL_REG(DDRC_BASE_PTR)
#define DDRC_PWRTMG                              DDRC_PWRTMG_REG(DDRC_BASE_PTR)
#define DDRC_HWLPCTL                             DDRC_HWLPCTL_REG(DDRC_BASE_PTR)
#define DDRC_RFSHCTL0                            DDRC_RFSHCTL0_REG(DDRC_BASE_PTR)
#define DDRC_RFSHCTL1                            DDRC_RFSHCTL1_REG(DDRC_BASE_PTR)
#define DDRC_RFSHCTL3                            DDRC_RFSHCTL3_REG(DDRC_BASE_PTR)
#define DDRC_RFSHTMG                             DDRC_RFSHTMG_REG(DDRC_BASE_PTR)
#define DDRC_INIT0                               DDRC_INIT0_REG(DDRC_BASE_PTR)
#define DDRC_INIT1                               DDRC_INIT1_REG(DDRC_BASE_PTR)
#define DDRC_INIT2                               DDRC_INIT2_REG(DDRC_BASE_PTR)
#define DDRC_INIT3                               DDRC_INIT3_REG(DDRC_BASE_PTR)
#define DDRC_INIT4                               DDRC_INIT4_REG(DDRC_BASE_PTR)
#define DDRC_INIT5                               DDRC_INIT5_REG(DDRC_BASE_PTR)
#define DDRC_RANKCTL                             DDRC_RANKCTL_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG0                            DDRC_DRAMTMG0_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG1                            DDRC_DRAMTMG1_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG2                            DDRC_DRAMTMG2_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG3                            DDRC_DRAMTMG3_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG4                            DDRC_DRAMTMG4_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG5                            DDRC_DRAMTMG5_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG6                            DDRC_DRAMTMG6_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG7                            DDRC_DRAMTMG7_REG(DDRC_BASE_PTR)
#define DDRC_DRAMTMG8                            DDRC_DRAMTMG8_REG(DDRC_BASE_PTR)
#define DDRC_ZQCTL0                              DDRC_ZQCTL0_REG(DDRC_BASE_PTR)
#define DDRC_ZQCTL1                              DDRC_ZQCTL1_REG(DDRC_BASE_PTR)
#define DDRC_ZQCTL2                              DDRC_ZQCTL2_REG(DDRC_BASE_PTR)
#define DDRC_ZQSTAT                              DDRC_ZQSTAT_REG(DDRC_BASE_PTR)
#define DDRC_DFITMG0                             DDRC_DFITMG0_REG(DDRC_BASE_PTR)
#define DDRC_DFITMG1                             DDRC_DFITMG1_REG(DDRC_BASE_PTR)
#define DDRC_DFILPCFG0                           DDRC_DFILPCFG0_REG(DDRC_BASE_PTR)
#define DDRC_DFIUPD0                             DDRC_DFIUPD0_REG(DDRC_BASE_PTR)
#define DDRC_DFIUPD1                             DDRC_DFIUPD1_REG(DDRC_BASE_PTR)
#define DDRC_DFIUPD2                             DDRC_DFIUPD2_REG(DDRC_BASE_PTR)
#define DDRC_DFIUPD3                             DDRC_DFIUPD3_REG(DDRC_BASE_PTR)
#define DDRC_DFIMISC                             DDRC_DFIMISC_REG(DDRC_BASE_PTR)
#define DDRC_ADDRMAP0                            DDRC_ADDRMAP0_REG(DDRC_BASE_PTR)
#define DDRC_ADDRMAP1                            DDRC_ADDRMAP1_REG(DDRC_BASE_PTR)
#define DDRC_ADDRMAP2                            DDRC_ADDRMAP2_REG(DDRC_BASE_PTR)
#define DDRC_ADDRMAP3                            DDRC_ADDRMAP3_REG(DDRC_BASE_PTR)
#define DDRC_ADDRMAP4                            DDRC_ADDRMAP4_REG(DDRC_BASE_PTR)
#define DDRC_ADDRMAP5                            DDRC_ADDRMAP5_REG(DDRC_BASE_PTR)
#define DDRC_ADDRMAP6                            DDRC_ADDRMAP6_REG(DDRC_BASE_PTR)
#define DDRC_ODTCFG                              DDRC_ODTCFG_REG(DDRC_BASE_PTR)
#define DDRC_ODTMAP                              DDRC_ODTMAP_REG(DDRC_BASE_PTR)
#define DDRC_SCHED                               DDRC_SCHED_REG(DDRC_BASE_PTR)
#define DDRC_SCHED1                              DDRC_SCHED1_REG(DDRC_BASE_PTR)
#define DDRC_PERFHPR1                            DDRC_PERFHPR1_REG(DDRC_BASE_PTR)
#define DDRC_PERFLPR1                            DDRC_PERFLPR1_REG(DDRC_BASE_PTR)
#define DDRC_PERFWR1                             DDRC_PERFWR1_REG(DDRC_BASE_PTR)
#define DDRC_PERFVPR1                            DDRC_PERFVPR1_REG(DDRC_BASE_PTR)
#define DDRC_PERFVPW1                            DDRC_PERFVPW1_REG(DDRC_BASE_PTR)
#define DDRC_DBG0                                DDRC_DBG0_REG(DDRC_BASE_PTR)
#define DDRC_DBG1                                DDRC_DBG1_REG(DDRC_BASE_PTR)
#define DDRC_DBGCAM                              DDRC_DBGCAM_REG(DDRC_BASE_PTR)
#define DDRC_DBGCMD                              DDRC_DBGCMD_REG(DDRC_BASE_PTR)
#define DDRC_DBGSTAT                             DDRC_DBGSTAT_REG(DDRC_BASE_PTR)
#define DDRC_SWCTL                               DDRC_SWCTL_REG(DDRC_BASE_PTR)
#define DDRC_SWSTAT                              DDRC_SWSTAT_REG(DDRC_BASE_PTR)

/*!
 * @}
 */ /* end of group DDRC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group DDRC_Peripheral */


/* ----------------------------------------------------------------------------
   -- DDRC_MP
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDRC_MP_Peripheral DDRC_MP
 * @{
 */

/** DDRC_MP - Peripheral register structure */
typedef struct DDRC_MP_MemMap {
  uint32_t PSTAT;                                  /**< Port Status Register, offset: 0x0 */
  uint32_t PCCFG;                                  /**< Port Common Configuration Register, offset: 0x4 */
  uint32_t PCFGR_0;                                /**< Port n Configuration Read Register, offset: 0x8 */
  uint32_t PCFGW_0;                                /**< Port n Configuration Write Register, offset: 0xC */
  uint8_t RESERVED_0[4];
  uint32_t PCFGIDMASKCH_00;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x14 */
  uint32_t PCFGIDVALUECH_00;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x18 */
  uint32_t PCFGIDMASKCH_10;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x1C */
  uint32_t PCFGIDVALUECH_10;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x20 */
  uint32_t PCFGIDMASKCH_20;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x24 */
  uint32_t PCFGIDVALUECH_20;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x28 */
  uint32_t PCFGIDMASKCH_30;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x2C */
  uint32_t PCFGIDVALUECH_30;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x30 */
  uint32_t PCFGIDMASKCH_40;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x34 */
  uint32_t PCFGIDVALUECH_40;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x38 */
  uint32_t PCFGIDMASKCH_50;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x3C */
  uint32_t PCFGIDVALUECH_50;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x40 */
  uint32_t PCFGIDMASKCH_60;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x44 */
  uint32_t PCFGIDVALUECH_60;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x48 */
  uint32_t PCFGIDMASKCH_70;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x4C */
  uint32_t PCFGIDVALUECH_70;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x50 */
  uint32_t PCFGIDMASKCH_80;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x54 */
  uint32_t PCFGIDVALUECH_80;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x58 */
  uint32_t PCFGIDMASKCH_90;                        /**< Port n Channel m Configuration ID Mask Register, offset: 0x5C */
  uint32_t PCFGIDVALUECH_90;                       /**< Port n Channel m Configuration ID Value Register, offset: 0x60 */
  uint32_t PCFGIDMASKCH_100;                       /**< Port n Channel m Configuration ID Mask Register, offset: 0x64 */
  uint32_t PCFGIDVALUECH_100;                      /**< Port n Channel m Configuration ID Value Register, offset: 0x68 */
  uint32_t PCFGIDMASKCH_110;                       /**< Port n Channel m Configuration ID Mask Register, offset: 0x6C */
  uint32_t PCFGIDVALUECH_110;                      /**< Port n Channel m Configuration ID Value Register, offset: 0x70 */
  uint32_t PCFGIDMASKCH_120;                       /**< Port n Channel m Configuration ID Mask Register, offset: 0x74 */
  uint32_t PCFGIDVALUECH_120;                      /**< Port n Channel m Configuration ID Value Register, offset: 0x78 */
  uint32_t PCFGIDMASKCH_130;                       /**< Port n Channel m Configuration ID Mask Register, offset: 0x7C */
  uint32_t PCFGIDVALUECH_130;                      /**< Port n Channel m Configuration ID Value Register, offset: 0x80 */
  uint32_t PCFGIDMASKCH_140;                       /**< Port n Channel m Configuration ID Mask Register, offset: 0x84 */
  uint32_t PCFGIDVALUECH_140;                      /**< Port n Channel m Configuration ID Value Register, offset: 0x88 */
  uint32_t PCFGIDMASKCH_150;                       /**< Port n Channel m Configuration ID Mask Register, offset: 0x8C */
  uint32_t PCFGIDVALUECH_150;                      /**< Port n Channel m Configuration ID Value Register, offset: 0x90 */
  uint32_t PCTRL_0;                                /**< Port n Control Register, offset: 0x94 */
  uint32_t PCFGQOS0_0;                             /**< Port n Read QoS Configuration Register 0, offset: 0x98 */
  uint32_t PCFGQOS1_0;                             /**< Port n Read QoS Configuration Register 1, offset: 0x9C */
  uint32_t PCFGWQOS0_0;                            /**< Port n Write QoS Configuration Register 0, offset: 0xA0 */
  uint32_t PCFGWQOS1_0;                            /**< Port n Write QoS Configuration Register 1, offset: 0xA4 */
  uint8_t RESERVED_1[2656];
  uint32_t SARBASE0;                               /**< SAR Base Address Register n, offset: 0xB08 */
  uint32_t SARSIZE0;                               /**< SAR Size Register n, offset: 0xB0C */
  uint32_t SARBASE1;                               /**< SAR Base Address Register n, offset: 0xB10 */
  uint32_t SARSIZE1;                               /**< SAR Size Register n, offset: 0xB14 */
  uint32_t SARBASE2;                               /**< SAR Base Address Register n, offset: 0xB18 */
  uint32_t SARSIZE2;                               /**< SAR Size Register n, offset: 0xB1C */
  uint32_t SARBASE3;                               /**< SAR Base Address Register n, offset: 0xB20 */
  uint32_t SARSIZE3;                               /**< SAR Size Register n, offset: 0xB24 */
} volatile *DDRC_MP_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- DDRC_MP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDRC_MP_Register_Accessor_Macros DDRC_MP - Register accessor macros
 * @{
 */


/* DDRC_MP - Register accessors */
#define DDRC_MP_PSTAT_REG(base)                  ((base)->PSTAT)
#define DDRC_MP_PCCFG_REG(base)                  ((base)->PCCFG)
#define DDRC_MP_PCFGR_0_REG(base)                ((base)->PCFGR_0)
#define DDRC_MP_PCFGW_0_REG(base)                ((base)->PCFGW_0)
#define DDRC_MP_PCFGIDMASKCH_00_REG(base)        ((base)->PCFGIDMASKCH_00)
#define DDRC_MP_PCFGIDVALUECH_00_REG(base)       ((base)->PCFGIDVALUECH_00)
#define DDRC_MP_PCFGIDMASKCH_10_REG(base)        ((base)->PCFGIDMASKCH_10)
#define DDRC_MP_PCFGIDVALUECH_10_REG(base)       ((base)->PCFGIDVALUECH_10)
#define DDRC_MP_PCFGIDMASKCH_20_REG(base)        ((base)->PCFGIDMASKCH_20)
#define DDRC_MP_PCFGIDVALUECH_20_REG(base)       ((base)->PCFGIDVALUECH_20)
#define DDRC_MP_PCFGIDMASKCH_30_REG(base)        ((base)->PCFGIDMASKCH_30)
#define DDRC_MP_PCFGIDVALUECH_30_REG(base)       ((base)->PCFGIDVALUECH_30)
#define DDRC_MP_PCFGIDMASKCH_40_REG(base)        ((base)->PCFGIDMASKCH_40)
#define DDRC_MP_PCFGIDVALUECH_40_REG(base)       ((base)->PCFGIDVALUECH_40)
#define DDRC_MP_PCFGIDMASKCH_50_REG(base)        ((base)->PCFGIDMASKCH_50)
#define DDRC_MP_PCFGIDVALUECH_50_REG(base)       ((base)->PCFGIDVALUECH_50)
#define DDRC_MP_PCFGIDMASKCH_60_REG(base)        ((base)->PCFGIDMASKCH_60)
#define DDRC_MP_PCFGIDVALUECH_60_REG(base)       ((base)->PCFGIDVALUECH_60)
#define DDRC_MP_PCFGIDMASKCH_70_REG(base)        ((base)->PCFGIDMASKCH_70)
#define DDRC_MP_PCFGIDVALUECH_70_REG(base)       ((base)->PCFGIDVALUECH_70)
#define DDRC_MP_PCFGIDMASKCH_80_REG(base)        ((base)->PCFGIDMASKCH_80)
#define DDRC_MP_PCFGIDVALUECH_80_REG(base)       ((base)->PCFGIDVALUECH_80)
#define DDRC_MP_PCFGIDMASKCH_90_REG(base)        ((base)->PCFGIDMASKCH_90)
#define DDRC_MP_PCFGIDVALUECH_90_REG(base)       ((base)->PCFGIDVALUECH_90)
#define DDRC_MP_PCFGIDMASKCH_100_REG(base)       ((base)->PCFGIDMASKCH_100)
#define DDRC_MP_PCFGIDVALUECH_100_REG(base)      ((base)->PCFGIDVALUECH_100)
#define DDRC_MP_PCFGIDMASKCH_110_REG(base)       ((base)->PCFGIDMASKCH_110)
#define DDRC_MP_PCFGIDVALUECH_110_REG(base)      ((base)->PCFGIDVALUECH_110)
#define DDRC_MP_PCFGIDMASKCH_120_REG(base)       ((base)->PCFGIDMASKCH_120)
#define DDRC_MP_PCFGIDVALUECH_120_REG(base)      ((base)->PCFGIDVALUECH_120)
#define DDRC_MP_PCFGIDMASKCH_130_REG(base)       ((base)->PCFGIDMASKCH_130)
#define DDRC_MP_PCFGIDVALUECH_130_REG(base)      ((base)->PCFGIDVALUECH_130)
#define DDRC_MP_PCFGIDMASKCH_140_REG(base)       ((base)->PCFGIDMASKCH_140)
#define DDRC_MP_PCFGIDVALUECH_140_REG(base)      ((base)->PCFGIDVALUECH_140)
#define DDRC_MP_PCFGIDMASKCH_150_REG(base)       ((base)->PCFGIDMASKCH_150)
#define DDRC_MP_PCFGIDVALUECH_150_REG(base)      ((base)->PCFGIDVALUECH_150)
#define DDRC_MP_PCTRL_0_REG(base)                ((base)->PCTRL_0)
#define DDRC_MP_PCFGQOS0_0_REG(base)             ((base)->PCFGQOS0_0)
#define DDRC_MP_PCFGQOS1_0_REG(base)             ((base)->PCFGQOS1_0)
#define DDRC_MP_PCFGWQOS0_0_REG(base)            ((base)->PCFGWQOS0_0)
#define DDRC_MP_PCFGWQOS1_0_REG(base)            ((base)->PCFGWQOS1_0)
#define DDRC_MP_SARBASE0_REG(base)               ((base)->SARBASE0)
#define DDRC_MP_SARSIZE0_REG(base)               ((base)->SARSIZE0)
#define DDRC_MP_SARBASE1_REG(base)               ((base)->SARBASE1)
#define DDRC_MP_SARSIZE1_REG(base)               ((base)->SARSIZE1)
#define DDRC_MP_SARBASE2_REG(base)               ((base)->SARBASE2)
#define DDRC_MP_SARSIZE2_REG(base)               ((base)->SARSIZE2)
#define DDRC_MP_SARBASE3_REG(base)               ((base)->SARBASE3)
#define DDRC_MP_SARSIZE3_REG(base)               ((base)->SARSIZE3)

/*!
 * @}
 */ /* end of group DDRC_MP_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- DDRC_MP Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDRC_MP_Register_Masks DDRC_MP Register Masks
 * @{
 */

/*! @name PSTAT - Port Status Register */
#define DDRC_MP_PSTAT_RD_PORT_BUSY_0_MASK        (0x1U)
#define DDRC_MP_PSTAT_RD_PORT_BUSY_0_SHIFT       (0U)

/*! @name PCCFG - Port Common Configuration Register */
#define DDRC_MP_PCCFG_GO2CRITICAL_EN_MASK        (0x1U)
#define DDRC_MP_PCCFG_GO2CRITICAL_EN_SHIFT       (0U)
#define DDRC_MP_PCCFG_PAGEMATCH_LIMIT_MASK       (0x10U)
#define DDRC_MP_PCCFG_PAGEMATCH_LIMIT_SHIFT      (4U)

/*! @name PCFGR_0 - Port n Configuration Read Register */
#define DDRC_MP_PCFGR_0_RD_PORT_PRIORITY_MASK    (0x3FFU)
#define DDRC_MP_PCFGR_0_RD_PORT_PRIORITY_SHIFT   (0U)
#define DDRC_MP_PCFGR_0_RD_PORT_PRIORITY(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGR_0_RD_PORT_PRIORITY_SHIFT)) & DDRC_MP_PCFGR_0_RD_PORT_PRIORITY_MASK)
#define DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN_MASK (0x800U)
#define DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN_SHIFT (11U)
#define DDRC_MP_PCFGR_0_RD_PORT_AGING_EN_MASK    (0x1000U)
#define DDRC_MP_PCFGR_0_RD_PORT_AGING_EN_SHIFT   (12U)
#define DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN_MASK   (0x2000U)
#define DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN_SHIFT  (13U)
#define DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN_MASK (0x4000U)
#define DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN_SHIFT (14U)
#define DDRC_MP_PCFGR_0_RDWR_ORDERED_EN_MASK     (0x10000U)
#define DDRC_MP_PCFGR_0_RDWR_ORDERED_EN_SHIFT    (16U)

/*! @name PCFGW_0 - Port n Configuration Write Register */
#define DDRC_MP_PCFGW_0_WR_PORT_PRIORITY_MASK    (0x3FFU)
#define DDRC_MP_PCFGW_0_WR_PORT_PRIORITY_SHIFT   (0U)
#define DDRC_MP_PCFGW_0_WR_PORT_PRIORITY(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGW_0_WR_PORT_PRIORITY_SHIFT)) & DDRC_MP_PCFGW_0_WR_PORT_PRIORITY_MASK)
#define DDRC_MP_PCFGW_0_WR_PORT_AGING_EN_MASK    (0x1000U)
#define DDRC_MP_PCFGW_0_WR_PORT_AGING_EN_SHIFT   (12U)
#define DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN_MASK   (0x2000U)
#define DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN_SHIFT  (13U)
#define DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN_MASK (0x4000U)
#define DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN_SHIFT (14U)

/*! @name PCFGIDMASKCH_00 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_00_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_00_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_00_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_00_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_00_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_00 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_00_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_00_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_00_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_00_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_00_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_10 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_10_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_10_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_10_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_10_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_10_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_10 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_10_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_10_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_10_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_10_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_10_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_20 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_20_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_20_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_20_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_20_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_20_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_20 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_20_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_20_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_20_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_20_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_20_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_30 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_30_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_30_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_30_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_30_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_30_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_30 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_30_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_30_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_30_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_30_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_30_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_40 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_40_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_40_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_40_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_40_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_40_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_40 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_40_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_40_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_40_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_40_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_40_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_50 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_50_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_50_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_50_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_50_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_50_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_50 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_50_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_50_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_50_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_50_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_50_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_60 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_60_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_60_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_60_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_60_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_60_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_60 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_60_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_60_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_60_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_60_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_60_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_70 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_70_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_70_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_70_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_70_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_70_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_70 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_70_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_70_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_70_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_70_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_70_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_80 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_80_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_80_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_80_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_80_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_80_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_80 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_80_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_80_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_80_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_80_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_80_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_90 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_90_ID_MASK_MASK     (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_90_ID_MASK_SHIFT    (0U)
#define DDRC_MP_PCFGIDMASKCH_90_ID_MASK(x)       (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_90_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_90_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_90 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_90_ID_VALUE_MASK   (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_90_ID_VALUE_SHIFT  (0U)
#define DDRC_MP_PCFGIDVALUECH_90_ID_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_90_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_90_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_100 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_100_ID_MASK_MASK    (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_100_ID_MASK_SHIFT   (0U)
#define DDRC_MP_PCFGIDMASKCH_100_ID_MASK(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_100_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_100_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_100 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_100_ID_VALUE_MASK  (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_100_ID_VALUE_SHIFT (0U)
#define DDRC_MP_PCFGIDVALUECH_100_ID_VALUE(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_100_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_100_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_110 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_110_ID_MASK_MASK    (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_110_ID_MASK_SHIFT   (0U)
#define DDRC_MP_PCFGIDMASKCH_110_ID_MASK(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_110_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_110_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_110 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_110_ID_VALUE_MASK  (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_110_ID_VALUE_SHIFT (0U)
#define DDRC_MP_PCFGIDVALUECH_110_ID_VALUE(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_110_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_110_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_120 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_120_ID_MASK_MASK    (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_120_ID_MASK_SHIFT   (0U)
#define DDRC_MP_PCFGIDMASKCH_120_ID_MASK(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_120_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_120_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_120 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_120_ID_VALUE_MASK  (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_120_ID_VALUE_SHIFT (0U)
#define DDRC_MP_PCFGIDVALUECH_120_ID_VALUE(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_120_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_120_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_130 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_130_ID_MASK_MASK    (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_130_ID_MASK_SHIFT   (0U)
#define DDRC_MP_PCFGIDMASKCH_130_ID_MASK(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_130_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_130_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_130 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_130_ID_VALUE_MASK  (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_130_ID_VALUE_SHIFT (0U)
#define DDRC_MP_PCFGIDVALUECH_130_ID_VALUE(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_130_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_130_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_140 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_140_ID_MASK_MASK    (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_140_ID_MASK_SHIFT   (0U)
#define DDRC_MP_PCFGIDMASKCH_140_ID_MASK(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_140_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_140_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_140 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_140_ID_VALUE_MASK  (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_140_ID_VALUE_SHIFT (0U)
#define DDRC_MP_PCFGIDVALUECH_140_ID_VALUE(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_140_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_140_ID_VALUE_MASK)

/*! @name PCFGIDMASKCH_150 - Port n Channel m Configuration ID Mask Register */
#define DDRC_MP_PCFGIDMASKCH_150_ID_MASK_MASK    (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDMASKCH_150_ID_MASK_SHIFT   (0U)
#define DDRC_MP_PCFGIDMASKCH_150_ID_MASK(x)      (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDMASKCH_150_ID_MASK_SHIFT)) & DDRC_MP_PCFGIDMASKCH_150_ID_MASK_MASK)

/*! @name PCFGIDVALUECH_150 - Port n Channel m Configuration ID Value Register */
#define DDRC_MP_PCFGIDVALUECH_150_ID_VALUE_MASK  (0xFFFFFFFFU)
#define DDRC_MP_PCFGIDVALUECH_150_ID_VALUE_SHIFT (0U)
#define DDRC_MP_PCFGIDVALUECH_150_ID_VALUE(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGIDVALUECH_150_ID_VALUE_SHIFT)) & DDRC_MP_PCFGIDVALUECH_150_ID_VALUE_MASK)

/*! @name PCTRL_0 - Port n Control Register */
#define DDRC_MP_PCTRL_0_PORT_EN_MASK             (0x1U)
#define DDRC_MP_PCTRL_0_PORT_EN_SHIFT            (0U)

/*! @name PCFGQOS0_0 - Port n Read QoS Configuration Register 0 */
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1_MASK  (0xFU)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1_SHIFT (0U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1_SHIFT)) & DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1_MASK)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2_MASK  (0xF00U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2_SHIFT (8U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2_SHIFT)) & DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2_MASK)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0_MASK (0x30000U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0_SHIFT (16U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0(x)   (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0_SHIFT)) & DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0_MASK)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1_MASK (0x300000U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1_SHIFT (20U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1(x)   (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1_SHIFT)) & DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1_MASK)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2_MASK (0x3000000U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2_SHIFT (24U)
#define DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2(x)   (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2_SHIFT)) & DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2_MASK)

/*! @name PCFGQOS1_0 - Port n Read QoS Configuration Register 1 */
#define DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB_MASK (0x7FFU)
#define DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB_SHIFT (0U)
#define DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB(x)  (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB_SHIFT)) & DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB_MASK)
#define DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR_MASK (0x7FF0000U)
#define DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR_SHIFT (16U)
#define DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR(x)  (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR_SHIFT)) & DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR_MASK)

/*! @name PCFGWQOS0_0 - Port n Write QoS Configuration Register 0 */
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL_MASK  (0xFU)
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL_SHIFT (0U)
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL(x)    (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL_SHIFT)) & DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL_MASK)
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0_MASK (0x30000U)
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0_SHIFT (16U)
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0(x)  (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0_SHIFT)) & DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0_MASK)
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1_MASK (0x300000U)
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1_SHIFT (20U)
#define DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1(x)  (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1_SHIFT)) & DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1_MASK)

/*! @name PCFGWQOS1_0 - Port n Write QoS Configuration Register 1 */
#define DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT_MASK (0x7FFU)
#define DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT_SHIFT (0U)
#define DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT(x)  (((uint32_t)(((uint32_t)(x)) << DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT_SHIFT)) & DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT_MASK)

/*! @name SARBASE0 - SAR Base Address Register n */
#define DDRC_MP_SARBASE0_BASE_ADDR_MASK          (0xFFFFFFFFU)
#define DDRC_MP_SARBASE0_BASE_ADDR_SHIFT         (0U)
#define DDRC_MP_SARBASE0_BASE_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_MP_SARBASE0_BASE_ADDR_SHIFT)) & DDRC_MP_SARBASE0_BASE_ADDR_MASK)

/*! @name SARSIZE0 - SAR Size Register n */
#define DDRC_MP_SARSIZE0_NBLOCKS_MASK            (0xFFU)
#define DDRC_MP_SARSIZE0_NBLOCKS_SHIFT           (0U)
#define DDRC_MP_SARSIZE0_NBLOCKS(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_MP_SARSIZE0_NBLOCKS_SHIFT)) & DDRC_MP_SARSIZE0_NBLOCKS_MASK)

/*! @name SARBASE1 - SAR Base Address Register n */
#define DDRC_MP_SARBASE1_BASE_ADDR_MASK          (0xFFFFFFFFU)
#define DDRC_MP_SARBASE1_BASE_ADDR_SHIFT         (0U)
#define DDRC_MP_SARBASE1_BASE_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_MP_SARBASE1_BASE_ADDR_SHIFT)) & DDRC_MP_SARBASE1_BASE_ADDR_MASK)

/*! @name SARSIZE1 - SAR Size Register n */
#define DDRC_MP_SARSIZE1_NBLOCKS_MASK            (0xFFU)
#define DDRC_MP_SARSIZE1_NBLOCKS_SHIFT           (0U)
#define DDRC_MP_SARSIZE1_NBLOCKS(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_MP_SARSIZE1_NBLOCKS_SHIFT)) & DDRC_MP_SARSIZE1_NBLOCKS_MASK)

/*! @name SARBASE2 - SAR Base Address Register n */
#define DDRC_MP_SARBASE2_BASE_ADDR_MASK          (0xFFFFFFFFU)
#define DDRC_MP_SARBASE2_BASE_ADDR_SHIFT         (0U)
#define DDRC_MP_SARBASE2_BASE_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_MP_SARBASE2_BASE_ADDR_SHIFT)) & DDRC_MP_SARBASE2_BASE_ADDR_MASK)

/*! @name SARSIZE2 - SAR Size Register n */
#define DDRC_MP_SARSIZE2_NBLOCKS_MASK            (0xFFU)
#define DDRC_MP_SARSIZE2_NBLOCKS_SHIFT           (0U)
#define DDRC_MP_SARSIZE2_NBLOCKS(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_MP_SARSIZE2_NBLOCKS_SHIFT)) & DDRC_MP_SARSIZE2_NBLOCKS_MASK)

/*! @name SARBASE3 - SAR Base Address Register n */
#define DDRC_MP_SARBASE3_BASE_ADDR_MASK          (0xFFFFFFFFU)
#define DDRC_MP_SARBASE3_BASE_ADDR_SHIFT         (0U)
#define DDRC_MP_SARBASE3_BASE_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << DDRC_MP_SARBASE3_BASE_ADDR_SHIFT)) & DDRC_MP_SARBASE3_BASE_ADDR_MASK)

/*! @name SARSIZE3 - SAR Size Register n */
#define DDRC_MP_SARSIZE3_NBLOCKS_MASK            (0xFFU)
#define DDRC_MP_SARSIZE3_NBLOCKS_SHIFT           (0U)
#define DDRC_MP_SARSIZE3_NBLOCKS(x)              (((uint32_t)(((uint32_t)(x)) << DDRC_MP_SARSIZE3_NBLOCKS_SHIFT)) & DDRC_MP_SARSIZE3_NBLOCKS_MASK)


/*!
 * @}
 */ /* end of group DDRC_MP_Register_Masks */


/* DDRC_MP - Peripheral instance base addresses */
/** Peripheral DDRC_MP base pointer */
#define DDRC_MP_BASE_PTR                         ((DDRC_MP_MemMapPtr)0x307A03FCu)
/** Array initializer of DDRC_MP peripheral base pointers */
#define DDRC_MP_BASE_PTRS                        { DDRC_MP_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- DDRC_MP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDRC_MP_Register_Accessor_Macros DDRC_MP - Register accessor macros
 * @{
 */


/* DDRC_MP - Register instance definitions */
/* DDRC_MP */
#define DDRC_MP_PSTAT                            DDRC_MP_PSTAT_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCCFG                            DDRC_MP_PCCFG_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGR_0                          DDRC_MP_PCFGR_0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGW_0                          DDRC_MP_PCFGW_0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_00                  DDRC_MP_PCFGIDMASKCH_00_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_00                 DDRC_MP_PCFGIDVALUECH_00_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_10                  DDRC_MP_PCFGIDMASKCH_10_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_10                 DDRC_MP_PCFGIDVALUECH_10_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_20                  DDRC_MP_PCFGIDMASKCH_20_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_20                 DDRC_MP_PCFGIDVALUECH_20_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_30                  DDRC_MP_PCFGIDMASKCH_30_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_30                 DDRC_MP_PCFGIDVALUECH_30_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_40                  DDRC_MP_PCFGIDMASKCH_40_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_40                 DDRC_MP_PCFGIDVALUECH_40_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_50                  DDRC_MP_PCFGIDMASKCH_50_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_50                 DDRC_MP_PCFGIDVALUECH_50_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_60                  DDRC_MP_PCFGIDMASKCH_60_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_60                 DDRC_MP_PCFGIDVALUECH_60_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_70                  DDRC_MP_PCFGIDMASKCH_70_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_70                 DDRC_MP_PCFGIDVALUECH_70_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_80                  DDRC_MP_PCFGIDMASKCH_80_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_80                 DDRC_MP_PCFGIDVALUECH_80_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_90                  DDRC_MP_PCFGIDMASKCH_90_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_90                 DDRC_MP_PCFGIDVALUECH_90_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_100                 DDRC_MP_PCFGIDMASKCH_100_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_100                DDRC_MP_PCFGIDVALUECH_100_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_110                 DDRC_MP_PCFGIDMASKCH_110_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_110                DDRC_MP_PCFGIDVALUECH_110_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_120                 DDRC_MP_PCFGIDMASKCH_120_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_120                DDRC_MP_PCFGIDVALUECH_120_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_130                 DDRC_MP_PCFGIDMASKCH_130_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_130                DDRC_MP_PCFGIDVALUECH_130_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_140                 DDRC_MP_PCFGIDMASKCH_140_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_140                DDRC_MP_PCFGIDVALUECH_140_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDMASKCH_150                 DDRC_MP_PCFGIDMASKCH_150_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGIDVALUECH_150                DDRC_MP_PCFGIDVALUECH_150_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCTRL_0                          DDRC_MP_PCTRL_0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGQOS0_0                       DDRC_MP_PCFGQOS0_0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGQOS1_0                       DDRC_MP_PCFGQOS1_0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGWQOS0_0                      DDRC_MP_PCFGWQOS0_0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_PCFGWQOS1_0                      DDRC_MP_PCFGWQOS1_0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_SARBASE0                         DDRC_MP_SARBASE0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_SARSIZE0                         DDRC_MP_SARSIZE0_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_SARBASE1                         DDRC_MP_SARBASE1_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_SARSIZE1                         DDRC_MP_SARSIZE1_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_SARBASE2                         DDRC_MP_SARBASE2_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_SARSIZE2                         DDRC_MP_SARSIZE2_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_SARBASE3                         DDRC_MP_SARBASE3_REG(DDRC_MP_BASE_PTR)
#define DDRC_MP_SARSIZE3                         DDRC_MP_SARSIZE3_REG(DDRC_MP_BASE_PTR)

/*!
 * @}
 */ /* end of group DDRC_MP_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group DDRC_MP_Peripheral */


/* ----------------------------------------------------------------------------
   -- DDR_PHY
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDR_PHY_Peripheral DDR_PHY
 * @{
 */

/** DDR_PHY - Peripheral register structure */
typedef struct DDR_PHY_MemMap {
  uint32_t PHY_CON0;                               /**< , offset: 0x0 */
  uint32_t PHY_CON1;                               /**< , offset: 0x4 */
  uint32_t PHY_CON2;                               /**< , offset: 0x8 */
  uint32_t PHY_CON3;                               /**< , offset: 0xC */
  uint32_t PHY_CON4;                               /**< , offset: 0x10 */
  uint32_t PHY_CON5;                               /**< , offset: 0x14 */
  uint32_t LP_CON0;                                /**< , offset: 0x18 */
  uint32_t RODT_CON0;                              /**< , offset: 0x1C */
  uint32_t OFFSET_RD_CON0;                         /**< , offset: 0x20 */
  uint8_t RESERVED_0[12];
  uint32_t OFFSET_WR_CON0;                         /**< , offset: 0x30 */
  uint8_t RESERVED_1[12];
  uint32_t GATE_CODE_CON0;                         /**< , offset: 0x40 */
  uint8_t RESERVED_2[8];
  uint32_t SHIFTC_CON0;                            /**< , offset: 0x4C */
  uint32_t CMD_SDLL_CON0;                          /**< , offset: 0x50 */
  uint8_t RESERVED_3[24];
  uint32_t LVL_CON0;                               /**< , offset: 0x6C */
  uint8_t RESERVED_4[8];
  uint32_t LVL_CON3;                               /**< , offset: 0x78 */
  uint32_t CMD_DESKEW_CON0;                        /**< , offset: 0x7C */
  uint32_t CMD_DESKEW_CON1;                        /**< , offset: 0x80 */
  uint32_t CMD_DESKEW_CON2;                        /**< , offset: 0x84 */
  uint32_t CMD_DESKEW_CON3;                        /**< , offset: 0x88 */
  uint8_t RESERVED_5[8];
  uint32_t CMD_DESKEW_CON4;                        /**< , offset: 0x94 */
  uint8_t RESERVED_6[4];
  uint32_t DRVDS_CON0;                             /**< , offset: 0x9C */
  uint8_t RESERVED_7[16];
  uint32_t MDLL_CON0;                              /**< , offset: 0xB0 */
  uint32_t MDLL_CON1;                              /**< , offset: 0xB4 */
  uint8_t RESERVED_8[8];
  uint32_t ZQ_CON0;                                /**< , offset: 0xC0 */
  uint32_t ZQ_CON1;                                /**< , offset: 0xC4 */
  uint32_t ZQ_CON2;                                /**< , offset: 0xC8 */
  uint8_t RESERVED_9[196];
  uint32_t RD_DESKEW_CON0;                         /**< , offset: 0x190 */
  uint8_t RESERVED_10[8];
  uint32_t RD_DESKEW_CON3;                         /**< , offset: 0x19C */
  uint8_t RESERVED_11[8];
  uint32_t RD_DESKEW_CON6;                         /**< , offset: 0x1A8 */
  uint8_t RESERVED_12[8];
  uint32_t RD_DESKEW_CON9;                         /**< , offset: 0x1B4 */
  uint8_t RESERVED_13[8];
  uint32_t RD_DESKEW_CON12;                        /**< , offset: 0x1C0 */
  uint8_t RESERVED_14[8];
  uint32_t RD_DESKEW_CON15;                        /**< , offset: 0x1CC */
  uint8_t RESERVED_15[8];
  uint32_t RD_DESKEW_CON18;                        /**< , offset: 0x1D8 */
  uint8_t RESERVED_16[8];
  uint32_t RD_DESKEW_CON21;                        /**< , offset: 0x1E4 */
  uint8_t RESERVED_17[8];
  uint32_t WR_DESKEW_CON0;                         /**< , offset: 0x1F0 */
  uint8_t RESERVED_18[8];
  uint32_t WR_DESKEW_CON3;                         /**< , offset: 0x1FC */
  uint8_t RESERVED_19[8];
  uint32_t WR_DESKEW_CON6;                         /**< , offset: 0x208 */
  uint8_t RESERVED_20[8];
  uint32_t WR_DESKEW_CON9;                         /**< , offset: 0x214 */
  uint8_t RESERVED_21[8];
  uint32_t WR_DESKEW_CON12;                        /**< , offset: 0x220 */
  uint8_t RESERVED_22[8];
  uint32_t WR_DESKEW_CON15;                        /**< , offset: 0x22C */
  uint8_t RESERVED_23[8];
  uint32_t WR_DESKEW_CON18;                        /**< , offset: 0x238 */
  uint8_t RESERVED_24[8];
  uint32_t WR_DESKEW_CON21;                        /**< , offset: 0x244 */
  uint8_t RESERVED_25[8];
  uint32_t DM_DESKEW_CON;                          /**< , offset: 0x250 */
  uint8_t RESERVED_26[332];
  uint32_t RDATA0;                                 /**< , offset: 0x3A0 */
  uint8_t RESERVED_27[8];
  uint32_t STAT0;                                  /**< , offset: 0x3AC */
} volatile *DDR_PHY_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- DDR_PHY - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDR_PHY_Register_Accessor_Macros DDR_PHY - Register accessor macros
 * @{
 */


/* DDR_PHY - Register accessors */
#define DDR_PHY_PHY_CON0_REG(base)               ((base)->PHY_CON0)
#define DDR_PHY_PHY_CON1_REG(base)               ((base)->PHY_CON1)
#define DDR_PHY_PHY_CON2_REG(base)               ((base)->PHY_CON2)
#define DDR_PHY_PHY_CON3_REG(base)               ((base)->PHY_CON3)
#define DDR_PHY_PHY_CON4_REG(base)               ((base)->PHY_CON4)
#define DDR_PHY_PHY_CON5_REG(base)               ((base)->PHY_CON5)
#define DDR_PHY_LP_CON0_REG(base)                ((base)->LP_CON0)
#define DDR_PHY_RODT_CON0_REG(base)              ((base)->RODT_CON0)
#define DDR_PHY_OFFSET_RD_CON0_REG(base)         ((base)->OFFSET_RD_CON0)
#define DDR_PHY_OFFSET_WR_CON0_REG(base)         ((base)->OFFSET_WR_CON0)
#define DDR_PHY_GATE_CODE_CON0_REG(base)         ((base)->GATE_CODE_CON0)
#define DDR_PHY_SHIFTC_CON0_REG(base)            ((base)->SHIFTC_CON0)
#define DDR_PHY_CMD_SDLL_CON0_REG(base)          ((base)->CMD_SDLL_CON0)
#define DDR_PHY_LVL_CON0_REG(base)               ((base)->LVL_CON0)
#define DDR_PHY_LVL_CON3_REG(base)               ((base)->LVL_CON3)
#define DDR_PHY_CMD_DESKEW_CON0_REG(base)        ((base)->CMD_DESKEW_CON0)
#define DDR_PHY_CMD_DESKEW_CON1_REG(base)        ((base)->CMD_DESKEW_CON1)
#define DDR_PHY_CMD_DESKEW_CON2_REG(base)        ((base)->CMD_DESKEW_CON2)
#define DDR_PHY_CMD_DESKEW_CON3_REG(base)        ((base)->CMD_DESKEW_CON3)
#define DDR_PHY_CMD_DESKEW_CON4_REG(base)        ((base)->CMD_DESKEW_CON4)
#define DDR_PHY_DRVDS_CON0_REG(base)             ((base)->DRVDS_CON0)
#define DDR_PHY_MDLL_CON0_REG(base)              ((base)->MDLL_CON0)
#define DDR_PHY_MDLL_CON1_REG(base)              ((base)->MDLL_CON1)
#define DDR_PHY_ZQ_CON0_REG(base)                ((base)->ZQ_CON0)
#define DDR_PHY_ZQ_CON1_REG(base)                ((base)->ZQ_CON1)
#define DDR_PHY_ZQ_CON2_REG(base)                ((base)->ZQ_CON2)
#define DDR_PHY_RD_DESKEW_CON0_REG(base)         ((base)->RD_DESKEW_CON0)
#define DDR_PHY_RD_DESKEW_CON3_REG(base)         ((base)->RD_DESKEW_CON3)
#define DDR_PHY_RD_DESKEW_CON6_REG(base)         ((base)->RD_DESKEW_CON6)
#define DDR_PHY_RD_DESKEW_CON9_REG(base)         ((base)->RD_DESKEW_CON9)
#define DDR_PHY_RD_DESKEW_CON12_REG(base)        ((base)->RD_DESKEW_CON12)
#define DDR_PHY_RD_DESKEW_CON15_REG(base)        ((base)->RD_DESKEW_CON15)
#define DDR_PHY_RD_DESKEW_CON18_REG(base)        ((base)->RD_DESKEW_CON18)
#define DDR_PHY_RD_DESKEW_CON21_REG(base)        ((base)->RD_DESKEW_CON21)
#define DDR_PHY_WR_DESKEW_CON0_REG(base)         ((base)->WR_DESKEW_CON0)
#define DDR_PHY_WR_DESKEW_CON3_REG(base)         ((base)->WR_DESKEW_CON3)
#define DDR_PHY_WR_DESKEW_CON6_REG(base)         ((base)->WR_DESKEW_CON6)
#define DDR_PHY_WR_DESKEW_CON9_REG(base)         ((base)->WR_DESKEW_CON9)
#define DDR_PHY_WR_DESKEW_CON12_REG(base)        ((base)->WR_DESKEW_CON12)
#define DDR_PHY_WR_DESKEW_CON15_REG(base)        ((base)->WR_DESKEW_CON15)
#define DDR_PHY_WR_DESKEW_CON18_REG(base)        ((base)->WR_DESKEW_CON18)
#define DDR_PHY_WR_DESKEW_CON21_REG(base)        ((base)->WR_DESKEW_CON21)
#define DDR_PHY_DM_DESKEW_CON_REG(base)          ((base)->DM_DESKEW_CON)
#define DDR_PHY_RDATA0_REG(base)                 ((base)->RDATA0)
#define DDR_PHY_STAT0_REG(base)                  ((base)->STAT0)

/*!
 * @}
 */ /* end of group DDR_PHY_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- DDR_PHY Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDR_PHY_Register_Masks DDR_PHY Register Masks
 * @{
 */

/*! @name PHY_CON0 -  */
#define DDR_PHY_PHY_CON0_CTRL_FNC_FB_MASK        (0x7U)
#define DDR_PHY_PHY_CON0_CTRL_FNC_FB_SHIFT       (0U)
#define DDR_PHY_PHY_CON0_CTRL_FNC_FB(x)          (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON0_CTRL_FNC_FB_SHIFT)) & DDR_PHY_PHY_CON0_CTRL_FNC_FB_MASK)
#define DDR_PHY_PHY_CON0_CTRL_TWPRE_MASK         (0x8U)
#define DDR_PHY_PHY_CON0_CTRL_TWPRE_SHIFT        (3U)
#define DDR_PHY_PHY_CON0_CTRL_CMOSRCV_MASK       (0x10U)
#define DDR_PHY_PHY_CON0_CTRL_CMOSRCV_SHIFT      (4U)
#define DDR_PHY_PHY_CON0_CTRL_ATGATE_MASK        (0x40U)
#define DDR_PHY_PHY_CON0_CTRL_ATGATE_SHIFT       (6U)
#define DDR_PHY_PHY_CON0_CTRL_SHGATE_MASK        (0x100U)
#define DDR_PHY_PHY_CON0_CTRL_SHGATE_SHIFT       (8U)
#define DDR_PHY_PHY_CON0_CTRL_DFDQS_MASK         (0x200U)
#define DDR_PHY_PHY_CON0_CTRL_DFDQS_SHIFT        (9U)
#define DDR_PHY_PHY_CON0_CTRL_DDR_MODE_MASK      (0x1800U)
#define DDR_PHY_PHY_CON0_CTRL_DDR_MODE_SHIFT     (11U)
#define DDR_PHY_PHY_CON0_CTRL_DDR_MODE(x)        (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON0_CTRL_DDR_MODE_SHIFT)) & DDR_PHY_PHY_CON0_CTRL_DDR_MODE_MASK)
#define DDR_PHY_PHY_CON0_WRLVL_MODE_MASK         (0x10000U)
#define DDR_PHY_PHY_CON0_WRLVL_MODE_SHIFT        (16U)
#define DDR_PHY_PHY_CON0_CTRL_UPD_RANGE_MASK     (0x300000U)
#define DDR_PHY_PHY_CON0_CTRL_UPD_RANGE_SHIFT    (20U)
#define DDR_PHY_PHY_CON0_CTRL_UPD_RANGE(x)       (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON0_CTRL_UPD_RANGE_SHIFT)) & DDR_PHY_PHY_CON0_CTRL_UPD_RANGE_MASK)
#define DDR_PHY_PHY_CON0_CTRL_UPD_MODE_MASK      (0xC00000U)
#define DDR_PHY_PHY_CON0_CTRL_UPD_MODE_SHIFT     (22U)
#define DDR_PHY_PHY_CON0_CTRL_UPD_MODE(x)        (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON0_CTRL_UPD_MODE_SHIFT)) & DDR_PHY_PHY_CON0_CTRL_UPD_MODE_MASK)

/*! @name PHY_CON1 -  */
#define DDR_PHY_PHY_CON1_ctrl_gateduradj_MASK    (0xF00000U)
#define DDR_PHY_PHY_CON1_ctrl_gateduradj_SHIFT   (20U)
#define DDR_PHY_PHY_CON1_ctrl_gateduradj(x)      (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON1_ctrl_gateduradj_SHIFT)) & DDR_PHY_PHY_CON1_ctrl_gateduradj_MASK)
#define DDR_PHY_PHY_CON1_CTRL_GATEADJ_MASK       (0xF0000000U)
#define DDR_PHY_PHY_CON1_CTRL_GATEADJ_SHIFT      (28U)
#define DDR_PHY_PHY_CON1_CTRL_GATEADJ(x)         (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON1_CTRL_GATEADJ_SHIFT)) & DDR_PHY_PHY_CON1_CTRL_GATEADJ_MASK)

/*! @name PHY_CON2 -  */
#define DDR_PHY_PHY_CON2_RDDESKEW_CLEAR_MASK     (0x2000U)
#define DDR_PHY_PHY_CON2_RDDESKEW_CLEAR_SHIFT    (13U)
#define DDR_PHY_PHY_CON2_WRDESKEW_CLEAR_MASK     (0x4000U)
#define DDR_PHY_PHY_CON2_WRDESKEW_CLEAR_SHIFT    (14U)
#define DDR_PHY_PHY_CON2_CA_CAL_MODE_MASK        (0x800000U)
#define DDR_PHY_PHY_CON2_CA_CAL_MODE_SHIFT       (23U)
#define DDR_PHY_PHY_CON2_GATE_CAL_MODE_MASK      (0x1000000U)
#define DDR_PHY_PHY_CON2_GATE_CAL_MODE_SHIFT     (24U)

/*! @name PHY_CON3 -  */
#define DDR_PHY_PHY_CON3_REG_MODE_MASK           (0xFFU)
#define DDR_PHY_PHY_CON3_REG_MODE_SHIFT          (0U)
#define DDR_PHY_PHY_CON3_REG_MODE(x)             (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON3_REG_MODE_SHIFT)) & DDR_PHY_PHY_CON3_REG_MODE_MASK)
#define DDR_PHY_PHY_CON3_WRLVL_START_MASK        (0x10000U)
#define DDR_PHY_PHY_CON3_WRLVL_START_SHIFT       (16U)
#define DDR_PHY_PHY_CON3_WL_CAL_MODE_MASK        (0x100000U)
#define DDR_PHY_PHY_CON3_WL_CAL_MODE_SHIFT       (20U)
#define DDR_PHY_PHY_CON3_WL_CAL_START_MASK       (0x200000U)
#define DDR_PHY_PHY_CON3_WL_CAL_START_SHIFT      (21U)
#define DDR_PHY_PHY_CON3_WRLVL_RESP_MASK         (0x1000000U)
#define DDR_PHY_PHY_CON3_WRLVL_RESP_SHIFT        (24U)
#define DDR_PHY_PHY_CON3_WL_CAL_RESP_MASK        (0x8000000U)
#define DDR_PHY_PHY_CON3_WL_CAL_RESP_SHIFT       (27U)

/*! @name PHY_CON4 -  */
#define DDR_PHY_PHY_CON4_CTRL_RDLAT_MASK         (0x1FU)
#define DDR_PHY_PHY_CON4_CTRL_RDLAT_SHIFT        (0U)
#define DDR_PHY_PHY_CON4_CTRL_RDLAT(x)           (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON4_CTRL_RDLAT_SHIFT)) & DDR_PHY_PHY_CON4_CTRL_RDLAT_MASK)
#define DDR_PHY_PHY_CON4_CTRL_BSTLEN_MASK        (0x1F00U)
#define DDR_PHY_PHY_CON4_CTRL_BSTLEN_SHIFT       (8U)
#define DDR_PHY_PHY_CON4_CTRL_BSTLEN(x)          (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON4_CTRL_BSTLEN_SHIFT)) & DDR_PHY_PHY_CON4_CTRL_BSTLEN_MASK)
#define DDR_PHY_PHY_CON4_CTRL_WRLAT_MASK         (0x1F0000U)
#define DDR_PHY_PHY_CON4_CTRL_WRLAT_SHIFT        (16U)
#define DDR_PHY_PHY_CON4_CTRL_WRLAT(x)           (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON4_CTRL_WRLAT_SHIFT)) & DDR_PHY_PHY_CON4_CTRL_WRLAT_MASK)

/*! @name PHY_CON5 -  */
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0_MASK (0x7U)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0_SHIFT (0U)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0(x)   (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0_SHIFT)) & DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0_MASK)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1_MASK (0x38U)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1_SHIFT (3U)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1(x)   (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1_SHIFT)) & DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1_MASK)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2_MASK   (0x1C0U)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2_SHIFT  (6U)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2_SHIFT)) & DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2_MASK)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3_MASK   (0xE00U)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3_SHIFT  (9U)
#define DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3_SHIFT)) & DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3_MASK)

/*! @name LP_CON0 -  */
#define DDR_PHY_LP_CON0_CTRL_PULLD_DQS_MASK      (0x1FFU)
#define DDR_PHY_LP_CON0_CTRL_PULLD_DQS_SHIFT     (0U)
#define DDR_PHY_LP_CON0_CTRL_PULLD_DQS(x)        (((uint32_t)(((uint32_t)(x)) << DDR_PHY_LP_CON0_CTRL_PULLD_DQS_SHIFT)) & DDR_PHY_LP_CON0_CTRL_PULLD_DQS_MASK)
#define DDR_PHY_LP_CON0_CTRL_PULLD_DQ_MASK       (0x1FF0000U)
#define DDR_PHY_LP_CON0_CTRL_PULLD_DQ_SHIFT      (16U)
#define DDR_PHY_LP_CON0_CTRL_PULLD_DQ(x)         (((uint32_t)(((uint32_t)(x)) << DDR_PHY_LP_CON0_CTRL_PULLD_DQ_SHIFT)) & DDR_PHY_LP_CON0_CTRL_PULLD_DQ_MASK)

/*! @name RODT_CON0 -  */
#define DDR_PHY_RODT_CON0_CTRL_READ_DIS_MASK     (0x10000U)
#define DDR_PHY_RODT_CON0_CTRL_READ_DIS_SHIFT    (16U)

/*! @name OFFSET_RD_CON0 -  */
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0_MASK (0xFFU)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0_SHIFT (0U)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0_SHIFT)) & DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0_MASK)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1_MASK (0xFF00U)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1_SHIFT (8U)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1_SHIFT)) & DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1_MASK)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2_MASK (0xFF0000U)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2_SHIFT (16U)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2_SHIFT)) & DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2_MASK)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3_MASK (0xFF000000U)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3_SHIFT (24U)
#define DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3_SHIFT)) & DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3_MASK)

/*! @name OFFSET_WR_CON0 -  */
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0_MASK (0xFFU)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0_SHIFT (0U)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0_SHIFT)) & DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0_MASK)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1_MASK (0xFF00U)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1_SHIFT (8U)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1_SHIFT)) & DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1_MASK)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2_MASK (0xFF0000U)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2_SHIFT (16U)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2_SHIFT)) & DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2_MASK)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3_MASK (0xFF000000U)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3_SHIFT (24U)
#define DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3_SHIFT)) & DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3_MASK)

/*! @name GATE_CODE_CON0 -  */
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0_MASK (0xFFU)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0_SHIFT (0U)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0_SHIFT)) & DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0_MASK)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1_MASK (0xFF00U)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1_SHIFT (8U)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1_SHIFT)) & DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1_MASK)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2_MASK (0xFF0000U)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2_SHIFT (16U)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2_SHIFT)) & DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2_MASK)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3_MASK (0xFF000000U)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3_SHIFT (24U)
#define DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3_SHIFT)) & DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3_MASK)

/*! @name SHIFTC_CON0 -  */
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0_MASK    (0x7U)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0_SHIFT   (0U)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0(x)      (((uint32_t)(((uint32_t)(x)) << DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0_SHIFT)) & DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0_MASK)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1_MASK    (0x38U)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1_SHIFT   (3U)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1(x)      (((uint32_t)(((uint32_t)(x)) << DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1_SHIFT)) & DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1_MASK)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2_MASK    (0x1C0U)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2_SHIFT   (6U)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2(x)      (((uint32_t)(((uint32_t)(x)) << DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2_SHIFT)) & DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2_MASK)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3_MASK    (0xE00U)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3_SHIFT   (9U)
#define DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3(x)      (((uint32_t)(((uint32_t)(x)) << DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3_SHIFT)) & DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3_MASK)

/*! @name CMD_SDLL_CON0 -  */
#define DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD_MASK  (0xFFU)
#define DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD_SHIFT (0U)
#define DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD_SHIFT)) & DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD_MASK)
#define DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC_MASK   (0x1000000U)
#define DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC_SHIFT  (24U)
#define DDR_PHY_CMD_SDLL_CON0_UPD_MODE_MASK      (0x10000000U)
#define DDR_PHY_CMD_SDLL_CON0_UPD_MODE_SHIFT     (28U)

/*! @name LVL_CON0 -  */
#define DDR_PHY_LVL_CON0_ctrl_wrlvl0_code_MASK   (0xFFU)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl0_code_SHIFT  (0U)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl0_code(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_LVL_CON0_ctrl_wrlvl0_code_SHIFT)) & DDR_PHY_LVL_CON0_ctrl_wrlvl0_code_MASK)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl1_code_MASK   (0xFF00U)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl1_code_SHIFT  (8U)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl1_code(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_LVL_CON0_ctrl_wrlvl1_code_SHIFT)) & DDR_PHY_LVL_CON0_ctrl_wrlvl1_code_MASK)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl2_code_MASK   (0xFF0000U)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl2_code_SHIFT  (16U)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl2_code(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_LVL_CON0_ctrl_wrlvl2_code_SHIFT)) & DDR_PHY_LVL_CON0_ctrl_wrlvl2_code_MASK)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl3_code_MASK   (0xFF000000U)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl3_code_SHIFT  (24U)
#define DDR_PHY_LVL_CON0_ctrl_wrlvl3_code(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_LVL_CON0_ctrl_wrlvl3_code_SHIFT)) & DDR_PHY_LVL_CON0_ctrl_wrlvl3_code_MASK)

/*! @name LVL_CON3 -  */
#define DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC_MASK  (0x1U)
#define DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC_SHIFT (0U)

/*! @name CMD_DESKEW_CON0 -  */
#define DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0_MASK (0xFFU)
#define DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0_SHIFT (0U)
#define DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0_SHIFT)) & DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0_MASK)
#define DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1_MASK (0xFF00U)
#define DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1_SHIFT (8U)
#define DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1_SHIFT)) & DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1_MASK)
#define DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE_MASK (0xFF0000U)
#define DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE_SHIFT (16U)
#define DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE_MASK (0xFF000000U)
#define DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE_SHIFT (24U)
#define DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE_MASK)

/*! @name CMD_DESKEW_CON1 -  */
#define DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE_MASK (0xFFU)
#define DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE_SHIFT (0U)
#define DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE_MASK (0xFF00U)
#define DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE_SHIFT (8U)
#define DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE_MASK (0xFF0000U)
#define DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE_SHIFT (16U)
#define DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE_MASK (0xFF000000U)
#define DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE_SHIFT (24U)
#define DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE_MASK)

/*! @name CMD_DESKEW_CON2 -  */
#define DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE_MASK (0xFFU)
#define DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE_SHIFT (0U)
#define DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE_MASK (0xFF00U)
#define DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE_SHIFT (8U)
#define DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE_MASK (0xFF0000U)
#define DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE_SHIFT (16U)
#define DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE(x)  (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE_MASK (0xFF000000U)
#define DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE_SHIFT (24U)
#define DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE_MASK)

/*! @name CMD_DESKEW_CON3 -  */
#define DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE_MASK (0xFFU)
#define DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE_SHIFT (0U)
#define DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE_MASK (0xFF00U)
#define DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE_SHIFT (8U)
#define DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE_MASK)
#define DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE_MASK (0xFF0000U)
#define DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE_SHIFT (16U)
#define DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE_MASK)

/*! @name CMD_DESKEW_CON4 -  */
#define DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE_MASK (0xFFU)
#define DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE_SHIFT (0U)
#define DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE(x) (((uint32_t)(((uint32_t)(x)) << DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE_SHIFT)) & DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE_MASK)

/*! @name DRVDS_CON0 -  */
#define DDR_PHY_DRVDS_CON0_CAADRDRVRDS_MASK      (0x7U)
#define DDR_PHY_DRVDS_CON0_CAADRDRVRDS_SHIFT     (0U)
#define DDR_PHY_DRVDS_CON0_CAADRDRVRDS(x)        (((uint32_t)(((uint32_t)(x)) << DDR_PHY_DRVDS_CON0_CAADRDRVRDS_SHIFT)) & DDR_PHY_DRVDS_CON0_CAADRDRVRDS_MASK)
#define DDR_PHY_DRVDS_CON0_CACSDRVRDS_MASK       (0x38U)
#define DDR_PHY_DRVDS_CON0_CACSDRVRDS_SHIFT      (3U)
#define DDR_PHY_DRVDS_CON0_CACSDRVRDS(x)         (((uint32_t)(((uint32_t)(x)) << DDR_PHY_DRVDS_CON0_CACSDRVRDS_SHIFT)) & DDR_PHY_DRVDS_CON0_CACSDRVRDS_MASK)
#define DDR_PHY_DRVDS_CON0_CACKEDRVRDS_MASK      (0x1C0U)
#define DDR_PHY_DRVDS_CON0_CACKEDRVRDS_SHIFT     (6U)
#define DDR_PHY_DRVDS_CON0_CACKEDRVRDS(x)        (((uint32_t)(((uint32_t)(x)) << DDR_PHY_DRVDS_CON0_CACKEDRVRDS_SHIFT)) & DDR_PHY_DRVDS_CON0_CACKEDRVRDS_MASK)
#define DDR_PHY_DRVDS_CON0_CACKDRVRDS_MASK       (0xE00U)
#define DDR_PHY_DRVDS_CON0_CACKDRVRDS_SHIFT      (9U)
#define DDR_PHY_DRVDS_CON0_CACKDRVRDS(x)         (((uint32_t)(((uint32_t)(x)) << DDR_PHY_DRVDS_CON0_CACKDRVRDS_SHIFT)) & DDR_PHY_DRVDS_CON0_CACKDRVRDS_MASK)

/*! @name MDLL_CON0 -  */
#define DDR_PHY_MDLL_CON0_CTRL_REF_MASK          (0x1EU)
#define DDR_PHY_MDLL_CON0_CTRL_REF_SHIFT         (1U)
#define DDR_PHY_MDLL_CON0_CTRL_REF(x)            (((uint32_t)(((uint32_t)(x)) << DDR_PHY_MDLL_CON0_CTRL_REF_SHIFT)) & DDR_PHY_MDLL_CON0_CTRL_REF_MASK)
#define DDR_PHY_MDLL_CON0_CTRL_DLL_ON_MASK       (0x20U)
#define DDR_PHY_MDLL_CON0_CTRL_DLL_ON_SHIFT      (5U)
#define DDR_PHY_MDLL_CON0_CTRL_START_MASK        (0x40U)
#define DDR_PHY_MDLL_CON0_CTRL_START_SHIFT       (6U)
#define DDR_PHY_MDLL_CON0_CTRL_FORCE_MASK        (0xFF80U)
#define DDR_PHY_MDLL_CON0_CTRL_FORCE_SHIFT       (7U)
#define DDR_PHY_MDLL_CON0_CTRL_FORCE(x)          (((uint32_t)(((uint32_t)(x)) << DDR_PHY_MDLL_CON0_CTRL_FORCE_SHIFT)) & DDR_PHY_MDLL_CON0_CTRL_FORCE_MASK)
#define DDR_PHY_MDLL_CON0_CTRL_INC_MASK          (0x7F0000U)
#define DDR_PHY_MDLL_CON0_CTRL_INC_SHIFT         (16U)
#define DDR_PHY_MDLL_CON0_CTRL_INC(x)            (((uint32_t)(((uint32_t)(x)) << DDR_PHY_MDLL_CON0_CTRL_INC_SHIFT)) & DDR_PHY_MDLL_CON0_CTRL_INC_MASK)
#define DDR_PHY_MDLL_CON0_CTRL_START_POINT_MASK  (0x7F000000U)
#define DDR_PHY_MDLL_CON0_CTRL_START_POINT_SHIFT (24U)
#define DDR_PHY_MDLL_CON0_CTRL_START_POINT(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_MDLL_CON0_CTRL_START_POINT_SHIFT)) & DDR_PHY_MDLL_CON0_CTRL_START_POINT_MASK)

/*! @name MDLL_CON1 -  */
#define DDR_PHY_MDLL_CON1_CTRL_LOCKED_MASK       (0x1U)
#define DDR_PHY_MDLL_CON1_CTRL_LOCKED_SHIFT      (0U)
#define DDR_PHY_MDLL_CON1_CTRL_FLOCK_MASK        (0x2U)
#define DDR_PHY_MDLL_CON1_CTRL_FLOCK_SHIFT       (1U)
#define DDR_PHY_MDLL_CON1_CTRL_CLOCK_MASK        (0x4U)
#define DDR_PHY_MDLL_CON1_CTRL_CLOCK_SHIFT       (2U)
#define DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE_MASK   (0x1FF00U)
#define DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE_SHIFT  (8U)
#define DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE_SHIFT)) & DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE_MASK)

/*! @name ZQ_CON0 -  */
#define DDR_PHY_ZQ_CON0_ZQ_AUTO_EN_MASK          (0x1U)
#define DDR_PHY_ZQ_CON0_ZQ_AUTO_EN_SHIFT         (0U)
#define DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR_MASK       (0x2U)
#define DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR_SHIFT      (1U)
#define DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE_MASK      (0xCU)
#define DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE_SHIFT     (2U)
#define DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE(x)        (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE_SHIFT)) & DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE_MASK)
#define DDR_PHY_ZQ_CON0_ZQ_UDT_DLY_MASK          (0xFF0U)
#define DDR_PHY_ZQ_CON0_ZQ_UDT_DLY_SHIFT         (4U)
#define DDR_PHY_ZQ_CON0_ZQ_UDT_DLY(x)            (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON0_ZQ_UDT_DLY_SHIFT)) & DDR_PHY_ZQ_CON0_ZQ_UDT_DLY_MASK)
#define DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP_MASK       (0x7000U)
#define DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP_SHIFT      (12U)
#define DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP(x)         (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP_SHIFT)) & DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP_MASK)
#define DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN_MASK       (0x38000U)
#define DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN_SHIFT      (15U)
#define DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN(x)         (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN_SHIFT)) & DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN_MASK)
#define DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN_MASK       (0x40000U)
#define DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN_SHIFT      (18U)
#define DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM_MASK      (0x80000U)
#define DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM_SHIFT     (19U)
#define DDR_PHY_ZQ_CON0_ZQ_RGDDR3_MASK           (0x100000U)
#define DDR_PHY_ZQ_CON0_ZQ_RGDDR3_SHIFT          (20U)
#define DDR_PHY_ZQ_CON0_ZQ_MODE_TERM_MASK        (0xE00000U)
#define DDR_PHY_ZQ_CON0_ZQ_MODE_TERM_SHIFT       (21U)
#define DDR_PHY_ZQ_CON0_ZQ_MODE_TERM(x)          (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON0_ZQ_MODE_TERM_SHIFT)) & DDR_PHY_ZQ_CON0_ZQ_MODE_TERM_MASK)
#define DDR_PHY_ZQ_CON0_ZQ_MODE_DDS_MASK         (0x7000000U)
#define DDR_PHY_ZQ_CON0_ZQ_MODE_DDS_SHIFT        (24U)
#define DDR_PHY_ZQ_CON0_ZQ_MODE_DDS(x)           (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON0_ZQ_MODE_DDS_SHIFT)) & DDR_PHY_ZQ_CON0_ZQ_MODE_DDS_MASK)
#define DDR_PHY_ZQ_CON0_ZQ_CLK_EN_MASK           (0x8000000U)
#define DDR_PHY_ZQ_CON0_ZQ_CLK_EN_SHIFT          (27U)

/*! @name ZQ_CON1 -  */
#define DDR_PHY_ZQ_CON1_ZQ_DONE_MASK             (0x1U)
#define DDR_PHY_ZQ_CON1_ZQ_DONE_SHIFT            (0U)
#define DDR_PHY_ZQ_CON1_ZQ_PENDING_MASK          (0x2U)
#define DDR_PHY_ZQ_CON1_ZQ_PENDING_SHIFT         (1U)
#define DDR_PHY_ZQ_CON1_ZQ_ERROR_MASK            (0x4U)
#define DDR_PHY_ZQ_CON1_ZQ_ERROR_SHIFT           (2U)
#define DDR_PHY_ZQ_CON1_ZQ_NMON_MASK             (0x38U)
#define DDR_PHY_ZQ_CON1_ZQ_NMON_SHIFT            (3U)
#define DDR_PHY_ZQ_CON1_ZQ_NMON(x)               (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON1_ZQ_NMON_SHIFT)) & DDR_PHY_ZQ_CON1_ZQ_NMON_MASK)
#define DDR_PHY_ZQ_CON1_ZQ_PMON_MASK             (0x1C0U)
#define DDR_PHY_ZQ_CON1_ZQ_PMON_SHIFT            (6U)
#define DDR_PHY_ZQ_CON1_ZQ_PMON(x)               (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON1_ZQ_PMON_SHIFT)) & DDR_PHY_ZQ_CON1_ZQ_PMON_MASK)

/*! @name ZQ_CON2 -  */
#define DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV_MASK     (0xFFFFU)
#define DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV_SHIFT    (0U)
#define DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV(x)       (((uint32_t)(((uint32_t)(x)) << DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV_SHIFT)) & DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV_MASK)

/*! @name RD_DESKEW_CON0 -  */
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0_MASK   (0xFFU)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0_SHIFT  (0U)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0_SHIFT)) & DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0_MASK)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1_MASK   (0xFF00U)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1_SHIFT  (8U)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1_SHIFT)) & DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1_MASK)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2_MASK   (0xFF0000U)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2_SHIFT  (16U)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2_SHIFT)) & DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2_MASK)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3_MASK   (0xFF000000U)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3_SHIFT  (24U)
#define DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3_SHIFT)) & DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3_MASK)

/*! @name RD_DESKEW_CON3 -  */
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0_MASK   (0xFFU)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0_SHIFT  (0U)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0_SHIFT)) & DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0_MASK)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1_MASK   (0xFF00U)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1_SHIFT  (8U)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1_SHIFT)) & DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1_MASK)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2_MASK   (0xFF0000U)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2_SHIFT  (16U)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2_SHIFT)) & DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2_MASK)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3_MASK   (0xFF000000U)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3_SHIFT  (24U)
#define DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3_SHIFT)) & DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3_MASK)

/*! @name RD_DESKEW_CON6 -  */
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0_MASK   (0xFFU)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0_SHIFT  (0U)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0_SHIFT)) & DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0_MASK)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1_MASK   (0xFF00U)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1_SHIFT  (8U)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1_SHIFT)) & DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1_MASK)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2_MASK   (0xFF0000U)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2_SHIFT  (16U)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2_SHIFT)) & DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2_MASK)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3_MASK   (0xFF000000U)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3_SHIFT  (24U)
#define DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3_SHIFT)) & DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3_MASK)

/*! @name RD_DESKEW_CON9 -  */
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0_MASK   (0xFFU)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0_SHIFT  (0U)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0_SHIFT)) & DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0_MASK)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1_MASK   (0xFF00U)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1_SHIFT  (8U)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1_SHIFT)) & DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1_MASK)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2_MASK   (0xFF0000U)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2_SHIFT  (16U)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2_SHIFT)) & DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2_MASK)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3_MASK   (0xFF000000U)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3_SHIFT  (24U)
#define DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3_SHIFT)) & DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3_MASK)

/*! @name RD_DESKEW_CON12 -  */
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0_MASK  (0xFFU)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0_SHIFT (0U)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0_SHIFT)) & DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0_MASK)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1_MASK  (0xFF00U)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1_SHIFT (8U)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1_SHIFT)) & DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1_MASK)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2_MASK  (0xFF0000U)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2_SHIFT (16U)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2_SHIFT)) & DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2_MASK)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3_MASK  (0xFF000000U)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3_SHIFT (24U)
#define DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3_SHIFT)) & DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3_MASK)

/*! @name RD_DESKEW_CON15 -  */
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0_MASK  (0xFFU)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0_SHIFT (0U)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0_SHIFT)) & DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0_MASK)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1_MASK  (0xFF00U)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1_SHIFT (8U)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1_SHIFT)) & DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1_MASK)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2_MASK  (0xFF0000U)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2_SHIFT (16U)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2_SHIFT)) & DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2_MASK)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3_MASK  (0xFF000000U)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3_SHIFT (24U)
#define DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3_SHIFT)) & DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3_MASK)

/*! @name RD_DESKEW_CON18 -  */
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0_MASK  (0xFFU)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0_SHIFT (0U)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0_SHIFT)) & DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0_MASK)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1_MASK  (0xFF00U)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1_SHIFT (8U)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1_SHIFT)) & DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1_MASK)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2_MASK  (0xFF0000U)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2_SHIFT (16U)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2_SHIFT)) & DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2_MASK)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3_MASK  (0xFF000000U)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3_SHIFT (24U)
#define DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3_SHIFT)) & DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3_MASK)

/*! @name RD_DESKEW_CON21 -  */
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0_MASK  (0xFFU)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0_SHIFT (0U)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0_SHIFT)) & DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0_MASK)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1_MASK  (0xFF00U)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1_SHIFT (8U)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1_SHIFT)) & DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1_MASK)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2_MASK  (0xFF0000U)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2_SHIFT (16U)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2_SHIFT)) & DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2_MASK)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3_MASK  (0xFF000000U)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3_SHIFT (24U)
#define DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3_SHIFT)) & DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3_MASK)

/*! @name WR_DESKEW_CON0 -  */
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0_MASK   (0xFFU)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0_SHIFT  (0U)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0_SHIFT)) & DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0_MASK)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1_MASK   (0xFF00U)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1_SHIFT  (8U)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1_SHIFT)) & DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1_MASK)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2_MASK   (0xFF0000U)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2_SHIFT  (16U)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2_SHIFT)) & DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2_MASK)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3_MASK   (0xFF000000U)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3_SHIFT  (24U)
#define DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3_SHIFT)) & DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3_MASK)

/*! @name WR_DESKEW_CON3 -  */
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0_MASK   (0xFFU)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0_SHIFT  (0U)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0_SHIFT)) & DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0_MASK)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1_MASK   (0xFF00U)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1_SHIFT  (8U)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1_SHIFT)) & DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1_MASK)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2_MASK   (0xFF0000U)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2_SHIFT  (16U)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2_SHIFT)) & DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2_MASK)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3_MASK   (0xFF000000U)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3_SHIFT  (24U)
#define DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3_SHIFT)) & DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3_MASK)

/*! @name WR_DESKEW_CON6 -  */
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0_MASK   (0xFFU)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0_SHIFT  (0U)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0_SHIFT)) & DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0_MASK)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1_MASK   (0xFF00U)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1_SHIFT  (8U)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1_SHIFT)) & DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1_MASK)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2_MASK   (0xFF0000U)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2_SHIFT  (16U)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2_SHIFT)) & DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2_MASK)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3_MASK   (0xFF000000U)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3_SHIFT  (24U)
#define DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3_SHIFT)) & DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3_MASK)

/*! @name WR_DESKEW_CON9 -  */
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0_MASK   (0xFFU)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0_SHIFT  (0U)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0_SHIFT)) & DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0_MASK)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1_MASK   (0xFF00U)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1_SHIFT  (8U)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1_SHIFT)) & DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1_MASK)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2_MASK   (0xFF0000U)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2_SHIFT  (16U)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2_SHIFT)) & DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2_MASK)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3_MASK   (0xFF000000U)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3_SHIFT  (24U)
#define DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3(x)     (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3_SHIFT)) & DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3_MASK)

/*! @name WR_DESKEW_CON12 -  */
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0_MASK  (0xFFU)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0_SHIFT (0U)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0_SHIFT)) & DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0_MASK)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1_MASK  (0xFF00U)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1_SHIFT (8U)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1_SHIFT)) & DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1_MASK)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2_MASK  (0xFF0000U)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2_SHIFT (16U)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2_SHIFT)) & DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2_MASK)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3_MASK  (0xFF000000U)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3_SHIFT (24U)
#define DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3_SHIFT)) & DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3_MASK)

/*! @name WR_DESKEW_CON15 -  */
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0_MASK  (0xFFU)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0_SHIFT (0U)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0_SHIFT)) & DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0_MASK)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1_MASK  (0xFF00U)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1_SHIFT (8U)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1_SHIFT)) & DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1_MASK)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2_MASK  (0xFF0000U)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2_SHIFT (16U)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2_SHIFT)) & DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2_MASK)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3_MASK  (0xFF000000U)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3_SHIFT (24U)
#define DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3_SHIFT)) & DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3_MASK)

/*! @name WR_DESKEW_CON18 -  */
#define DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0_MASK  (0xFFU)
#define DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0_SHIFT (0U)
#define DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0_SHIFT)) & DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0_MASK)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1_MASK  (0xFF00U)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1_SHIFT (8U)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1_SHIFT)) & DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1_MASK)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2_MASK  (0xFF0000U)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2_SHIFT (16U)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2_SHIFT)) & DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2_MASK)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3_MASK  (0xFF000000U)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3_SHIFT (24U)
#define DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3_SHIFT)) & DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3_MASK)

/*! @name WR_DESKEW_CON21 -  */
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0_MASK  (0xFFU)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0_SHIFT (0U)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0_SHIFT)) & DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0_MASK)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1_MASK  (0xFF00U)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1_SHIFT (8U)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1_SHIFT)) & DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1_MASK)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2_MASK  (0xFF0000U)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2_SHIFT (16U)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2_SHIFT)) & DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2_MASK)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3_MASK  (0xFF000000U)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3_SHIFT (24U)
#define DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3(x)    (((uint32_t)(((uint32_t)(x)) << DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3_SHIFT)) & DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3_MASK)

/*! @name DM_DESKEW_CON -  */
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW0_MASK     (0xFFU)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW0_SHIFT    (0U)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW0(x)       (((uint32_t)(((uint32_t)(x)) << DDR_PHY_DM_DESKEW_CON_DMDESKEW0_SHIFT)) & DDR_PHY_DM_DESKEW_CON_DMDESKEW0_MASK)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW1_MASK     (0xFF00U)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW1_SHIFT    (8U)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW1(x)       (((uint32_t)(((uint32_t)(x)) << DDR_PHY_DM_DESKEW_CON_DMDESKEW1_SHIFT)) & DDR_PHY_DM_DESKEW_CON_DMDESKEW1_MASK)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW2_MASK     (0xFF0000U)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW2_SHIFT    (16U)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW2(x)       (((uint32_t)(((uint32_t)(x)) << DDR_PHY_DM_DESKEW_CON_DMDESKEW2_SHIFT)) & DDR_PHY_DM_DESKEW_CON_DMDESKEW2_MASK)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW3_MASK     (0xFF000000U)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW3_SHIFT    (24U)
#define DDR_PHY_DM_DESKEW_CON_DMDESKEW3(x)       (((uint32_t)(((uint32_t)(x)) << DDR_PHY_DM_DESKEW_CON_DMDESKEW3_SHIFT)) & DDR_PHY_DM_DESKEW_CON_DMDESKEW3_MASK)

/*! @name RDATA0 -  */
#define DDR_PHY_RDATA0_DQ_IO_RD0_MASK            (0xFFU)
#define DDR_PHY_RDATA0_DQ_IO_RD0_SHIFT           (0U)
#define DDR_PHY_RDATA0_DQ_IO_RD0(x)              (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RDATA0_DQ_IO_RD0_SHIFT)) & DDR_PHY_RDATA0_DQ_IO_RD0_MASK)
#define DDR_PHY_RDATA0_DQ_IO_RD1_MASK            (0xFF00U)
#define DDR_PHY_RDATA0_DQ_IO_RD1_SHIFT           (8U)
#define DDR_PHY_RDATA0_DQ_IO_RD1(x)              (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RDATA0_DQ_IO_RD1_SHIFT)) & DDR_PHY_RDATA0_DQ_IO_RD1_MASK)
#define DDR_PHY_RDATA0_DQ_IO_RD2_MASK            (0xFF0000U)
#define DDR_PHY_RDATA0_DQ_IO_RD2_SHIFT           (16U)
#define DDR_PHY_RDATA0_DQ_IO_RD2(x)              (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RDATA0_DQ_IO_RD2_SHIFT)) & DDR_PHY_RDATA0_DQ_IO_RD2_MASK)
#define DDR_PHY_RDATA0_DQ_IO_RD3_MASK            (0xFF000000U)
#define DDR_PHY_RDATA0_DQ_IO_RD3_SHIFT           (24U)
#define DDR_PHY_RDATA0_DQ_IO_RD3(x)              (((uint32_t)(((uint32_t)(x)) << DDR_PHY_RDATA0_DQ_IO_RD3_SHIFT)) & DDR_PHY_RDATA0_DQ_IO_RD3_MASK)

/*! @name STAT0 -  */
#define DDR_PHY_STAT0_VERSION_INFO_MASK          (0xFFFFFFFFU)
#define DDR_PHY_STAT0_VERSION_INFO_SHIFT         (0U)
#define DDR_PHY_STAT0_VERSION_INFO(x)            (((uint32_t)(((uint32_t)(x)) << DDR_PHY_STAT0_VERSION_INFO_SHIFT)) & DDR_PHY_STAT0_VERSION_INFO_MASK)


/*!
 * @}
 */ /* end of group DDR_PHY_Register_Masks */


/* DDR_PHY - Peripheral instance base addresses */
/** Peripheral DDR_PHY base pointer */
#define DDR_PHY_BASE_PTR                         ((DDR_PHY_MemMapPtr)0x30790000u)
/** Array initializer of DDR_PHY peripheral base pointers */
#define DDR_PHY_BASE_PTRS                        { DDR_PHY_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- DDR_PHY - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup DDR_PHY_Register_Accessor_Macros DDR_PHY - Register accessor macros
 * @{
 */


/* DDR_PHY - Register instance definitions */
/* DDR_PHY */
#define DDR_PHY_PHY_CON0                         DDR_PHY_PHY_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_PHY_CON1                         DDR_PHY_PHY_CON1_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_PHY_CON2                         DDR_PHY_PHY_CON2_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_PHY_CON3                         DDR_PHY_PHY_CON3_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_PHY_CON4                         DDR_PHY_PHY_CON4_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_PHY_CON5                         DDR_PHY_PHY_CON5_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_LP_CON0                          DDR_PHY_LP_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RODT_CON0                        DDR_PHY_RODT_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_OFFSET_RD_CON0                   DDR_PHY_OFFSET_RD_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_OFFSET_WR_CON0                   DDR_PHY_OFFSET_WR_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_GATE_CODE_CON0                   DDR_PHY_GATE_CODE_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_SHIFTC_CON0                      DDR_PHY_SHIFTC_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_CMD_SDLL_CON0                    DDR_PHY_CMD_SDLL_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_LVL_CON0                         DDR_PHY_LVL_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_LVL_CON3                         DDR_PHY_LVL_CON3_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_CMD_DESKEW_CON0                  DDR_PHY_CMD_DESKEW_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_CMD_DESKEW_CON1                  DDR_PHY_CMD_DESKEW_CON1_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_CMD_DESKEW_CON2                  DDR_PHY_CMD_DESKEW_CON2_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_CMD_DESKEW_CON3                  DDR_PHY_CMD_DESKEW_CON3_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_CMD_DESKEW_CON4                  DDR_PHY_CMD_DESKEW_CON4_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_DRVDS_CON0                       DDR_PHY_DRVDS_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_MDLL_CON0                        DDR_PHY_MDLL_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_MDLL_CON1                        DDR_PHY_MDLL_CON1_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_ZQ_CON0                          DDR_PHY_ZQ_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_ZQ_CON1                          DDR_PHY_ZQ_CON1_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_ZQ_CON2                          DDR_PHY_ZQ_CON2_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RD_DESKEW_CON0                   DDR_PHY_RD_DESKEW_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RD_DESKEW_CON3                   DDR_PHY_RD_DESKEW_CON3_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RD_DESKEW_CON6                   DDR_PHY_RD_DESKEW_CON6_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RD_DESKEW_CON9                   DDR_PHY_RD_DESKEW_CON9_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RD_DESKEW_CON12                  DDR_PHY_RD_DESKEW_CON12_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RD_DESKEW_CON15                  DDR_PHY_RD_DESKEW_CON15_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RD_DESKEW_CON18                  DDR_PHY_RD_DESKEW_CON18_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RD_DESKEW_CON21                  DDR_PHY_RD_DESKEW_CON21_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_WR_DESKEW_CON0                   DDR_PHY_WR_DESKEW_CON0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_WR_DESKEW_CON3                   DDR_PHY_WR_DESKEW_CON3_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_WR_DESKEW_CON6                   DDR_PHY_WR_DESKEW_CON6_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_WR_DESKEW_CON9                   DDR_PHY_WR_DESKEW_CON9_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_WR_DESKEW_CON12                  DDR_PHY_WR_DESKEW_CON12_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_WR_DESKEW_CON15                  DDR_PHY_WR_DESKEW_CON15_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_WR_DESKEW_CON18                  DDR_PHY_WR_DESKEW_CON18_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_WR_DESKEW_CON21                  DDR_PHY_WR_DESKEW_CON21_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_DM_DESKEW_CON                    DDR_PHY_DM_DESKEW_CON_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_RDATA0                           DDR_PHY_RDATA0_REG(DDR_PHY_BASE_PTR)
#define DDR_PHY_STAT0                            DDR_PHY_STAT0_REG(DDR_PHY_BASE_PTR)

/*!
 * @}
 */ /* end of group DDR_PHY_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group DDR_PHY_Peripheral */


/* ----------------------------------------------------------------------------
   -- ECSPI
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ECSPI_Peripheral ECSPI
 * @{
 */

/** ECSPI - Peripheral register structure */
typedef struct ECSPI_MemMap {
  uint32_t RXDATA;                                 /**< Receive Data Register, offset: 0x0 */
  uint32_t TXDATA;                                 /**< Transmit Data Register, offset: 0x4 */
  uint32_t CONREG;                                 /**< Control Register, offset: 0x8 */
  uint32_t CONFIGREG;                              /**< Config Register, offset: 0xC */
  uint32_t INTREG;                                 /**< Interrupt Control Register, offset: 0x10 */
  uint32_t DMAREG;                                 /**< DMA Control Register, offset: 0x14 */
  uint32_t STATREG;                                /**< Status Register, offset: 0x18 */
  uint32_t PERIODREG;                              /**< Sample Period Control Register, offset: 0x1C */
  uint32_t TESTREG;                                /**< Test Control Register, offset: 0x20 */
  uint8_t RESERVED_0[28];
  uint32_t MSGDATA;                                /**< Message Data Register, offset: 0x40 */
} volatile *ECSPI_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- ECSPI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ECSPI_Register_Accessor_Macros ECSPI - Register accessor macros
 * @{
 */


/* ECSPI - Register accessors */
#define ECSPI_RXDATA_REG(base)                   ((base)->RXDATA)
#define ECSPI_TXDATA_REG(base)                   ((base)->TXDATA)
#define ECSPI_CONREG_REG(base)                   ((base)->CONREG)
#define ECSPI_CONFIGREG_REG(base)                ((base)->CONFIGREG)
#define ECSPI_INTREG_REG(base)                   ((base)->INTREG)
#define ECSPI_DMAREG_REG(base)                   ((base)->DMAREG)
#define ECSPI_STATREG_REG(base)                  ((base)->STATREG)
#define ECSPI_PERIODREG_REG(base)                ((base)->PERIODREG)
#define ECSPI_TESTREG_REG(base)                  ((base)->TESTREG)
#define ECSPI_MSGDATA_REG(base)                  ((base)->MSGDATA)

/*!
 * @}
 */ /* end of group ECSPI_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- ECSPI Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ECSPI_Register_Masks ECSPI Register Masks
 * @{
 */

/*! @name RXDATA - Receive Data Register */
#define ECSPI_RXDATA_ECSPI_RXDATA_MASK           (0xFFFFFFFFU)
#define ECSPI_RXDATA_ECSPI_RXDATA_SHIFT          (0U)
#define ECSPI_RXDATA_ECSPI_RXDATA(x)             (((uint32_t)(((uint32_t)(x)) << ECSPI_RXDATA_ECSPI_RXDATA_SHIFT)) & ECSPI_RXDATA_ECSPI_RXDATA_MASK)

/*! @name TXDATA - Transmit Data Register */
#define ECSPI_TXDATA_ECSPI_TXDATA_MASK           (0xFFFFFFFFU)
#define ECSPI_TXDATA_ECSPI_TXDATA_SHIFT          (0U)
#define ECSPI_TXDATA_ECSPI_TXDATA(x)             (((uint32_t)(((uint32_t)(x)) << ECSPI_TXDATA_ECSPI_TXDATA_SHIFT)) & ECSPI_TXDATA_ECSPI_TXDATA_MASK)

/*! @name CONREG - Control Register */
#define ECSPI_CONREG_EN_MASK                     (0x1U)
#define ECSPI_CONREG_EN_SHIFT                    (0U)
#define ECSPI_CONREG_HT_MASK                     (0x2U)
#define ECSPI_CONREG_HT_SHIFT                    (1U)
#define ECSPI_CONREG_XCH_MASK                    (0x4U)
#define ECSPI_CONREG_XCH_SHIFT                   (2U)
#define ECSPI_CONREG_SMC_MASK                    (0x8U)
#define ECSPI_CONREG_SMC_SHIFT                   (3U)
#define ECSPI_CONREG_CHANNEL_MODE_MASK           (0xF0U)
#define ECSPI_CONREG_CHANNEL_MODE_SHIFT          (4U)
#define ECSPI_CONREG_CHANNEL_MODE(x)             (((uint32_t)(((uint32_t)(x)) << ECSPI_CONREG_CHANNEL_MODE_SHIFT)) & ECSPI_CONREG_CHANNEL_MODE_MASK)
#define ECSPI_CONREG_POST_DIVIDER_MASK           (0xF00U)
#define ECSPI_CONREG_POST_DIVIDER_SHIFT          (8U)
#define ECSPI_CONREG_POST_DIVIDER(x)             (((uint32_t)(((uint32_t)(x)) << ECSPI_CONREG_POST_DIVIDER_SHIFT)) & ECSPI_CONREG_POST_DIVIDER_MASK)
#define ECSPI_CONREG_PRE_DIVIDER_MASK            (0xF000U)
#define ECSPI_CONREG_PRE_DIVIDER_SHIFT           (12U)
#define ECSPI_CONREG_PRE_DIVIDER(x)              (((uint32_t)(((uint32_t)(x)) << ECSPI_CONREG_PRE_DIVIDER_SHIFT)) & ECSPI_CONREG_PRE_DIVIDER_MASK)
#define ECSPI_CONREG_DRCTL_MASK                  (0x30000U)
#define ECSPI_CONREG_DRCTL_SHIFT                 (16U)
#define ECSPI_CONREG_DRCTL(x)                    (((uint32_t)(((uint32_t)(x)) << ECSPI_CONREG_DRCTL_SHIFT)) & ECSPI_CONREG_DRCTL_MASK)
#define ECSPI_CONREG_CHANNEL_SELECT_MASK         (0xC0000U)
#define ECSPI_CONREG_CHANNEL_SELECT_SHIFT        (18U)
#define ECSPI_CONREG_CHANNEL_SELECT(x)           (((uint32_t)(((uint32_t)(x)) << ECSPI_CONREG_CHANNEL_SELECT_SHIFT)) & ECSPI_CONREG_CHANNEL_SELECT_MASK)
#define ECSPI_CONREG_BURST_LENGTH_MASK           (0xFFF00000U)
#define ECSPI_CONREG_BURST_LENGTH_SHIFT          (20U)
#define ECSPI_CONREG_BURST_LENGTH(x)             (((uint32_t)(((uint32_t)(x)) << ECSPI_CONREG_BURST_LENGTH_SHIFT)) & ECSPI_CONREG_BURST_LENGTH_MASK)

/*! @name CONFIGREG - Config Register */
#define ECSPI_CONFIGREG_SCLK_PHA_MASK            (0xFU)
#define ECSPI_CONFIGREG_SCLK_PHA_SHIFT           (0U)
#define ECSPI_CONFIGREG_SCLK_PHA(x)              (((uint32_t)(((uint32_t)(x)) << ECSPI_CONFIGREG_SCLK_PHA_SHIFT)) & ECSPI_CONFIGREG_SCLK_PHA_MASK)
#define ECSPI_CONFIGREG_SCLK_POL_MASK            (0xF0U)
#define ECSPI_CONFIGREG_SCLK_POL_SHIFT           (4U)
#define ECSPI_CONFIGREG_SCLK_POL(x)              (((uint32_t)(((uint32_t)(x)) << ECSPI_CONFIGREG_SCLK_POL_SHIFT)) & ECSPI_CONFIGREG_SCLK_POL_MASK)
#define ECSPI_CONFIGREG_SS_CTL_MASK              (0xF00U)
#define ECSPI_CONFIGREG_SS_CTL_SHIFT             (8U)
#define ECSPI_CONFIGREG_SS_CTL(x)                (((uint32_t)(((uint32_t)(x)) << ECSPI_CONFIGREG_SS_CTL_SHIFT)) & ECSPI_CONFIGREG_SS_CTL_MASK)
#define ECSPI_CONFIGREG_SS_POL_MASK              (0xF000U)
#define ECSPI_CONFIGREG_SS_POL_SHIFT             (12U)
#define ECSPI_CONFIGREG_SS_POL(x)                (((uint32_t)(((uint32_t)(x)) << ECSPI_CONFIGREG_SS_POL_SHIFT)) & ECSPI_CONFIGREG_SS_POL_MASK)
#define ECSPI_CONFIGREG_DATA_CTL_MASK            (0xF0000U)
#define ECSPI_CONFIGREG_DATA_CTL_SHIFT           (16U)
#define ECSPI_CONFIGREG_DATA_CTL(x)              (((uint32_t)(((uint32_t)(x)) << ECSPI_CONFIGREG_DATA_CTL_SHIFT)) & ECSPI_CONFIGREG_DATA_CTL_MASK)
#define ECSPI_CONFIGREG_SCLK_CTL_MASK            (0xF00000U)
#define ECSPI_CONFIGREG_SCLK_CTL_SHIFT           (20U)
#define ECSPI_CONFIGREG_SCLK_CTL(x)              (((uint32_t)(((uint32_t)(x)) << ECSPI_CONFIGREG_SCLK_CTL_SHIFT)) & ECSPI_CONFIGREG_SCLK_CTL_MASK)
#define ECSPI_CONFIGREG_HT_LENGTH_MASK           (0x1F000000U)
#define ECSPI_CONFIGREG_HT_LENGTH_SHIFT          (24U)
#define ECSPI_CONFIGREG_HT_LENGTH(x)             (((uint32_t)(((uint32_t)(x)) << ECSPI_CONFIGREG_HT_LENGTH_SHIFT)) & ECSPI_CONFIGREG_HT_LENGTH_MASK)

/*! @name INTREG - Interrupt Control Register */
#define ECSPI_INTREG_TEEN_MASK                   (0x1U)
#define ECSPI_INTREG_TEEN_SHIFT                  (0U)
#define ECSPI_INTREG_TDREN_MASK                  (0x2U)
#define ECSPI_INTREG_TDREN_SHIFT                 (1U)
#define ECSPI_INTREG_TFEN_MASK                   (0x4U)
#define ECSPI_INTREG_TFEN_SHIFT                  (2U)
#define ECSPI_INTREG_RREN_MASK                   (0x8U)
#define ECSPI_INTREG_RREN_SHIFT                  (3U)
#define ECSPI_INTREG_RDREN_MASK                  (0x10U)
#define ECSPI_INTREG_RDREN_SHIFT                 (4U)
#define ECSPI_INTREG_RFEN_MASK                   (0x20U)
#define ECSPI_INTREG_RFEN_SHIFT                  (5U)
#define ECSPI_INTREG_ROEN_MASK                   (0x40U)
#define ECSPI_INTREG_ROEN_SHIFT                  (6U)
#define ECSPI_INTREG_TCEN_MASK                   (0x80U)
#define ECSPI_INTREG_TCEN_SHIFT                  (7U)

/*! @name DMAREG - DMA Control Register */
#define ECSPI_DMAREG_TX_THRESHOLD_MASK           (0x3FU)
#define ECSPI_DMAREG_TX_THRESHOLD_SHIFT          (0U)
#define ECSPI_DMAREG_TX_THRESHOLD(x)             (((uint32_t)(((uint32_t)(x)) << ECSPI_DMAREG_TX_THRESHOLD_SHIFT)) & ECSPI_DMAREG_TX_THRESHOLD_MASK)
#define ECSPI_DMAREG_TEDEN_MASK                  (0x80U)
#define ECSPI_DMAREG_TEDEN_SHIFT                 (7U)
#define ECSPI_DMAREG_RX_THRESHOLD_MASK           (0x3F0000U)
#define ECSPI_DMAREG_RX_THRESHOLD_SHIFT          (16U)
#define ECSPI_DMAREG_RX_THRESHOLD(x)             (((uint32_t)(((uint32_t)(x)) << ECSPI_DMAREG_RX_THRESHOLD_SHIFT)) & ECSPI_DMAREG_RX_THRESHOLD_MASK)
#define ECSPI_DMAREG_RXDEN_MASK                  (0x800000U)
#define ECSPI_DMAREG_RXDEN_SHIFT                 (23U)
#define ECSPI_DMAREG_RX_DMA_LENGTH_MASK          (0x3F000000U)
#define ECSPI_DMAREG_RX_DMA_LENGTH_SHIFT         (24U)
#define ECSPI_DMAREG_RX_DMA_LENGTH(x)            (((uint32_t)(((uint32_t)(x)) << ECSPI_DMAREG_RX_DMA_LENGTH_SHIFT)) & ECSPI_DMAREG_RX_DMA_LENGTH_MASK)
#define ECSPI_DMAREG_RXTDEN_MASK                 (0x80000000U)
#define ECSPI_DMAREG_RXTDEN_SHIFT                (31U)

/*! @name STATREG - Status Register */
#define ECSPI_STATREG_TE_MASK                    (0x1U)
#define ECSPI_STATREG_TE_SHIFT                   (0U)
#define ECSPI_STATREG_TDR_MASK                   (0x2U)
#define ECSPI_STATREG_TDR_SHIFT                  (1U)
#define ECSPI_STATREG_TF_MASK                    (0x4U)
#define ECSPI_STATREG_TF_SHIFT                   (2U)
#define ECSPI_STATREG_RR_MASK                    (0x8U)
#define ECSPI_STATREG_RR_SHIFT                   (3U)
#define ECSPI_STATREG_RDR_MASK                   (0x10U)
#define ECSPI_STATREG_RDR_SHIFT                  (4U)
#define ECSPI_STATREG_RF_MASK                    (0x20U)
#define ECSPI_STATREG_RF_SHIFT                   (5U)
#define ECSPI_STATREG_RO_MASK                    (0x40U)
#define ECSPI_STATREG_RO_SHIFT                   (6U)
#define ECSPI_STATREG_TC_MASK                    (0x80U)
#define ECSPI_STATREG_TC_SHIFT                   (7U)

/*! @name PERIODREG - Sample Period Control Register */
#define ECSPI_PERIODREG_SAMPLE_PERIOD_MASK       (0x7FFFU)
#define ECSPI_PERIODREG_SAMPLE_PERIOD_SHIFT      (0U)
#define ECSPI_PERIODREG_SAMPLE_PERIOD(x)         (((uint32_t)(((uint32_t)(x)) << ECSPI_PERIODREG_SAMPLE_PERIOD_SHIFT)) & ECSPI_PERIODREG_SAMPLE_PERIOD_MASK)
#define ECSPI_PERIODREG_CSRC_MASK                (0x8000U)
#define ECSPI_PERIODREG_CSRC_SHIFT               (15U)
#define ECSPI_PERIODREG_CSD_CTL_MASK             (0x3F0000U)
#define ECSPI_PERIODREG_CSD_CTL_SHIFT            (16U)
#define ECSPI_PERIODREG_CSD_CTL(x)               (((uint32_t)(((uint32_t)(x)) << ECSPI_PERIODREG_CSD_CTL_SHIFT)) & ECSPI_PERIODREG_CSD_CTL_MASK)

/*! @name TESTREG - Test Control Register */
#define ECSPI_TESTREG_TXCNT_MASK                 (0x7FU)
#define ECSPI_TESTREG_TXCNT_SHIFT                (0U)
#define ECSPI_TESTREG_TXCNT(x)                   (((uint32_t)(((uint32_t)(x)) << ECSPI_TESTREG_TXCNT_SHIFT)) & ECSPI_TESTREG_TXCNT_MASK)
#define ECSPI_TESTREG_RXCNT_MASK                 (0x7F00U)
#define ECSPI_TESTREG_RXCNT_SHIFT                (8U)
#define ECSPI_TESTREG_RXCNT(x)                   (((uint32_t)(((uint32_t)(x)) << ECSPI_TESTREG_RXCNT_SHIFT)) & ECSPI_TESTREG_RXCNT_MASK)
#define ECSPI_TESTREG_LBC_MASK                   (0x80000000U)
#define ECSPI_TESTREG_LBC_SHIFT                  (31U)

/*! @name MSGDATA - Message Data Register */
#define ECSPI_MSGDATA_ECSPI_MSGDATA_MASK         (0xFFFFFFFFU)
#define ECSPI_MSGDATA_ECSPI_MSGDATA_SHIFT        (0U)
#define ECSPI_MSGDATA_ECSPI_MSGDATA(x)           (((uint32_t)(((uint32_t)(x)) << ECSPI_MSGDATA_ECSPI_MSGDATA_SHIFT)) & ECSPI_MSGDATA_ECSPI_MSGDATA_MASK)


/*!
 * @}
 */ /* end of group ECSPI_Register_Masks */


/* ECSPI - Peripheral instance base addresses */
/** Peripheral ECSPI1 base pointer */
#define ECSPI1_BASE_PTR                          ((ECSPI_MemMapPtr)0x30820000u)
/** Peripheral ECSPI2 base pointer */
#define ECSPI2_BASE_PTR                          ((ECSPI_MemMapPtr)0x30830000u)
/** Peripheral ECSPI3 base pointer */
#define ECSPI3_BASE_PTR                          ((ECSPI_MemMapPtr)0x30840000u)
/** Peripheral ECSPI4 base pointer */
#define ECSPI4_BASE_PTR                          ((ECSPI_MemMapPtr)0x30630000u)
/** Array initializer of ECSPI peripheral base pointers */
#define ECSPI_BASE_PTRS                          { ECSPI1_BASE_PTR, ECSPI2_BASE_PTR, ECSPI3_BASE_PTR, ECSPI4_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- ECSPI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ECSPI_Register_Accessor_Macros ECSPI - Register accessor macros
 * @{
 */


/* ECSPI - Register instance definitions */
/* ECSPI1 */
#define ECSPI1_RXDATA                            ECSPI_RXDATA_REG(ECSPI1_BASE_PTR)
#define ECSPI1_TXDATA                            ECSPI_TXDATA_REG(ECSPI1_BASE_PTR)
#define ECSPI1_CONREG                            ECSPI_CONREG_REG(ECSPI1_BASE_PTR)
#define ECSPI1_CONFIGREG                         ECSPI_CONFIGREG_REG(ECSPI1_BASE_PTR)
#define ECSPI1_INTREG                            ECSPI_INTREG_REG(ECSPI1_BASE_PTR)
#define ECSPI1_DMAREG                            ECSPI_DMAREG_REG(ECSPI1_BASE_PTR)
#define ECSPI1_STATREG                           ECSPI_STATREG_REG(ECSPI1_BASE_PTR)
#define ECSPI1_PERIODREG                         ECSPI_PERIODREG_REG(ECSPI1_BASE_PTR)
#define ECSPI1_TESTREG                           ECSPI_TESTREG_REG(ECSPI1_BASE_PTR)
#define ECSPI1_MSGDATA                           ECSPI_MSGDATA_REG(ECSPI1_BASE_PTR)
/* ECSPI2 */
#define ECSPI2_RXDATA                            ECSPI_RXDATA_REG(ECSPI2_BASE_PTR)
#define ECSPI2_TXDATA                            ECSPI_TXDATA_REG(ECSPI2_BASE_PTR)
#define ECSPI2_CONREG                            ECSPI_CONREG_REG(ECSPI2_BASE_PTR)
#define ECSPI2_CONFIGREG                         ECSPI_CONFIGREG_REG(ECSPI2_BASE_PTR)
#define ECSPI2_INTREG                            ECSPI_INTREG_REG(ECSPI2_BASE_PTR)
#define ECSPI2_DMAREG                            ECSPI_DMAREG_REG(ECSPI2_BASE_PTR)
#define ECSPI2_STATREG                           ECSPI_STATREG_REG(ECSPI2_BASE_PTR)
#define ECSPI2_PERIODREG                         ECSPI_PERIODREG_REG(ECSPI2_BASE_PTR)
#define ECSPI2_TESTREG                           ECSPI_TESTREG_REG(ECSPI2_BASE_PTR)
#define ECSPI2_MSGDATA                           ECSPI_MSGDATA_REG(ECSPI2_BASE_PTR)
/* ECSPI3 */
#define ECSPI3_RXDATA                            ECSPI_RXDATA_REG(ECSPI3_BASE_PTR)
#define ECSPI3_TXDATA                            ECSPI_TXDATA_REG(ECSPI3_BASE_PTR)
#define ECSPI3_CONREG                            ECSPI_CONREG_REG(ECSPI3_BASE_PTR)
#define ECSPI3_CONFIGREG                         ECSPI_CONFIGREG_REG(ECSPI3_BASE_PTR)
#define ECSPI3_INTREG                            ECSPI_INTREG_REG(ECSPI3_BASE_PTR)
#define ECSPI3_DMAREG                            ECSPI_DMAREG_REG(ECSPI3_BASE_PTR)
#define ECSPI3_STATREG                           ECSPI_STATREG_REG(ECSPI3_BASE_PTR)
#define ECSPI3_PERIODREG                         ECSPI_PERIODREG_REG(ECSPI3_BASE_PTR)
#define ECSPI3_TESTREG                           ECSPI_TESTREG_REG(ECSPI3_BASE_PTR)
#define ECSPI3_MSGDATA                           ECSPI_MSGDATA_REG(ECSPI3_BASE_PTR)
/* ECSPI4 */
#define ECSPI4_RXDATA                            ECSPI_RXDATA_REG(ECSPI4_BASE_PTR)
#define ECSPI4_TXDATA                            ECSPI_TXDATA_REG(ECSPI4_BASE_PTR)
#define ECSPI4_CONREG                            ECSPI_CONREG_REG(ECSPI4_BASE_PTR)
#define ECSPI4_CONFIGREG                         ECSPI_CONFIGREG_REG(ECSPI4_BASE_PTR)
#define ECSPI4_INTREG                            ECSPI_INTREG_REG(ECSPI4_BASE_PTR)
#define ECSPI4_DMAREG                            ECSPI_DMAREG_REG(ECSPI4_BASE_PTR)
#define ECSPI4_STATREG                           ECSPI_STATREG_REG(ECSPI4_BASE_PTR)
#define ECSPI4_PERIODREG                         ECSPI_PERIODREG_REG(ECSPI4_BASE_PTR)
#define ECSPI4_TESTREG                           ECSPI_TESTREG_REG(ECSPI4_BASE_PTR)
#define ECSPI4_MSGDATA                           ECSPI_MSGDATA_REG(ECSPI4_BASE_PTR)

/*!
 * @}
 */ /* end of group ECSPI_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group ECSPI_Peripheral */


/* ----------------------------------------------------------------------------
   -- EIM
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup EIM_Peripheral EIM
 * @{
 */

/** EIM - Peripheral register structure */
typedef struct EIM_MemMap {
  uint32_t CS0GCR1;                                /**< Chip Select n General Configuration Register 1, offset: 0x0 */
  uint32_t CS0GCR2;                                /**< Chip Select n General Configuration Register 2, offset: 0x4 */
  uint32_t CS0RCR1;                                /**< Chip Select n Read Configuration Register 1, offset: 0x8 */
  uint32_t CS0RCR2;                                /**< Chip Select n Read Configuration Register 2, offset: 0xC */
  uint32_t CS0WCR1;                                /**< Chip Select n Write Configuration Register 1, offset: 0x10 */
  uint32_t CS0WCR2;                                /**< Chip Select n Write Configuration Register 2, offset: 0x14 */
  uint32_t CS1GCR1;                                /**< Chip Select n General Configuration Register 1, offset: 0x18 */
  uint32_t CS1GCR2;                                /**< Chip Select n General Configuration Register 2, offset: 0x1C */
  uint32_t CS1RCR1;                                /**< Chip Select n Read Configuration Register 1, offset: 0x20 */
  uint32_t CS1RCR2;                                /**< Chip Select n Read Configuration Register 2, offset: 0x24 */
  uint32_t CS1WCR1;                                /**< Chip Select n Write Configuration Register 1, offset: 0x28 */
  uint32_t CS1WCR2;                                /**< Chip Select n Write Configuration Register 2, offset: 0x2C */
  uint32_t CS2GCR1;                                /**< Chip Select n General Configuration Register 1, offset: 0x30 */
  uint32_t CS2GCR2;                                /**< Chip Select n General Configuration Register 2, offset: 0x34 */
  uint32_t CS2RCR1;                                /**< Chip Select n Read Configuration Register 1, offset: 0x38 */
  uint32_t CS2RCR2;                                /**< Chip Select n Read Configuration Register 2, offset: 0x3C */
  uint32_t CS2WCR1;                                /**< Chip Select n Write Configuration Register 1, offset: 0x40 */
  uint32_t CS2WCR2;                                /**< Chip Select n Write Configuration Register 2, offset: 0x44 */
  uint32_t CS3GCR1;                                /**< Chip Select n General Configuration Register 1, offset: 0x48 */
  uint32_t CS3GCR2;                                /**< Chip Select n General Configuration Register 2, offset: 0x4C */
  uint32_t CS3RCR1;                                /**< Chip Select n Read Configuration Register 1, offset: 0x50 */
  uint32_t CS3RCR2;                                /**< Chip Select n Read Configuration Register 2, offset: 0x54 */
  uint32_t CS3WCR1;                                /**< Chip Select n Write Configuration Register 1, offset: 0x58 */
  uint32_t CS3WCR2;                                /**< Chip Select n Write Configuration Register 2, offset: 0x5C */
  uint32_t CS4GCR1;                                /**< Chip Select n General Configuration Register 1, offset: 0x60 */
  uint32_t CS4GCR2;                                /**< Chip Select n General Configuration Register 2, offset: 0x64 */
  uint32_t CS4RCR1;                                /**< Chip Select n Read Configuration Register 1, offset: 0x68 */
  uint32_t CS4RCR2;                                /**< Chip Select n Read Configuration Register 2, offset: 0x6C */
  uint32_t CS4WCR1;                                /**< Chip Select n Write Configuration Register 1, offset: 0x70 */
  uint32_t CS4WCR2;                                /**< Chip Select n Write Configuration Register 2, offset: 0x74 */
  uint32_t CS5GCR1;                                /**< Chip Select n General Configuration Register 1, offset: 0x78 */
  uint32_t CS5GCR2;                                /**< Chip Select n General Configuration Register 2, offset: 0x7C */
  uint32_t CS5RCR1;                                /**< Chip Select n Read Configuration Register 1, offset: 0x80 */
  uint32_t CS5RCR2;                                /**< Chip Select n Read Configuration Register 2, offset: 0x84 */
  uint32_t CS5WCR1;                                /**< Chip Select n Write Configuration Register 1, offset: 0x88 */
  uint32_t CS5WCR2;                                /**< Chip Select n Write Configuration Register 2, offset: 0x8C */
  uint32_t WCR;                                    /**< EIM Configuration Register, offset: 0x90 */
  uint32_t DCR;                                    /**< DLL Control Register, offset: 0x94 */
  uint32_t DSR;                                    /**< DLL Status Register, offset: 0x98 */
  uint32_t WIAR;                                   /**< EIM IP Access Register, offset: 0x9C */
  uint32_t EAR;                                    /**< Error Address Register, offset: 0xA0 */
} volatile *EIM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- EIM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup EIM_Register_Accessor_Macros EIM - Register accessor macros
 * @{
 */


/* EIM - Register accessors */
#define EIM_CS0GCR1_REG(base)                    ((base)->CS0GCR1)
#define EIM_CS0GCR2_REG(base)                    ((base)->CS0GCR2)
#define EIM_CS0RCR1_REG(base)                    ((base)->CS0RCR1)
#define EIM_CS0RCR2_REG(base)                    ((base)->CS0RCR2)
#define EIM_CS0WCR1_REG(base)                    ((base)->CS0WCR1)
#define EIM_CS0WCR2_REG(base)                    ((base)->CS0WCR2)
#define EIM_CS1GCR1_REG(base)                    ((base)->CS1GCR1)
#define EIM_CS1GCR2_REG(base)                    ((base)->CS1GCR2)
#define EIM_CS1RCR1_REG(base)                    ((base)->CS1RCR1)
#define EIM_CS1RCR2_REG(base)                    ((base)->CS1RCR2)
#define EIM_CS1WCR1_REG(base)                    ((base)->CS1WCR1)
#define EIM_CS1WCR2_REG(base)                    ((base)->CS1WCR2)
#define EIM_CS2GCR1_REG(base)                    ((base)->CS2GCR1)
#define EIM_CS2GCR2_REG(base)                    ((base)->CS2GCR2)
#define EIM_CS2RCR1_REG(base)                    ((base)->CS2RCR1)
#define EIM_CS2RCR2_REG(base)                    ((base)->CS2RCR2)
#define EIM_CS2WCR1_REG(base)                    ((base)->CS2WCR1)
#define EIM_CS2WCR2_REG(base)                    ((base)->CS2WCR2)
#define EIM_CS3GCR1_REG(base)                    ((base)->CS3GCR1)
#define EIM_CS3GCR2_REG(base)                    ((base)->CS3GCR2)
#define EIM_CS3RCR1_REG(base)                    ((base)->CS3RCR1)
#define EIM_CS3RCR2_REG(base)                    ((base)->CS3RCR2)
#define EIM_CS3WCR1_REG(base)                    ((base)->CS3WCR1)
#define EIM_CS3WCR2_REG(base)                    ((base)->CS3WCR2)
#define EIM_CS4GCR1_REG(base)                    ((base)->CS4GCR1)
#define EIM_CS4GCR2_REG(base)                    ((base)->CS4GCR2)
#define EIM_CS4RCR1_REG(base)                    ((base)->CS4RCR1)
#define EIM_CS4RCR2_REG(base)                    ((base)->CS4RCR2)
#define EIM_CS4WCR1_REG(base)                    ((base)->CS4WCR1)
#define EIM_CS4WCR2_REG(base)                    ((base)->CS4WCR2)
#define EIM_CS5GCR1_REG(base)                    ((base)->CS5GCR1)
#define EIM_CS5GCR2_REG(base)                    ((base)->CS5GCR2)
#define EIM_CS5RCR1_REG(base)                    ((base)->CS5RCR1)
#define EIM_CS5RCR2_REG(base)                    ((base)->CS5RCR2)
#define EIM_CS5WCR1_REG(base)                    ((base)->CS5WCR1)
#define EIM_CS5WCR2_REG(base)                    ((base)->CS5WCR2)
#define EIM_WCR_REG(base)                        ((base)->WCR)
#define EIM_DCR_REG(base)                        ((base)->DCR)
#define EIM_DSR_REG(base)                        ((base)->DSR)
#define EIM_WIAR_REG(base)                       ((base)->WIAR)
#define EIM_EAR_REG(base)                        ((base)->EAR)

/*!
 * @}
 */ /* end of group EIM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- EIM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup EIM_Register_Masks EIM Register Masks
 * @{
 */

/*! @name CS0GCR1 - Chip Select n General Configuration Register 1 */
#define EIM_CS0GCR1_CSEN_MASK                    (0x1U)
#define EIM_CS0GCR1_CSEN_SHIFT                   (0U)
#define EIM_CS0GCR1_SWR_MASK                     (0x2U)
#define EIM_CS0GCR1_SWR_SHIFT                    (1U)
#define EIM_CS0GCR1_SRD_MASK                     (0x4U)
#define EIM_CS0GCR1_SRD_SHIFT                    (2U)
#define EIM_CS0GCR1_MUM_MASK                     (0x8U)
#define EIM_CS0GCR1_MUM_SHIFT                    (3U)
#define EIM_CS0GCR1_WFL_MASK                     (0x10U)
#define EIM_CS0GCR1_WFL_SHIFT                    (4U)
#define EIM_CS0GCR1_RFL_MASK                     (0x20U)
#define EIM_CS0GCR1_RFL_SHIFT                    (5U)
#define EIM_CS0GCR1_CRE_MASK                     (0x40U)
#define EIM_CS0GCR1_CRE_SHIFT                    (6U)
#define EIM_CS0GCR1_CREP_MASK                    (0x80U)
#define EIM_CS0GCR1_CREP_SHIFT                   (7U)
#define EIM_CS0GCR1_BL_MASK                      (0x700U)
#define EIM_CS0GCR1_BL_SHIFT                     (8U)
#define EIM_CS0GCR1_BL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR1_BL_SHIFT)) & EIM_CS0GCR1_BL_MASK)
#define EIM_CS0GCR1_WC_MASK                      (0x800U)
#define EIM_CS0GCR1_WC_SHIFT                     (11U)
#define EIM_CS0GCR1_BCD_MASK                     (0x3000U)
#define EIM_CS0GCR1_BCD_SHIFT                    (12U)
#define EIM_CS0GCR1_BCD(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR1_BCD_SHIFT)) & EIM_CS0GCR1_BCD_MASK)
#define EIM_CS0GCR1_BCS_MASK                     (0xC000U)
#define EIM_CS0GCR1_BCS_SHIFT                    (14U)
#define EIM_CS0GCR1_BCS(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR1_BCS_SHIFT)) & EIM_CS0GCR1_BCS_MASK)
#define EIM_CS0GCR1_DSZ_MASK                     (0x70000U)
#define EIM_CS0GCR1_DSZ_SHIFT                    (16U)
#define EIM_CS0GCR1_DSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR1_DSZ_SHIFT)) & EIM_CS0GCR1_DSZ_MASK)
#define EIM_CS0GCR1_SP_MASK                      (0x80000U)
#define EIM_CS0GCR1_SP_SHIFT                     (19U)
#define EIM_CS0GCR1_CSREC_MASK                   (0x700000U)
#define EIM_CS0GCR1_CSREC_SHIFT                  (20U)
#define EIM_CS0GCR1_CSREC(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR1_CSREC_SHIFT)) & EIM_CS0GCR1_CSREC_MASK)
#define EIM_CS0GCR1_AUS_MASK                     (0x800000U)
#define EIM_CS0GCR1_AUS_SHIFT                    (23U)
#define EIM_CS0GCR1_GBC_MASK                     (0x7000000U)
#define EIM_CS0GCR1_GBC_SHIFT                    (24U)
#define EIM_CS0GCR1_GBC(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR1_GBC_SHIFT)) & EIM_CS0GCR1_GBC_MASK)
#define EIM_CS0GCR1_WP_MASK                      (0x8000000U)
#define EIM_CS0GCR1_WP_SHIFT                     (27U)
#define EIM_CS0GCR1_PSZ_MASK                     (0xF0000000U)
#define EIM_CS0GCR1_PSZ_SHIFT                    (28U)
#define EIM_CS0GCR1_PSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR1_PSZ_SHIFT)) & EIM_CS0GCR1_PSZ_MASK)

/*! @name CS0GCR2 - Chip Select n General Configuration Register 2 */
#define EIM_CS0GCR2_ADH_MASK                     (0x3U)
#define EIM_CS0GCR2_ADH_SHIFT                    (0U)
#define EIM_CS0GCR2_ADH(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR2_ADH_SHIFT)) & EIM_CS0GCR2_ADH_MASK)
#define EIM_CS0GCR2_DAPS_MASK                    (0xF0U)
#define EIM_CS0GCR2_DAPS_SHIFT                   (4U)
#define EIM_CS0GCR2_DAPS(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0GCR2_DAPS_SHIFT)) & EIM_CS0GCR2_DAPS_MASK)
#define EIM_CS0GCR2_DAE_MASK                     (0x100U)
#define EIM_CS0GCR2_DAE_SHIFT                    (8U)
#define EIM_CS0GCR2_DAP_MASK                     (0x200U)
#define EIM_CS0GCR2_DAP_SHIFT                    (9U)
#define EIM_CS0GCR2_MUX16_BYP_GRANT_MASK         (0x1000U)
#define EIM_CS0GCR2_MUX16_BYP_GRANT_SHIFT        (12U)

/*! @name CS0RCR1 - Chip Select n Read Configuration Register 1 */
#define EIM_CS0RCR1_RCSN_MASK                    (0x7U)
#define EIM_CS0RCR1_RCSN_SHIFT                   (0U)
#define EIM_CS0RCR1_RCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR1_RCSN_SHIFT)) & EIM_CS0RCR1_RCSN_MASK)
#define EIM_CS0RCR1_RCSA_MASK                    (0x70U)
#define EIM_CS0RCR1_RCSA_SHIFT                   (4U)
#define EIM_CS0RCR1_RCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR1_RCSA_SHIFT)) & EIM_CS0RCR1_RCSA_MASK)
#define EIM_CS0RCR1_OEN_MASK                     (0x700U)
#define EIM_CS0RCR1_OEN_SHIFT                    (8U)
#define EIM_CS0RCR1_OEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR1_OEN_SHIFT)) & EIM_CS0RCR1_OEN_MASK)
#define EIM_CS0RCR1_OEA_MASK                     (0x7000U)
#define EIM_CS0RCR1_OEA_SHIFT                    (12U)
#define EIM_CS0RCR1_OEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR1_OEA_SHIFT)) & EIM_CS0RCR1_OEA_MASK)
#define EIM_CS0RCR1_RADVN_MASK                   (0x70000U)
#define EIM_CS0RCR1_RADVN_SHIFT                  (16U)
#define EIM_CS0RCR1_RADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR1_RADVN_SHIFT)) & EIM_CS0RCR1_RADVN_MASK)
#define EIM_CS0RCR1_RAL_MASK                     (0x80000U)
#define EIM_CS0RCR1_RAL_SHIFT                    (19U)
#define EIM_CS0RCR1_RADVA_MASK                   (0x700000U)
#define EIM_CS0RCR1_RADVA_SHIFT                  (20U)
#define EIM_CS0RCR1_RADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR1_RADVA_SHIFT)) & EIM_CS0RCR1_RADVA_MASK)
#define EIM_CS0RCR1_RWSC_MASK                    (0x3F000000U)
#define EIM_CS0RCR1_RWSC_SHIFT                   (24U)
#define EIM_CS0RCR1_RWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR1_RWSC_SHIFT)) & EIM_CS0RCR1_RWSC_MASK)

/*! @name CS0RCR2 - Chip Select n Read Configuration Register 2 */
#define EIM_CS0RCR2_RBEN_MASK                    (0x7U)
#define EIM_CS0RCR2_RBEN_SHIFT                   (0U)
#define EIM_CS0RCR2_RBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR2_RBEN_SHIFT)) & EIM_CS0RCR2_RBEN_MASK)
#define EIM_CS0RCR2_RBE_MASK                     (0x8U)
#define EIM_CS0RCR2_RBE_SHIFT                    (3U)
#define EIM_CS0RCR2_RBEA_MASK                    (0x70U)
#define EIM_CS0RCR2_RBEA_SHIFT                   (4U)
#define EIM_CS0RCR2_RBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR2_RBEA_SHIFT)) & EIM_CS0RCR2_RBEA_MASK)
#define EIM_CS0RCR2_RL_MASK                      (0x300U)
#define EIM_CS0RCR2_RL_SHIFT                     (8U)
#define EIM_CS0RCR2_RL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR2_RL_SHIFT)) & EIM_CS0RCR2_RL_MASK)
#define EIM_CS0RCR2_PAT_MASK                     (0x7000U)
#define EIM_CS0RCR2_PAT_SHIFT                    (12U)
#define EIM_CS0RCR2_PAT(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0RCR2_PAT_SHIFT)) & EIM_CS0RCR2_PAT_MASK)
#define EIM_CS0RCR2_APR_MASK                     (0x8000U)
#define EIM_CS0RCR2_APR_SHIFT                    (15U)

/*! @name CS0WCR1 - Chip Select n Write Configuration Register 1 */
#define EIM_CS0WCR1_WCSN_MASK                    (0x7U)
#define EIM_CS0WCR1_WCSN_SHIFT                   (0U)
#define EIM_CS0WCR1_WCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WCSN_SHIFT)) & EIM_CS0WCR1_WCSN_MASK)
#define EIM_CS0WCR1_WCSA_MASK                    (0x38U)
#define EIM_CS0WCR1_WCSA_SHIFT                   (3U)
#define EIM_CS0WCR1_WCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WCSA_SHIFT)) & EIM_CS0WCR1_WCSA_MASK)
#define EIM_CS0WCR1_WEN_MASK                     (0x1C0U)
#define EIM_CS0WCR1_WEN_SHIFT                    (6U)
#define EIM_CS0WCR1_WEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WEN_SHIFT)) & EIM_CS0WCR1_WEN_MASK)
#define EIM_CS0WCR1_WEA_MASK                     (0xE00U)
#define EIM_CS0WCR1_WEA_SHIFT                    (9U)
#define EIM_CS0WCR1_WEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WEA_SHIFT)) & EIM_CS0WCR1_WEA_MASK)
#define EIM_CS0WCR1_WBEN_MASK                    (0x7000U)
#define EIM_CS0WCR1_WBEN_SHIFT                   (12U)
#define EIM_CS0WCR1_WBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WBEN_SHIFT)) & EIM_CS0WCR1_WBEN_MASK)
#define EIM_CS0WCR1_WBEA_MASK                    (0x38000U)
#define EIM_CS0WCR1_WBEA_SHIFT                   (15U)
#define EIM_CS0WCR1_WBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WBEA_SHIFT)) & EIM_CS0WCR1_WBEA_MASK)
#define EIM_CS0WCR1_WADVN_MASK                   (0x1C0000U)
#define EIM_CS0WCR1_WADVN_SHIFT                  (18U)
#define EIM_CS0WCR1_WADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WADVN_SHIFT)) & EIM_CS0WCR1_WADVN_MASK)
#define EIM_CS0WCR1_WADVA_MASK                   (0xE00000U)
#define EIM_CS0WCR1_WADVA_SHIFT                  (21U)
#define EIM_CS0WCR1_WADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WADVA_SHIFT)) & EIM_CS0WCR1_WADVA_MASK)
#define EIM_CS0WCR1_WWSC_MASK                    (0x3F000000U)
#define EIM_CS0WCR1_WWSC_SHIFT                   (24U)
#define EIM_CS0WCR1_WWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS0WCR1_WWSC_SHIFT)) & EIM_CS0WCR1_WWSC_MASK)
#define EIM_CS0WCR1_WBED_MASK                    (0x40000000U)
#define EIM_CS0WCR1_WBED_SHIFT                   (30U)
#define EIM_CS0WCR1_WAL_MASK                     (0x80000000U)
#define EIM_CS0WCR1_WAL_SHIFT                    (31U)

/*! @name CS0WCR2 - Chip Select n Write Configuration Register 2 */
#define EIM_CS0WCR2_WBCDD_MASK                   (0x1U)
#define EIM_CS0WCR2_WBCDD_SHIFT                  (0U)

/*! @name CS1GCR1 - Chip Select n General Configuration Register 1 */
#define EIM_CS1GCR1_CSEN_MASK                    (0x1U)
#define EIM_CS1GCR1_CSEN_SHIFT                   (0U)
#define EIM_CS1GCR1_SWR_MASK                     (0x2U)
#define EIM_CS1GCR1_SWR_SHIFT                    (1U)
#define EIM_CS1GCR1_SRD_MASK                     (0x4U)
#define EIM_CS1GCR1_SRD_SHIFT                    (2U)
#define EIM_CS1GCR1_MUM_MASK                     (0x8U)
#define EIM_CS1GCR1_MUM_SHIFT                    (3U)
#define EIM_CS1GCR1_WFL_MASK                     (0x10U)
#define EIM_CS1GCR1_WFL_SHIFT                    (4U)
#define EIM_CS1GCR1_RFL_MASK                     (0x20U)
#define EIM_CS1GCR1_RFL_SHIFT                    (5U)
#define EIM_CS1GCR1_CRE_MASK                     (0x40U)
#define EIM_CS1GCR1_CRE_SHIFT                    (6U)
#define EIM_CS1GCR1_CREP_MASK                    (0x80U)
#define EIM_CS1GCR1_CREP_SHIFT                   (7U)
#define EIM_CS1GCR1_BL_MASK                      (0x700U)
#define EIM_CS1GCR1_BL_SHIFT                     (8U)
#define EIM_CS1GCR1_BL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR1_BL_SHIFT)) & EIM_CS1GCR1_BL_MASK)
#define EIM_CS1GCR1_WC_MASK                      (0x800U)
#define EIM_CS1GCR1_WC_SHIFT                     (11U)
#define EIM_CS1GCR1_BCD_MASK                     (0x3000U)
#define EIM_CS1GCR1_BCD_SHIFT                    (12U)
#define EIM_CS1GCR1_BCD(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR1_BCD_SHIFT)) & EIM_CS1GCR1_BCD_MASK)
#define EIM_CS1GCR1_BCS_MASK                     (0xC000U)
#define EIM_CS1GCR1_BCS_SHIFT                    (14U)
#define EIM_CS1GCR1_BCS(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR1_BCS_SHIFT)) & EIM_CS1GCR1_BCS_MASK)
#define EIM_CS1GCR1_DSZ_MASK                     (0x70000U)
#define EIM_CS1GCR1_DSZ_SHIFT                    (16U)
#define EIM_CS1GCR1_DSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR1_DSZ_SHIFT)) & EIM_CS1GCR1_DSZ_MASK)
#define EIM_CS1GCR1_SP_MASK                      (0x80000U)
#define EIM_CS1GCR1_SP_SHIFT                     (19U)
#define EIM_CS1GCR1_CSREC_MASK                   (0x700000U)
#define EIM_CS1GCR1_CSREC_SHIFT                  (20U)
#define EIM_CS1GCR1_CSREC(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR1_CSREC_SHIFT)) & EIM_CS1GCR1_CSREC_MASK)
#define EIM_CS1GCR1_AUS_MASK                     (0x800000U)
#define EIM_CS1GCR1_AUS_SHIFT                    (23U)
#define EIM_CS1GCR1_GBC_MASK                     (0x7000000U)
#define EIM_CS1GCR1_GBC_SHIFT                    (24U)
#define EIM_CS1GCR1_GBC(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR1_GBC_SHIFT)) & EIM_CS1GCR1_GBC_MASK)
#define EIM_CS1GCR1_WP_MASK                      (0x8000000U)
#define EIM_CS1GCR1_WP_SHIFT                     (27U)
#define EIM_CS1GCR1_PSZ_MASK                     (0xF0000000U)
#define EIM_CS1GCR1_PSZ_SHIFT                    (28U)
#define EIM_CS1GCR1_PSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR1_PSZ_SHIFT)) & EIM_CS1GCR1_PSZ_MASK)

/*! @name CS1GCR2 - Chip Select n General Configuration Register 2 */
#define EIM_CS1GCR2_ADH_MASK                     (0x3U)
#define EIM_CS1GCR2_ADH_SHIFT                    (0U)
#define EIM_CS1GCR2_ADH(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR2_ADH_SHIFT)) & EIM_CS1GCR2_ADH_MASK)
#define EIM_CS1GCR2_DAPS_MASK                    (0xF0U)
#define EIM_CS1GCR2_DAPS_SHIFT                   (4U)
#define EIM_CS1GCR2_DAPS(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1GCR2_DAPS_SHIFT)) & EIM_CS1GCR2_DAPS_MASK)
#define EIM_CS1GCR2_DAE_MASK                     (0x100U)
#define EIM_CS1GCR2_DAE_SHIFT                    (8U)
#define EIM_CS1GCR2_DAP_MASK                     (0x200U)
#define EIM_CS1GCR2_DAP_SHIFT                    (9U)
#define EIM_CS1GCR2_MUX16_BYP_GRANT_MASK         (0x1000U)
#define EIM_CS1GCR2_MUX16_BYP_GRANT_SHIFT        (12U)

/*! @name CS1RCR1 - Chip Select n Read Configuration Register 1 */
#define EIM_CS1RCR1_RCSN_MASK                    (0x7U)
#define EIM_CS1RCR1_RCSN_SHIFT                   (0U)
#define EIM_CS1RCR1_RCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR1_RCSN_SHIFT)) & EIM_CS1RCR1_RCSN_MASK)
#define EIM_CS1RCR1_RCSA_MASK                    (0x70U)
#define EIM_CS1RCR1_RCSA_SHIFT                   (4U)
#define EIM_CS1RCR1_RCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR1_RCSA_SHIFT)) & EIM_CS1RCR1_RCSA_MASK)
#define EIM_CS1RCR1_OEN_MASK                     (0x700U)
#define EIM_CS1RCR1_OEN_SHIFT                    (8U)
#define EIM_CS1RCR1_OEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR1_OEN_SHIFT)) & EIM_CS1RCR1_OEN_MASK)
#define EIM_CS1RCR1_OEA_MASK                     (0x7000U)
#define EIM_CS1RCR1_OEA_SHIFT                    (12U)
#define EIM_CS1RCR1_OEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR1_OEA_SHIFT)) & EIM_CS1RCR1_OEA_MASK)
#define EIM_CS1RCR1_RADVN_MASK                   (0x70000U)
#define EIM_CS1RCR1_RADVN_SHIFT                  (16U)
#define EIM_CS1RCR1_RADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR1_RADVN_SHIFT)) & EIM_CS1RCR1_RADVN_MASK)
#define EIM_CS1RCR1_RAL_MASK                     (0x80000U)
#define EIM_CS1RCR1_RAL_SHIFT                    (19U)
#define EIM_CS1RCR1_RADVA_MASK                   (0x700000U)
#define EIM_CS1RCR1_RADVA_SHIFT                  (20U)
#define EIM_CS1RCR1_RADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR1_RADVA_SHIFT)) & EIM_CS1RCR1_RADVA_MASK)
#define EIM_CS1RCR1_RWSC_MASK                    (0x3F000000U)
#define EIM_CS1RCR1_RWSC_SHIFT                   (24U)
#define EIM_CS1RCR1_RWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR1_RWSC_SHIFT)) & EIM_CS1RCR1_RWSC_MASK)

/*! @name CS1RCR2 - Chip Select n Read Configuration Register 2 */
#define EIM_CS1RCR2_RBEN_MASK                    (0x7U)
#define EIM_CS1RCR2_RBEN_SHIFT                   (0U)
#define EIM_CS1RCR2_RBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR2_RBEN_SHIFT)) & EIM_CS1RCR2_RBEN_MASK)
#define EIM_CS1RCR2_RBE_MASK                     (0x8U)
#define EIM_CS1RCR2_RBE_SHIFT                    (3U)
#define EIM_CS1RCR2_RBEA_MASK                    (0x70U)
#define EIM_CS1RCR2_RBEA_SHIFT                   (4U)
#define EIM_CS1RCR2_RBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR2_RBEA_SHIFT)) & EIM_CS1RCR2_RBEA_MASK)
#define EIM_CS1RCR2_RL_MASK                      (0x300U)
#define EIM_CS1RCR2_RL_SHIFT                     (8U)
#define EIM_CS1RCR2_RL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR2_RL_SHIFT)) & EIM_CS1RCR2_RL_MASK)
#define EIM_CS1RCR2_PAT_MASK                     (0x7000U)
#define EIM_CS1RCR2_PAT_SHIFT                    (12U)
#define EIM_CS1RCR2_PAT(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1RCR2_PAT_SHIFT)) & EIM_CS1RCR2_PAT_MASK)
#define EIM_CS1RCR2_APR_MASK                     (0x8000U)
#define EIM_CS1RCR2_APR_SHIFT                    (15U)

/*! @name CS1WCR1 - Chip Select n Write Configuration Register 1 */
#define EIM_CS1WCR1_WCSN_MASK                    (0x7U)
#define EIM_CS1WCR1_WCSN_SHIFT                   (0U)
#define EIM_CS1WCR1_WCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WCSN_SHIFT)) & EIM_CS1WCR1_WCSN_MASK)
#define EIM_CS1WCR1_WCSA_MASK                    (0x38U)
#define EIM_CS1WCR1_WCSA_SHIFT                   (3U)
#define EIM_CS1WCR1_WCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WCSA_SHIFT)) & EIM_CS1WCR1_WCSA_MASK)
#define EIM_CS1WCR1_WEN_MASK                     (0x1C0U)
#define EIM_CS1WCR1_WEN_SHIFT                    (6U)
#define EIM_CS1WCR1_WEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WEN_SHIFT)) & EIM_CS1WCR1_WEN_MASK)
#define EIM_CS1WCR1_WEA_MASK                     (0xE00U)
#define EIM_CS1WCR1_WEA_SHIFT                    (9U)
#define EIM_CS1WCR1_WEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WEA_SHIFT)) & EIM_CS1WCR1_WEA_MASK)
#define EIM_CS1WCR1_WBEN_MASK                    (0x7000U)
#define EIM_CS1WCR1_WBEN_SHIFT                   (12U)
#define EIM_CS1WCR1_WBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WBEN_SHIFT)) & EIM_CS1WCR1_WBEN_MASK)
#define EIM_CS1WCR1_WBEA_MASK                    (0x38000U)
#define EIM_CS1WCR1_WBEA_SHIFT                   (15U)
#define EIM_CS1WCR1_WBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WBEA_SHIFT)) & EIM_CS1WCR1_WBEA_MASK)
#define EIM_CS1WCR1_WADVN_MASK                   (0x1C0000U)
#define EIM_CS1WCR1_WADVN_SHIFT                  (18U)
#define EIM_CS1WCR1_WADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WADVN_SHIFT)) & EIM_CS1WCR1_WADVN_MASK)
#define EIM_CS1WCR1_WADVA_MASK                   (0xE00000U)
#define EIM_CS1WCR1_WADVA_SHIFT                  (21U)
#define EIM_CS1WCR1_WADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WADVA_SHIFT)) & EIM_CS1WCR1_WADVA_MASK)
#define EIM_CS1WCR1_WWSC_MASK                    (0x3F000000U)
#define EIM_CS1WCR1_WWSC_SHIFT                   (24U)
#define EIM_CS1WCR1_WWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS1WCR1_WWSC_SHIFT)) & EIM_CS1WCR1_WWSC_MASK)
#define EIM_CS1WCR1_WBED_MASK                    (0x40000000U)
#define EIM_CS1WCR1_WBED_SHIFT                   (30U)
#define EIM_CS1WCR1_WAL_MASK                     (0x80000000U)
#define EIM_CS1WCR1_WAL_SHIFT                    (31U)

/*! @name CS1WCR2 - Chip Select n Write Configuration Register 2 */
#define EIM_CS1WCR2_WBCDD_MASK                   (0x1U)
#define EIM_CS1WCR2_WBCDD_SHIFT                  (0U)

/*! @name CS2GCR1 - Chip Select n General Configuration Register 1 */
#define EIM_CS2GCR1_CSEN_MASK                    (0x1U)
#define EIM_CS2GCR1_CSEN_SHIFT                   (0U)
#define EIM_CS2GCR1_SWR_MASK                     (0x2U)
#define EIM_CS2GCR1_SWR_SHIFT                    (1U)
#define EIM_CS2GCR1_SRD_MASK                     (0x4U)
#define EIM_CS2GCR1_SRD_SHIFT                    (2U)
#define EIM_CS2GCR1_MUM_MASK                     (0x8U)
#define EIM_CS2GCR1_MUM_SHIFT                    (3U)
#define EIM_CS2GCR1_WFL_MASK                     (0x10U)
#define EIM_CS2GCR1_WFL_SHIFT                    (4U)
#define EIM_CS2GCR1_RFL_MASK                     (0x20U)
#define EIM_CS2GCR1_RFL_SHIFT                    (5U)
#define EIM_CS2GCR1_CRE_MASK                     (0x40U)
#define EIM_CS2GCR1_CRE_SHIFT                    (6U)
#define EIM_CS2GCR1_CREP_MASK                    (0x80U)
#define EIM_CS2GCR1_CREP_SHIFT                   (7U)
#define EIM_CS2GCR1_BL_MASK                      (0x700U)
#define EIM_CS2GCR1_BL_SHIFT                     (8U)
#define EIM_CS2GCR1_BL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR1_BL_SHIFT)) & EIM_CS2GCR1_BL_MASK)
#define EIM_CS2GCR1_WC_MASK                      (0x800U)
#define EIM_CS2GCR1_WC_SHIFT                     (11U)
#define EIM_CS2GCR1_BCD_MASK                     (0x3000U)
#define EIM_CS2GCR1_BCD_SHIFT                    (12U)
#define EIM_CS2GCR1_BCD(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR1_BCD_SHIFT)) & EIM_CS2GCR1_BCD_MASK)
#define EIM_CS2GCR1_BCS_MASK                     (0xC000U)
#define EIM_CS2GCR1_BCS_SHIFT                    (14U)
#define EIM_CS2GCR1_BCS(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR1_BCS_SHIFT)) & EIM_CS2GCR1_BCS_MASK)
#define EIM_CS2GCR1_DSZ_MASK                     (0x70000U)
#define EIM_CS2GCR1_DSZ_SHIFT                    (16U)
#define EIM_CS2GCR1_DSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR1_DSZ_SHIFT)) & EIM_CS2GCR1_DSZ_MASK)
#define EIM_CS2GCR1_SP_MASK                      (0x80000U)
#define EIM_CS2GCR1_SP_SHIFT                     (19U)
#define EIM_CS2GCR1_CSREC_MASK                   (0x700000U)
#define EIM_CS2GCR1_CSREC_SHIFT                  (20U)
#define EIM_CS2GCR1_CSREC(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR1_CSREC_SHIFT)) & EIM_CS2GCR1_CSREC_MASK)
#define EIM_CS2GCR1_AUS_MASK                     (0x800000U)
#define EIM_CS2GCR1_AUS_SHIFT                    (23U)
#define EIM_CS2GCR1_GBC_MASK                     (0x7000000U)
#define EIM_CS2GCR1_GBC_SHIFT                    (24U)
#define EIM_CS2GCR1_GBC(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR1_GBC_SHIFT)) & EIM_CS2GCR1_GBC_MASK)
#define EIM_CS2GCR1_WP_MASK                      (0x8000000U)
#define EIM_CS2GCR1_WP_SHIFT                     (27U)
#define EIM_CS2GCR1_PSZ_MASK                     (0xF0000000U)
#define EIM_CS2GCR1_PSZ_SHIFT                    (28U)
#define EIM_CS2GCR1_PSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR1_PSZ_SHIFT)) & EIM_CS2GCR1_PSZ_MASK)

/*! @name CS2GCR2 - Chip Select n General Configuration Register 2 */
#define EIM_CS2GCR2_ADH_MASK                     (0x3U)
#define EIM_CS2GCR2_ADH_SHIFT                    (0U)
#define EIM_CS2GCR2_ADH(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR2_ADH_SHIFT)) & EIM_CS2GCR2_ADH_MASK)
#define EIM_CS2GCR2_DAPS_MASK                    (0xF0U)
#define EIM_CS2GCR2_DAPS_SHIFT                   (4U)
#define EIM_CS2GCR2_DAPS(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2GCR2_DAPS_SHIFT)) & EIM_CS2GCR2_DAPS_MASK)
#define EIM_CS2GCR2_DAE_MASK                     (0x100U)
#define EIM_CS2GCR2_DAE_SHIFT                    (8U)
#define EIM_CS2GCR2_DAP_MASK                     (0x200U)
#define EIM_CS2GCR2_DAP_SHIFT                    (9U)
#define EIM_CS2GCR2_MUX16_BYP_GRANT_MASK         (0x1000U)
#define EIM_CS2GCR2_MUX16_BYP_GRANT_SHIFT        (12U)

/*! @name CS2RCR1 - Chip Select n Read Configuration Register 1 */
#define EIM_CS2RCR1_RCSN_MASK                    (0x7U)
#define EIM_CS2RCR1_RCSN_SHIFT                   (0U)
#define EIM_CS2RCR1_RCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR1_RCSN_SHIFT)) & EIM_CS2RCR1_RCSN_MASK)
#define EIM_CS2RCR1_RCSA_MASK                    (0x70U)
#define EIM_CS2RCR1_RCSA_SHIFT                   (4U)
#define EIM_CS2RCR1_RCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR1_RCSA_SHIFT)) & EIM_CS2RCR1_RCSA_MASK)
#define EIM_CS2RCR1_OEN_MASK                     (0x700U)
#define EIM_CS2RCR1_OEN_SHIFT                    (8U)
#define EIM_CS2RCR1_OEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR1_OEN_SHIFT)) & EIM_CS2RCR1_OEN_MASK)
#define EIM_CS2RCR1_OEA_MASK                     (0x7000U)
#define EIM_CS2RCR1_OEA_SHIFT                    (12U)
#define EIM_CS2RCR1_OEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR1_OEA_SHIFT)) & EIM_CS2RCR1_OEA_MASK)
#define EIM_CS2RCR1_RADVN_MASK                   (0x70000U)
#define EIM_CS2RCR1_RADVN_SHIFT                  (16U)
#define EIM_CS2RCR1_RADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR1_RADVN_SHIFT)) & EIM_CS2RCR1_RADVN_MASK)
#define EIM_CS2RCR1_RAL_MASK                     (0x80000U)
#define EIM_CS2RCR1_RAL_SHIFT                    (19U)
#define EIM_CS2RCR1_RADVA_MASK                   (0x700000U)
#define EIM_CS2RCR1_RADVA_SHIFT                  (20U)
#define EIM_CS2RCR1_RADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR1_RADVA_SHIFT)) & EIM_CS2RCR1_RADVA_MASK)
#define EIM_CS2RCR1_RWSC_MASK                    (0x3F000000U)
#define EIM_CS2RCR1_RWSC_SHIFT                   (24U)
#define EIM_CS2RCR1_RWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR1_RWSC_SHIFT)) & EIM_CS2RCR1_RWSC_MASK)

/*! @name CS2RCR2 - Chip Select n Read Configuration Register 2 */
#define EIM_CS2RCR2_RBEN_MASK                    (0x7U)
#define EIM_CS2RCR2_RBEN_SHIFT                   (0U)
#define EIM_CS2RCR2_RBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR2_RBEN_SHIFT)) & EIM_CS2RCR2_RBEN_MASK)
#define EIM_CS2RCR2_RBE_MASK                     (0x8U)
#define EIM_CS2RCR2_RBE_SHIFT                    (3U)
#define EIM_CS2RCR2_RBEA_MASK                    (0x70U)
#define EIM_CS2RCR2_RBEA_SHIFT                   (4U)
#define EIM_CS2RCR2_RBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR2_RBEA_SHIFT)) & EIM_CS2RCR2_RBEA_MASK)
#define EIM_CS2RCR2_RL_MASK                      (0x300U)
#define EIM_CS2RCR2_RL_SHIFT                     (8U)
#define EIM_CS2RCR2_RL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR2_RL_SHIFT)) & EIM_CS2RCR2_RL_MASK)
#define EIM_CS2RCR2_PAT_MASK                     (0x7000U)
#define EIM_CS2RCR2_PAT_SHIFT                    (12U)
#define EIM_CS2RCR2_PAT(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2RCR2_PAT_SHIFT)) & EIM_CS2RCR2_PAT_MASK)
#define EIM_CS2RCR2_APR_MASK                     (0x8000U)
#define EIM_CS2RCR2_APR_SHIFT                    (15U)

/*! @name CS2WCR1 - Chip Select n Write Configuration Register 1 */
#define EIM_CS2WCR1_WCSN_MASK                    (0x7U)
#define EIM_CS2WCR1_WCSN_SHIFT                   (0U)
#define EIM_CS2WCR1_WCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WCSN_SHIFT)) & EIM_CS2WCR1_WCSN_MASK)
#define EIM_CS2WCR1_WCSA_MASK                    (0x38U)
#define EIM_CS2WCR1_WCSA_SHIFT                   (3U)
#define EIM_CS2WCR1_WCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WCSA_SHIFT)) & EIM_CS2WCR1_WCSA_MASK)
#define EIM_CS2WCR1_WEN_MASK                     (0x1C0U)
#define EIM_CS2WCR1_WEN_SHIFT                    (6U)
#define EIM_CS2WCR1_WEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WEN_SHIFT)) & EIM_CS2WCR1_WEN_MASK)
#define EIM_CS2WCR1_WEA_MASK                     (0xE00U)
#define EIM_CS2WCR1_WEA_SHIFT                    (9U)
#define EIM_CS2WCR1_WEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WEA_SHIFT)) & EIM_CS2WCR1_WEA_MASK)
#define EIM_CS2WCR1_WBEN_MASK                    (0x7000U)
#define EIM_CS2WCR1_WBEN_SHIFT                   (12U)
#define EIM_CS2WCR1_WBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WBEN_SHIFT)) & EIM_CS2WCR1_WBEN_MASK)
#define EIM_CS2WCR1_WBEA_MASK                    (0x38000U)
#define EIM_CS2WCR1_WBEA_SHIFT                   (15U)
#define EIM_CS2WCR1_WBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WBEA_SHIFT)) & EIM_CS2WCR1_WBEA_MASK)
#define EIM_CS2WCR1_WADVN_MASK                   (0x1C0000U)
#define EIM_CS2WCR1_WADVN_SHIFT                  (18U)
#define EIM_CS2WCR1_WADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WADVN_SHIFT)) & EIM_CS2WCR1_WADVN_MASK)
#define EIM_CS2WCR1_WADVA_MASK                   (0xE00000U)
#define EIM_CS2WCR1_WADVA_SHIFT                  (21U)
#define EIM_CS2WCR1_WADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WADVA_SHIFT)) & EIM_CS2WCR1_WADVA_MASK)
#define EIM_CS2WCR1_WWSC_MASK                    (0x3F000000U)
#define EIM_CS2WCR1_WWSC_SHIFT                   (24U)
#define EIM_CS2WCR1_WWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS2WCR1_WWSC_SHIFT)) & EIM_CS2WCR1_WWSC_MASK)
#define EIM_CS2WCR1_WBED_MASK                    (0x40000000U)
#define EIM_CS2WCR1_WBED_SHIFT                   (30U)
#define EIM_CS2WCR1_WAL_MASK                     (0x80000000U)
#define EIM_CS2WCR1_WAL_SHIFT                    (31U)

/*! @name CS2WCR2 - Chip Select n Write Configuration Register 2 */
#define EIM_CS2WCR2_WBCDD_MASK                   (0x1U)
#define EIM_CS2WCR2_WBCDD_SHIFT                  (0U)

/*! @name CS3GCR1 - Chip Select n General Configuration Register 1 */
#define EIM_CS3GCR1_CSEN_MASK                    (0x1U)
#define EIM_CS3GCR1_CSEN_SHIFT                   (0U)
#define EIM_CS3GCR1_SWR_MASK                     (0x2U)
#define EIM_CS3GCR1_SWR_SHIFT                    (1U)
#define EIM_CS3GCR1_SRD_MASK                     (0x4U)
#define EIM_CS3GCR1_SRD_SHIFT                    (2U)
#define EIM_CS3GCR1_MUM_MASK                     (0x8U)
#define EIM_CS3GCR1_MUM_SHIFT                    (3U)
#define EIM_CS3GCR1_WFL_MASK                     (0x10U)
#define EIM_CS3GCR1_WFL_SHIFT                    (4U)
#define EIM_CS3GCR1_RFL_MASK                     (0x20U)
#define EIM_CS3GCR1_RFL_SHIFT                    (5U)
#define EIM_CS3GCR1_CRE_MASK                     (0x40U)
#define EIM_CS3GCR1_CRE_SHIFT                    (6U)
#define EIM_CS3GCR1_CREP_MASK                    (0x80U)
#define EIM_CS3GCR1_CREP_SHIFT                   (7U)
#define EIM_CS3GCR1_BL_MASK                      (0x700U)
#define EIM_CS3GCR1_BL_SHIFT                     (8U)
#define EIM_CS3GCR1_BL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR1_BL_SHIFT)) & EIM_CS3GCR1_BL_MASK)
#define EIM_CS3GCR1_WC_MASK                      (0x800U)
#define EIM_CS3GCR1_WC_SHIFT                     (11U)
#define EIM_CS3GCR1_BCD_MASK                     (0x3000U)
#define EIM_CS3GCR1_BCD_SHIFT                    (12U)
#define EIM_CS3GCR1_BCD(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR1_BCD_SHIFT)) & EIM_CS3GCR1_BCD_MASK)
#define EIM_CS3GCR1_BCS_MASK                     (0xC000U)
#define EIM_CS3GCR1_BCS_SHIFT                    (14U)
#define EIM_CS3GCR1_BCS(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR1_BCS_SHIFT)) & EIM_CS3GCR1_BCS_MASK)
#define EIM_CS3GCR1_DSZ_MASK                     (0x70000U)
#define EIM_CS3GCR1_DSZ_SHIFT                    (16U)
#define EIM_CS3GCR1_DSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR1_DSZ_SHIFT)) & EIM_CS3GCR1_DSZ_MASK)
#define EIM_CS3GCR1_SP_MASK                      (0x80000U)
#define EIM_CS3GCR1_SP_SHIFT                     (19U)
#define EIM_CS3GCR1_CSREC_MASK                   (0x700000U)
#define EIM_CS3GCR1_CSREC_SHIFT                  (20U)
#define EIM_CS3GCR1_CSREC(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR1_CSREC_SHIFT)) & EIM_CS3GCR1_CSREC_MASK)
#define EIM_CS3GCR1_AUS_MASK                     (0x800000U)
#define EIM_CS3GCR1_AUS_SHIFT                    (23U)
#define EIM_CS3GCR1_GBC_MASK                     (0x7000000U)
#define EIM_CS3GCR1_GBC_SHIFT                    (24U)
#define EIM_CS3GCR1_GBC(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR1_GBC_SHIFT)) & EIM_CS3GCR1_GBC_MASK)
#define EIM_CS3GCR1_WP_MASK                      (0x8000000U)
#define EIM_CS3GCR1_WP_SHIFT                     (27U)
#define EIM_CS3GCR1_PSZ_MASK                     (0xF0000000U)
#define EIM_CS3GCR1_PSZ_SHIFT                    (28U)
#define EIM_CS3GCR1_PSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR1_PSZ_SHIFT)) & EIM_CS3GCR1_PSZ_MASK)

/*! @name CS3GCR2 - Chip Select n General Configuration Register 2 */
#define EIM_CS3GCR2_ADH_MASK                     (0x3U)
#define EIM_CS3GCR2_ADH_SHIFT                    (0U)
#define EIM_CS3GCR2_ADH(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR2_ADH_SHIFT)) & EIM_CS3GCR2_ADH_MASK)
#define EIM_CS3GCR2_DAPS_MASK                    (0xF0U)
#define EIM_CS3GCR2_DAPS_SHIFT                   (4U)
#define EIM_CS3GCR2_DAPS(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3GCR2_DAPS_SHIFT)) & EIM_CS3GCR2_DAPS_MASK)
#define EIM_CS3GCR2_DAE_MASK                     (0x100U)
#define EIM_CS3GCR2_DAE_SHIFT                    (8U)
#define EIM_CS3GCR2_DAP_MASK                     (0x200U)
#define EIM_CS3GCR2_DAP_SHIFT                    (9U)
#define EIM_CS3GCR2_MUX16_BYP_GRANT_MASK         (0x1000U)
#define EIM_CS3GCR2_MUX16_BYP_GRANT_SHIFT        (12U)

/*! @name CS3RCR1 - Chip Select n Read Configuration Register 1 */
#define EIM_CS3RCR1_RCSN_MASK                    (0x7U)
#define EIM_CS3RCR1_RCSN_SHIFT                   (0U)
#define EIM_CS3RCR1_RCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR1_RCSN_SHIFT)) & EIM_CS3RCR1_RCSN_MASK)
#define EIM_CS3RCR1_RCSA_MASK                    (0x70U)
#define EIM_CS3RCR1_RCSA_SHIFT                   (4U)
#define EIM_CS3RCR1_RCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR1_RCSA_SHIFT)) & EIM_CS3RCR1_RCSA_MASK)
#define EIM_CS3RCR1_OEN_MASK                     (0x700U)
#define EIM_CS3RCR1_OEN_SHIFT                    (8U)
#define EIM_CS3RCR1_OEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR1_OEN_SHIFT)) & EIM_CS3RCR1_OEN_MASK)
#define EIM_CS3RCR1_OEA_MASK                     (0x7000U)
#define EIM_CS3RCR1_OEA_SHIFT                    (12U)
#define EIM_CS3RCR1_OEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR1_OEA_SHIFT)) & EIM_CS3RCR1_OEA_MASK)
#define EIM_CS3RCR1_RADVN_MASK                   (0x70000U)
#define EIM_CS3RCR1_RADVN_SHIFT                  (16U)
#define EIM_CS3RCR1_RADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR1_RADVN_SHIFT)) & EIM_CS3RCR1_RADVN_MASK)
#define EIM_CS3RCR1_RAL_MASK                     (0x80000U)
#define EIM_CS3RCR1_RAL_SHIFT                    (19U)
#define EIM_CS3RCR1_RADVA_MASK                   (0x700000U)
#define EIM_CS3RCR1_RADVA_SHIFT                  (20U)
#define EIM_CS3RCR1_RADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR1_RADVA_SHIFT)) & EIM_CS3RCR1_RADVA_MASK)
#define EIM_CS3RCR1_RWSC_MASK                    (0x3F000000U)
#define EIM_CS3RCR1_RWSC_SHIFT                   (24U)
#define EIM_CS3RCR1_RWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR1_RWSC_SHIFT)) & EIM_CS3RCR1_RWSC_MASK)

/*! @name CS3RCR2 - Chip Select n Read Configuration Register 2 */
#define EIM_CS3RCR2_RBEN_MASK                    (0x7U)
#define EIM_CS3RCR2_RBEN_SHIFT                   (0U)
#define EIM_CS3RCR2_RBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR2_RBEN_SHIFT)) & EIM_CS3RCR2_RBEN_MASK)
#define EIM_CS3RCR2_RBE_MASK                     (0x8U)
#define EIM_CS3RCR2_RBE_SHIFT                    (3U)
#define EIM_CS3RCR2_RBEA_MASK                    (0x70U)
#define EIM_CS3RCR2_RBEA_SHIFT                   (4U)
#define EIM_CS3RCR2_RBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR2_RBEA_SHIFT)) & EIM_CS3RCR2_RBEA_MASK)
#define EIM_CS3RCR2_RL_MASK                      (0x300U)
#define EIM_CS3RCR2_RL_SHIFT                     (8U)
#define EIM_CS3RCR2_RL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR2_RL_SHIFT)) & EIM_CS3RCR2_RL_MASK)
#define EIM_CS3RCR2_PAT_MASK                     (0x7000U)
#define EIM_CS3RCR2_PAT_SHIFT                    (12U)
#define EIM_CS3RCR2_PAT(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3RCR2_PAT_SHIFT)) & EIM_CS3RCR2_PAT_MASK)
#define EIM_CS3RCR2_APR_MASK                     (0x8000U)
#define EIM_CS3RCR2_APR_SHIFT                    (15U)

/*! @name CS3WCR1 - Chip Select n Write Configuration Register 1 */
#define EIM_CS3WCR1_WCSN_MASK                    (0x7U)
#define EIM_CS3WCR1_WCSN_SHIFT                   (0U)
#define EIM_CS3WCR1_WCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WCSN_SHIFT)) & EIM_CS3WCR1_WCSN_MASK)
#define EIM_CS3WCR1_WCSA_MASK                    (0x38U)
#define EIM_CS3WCR1_WCSA_SHIFT                   (3U)
#define EIM_CS3WCR1_WCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WCSA_SHIFT)) & EIM_CS3WCR1_WCSA_MASK)
#define EIM_CS3WCR1_WEN_MASK                     (0x1C0U)
#define EIM_CS3WCR1_WEN_SHIFT                    (6U)
#define EIM_CS3WCR1_WEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WEN_SHIFT)) & EIM_CS3WCR1_WEN_MASK)
#define EIM_CS3WCR1_WEA_MASK                     (0xE00U)
#define EIM_CS3WCR1_WEA_SHIFT                    (9U)
#define EIM_CS3WCR1_WEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WEA_SHIFT)) & EIM_CS3WCR1_WEA_MASK)
#define EIM_CS3WCR1_WBEN_MASK                    (0x7000U)
#define EIM_CS3WCR1_WBEN_SHIFT                   (12U)
#define EIM_CS3WCR1_WBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WBEN_SHIFT)) & EIM_CS3WCR1_WBEN_MASK)
#define EIM_CS3WCR1_WBEA_MASK                    (0x38000U)
#define EIM_CS3WCR1_WBEA_SHIFT                   (15U)
#define EIM_CS3WCR1_WBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WBEA_SHIFT)) & EIM_CS3WCR1_WBEA_MASK)
#define EIM_CS3WCR1_WADVN_MASK                   (0x1C0000U)
#define EIM_CS3WCR1_WADVN_SHIFT                  (18U)
#define EIM_CS3WCR1_WADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WADVN_SHIFT)) & EIM_CS3WCR1_WADVN_MASK)
#define EIM_CS3WCR1_WADVA_MASK                   (0xE00000U)
#define EIM_CS3WCR1_WADVA_SHIFT                  (21U)
#define EIM_CS3WCR1_WADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WADVA_SHIFT)) & EIM_CS3WCR1_WADVA_MASK)
#define EIM_CS3WCR1_WWSC_MASK                    (0x3F000000U)
#define EIM_CS3WCR1_WWSC_SHIFT                   (24U)
#define EIM_CS3WCR1_WWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS3WCR1_WWSC_SHIFT)) & EIM_CS3WCR1_WWSC_MASK)
#define EIM_CS3WCR1_WBED_MASK                    (0x40000000U)
#define EIM_CS3WCR1_WBED_SHIFT                   (30U)
#define EIM_CS3WCR1_WAL_MASK                     (0x80000000U)
#define EIM_CS3WCR1_WAL_SHIFT                    (31U)

/*! @name CS3WCR2 - Chip Select n Write Configuration Register 2 */
#define EIM_CS3WCR2_WBCDD_MASK                   (0x1U)
#define EIM_CS3WCR2_WBCDD_SHIFT                  (0U)

/*! @name CS4GCR1 - Chip Select n General Configuration Register 1 */
#define EIM_CS4GCR1_CSEN_MASK                    (0x1U)
#define EIM_CS4GCR1_CSEN_SHIFT                   (0U)
#define EIM_CS4GCR1_SWR_MASK                     (0x2U)
#define EIM_CS4GCR1_SWR_SHIFT                    (1U)
#define EIM_CS4GCR1_SRD_MASK                     (0x4U)
#define EIM_CS4GCR1_SRD_SHIFT                    (2U)
#define EIM_CS4GCR1_MUM_MASK                     (0x8U)
#define EIM_CS4GCR1_MUM_SHIFT                    (3U)
#define EIM_CS4GCR1_WFL_MASK                     (0x10U)
#define EIM_CS4GCR1_WFL_SHIFT                    (4U)
#define EIM_CS4GCR1_RFL_MASK                     (0x20U)
#define EIM_CS4GCR1_RFL_SHIFT                    (5U)
#define EIM_CS4GCR1_CRE_MASK                     (0x40U)
#define EIM_CS4GCR1_CRE_SHIFT                    (6U)
#define EIM_CS4GCR1_CREP_MASK                    (0x80U)
#define EIM_CS4GCR1_CREP_SHIFT                   (7U)
#define EIM_CS4GCR1_BL_MASK                      (0x700U)
#define EIM_CS4GCR1_BL_SHIFT                     (8U)
#define EIM_CS4GCR1_BL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR1_BL_SHIFT)) & EIM_CS4GCR1_BL_MASK)
#define EIM_CS4GCR1_WC_MASK                      (0x800U)
#define EIM_CS4GCR1_WC_SHIFT                     (11U)
#define EIM_CS4GCR1_BCD_MASK                     (0x3000U)
#define EIM_CS4GCR1_BCD_SHIFT                    (12U)
#define EIM_CS4GCR1_BCD(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR1_BCD_SHIFT)) & EIM_CS4GCR1_BCD_MASK)
#define EIM_CS4GCR1_BCS_MASK                     (0xC000U)
#define EIM_CS4GCR1_BCS_SHIFT                    (14U)
#define EIM_CS4GCR1_BCS(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR1_BCS_SHIFT)) & EIM_CS4GCR1_BCS_MASK)
#define EIM_CS4GCR1_DSZ_MASK                     (0x70000U)
#define EIM_CS4GCR1_DSZ_SHIFT                    (16U)
#define EIM_CS4GCR1_DSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR1_DSZ_SHIFT)) & EIM_CS4GCR1_DSZ_MASK)
#define EIM_CS4GCR1_SP_MASK                      (0x80000U)
#define EIM_CS4GCR1_SP_SHIFT                     (19U)
#define EIM_CS4GCR1_CSREC_MASK                   (0x700000U)
#define EIM_CS4GCR1_CSREC_SHIFT                  (20U)
#define EIM_CS4GCR1_CSREC(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR1_CSREC_SHIFT)) & EIM_CS4GCR1_CSREC_MASK)
#define EIM_CS4GCR1_AUS_MASK                     (0x800000U)
#define EIM_CS4GCR1_AUS_SHIFT                    (23U)
#define EIM_CS4GCR1_GBC_MASK                     (0x7000000U)
#define EIM_CS4GCR1_GBC_SHIFT                    (24U)
#define EIM_CS4GCR1_GBC(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR1_GBC_SHIFT)) & EIM_CS4GCR1_GBC_MASK)
#define EIM_CS4GCR1_WP_MASK                      (0x8000000U)
#define EIM_CS4GCR1_WP_SHIFT                     (27U)
#define EIM_CS4GCR1_PSZ_MASK                     (0xF0000000U)
#define EIM_CS4GCR1_PSZ_SHIFT                    (28U)
#define EIM_CS4GCR1_PSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR1_PSZ_SHIFT)) & EIM_CS4GCR1_PSZ_MASK)

/*! @name CS4GCR2 - Chip Select n General Configuration Register 2 */
#define EIM_CS4GCR2_ADH_MASK                     (0x3U)
#define EIM_CS4GCR2_ADH_SHIFT                    (0U)
#define EIM_CS4GCR2_ADH(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR2_ADH_SHIFT)) & EIM_CS4GCR2_ADH_MASK)
#define EIM_CS4GCR2_DAPS_MASK                    (0xF0U)
#define EIM_CS4GCR2_DAPS_SHIFT                   (4U)
#define EIM_CS4GCR2_DAPS(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4GCR2_DAPS_SHIFT)) & EIM_CS4GCR2_DAPS_MASK)
#define EIM_CS4GCR2_DAE_MASK                     (0x100U)
#define EIM_CS4GCR2_DAE_SHIFT                    (8U)
#define EIM_CS4GCR2_DAP_MASK                     (0x200U)
#define EIM_CS4GCR2_DAP_SHIFT                    (9U)
#define EIM_CS4GCR2_MUX16_BYP_GRANT_MASK         (0x1000U)
#define EIM_CS4GCR2_MUX16_BYP_GRANT_SHIFT        (12U)

/*! @name CS4RCR1 - Chip Select n Read Configuration Register 1 */
#define EIM_CS4RCR1_RCSN_MASK                    (0x7U)
#define EIM_CS4RCR1_RCSN_SHIFT                   (0U)
#define EIM_CS4RCR1_RCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR1_RCSN_SHIFT)) & EIM_CS4RCR1_RCSN_MASK)
#define EIM_CS4RCR1_RCSA_MASK                    (0x70U)
#define EIM_CS4RCR1_RCSA_SHIFT                   (4U)
#define EIM_CS4RCR1_RCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR1_RCSA_SHIFT)) & EIM_CS4RCR1_RCSA_MASK)
#define EIM_CS4RCR1_OEN_MASK                     (0x700U)
#define EIM_CS4RCR1_OEN_SHIFT                    (8U)
#define EIM_CS4RCR1_OEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR1_OEN_SHIFT)) & EIM_CS4RCR1_OEN_MASK)
#define EIM_CS4RCR1_OEA_MASK                     (0x7000U)
#define EIM_CS4RCR1_OEA_SHIFT                    (12U)
#define EIM_CS4RCR1_OEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR1_OEA_SHIFT)) & EIM_CS4RCR1_OEA_MASK)
#define EIM_CS4RCR1_RADVN_MASK                   (0x70000U)
#define EIM_CS4RCR1_RADVN_SHIFT                  (16U)
#define EIM_CS4RCR1_RADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR1_RADVN_SHIFT)) & EIM_CS4RCR1_RADVN_MASK)
#define EIM_CS4RCR1_RAL_MASK                     (0x80000U)
#define EIM_CS4RCR1_RAL_SHIFT                    (19U)
#define EIM_CS4RCR1_RADVA_MASK                   (0x700000U)
#define EIM_CS4RCR1_RADVA_SHIFT                  (20U)
#define EIM_CS4RCR1_RADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR1_RADVA_SHIFT)) & EIM_CS4RCR1_RADVA_MASK)
#define EIM_CS4RCR1_RWSC_MASK                    (0x3F000000U)
#define EIM_CS4RCR1_RWSC_SHIFT                   (24U)
#define EIM_CS4RCR1_RWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR1_RWSC_SHIFT)) & EIM_CS4RCR1_RWSC_MASK)

/*! @name CS4RCR2 - Chip Select n Read Configuration Register 2 */
#define EIM_CS4RCR2_RBEN_MASK                    (0x7U)
#define EIM_CS4RCR2_RBEN_SHIFT                   (0U)
#define EIM_CS4RCR2_RBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR2_RBEN_SHIFT)) & EIM_CS4RCR2_RBEN_MASK)
#define EIM_CS4RCR2_RBE_MASK                     (0x8U)
#define EIM_CS4RCR2_RBE_SHIFT                    (3U)
#define EIM_CS4RCR2_RBEA_MASK                    (0x70U)
#define EIM_CS4RCR2_RBEA_SHIFT                   (4U)
#define EIM_CS4RCR2_RBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR2_RBEA_SHIFT)) & EIM_CS4RCR2_RBEA_MASK)
#define EIM_CS4RCR2_RL_MASK                      (0x300U)
#define EIM_CS4RCR2_RL_SHIFT                     (8U)
#define EIM_CS4RCR2_RL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR2_RL_SHIFT)) & EIM_CS4RCR2_RL_MASK)
#define EIM_CS4RCR2_PAT_MASK                     (0x7000U)
#define EIM_CS4RCR2_PAT_SHIFT                    (12U)
#define EIM_CS4RCR2_PAT(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4RCR2_PAT_SHIFT)) & EIM_CS4RCR2_PAT_MASK)
#define EIM_CS4RCR2_APR_MASK                     (0x8000U)
#define EIM_CS4RCR2_APR_SHIFT                    (15U)

/*! @name CS4WCR1 - Chip Select n Write Configuration Register 1 */
#define EIM_CS4WCR1_WCSN_MASK                    (0x7U)
#define EIM_CS4WCR1_WCSN_SHIFT                   (0U)
#define EIM_CS4WCR1_WCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WCSN_SHIFT)) & EIM_CS4WCR1_WCSN_MASK)
#define EIM_CS4WCR1_WCSA_MASK                    (0x38U)
#define EIM_CS4WCR1_WCSA_SHIFT                   (3U)
#define EIM_CS4WCR1_WCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WCSA_SHIFT)) & EIM_CS4WCR1_WCSA_MASK)
#define EIM_CS4WCR1_WEN_MASK                     (0x1C0U)
#define EIM_CS4WCR1_WEN_SHIFT                    (6U)
#define EIM_CS4WCR1_WEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WEN_SHIFT)) & EIM_CS4WCR1_WEN_MASK)
#define EIM_CS4WCR1_WEA_MASK                     (0xE00U)
#define EIM_CS4WCR1_WEA_SHIFT                    (9U)
#define EIM_CS4WCR1_WEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WEA_SHIFT)) & EIM_CS4WCR1_WEA_MASK)
#define EIM_CS4WCR1_WBEN_MASK                    (0x7000U)
#define EIM_CS4WCR1_WBEN_SHIFT                   (12U)
#define EIM_CS4WCR1_WBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WBEN_SHIFT)) & EIM_CS4WCR1_WBEN_MASK)
#define EIM_CS4WCR1_WBEA_MASK                    (0x38000U)
#define EIM_CS4WCR1_WBEA_SHIFT                   (15U)
#define EIM_CS4WCR1_WBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WBEA_SHIFT)) & EIM_CS4WCR1_WBEA_MASK)
#define EIM_CS4WCR1_WADVN_MASK                   (0x1C0000U)
#define EIM_CS4WCR1_WADVN_SHIFT                  (18U)
#define EIM_CS4WCR1_WADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WADVN_SHIFT)) & EIM_CS4WCR1_WADVN_MASK)
#define EIM_CS4WCR1_WADVA_MASK                   (0xE00000U)
#define EIM_CS4WCR1_WADVA_SHIFT                  (21U)
#define EIM_CS4WCR1_WADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WADVA_SHIFT)) & EIM_CS4WCR1_WADVA_MASK)
#define EIM_CS4WCR1_WWSC_MASK                    (0x3F000000U)
#define EIM_CS4WCR1_WWSC_SHIFT                   (24U)
#define EIM_CS4WCR1_WWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS4WCR1_WWSC_SHIFT)) & EIM_CS4WCR1_WWSC_MASK)
#define EIM_CS4WCR1_WBED_MASK                    (0x40000000U)
#define EIM_CS4WCR1_WBED_SHIFT                   (30U)
#define EIM_CS4WCR1_WAL_MASK                     (0x80000000U)
#define EIM_CS4WCR1_WAL_SHIFT                    (31U)

/*! @name CS4WCR2 - Chip Select n Write Configuration Register 2 */
#define EIM_CS4WCR2_WBCDD_MASK                   (0x1U)
#define EIM_CS4WCR2_WBCDD_SHIFT                  (0U)

/*! @name CS5GCR1 - Chip Select n General Configuration Register 1 */
#define EIM_CS5GCR1_CSEN_MASK                    (0x1U)
#define EIM_CS5GCR1_CSEN_SHIFT                   (0U)
#define EIM_CS5GCR1_SWR_MASK                     (0x2U)
#define EIM_CS5GCR1_SWR_SHIFT                    (1U)
#define EIM_CS5GCR1_SRD_MASK                     (0x4U)
#define EIM_CS5GCR1_SRD_SHIFT                    (2U)
#define EIM_CS5GCR1_MUM_MASK                     (0x8U)
#define EIM_CS5GCR1_MUM_SHIFT                    (3U)
#define EIM_CS5GCR1_WFL_MASK                     (0x10U)
#define EIM_CS5GCR1_WFL_SHIFT                    (4U)
#define EIM_CS5GCR1_RFL_MASK                     (0x20U)
#define EIM_CS5GCR1_RFL_SHIFT                    (5U)
#define EIM_CS5GCR1_CRE_MASK                     (0x40U)
#define EIM_CS5GCR1_CRE_SHIFT                    (6U)
#define EIM_CS5GCR1_CREP_MASK                    (0x80U)
#define EIM_CS5GCR1_CREP_SHIFT                   (7U)
#define EIM_CS5GCR1_BL_MASK                      (0x700U)
#define EIM_CS5GCR1_BL_SHIFT                     (8U)
#define EIM_CS5GCR1_BL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR1_BL_SHIFT)) & EIM_CS5GCR1_BL_MASK)
#define EIM_CS5GCR1_WC_MASK                      (0x800U)
#define EIM_CS5GCR1_WC_SHIFT                     (11U)
#define EIM_CS5GCR1_BCD_MASK                     (0x3000U)
#define EIM_CS5GCR1_BCD_SHIFT                    (12U)
#define EIM_CS5GCR1_BCD(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR1_BCD_SHIFT)) & EIM_CS5GCR1_BCD_MASK)
#define EIM_CS5GCR1_BCS_MASK                     (0xC000U)
#define EIM_CS5GCR1_BCS_SHIFT                    (14U)
#define EIM_CS5GCR1_BCS(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR1_BCS_SHIFT)) & EIM_CS5GCR1_BCS_MASK)
#define EIM_CS5GCR1_DSZ_MASK                     (0x70000U)
#define EIM_CS5GCR1_DSZ_SHIFT                    (16U)
#define EIM_CS5GCR1_DSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR1_DSZ_SHIFT)) & EIM_CS5GCR1_DSZ_MASK)
#define EIM_CS5GCR1_SP_MASK                      (0x80000U)
#define EIM_CS5GCR1_SP_SHIFT                     (19U)
#define EIM_CS5GCR1_CSREC_MASK                   (0x700000U)
#define EIM_CS5GCR1_CSREC_SHIFT                  (20U)
#define EIM_CS5GCR1_CSREC(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR1_CSREC_SHIFT)) & EIM_CS5GCR1_CSREC_MASK)
#define EIM_CS5GCR1_AUS_MASK                     (0x800000U)
#define EIM_CS5GCR1_AUS_SHIFT                    (23U)
#define EIM_CS5GCR1_GBC_MASK                     (0x7000000U)
#define EIM_CS5GCR1_GBC_SHIFT                    (24U)
#define EIM_CS5GCR1_GBC(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR1_GBC_SHIFT)) & EIM_CS5GCR1_GBC_MASK)
#define EIM_CS5GCR1_WP_MASK                      (0x8000000U)
#define EIM_CS5GCR1_WP_SHIFT                     (27U)
#define EIM_CS5GCR1_PSZ_MASK                     (0xF0000000U)
#define EIM_CS5GCR1_PSZ_SHIFT                    (28U)
#define EIM_CS5GCR1_PSZ(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR1_PSZ_SHIFT)) & EIM_CS5GCR1_PSZ_MASK)

/*! @name CS5GCR2 - Chip Select n General Configuration Register 2 */
#define EIM_CS5GCR2_ADH_MASK                     (0x3U)
#define EIM_CS5GCR2_ADH_SHIFT                    (0U)
#define EIM_CS5GCR2_ADH(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR2_ADH_SHIFT)) & EIM_CS5GCR2_ADH_MASK)
#define EIM_CS5GCR2_DAPS_MASK                    (0xF0U)
#define EIM_CS5GCR2_DAPS_SHIFT                   (4U)
#define EIM_CS5GCR2_DAPS(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5GCR2_DAPS_SHIFT)) & EIM_CS5GCR2_DAPS_MASK)
#define EIM_CS5GCR2_DAE_MASK                     (0x100U)
#define EIM_CS5GCR2_DAE_SHIFT                    (8U)
#define EIM_CS5GCR2_DAP_MASK                     (0x200U)
#define EIM_CS5GCR2_DAP_SHIFT                    (9U)
#define EIM_CS5GCR2_MUX16_BYP_GRANT_MASK         (0x1000U)
#define EIM_CS5GCR2_MUX16_BYP_GRANT_SHIFT        (12U)

/*! @name CS5RCR1 - Chip Select n Read Configuration Register 1 */
#define EIM_CS5RCR1_RCSN_MASK                    (0x7U)
#define EIM_CS5RCR1_RCSN_SHIFT                   (0U)
#define EIM_CS5RCR1_RCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR1_RCSN_SHIFT)) & EIM_CS5RCR1_RCSN_MASK)
#define EIM_CS5RCR1_RCSA_MASK                    (0x70U)
#define EIM_CS5RCR1_RCSA_SHIFT                   (4U)
#define EIM_CS5RCR1_RCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR1_RCSA_SHIFT)) & EIM_CS5RCR1_RCSA_MASK)
#define EIM_CS5RCR1_OEN_MASK                     (0x700U)
#define EIM_CS5RCR1_OEN_SHIFT                    (8U)
#define EIM_CS5RCR1_OEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR1_OEN_SHIFT)) & EIM_CS5RCR1_OEN_MASK)
#define EIM_CS5RCR1_OEA_MASK                     (0x7000U)
#define EIM_CS5RCR1_OEA_SHIFT                    (12U)
#define EIM_CS5RCR1_OEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR1_OEA_SHIFT)) & EIM_CS5RCR1_OEA_MASK)
#define EIM_CS5RCR1_RADVN_MASK                   (0x70000U)
#define EIM_CS5RCR1_RADVN_SHIFT                  (16U)
#define EIM_CS5RCR1_RADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR1_RADVN_SHIFT)) & EIM_CS5RCR1_RADVN_MASK)
#define EIM_CS5RCR1_RAL_MASK                     (0x80000U)
#define EIM_CS5RCR1_RAL_SHIFT                    (19U)
#define EIM_CS5RCR1_RADVA_MASK                   (0x700000U)
#define EIM_CS5RCR1_RADVA_SHIFT                  (20U)
#define EIM_CS5RCR1_RADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR1_RADVA_SHIFT)) & EIM_CS5RCR1_RADVA_MASK)
#define EIM_CS5RCR1_RWSC_MASK                    (0x3F000000U)
#define EIM_CS5RCR1_RWSC_SHIFT                   (24U)
#define EIM_CS5RCR1_RWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR1_RWSC_SHIFT)) & EIM_CS5RCR1_RWSC_MASK)

/*! @name CS5RCR2 - Chip Select n Read Configuration Register 2 */
#define EIM_CS5RCR2_RBEN_MASK                    (0x7U)
#define EIM_CS5RCR2_RBEN_SHIFT                   (0U)
#define EIM_CS5RCR2_RBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR2_RBEN_SHIFT)) & EIM_CS5RCR2_RBEN_MASK)
#define EIM_CS5RCR2_RBE_MASK                     (0x8U)
#define EIM_CS5RCR2_RBE_SHIFT                    (3U)
#define EIM_CS5RCR2_RBEA_MASK                    (0x70U)
#define EIM_CS5RCR2_RBEA_SHIFT                   (4U)
#define EIM_CS5RCR2_RBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR2_RBEA_SHIFT)) & EIM_CS5RCR2_RBEA_MASK)
#define EIM_CS5RCR2_RL_MASK                      (0x300U)
#define EIM_CS5RCR2_RL_SHIFT                     (8U)
#define EIM_CS5RCR2_RL(x)                        (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR2_RL_SHIFT)) & EIM_CS5RCR2_RL_MASK)
#define EIM_CS5RCR2_PAT_MASK                     (0x7000U)
#define EIM_CS5RCR2_PAT_SHIFT                    (12U)
#define EIM_CS5RCR2_PAT(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5RCR2_PAT_SHIFT)) & EIM_CS5RCR2_PAT_MASK)
#define EIM_CS5RCR2_APR_MASK                     (0x8000U)
#define EIM_CS5RCR2_APR_SHIFT                    (15U)

/*! @name CS5WCR1 - Chip Select n Write Configuration Register 1 */
#define EIM_CS5WCR1_WCSN_MASK                    (0x7U)
#define EIM_CS5WCR1_WCSN_SHIFT                   (0U)
#define EIM_CS5WCR1_WCSN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WCSN_SHIFT)) & EIM_CS5WCR1_WCSN_MASK)
#define EIM_CS5WCR1_WCSA_MASK                    (0x38U)
#define EIM_CS5WCR1_WCSA_SHIFT                   (3U)
#define EIM_CS5WCR1_WCSA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WCSA_SHIFT)) & EIM_CS5WCR1_WCSA_MASK)
#define EIM_CS5WCR1_WEN_MASK                     (0x1C0U)
#define EIM_CS5WCR1_WEN_SHIFT                    (6U)
#define EIM_CS5WCR1_WEN(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WEN_SHIFT)) & EIM_CS5WCR1_WEN_MASK)
#define EIM_CS5WCR1_WEA_MASK                     (0xE00U)
#define EIM_CS5WCR1_WEA_SHIFT                    (9U)
#define EIM_CS5WCR1_WEA(x)                       (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WEA_SHIFT)) & EIM_CS5WCR1_WEA_MASK)
#define EIM_CS5WCR1_WBEN_MASK                    (0x7000U)
#define EIM_CS5WCR1_WBEN_SHIFT                   (12U)
#define EIM_CS5WCR1_WBEN(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WBEN_SHIFT)) & EIM_CS5WCR1_WBEN_MASK)
#define EIM_CS5WCR1_WBEA_MASK                    (0x38000U)
#define EIM_CS5WCR1_WBEA_SHIFT                   (15U)
#define EIM_CS5WCR1_WBEA(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WBEA_SHIFT)) & EIM_CS5WCR1_WBEA_MASK)
#define EIM_CS5WCR1_WADVN_MASK                   (0x1C0000U)
#define EIM_CS5WCR1_WADVN_SHIFT                  (18U)
#define EIM_CS5WCR1_WADVN(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WADVN_SHIFT)) & EIM_CS5WCR1_WADVN_MASK)
#define EIM_CS5WCR1_WADVA_MASK                   (0xE00000U)
#define EIM_CS5WCR1_WADVA_SHIFT                  (21U)
#define EIM_CS5WCR1_WADVA(x)                     (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WADVA_SHIFT)) & EIM_CS5WCR1_WADVA_MASK)
#define EIM_CS5WCR1_WWSC_MASK                    (0x3F000000U)
#define EIM_CS5WCR1_WWSC_SHIFT                   (24U)
#define EIM_CS5WCR1_WWSC(x)                      (((uint32_t)(((uint32_t)(x)) << EIM_CS5WCR1_WWSC_SHIFT)) & EIM_CS5WCR1_WWSC_MASK)
#define EIM_CS5WCR1_WBED_MASK                    (0x40000000U)
#define EIM_CS5WCR1_WBED_SHIFT                   (30U)
#define EIM_CS5WCR1_WAL_MASK                     (0x80000000U)
#define EIM_CS5WCR1_WAL_SHIFT                    (31U)

/*! @name CS5WCR2 - Chip Select n Write Configuration Register 2 */
#define EIM_CS5WCR2_WBCDD_MASK                   (0x1U)
#define EIM_CS5WCR2_WBCDD_SHIFT                  (0U)

/*! @name WCR - EIM Configuration Register */
#define EIM_WCR_BCM_MASK                         (0x1U)
#define EIM_WCR_BCM_SHIFT                        (0U)
#define EIM_WCR_GBCD_MASK                        (0x6U)
#define EIM_WCR_GBCD_SHIFT                       (1U)
#define EIM_WCR_GBCD(x)                          (((uint32_t)(((uint32_t)(x)) << EIM_WCR_GBCD_SHIFT)) & EIM_WCR_GBCD_MASK)
#define EIM_WCR_CONT_BCLK_SEL_MASK               (0x8U)
#define EIM_WCR_CONT_BCLK_SEL_SHIFT              (3U)
#define EIM_WCR_INTEN_MASK                       (0x10U)
#define EIM_WCR_INTEN_SHIFT                      (4U)
#define EIM_WCR_INTPOL_MASK                      (0x20U)
#define EIM_WCR_INTPOL_SHIFT                     (5U)
#define EIM_WCR_WDOG_EN_MASK                     (0x100U)
#define EIM_WCR_WDOG_EN_SHIFT                    (8U)
#define EIM_WCR_WDOG_LIMIT_MASK                  (0x600U)
#define EIM_WCR_WDOG_LIMIT_SHIFT                 (9U)
#define EIM_WCR_WDOG_LIMIT(x)                    (((uint32_t)(((uint32_t)(x)) << EIM_WCR_WDOG_LIMIT_SHIFT)) & EIM_WCR_WDOG_LIMIT_MASK)
#define EIM_WCR_FRUN_ACLK_EN_MASK                (0x800U)
#define EIM_WCR_FRUN_ACLK_EN_SHIFT               (11U)

/*! @name DCR - DLL Control Register */
#define EIM_DCR_DLL_CTRL_ENABLE_MASK             (0x1U)
#define EIM_DCR_DLL_CTRL_ENABLE_SHIFT            (0U)
#define EIM_DCR_DLL_CTRL_RESET_MASK              (0x2U)
#define EIM_DCR_DLL_CTRL_RESET_SHIFT             (1U)
#define EIM_DCR_DLL_CTRL_SLV_FORCE_UPD_MASK      (0x4U)
#define EIM_DCR_DLL_CTRL_SLV_FORCE_UPD_SHIFT     (2U)
#define EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC_MASK     (0x8U)
#define EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC_SHIFT    (3U)
#define EIM_DCR_DLL_CTRL_SLV_OFFSET_MASK         (0x70U)
#define EIM_DCR_DLL_CTRL_SLV_OFFSET_SHIFT        (4U)
#define EIM_DCR_DLL_CTRL_SLV_OFFSET(x)           (((uint32_t)(((uint32_t)(x)) << EIM_DCR_DLL_CTRL_SLV_OFFSET_SHIFT)) & EIM_DCR_DLL_CTRL_SLV_OFFSET_MASK)
#define EIM_DCR_DLL_CTRL_GATE_UPDATE_MASK        (0x80U)
#define EIM_DCR_DLL_CTRL_GATE_UPDATE_SHIFT       (7U)
#define EIM_DCR_DLL_CTRL_SLV_OVERRIDE_MASK       (0x100U)
#define EIM_DCR_DLL_CTRL_SLV_OVERRIDE_SHIFT      (8U)
#define EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL_MASK   (0xFE00U)
#define EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT  (9U)
#define EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(x)     (((uint32_t)(((uint32_t)(x)) << EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT)) & EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL_MASK)
#define EIM_DCR_DLL_CTRL_REF_INITIAL_VAL_MASK    (0x7F0000U)
#define EIM_DCR_DLL_CTRL_REF_INITIAL_VAL_SHIFT   (16U)
#define EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(x)      (((uint32_t)(((uint32_t)(x)) << EIM_DCR_DLL_CTRL_REF_INITIAL_VAL_SHIFT)) & EIM_DCR_DLL_CTRL_REF_INITIAL_VAL_MASK)
#define EIM_DCR_DLL_CTRL_SLV_UPDATE_INT_MASK     (0xF800000U)
#define EIM_DCR_DLL_CTRL_SLV_UPDATE_INT_SHIFT    (23U)
#define EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(x)       (((uint32_t)(((uint32_t)(x)) << EIM_DCR_DLL_CTRL_SLV_UPDATE_INT_SHIFT)) & EIM_DCR_DLL_CTRL_SLV_UPDATE_INT_MASK)
#define EIM_DCR_DLL_CTRL_REF_UPDATE_INT_MASK     (0xF0000000U)
#define EIM_DCR_DLL_CTRL_REF_UPDATE_INT_SHIFT    (28U)
#define EIM_DCR_DLL_CTRL_REF_UPDATE_INT(x)       (((uint32_t)(((uint32_t)(x)) << EIM_DCR_DLL_CTRL_REF_UPDATE_INT_SHIFT)) & EIM_DCR_DLL_CTRL_REF_UPDATE_INT_MASK)

/*! @name DSR - DLL Status Register */
#define EIM_DSR_DLL_STS_SLV_LOCK_MASK            (0x1U)
#define EIM_DSR_DLL_STS_SLV_LOCK_SHIFT           (0U)
#define EIM_DSR_DLL_STS_REF_LOCK_MASK            (0x2U)
#define EIM_DSR_DLL_STS_REF_LOCK_SHIFT           (1U)
#define EIM_DSR_DLL_STS_SLV_SEL_MASK             (0x1FCU)
#define EIM_DSR_DLL_STS_SLV_SEL_SHIFT            (2U)
#define EIM_DSR_DLL_STS_SLV_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EIM_DSR_DLL_STS_SLV_SEL_SHIFT)) & EIM_DSR_DLL_STS_SLV_SEL_MASK)
#define EIM_DSR_DLL_STS_REF_SEL_MASK             (0xFE00U)
#define EIM_DSR_DLL_STS_REF_SEL_SHIFT            (9U)
#define EIM_DSR_DLL_STS_REF_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EIM_DSR_DLL_STS_REF_SEL_SHIFT)) & EIM_DSR_DLL_STS_REF_SEL_MASK)

/*! @name WIAR - EIM IP Access Register */
#define EIM_WIAR_IPS_REQ_MASK                    (0x1U)
#define EIM_WIAR_IPS_REQ_SHIFT                   (0U)
#define EIM_WIAR_IPS_ACK_MASK                    (0x2U)
#define EIM_WIAR_IPS_ACK_SHIFT                   (1U)
#define EIM_WIAR_INT_MASK                        (0x4U)
#define EIM_WIAR_INT_SHIFT                       (2U)
#define EIM_WIAR_ERRST_MASK                      (0x8U)
#define EIM_WIAR_ERRST_SHIFT                     (3U)
#define EIM_WIAR_ACLK_EN_MASK                    (0x10U)
#define EIM_WIAR_ACLK_EN_SHIFT                   (4U)

/*! @name EAR - Error Address Register */
#define EIM_EAR_Error_ADDR_MASK                  (0xFFFFFFFFU)
#define EIM_EAR_Error_ADDR_SHIFT                 (0U)
#define EIM_EAR_Error_ADDR(x)                    (((uint32_t)(((uint32_t)(x)) << EIM_EAR_Error_ADDR_SHIFT)) & EIM_EAR_Error_ADDR_MASK)


/*!
 * @}
 */ /* end of group EIM_Register_Masks */


/* EIM - Peripheral instance base addresses */
/** Peripheral EIM base pointer */
#define EIM_BASE_PTR                             ((EIM_MemMapPtr)0x30BC0000u)
/** Array initializer of EIM peripheral base pointers */
#define EIM_BASE_PTRS                            { EIM_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- EIM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup EIM_Register_Accessor_Macros EIM - Register accessor macros
 * @{
 */


/* EIM - Register instance definitions */
/* EIM */
#define EIM_CS0GCR1                              EIM_CS0GCR1_REG(EIM_BASE_PTR)
#define EIM_CS0GCR2                              EIM_CS0GCR2_REG(EIM_BASE_PTR)
#define EIM_CS0RCR1                              EIM_CS0RCR1_REG(EIM_BASE_PTR)
#define EIM_CS0RCR2                              EIM_CS0RCR2_REG(EIM_BASE_PTR)
#define EIM_CS0WCR1                              EIM_CS0WCR1_REG(EIM_BASE_PTR)
#define EIM_CS0WCR2                              EIM_CS0WCR2_REG(EIM_BASE_PTR)
#define EIM_CS1GCR1                              EIM_CS1GCR1_REG(EIM_BASE_PTR)
#define EIM_CS1GCR2                              EIM_CS1GCR2_REG(EIM_BASE_PTR)
#define EIM_CS1RCR1                              EIM_CS1RCR1_REG(EIM_BASE_PTR)
#define EIM_CS1RCR2                              EIM_CS1RCR2_REG(EIM_BASE_PTR)
#define EIM_CS1WCR1                              EIM_CS1WCR1_REG(EIM_BASE_PTR)
#define EIM_CS1WCR2                              EIM_CS1WCR2_REG(EIM_BASE_PTR)
#define EIM_CS2GCR1                              EIM_CS2GCR1_REG(EIM_BASE_PTR)
#define EIM_CS2GCR2                              EIM_CS2GCR2_REG(EIM_BASE_PTR)
#define EIM_CS2RCR1                              EIM_CS2RCR1_REG(EIM_BASE_PTR)
#define EIM_CS2RCR2                              EIM_CS2RCR2_REG(EIM_BASE_PTR)
#define EIM_CS2WCR1                              EIM_CS2WCR1_REG(EIM_BASE_PTR)
#define EIM_CS2WCR2                              EIM_CS2WCR2_REG(EIM_BASE_PTR)
#define EIM_CS3GCR1                              EIM_CS3GCR1_REG(EIM_BASE_PTR)
#define EIM_CS3GCR2                              EIM_CS3GCR2_REG(EIM_BASE_PTR)
#define EIM_CS3RCR1                              EIM_CS3RCR1_REG(EIM_BASE_PTR)
#define EIM_CS3RCR2                              EIM_CS3RCR2_REG(EIM_BASE_PTR)
#define EIM_CS3WCR1                              EIM_CS3WCR1_REG(EIM_BASE_PTR)
#define EIM_CS3WCR2                              EIM_CS3WCR2_REG(EIM_BASE_PTR)
#define EIM_CS4GCR1                              EIM_CS4GCR1_REG(EIM_BASE_PTR)
#define EIM_CS4GCR2                              EIM_CS4GCR2_REG(EIM_BASE_PTR)
#define EIM_CS4RCR1                              EIM_CS4RCR1_REG(EIM_BASE_PTR)
#define EIM_CS4RCR2                              EIM_CS4RCR2_REG(EIM_BASE_PTR)
#define EIM_CS4WCR1                              EIM_CS4WCR1_REG(EIM_BASE_PTR)
#define EIM_CS4WCR2                              EIM_CS4WCR2_REG(EIM_BASE_PTR)
#define EIM_CS5GCR1                              EIM_CS5GCR1_REG(EIM_BASE_PTR)
#define EIM_CS5GCR2                              EIM_CS5GCR2_REG(EIM_BASE_PTR)
#define EIM_CS5RCR1                              EIM_CS5RCR1_REG(EIM_BASE_PTR)
#define EIM_CS5RCR2                              EIM_CS5RCR2_REG(EIM_BASE_PTR)
#define EIM_CS5WCR1                              EIM_CS5WCR1_REG(EIM_BASE_PTR)
#define EIM_CS5WCR2                              EIM_CS5WCR2_REG(EIM_BASE_PTR)
#define EIM_WCR                                  EIM_WCR_REG(EIM_BASE_PTR)
#define EIM_DCR                                  EIM_DCR_REG(EIM_BASE_PTR)
#define EIM_DSR                                  EIM_DSR_REG(EIM_BASE_PTR)
#define EIM_WIAR                                 EIM_WIAR_REG(EIM_BASE_PTR)
#define EIM_EAR                                  EIM_EAR_REG(EIM_BASE_PTR)

/*!
 * @}
 */ /* end of group EIM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group EIM_Peripheral */


/* ----------------------------------------------------------------------------
   -- ENET
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ENET_Peripheral ENET
 * @{
 */

/** ENET - Peripheral register structure */
typedef struct ENET_MemMap {
  uint8_t RESERVED_0[4];
  uint32_t EIR;                                    /**< Interrupt Event Register, offset: 0x4 */
  uint32_t EIMR;                                   /**< Interrupt Mask Register, offset: 0x8 */
  uint8_t RESERVED_1[4];
  uint32_t RDAR;                                   /**< Receive Descriptor Active Register - Ring 0, offset: 0x10 */
  uint32_t TDAR;                                   /**< Transmit Descriptor Active Register - Ring 0, offset: 0x14 */
  uint8_t RESERVED_2[12];
  uint32_t ECR;                                    /**< Ethernet Control Register, offset: 0x24 */
  uint8_t RESERVED_3[24];
  uint32_t MMFR;                                   /**< MII Management Frame Register, offset: 0x40 */
  uint32_t MSCR;                                   /**< MII Speed Control Register, offset: 0x44 */
  uint8_t RESERVED_4[28];
  uint32_t MIBC;                                   /**< MIB Control Register, offset: 0x64 */
  uint8_t RESERVED_5[28];
  uint32_t RCR;                                    /**< Receive Control Register, offset: 0x84 */
  uint8_t RESERVED_6[60];
  uint32_t TCR;                                    /**< Transmit Control Register, offset: 0xC4 */
  uint8_t RESERVED_7[28];
  uint32_t PALR;                                   /**< Physical Address Lower Register, offset: 0xE4 */
  uint32_t PAUR;                                   /**< Physical Address Upper Register, offset: 0xE8 */
  uint32_t OPD;                                    /**< Opcode/Pause Duration Register, offset: 0xEC */
  uint32_t TXIC[3];                                /**< Transmit Interrupt Coalescing Register, array offset: 0xF0, array step: 0x4 */
  uint8_t RESERVED_8[4];
  uint32_t RXIC[3];                                /**< Receive Interrupt Coalescing Register, array offset: 0x100, array step: 0x4 */
  uint8_t RESERVED_9[12];
  uint32_t IAUR;                                   /**< Descriptor Individual Upper Address Register, offset: 0x118 */
  uint32_t IALR;                                   /**< Descriptor Individual Lower Address Register, offset: 0x11C */
  uint32_t GAUR;                                   /**< Descriptor Group Upper Address Register, offset: 0x120 */
  uint32_t GALR;                                   /**< Descriptor Group Lower Address Register, offset: 0x124 */
  uint8_t RESERVED_10[28];
  uint32_t TFWR;                                   /**< Transmit FIFO Watermark Register, offset: 0x144 */
  uint8_t RESERVED_11[24];
  uint32_t RDSR1;                                  /**< Receive Descriptor Ring 1 Start Register, offset: 0x160 */
  uint32_t TDSR1;                                  /**< Transmit Buffer Descriptor Ring 1 Start Register, offset: 0x164 */
  uint32_t MRBR1;                                  /**< Maximum Receive Buffer Size Register - Ring 1, offset: 0x168 */
  uint32_t RDSR2;                                  /**< Receive Descriptor Ring 2 Start Register, offset: 0x16C */
  uint32_t TDSR2;                                  /**< Transmit Buffer Descriptor Ring 2 Start Register, offset: 0x170 */
  uint32_t MRBR2;                                  /**< Maximum Receive Buffer Size Register - Ring 2, offset: 0x174 */
  uint8_t RESERVED_12[8];
  uint32_t RDSR;                                   /**< Receive Descriptor Ring 0 Start Register, offset: 0x180 */
  uint32_t TDSR;                                   /**< Transmit Buffer Descriptor Ring 0 Start Register, offset: 0x184 */
  uint32_t MRBR;                                   /**< Maximum Receive Buffer Size Register - Ring 0, offset: 0x188 */
  uint8_t RESERVED_13[4];
  uint32_t RSFL;                                   /**< Receive FIFO Section Full Threshold, offset: 0x190 */
  uint32_t RSEM;                                   /**< Receive FIFO Section Empty Threshold, offset: 0x194 */
  uint32_t RAEM;                                   /**< Receive FIFO Almost Empty Threshold, offset: 0x198 */
  uint32_t RAFL;                                   /**< Receive FIFO Almost Full Threshold, offset: 0x19C */
  uint32_t TSEM;                                   /**< Transmit FIFO Section Empty Threshold, offset: 0x1A0 */
  uint32_t TAEM;                                   /**< Transmit FIFO Almost Empty Threshold, offset: 0x1A4 */
  uint32_t TAFL;                                   /**< Transmit FIFO Almost Full Threshold, offset: 0x1A8 */
  uint32_t TIPG;                                   /**< Transmit Inter-Packet Gap, offset: 0x1AC */
  uint32_t FTRL;                                   /**< Frame Truncation Length, offset: 0x1B0 */
  uint8_t RESERVED_14[12];
  uint32_t TACC;                                   /**< Transmit Accelerator Function Configuration, offset: 0x1C0 */
  uint32_t RACC;                                   /**< Receive Accelerator Function Configuration, offset: 0x1C4 */
  uint32_t RCMR[2];                                /**< Receive Classification Match Register for Class n, array offset: 0x1C8, array step: 0x4 */
  uint8_t RESERVED_15[8];
  uint32_t DMACFG[2];                              /**< DMA Class Based Configuration, array offset: 0x1D8, array step: 0x4 */
  uint32_t RDAR1;                                  /**< Receive Descriptor Active Register - Ring 1, offset: 0x1E0 */
  uint32_t TDAR1;                                  /**< Transmit Descriptor Active Register - Ring 1, offset: 0x1E4 */
  uint32_t RDAR2;                                  /**< Receive Descriptor Active Register - Ring 2, offset: 0x1E8 */
  uint32_t TDAR2;                                  /**< Transmit Descriptor Active Register - Ring 2, offset: 0x1EC */
  uint32_t QOS;                                    /**< QOS Scheme, offset: 0x1F0 */
  uint8_t RESERVED_16[12];
  uint32_t RMON_T_DROP;                            /**< Reserved Statistic Register, offset: 0x200 */
  uint32_t RMON_T_PACKETS;                         /**< Tx Packet Count Statistic Register, offset: 0x204 */
  uint32_t RMON_T_BC_PKT;                          /**< Tx Broadcast Packets Statistic Register, offset: 0x208 */
  uint32_t RMON_T_MC_PKT;                          /**< Tx Multicast Packets Statistic Register, offset: 0x20C */
  uint32_t RMON_T_CRC_ALIGN;                       /**< Tx Packets with CRC/Align Error Statistic Register, offset: 0x210 */
  uint32_t RMON_T_UNDERSIZE;                       /**< Tx Packets Less Than Bytes and Good CRC Statistic Register, offset: 0x214 */
  uint32_t RMON_T_OVERSIZE;                        /**< Tx Packets GT MAX_FL bytes and Good CRC Statistic Register, offset: 0x218 */
  uint32_t RMON_T_FRAG;                            /**< Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register, offset: 0x21C */
  uint32_t RMON_T_JAB;                             /**< Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register, offset: 0x220 */
  uint32_t RMON_T_COL;                             /**< Tx Collision Count Statistic Register, offset: 0x224 */
  uint32_t RMON_T_P64;                             /**< Tx 64-Byte Packets Statistic Register, offset: 0x228 */
  uint32_t RMON_T_P65TO127;                        /**< Tx 65- to 127-byte Packets Statistic Register, offset: 0x22C */
  uint32_t RMON_T_P128TO255;                       /**< Tx 128- to 255-byte Packets Statistic Register, offset: 0x230 */
  uint32_t RMON_T_P256TO511;                       /**< Tx 256- to 511-byte Packets Statistic Register, offset: 0x234 */
  uint32_t RMON_T_P512TO1023;                      /**< Tx 512- to 1023-byte Packets Statistic Register, offset: 0x238 */
  uint32_t RMON_T_P1024TO2047;                     /**< Tx 1024- to 2047-byte Packets Statistic Register, offset: 0x23C */
  uint32_t RMON_T_P_GTE2048;                       /**< Tx Packets Greater Than 2048 Bytes Statistic Register, offset: 0x240 */
  uint32_t RMON_T_OCTETS;                          /**< Tx Octets Statistic Register, offset: 0x244 */
  uint32_t IEEE_T_DROP;                            /**< Reserved Statistic Register, offset: 0x248 */
  uint32_t IEEE_T_FRAME_OK;                        /**< Frames Transmitted OK Statistic Register, offset: 0x24C */
  uint32_t IEEE_T_1COL;                            /**< Frames Transmitted with Single Collision Statistic Register, offset: 0x250 */
  uint32_t IEEE_T_MCOL;                            /**< Frames Transmitted with Multiple Collisions Statistic Register, offset: 0x254 */
  uint32_t IEEE_T_DEF;                             /**< Frames Transmitted after Deferral Delay Statistic Register, offset: 0x258 */
  uint32_t IEEE_T_LCOL;                            /**< Frames Transmitted with Late Collision Statistic Register, offset: 0x25C */
  uint32_t IEEE_T_EXCOL;                           /**< Frames Transmitted with Excessive Collisions Statistic Register, offset: 0x260 */
  uint32_t IEEE_T_MACERR;                          /**< Frames Transmitted with Tx FIFO Underrun Statistic Register, offset: 0x264 */
  uint32_t IEEE_T_CSERR;                           /**< Frames Transmitted with Carrier Sense Error Statistic Register, offset: 0x268 */
  uint32_t IEEE_T_SQE;                             /**< Reserved Statistic Register, offset: 0x26C */
  uint32_t IEEE_T_FDXFC;                           /**< Flow Control Pause Frames Transmitted Statistic Register, offset: 0x270 */
  uint32_t IEEE_T_OCTETS_OK;                       /**< Octet Count for Frames Transmitted w/o Error Statistic Register, offset: 0x274 */
  uint8_t RESERVED_17[12];
  uint32_t RMON_R_PACKETS;                         /**< Rx Packet Count Statistic Register, offset: 0x284 */
  uint32_t RMON_R_BC_PKT;                          /**< Rx Broadcast Packets Statistic Register, offset: 0x288 */
  uint32_t RMON_R_MC_PKT;                          /**< Rx Multicast Packets Statistic Register, offset: 0x28C */
  uint32_t RMON_R_CRC_ALIGN;                       /**< Rx Packets with CRC/Align Error Statistic Register, offset: 0x290 */
  uint32_t RMON_R_UNDERSIZE;                       /**< Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register, offset: 0x294 */
  uint32_t RMON_R_OVERSIZE;                        /**< Rx Packets Greater Than MAX_FL and Good CRC Statistic Register, offset: 0x298 */
  uint32_t RMON_R_FRAG;                            /**< Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register, offset: 0x29C */
  uint32_t RMON_R_JAB;                             /**< Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register, offset: 0x2A0 */
  uint32_t RMON_R_RESVD_0;                         /**< Reserved Statistic Register, offset: 0x2A4 */
  uint32_t RMON_R_P64;                             /**< Rx 64-Byte Packets Statistic Register, offset: 0x2A8 */
  uint32_t RMON_R_P65TO127;                        /**< Rx 65- to 127-Byte Packets Statistic Register, offset: 0x2AC */
  uint32_t RMON_R_P128TO255;                       /**< Rx 128- to 255-Byte Packets Statistic Register, offset: 0x2B0 */
  uint32_t RMON_R_P256TO511;                       /**< Rx 256- to 511-Byte Packets Statistic Register, offset: 0x2B4 */
  uint32_t RMON_R_P512TO1023;                      /**< Rx 512- to 1023-Byte Packets Statistic Register, offset: 0x2B8 */
  uint32_t RMON_R_P1024TO2047;                     /**< Rx 1024- to 2047-Byte Packets Statistic Register, offset: 0x2BC */
  uint32_t RMON_R_P_GTE2048;                       /**< Rx Packets Greater than 2048 Bytes Statistic Register, offset: 0x2C0 */
  uint32_t RMON_R_OCTETS;                          /**< Rx Octets Statistic Register, offset: 0x2C4 */
  uint32_t IEEE_R_DROP;                            /**< Frames not Counted Correctly Statistic Register, offset: 0x2C8 */
  uint32_t IEEE_R_FRAME_OK;                        /**< Frames Received OK Statistic Register, offset: 0x2CC */
  uint32_t IEEE_R_CRC;                             /**< Frames Received with CRC Error Statistic Register, offset: 0x2D0 */
  uint32_t IEEE_R_ALIGN;                           /**< Frames Received with Alignment Error Statistic Register, offset: 0x2D4 */
  uint32_t IEEE_R_MACERR;                          /**< Receive FIFO Overflow Count Statistic Register, offset: 0x2D8 */
  uint32_t IEEE_R_FDXFC;                           /**< Flow Control Pause Frames Received Statistic Register, offset: 0x2DC */
  uint32_t IEEE_R_OCTETS_OK;                       /**< Octet Count for Frames Received without Error Statistic Register, offset: 0x2E0 */
  uint8_t RESERVED_18[284];
  uint32_t ATCR;                                   /**< Adjustable Timer Control Register, offset: 0x400 */
  uint32_t ATVR;                                   /**< Timer Value Register, offset: 0x404 */
  uint32_t ATOFF;                                  /**< Timer Offset Register, offset: 0x408 */
  uint32_t ATPER;                                  /**< Timer Period Register, offset: 0x40C */
  uint32_t ATCOR;                                  /**< Timer Correction Register, offset: 0x410 */
  uint32_t ATINC;                                  /**< Time-Stamping Clock Period Register, offset: 0x414 */
  uint32_t ATSTMP;                                 /**< Timestamp of Last Transmitted Frame, offset: 0x418 */
  uint8_t RESERVED_19[488];
  uint32_t TGSR;                                   /**< Timer Global Status Register, offset: 0x604 */
  struct {                                         /* offset: 0x608, array step: 0x8 */
    uint32_t TCSR;                                   /**< Timer Control Status Register, array offset: 0x608, array step: 0x8 */
    uint32_t TCCR;                                   /**< Timer Compare Capture Register, array offset: 0x60C, array step: 0x8 */
  } CHANNEL[4];
} volatile *ENET_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- ENET - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ENET_Register_Accessor_Macros ENET - Register accessor macros
 * @{
 */


/* ENET - Register accessors */
#define ENET_EIR_REG(base)                       ((base)->EIR)
#define ENET_EIMR_REG(base)                      ((base)->EIMR)
#define ENET_RDAR_REG(base)                      ((base)->RDAR)
#define ENET_TDAR_REG(base)                      ((base)->TDAR)
#define ENET_ECR_REG(base)                       ((base)->ECR)
#define ENET_MMFR_REG(base)                      ((base)->MMFR)
#define ENET_MSCR_REG(base)                      ((base)->MSCR)
#define ENET_MIBC_REG(base)                      ((base)->MIBC)
#define ENET_RCR_REG(base)                       ((base)->RCR)
#define ENET_TCR_REG(base)                       ((base)->TCR)
#define ENET_PALR_REG(base)                      ((base)->PALR)
#define ENET_PAUR_REG(base)                      ((base)->PAUR)
#define ENET_OPD_REG(base)                       ((base)->OPD)
#define ENET_TXIC_REG(base,index)                ((base)->TXIC[index])
#define ENET_RXIC_REG(base,index)                ((base)->RXIC[index])
#define ENET_IAUR_REG(base)                      ((base)->IAUR)
#define ENET_IALR_REG(base)                      ((base)->IALR)
#define ENET_GAUR_REG(base)                      ((base)->GAUR)
#define ENET_GALR_REG(base)                      ((base)->GALR)
#define ENET_TFWR_REG(base)                      ((base)->TFWR)
#define ENET_RDSR1_REG(base)                     ((base)->RDSR1)
#define ENET_TDSR1_REG(base)                     ((base)->TDSR1)
#define ENET_MRBR1_REG(base)                     ((base)->MRBR1)
#define ENET_RDSR2_REG(base)                     ((base)->RDSR2)
#define ENET_TDSR2_REG(base)                     ((base)->TDSR2)
#define ENET_MRBR2_REG(base)                     ((base)->MRBR2)
#define ENET_RDSR_REG(base)                      ((base)->RDSR)
#define ENET_TDSR_REG(base)                      ((base)->TDSR)
#define ENET_MRBR_REG(base)                      ((base)->MRBR)
#define ENET_RSFL_REG(base)                      ((base)->RSFL)
#define ENET_RSEM_REG(base)                      ((base)->RSEM)
#define ENET_RAEM_REG(base)                      ((base)->RAEM)
#define ENET_RAFL_REG(base)                      ((base)->RAFL)
#define ENET_TSEM_REG(base)                      ((base)->TSEM)
#define ENET_TAEM_REG(base)                      ((base)->TAEM)
#define ENET_TAFL_REG(base)                      ((base)->TAFL)
#define ENET_TIPG_REG(base)                      ((base)->TIPG)
#define ENET_FTRL_REG(base)                      ((base)->FTRL)
#define ENET_TACC_REG(base)                      ((base)->TACC)
#define ENET_RACC_REG(base)                      ((base)->RACC)
#define ENET_RCMR_REG(base,index)                ((base)->RCMR[index])
#define ENET_DMACFG_REG(base,index)              ((base)->DMACFG[index])
#define ENET_RDAR1_REG(base)                     ((base)->RDAR1)
#define ENET_TDAR1_REG(base)                     ((base)->TDAR1)
#define ENET_RDAR2_REG(base)                     ((base)->RDAR2)
#define ENET_TDAR2_REG(base)                     ((base)->TDAR2)
#define ENET_QOS_REG(base)                       ((base)->QOS)
#define ENET_RMON_T_DROP_REG(base)               ((base)->RMON_T_DROP)
#define ENET_RMON_T_PACKETS_REG(base)            ((base)->RMON_T_PACKETS)
#define ENET_RMON_T_BC_PKT_REG(base)             ((base)->RMON_T_BC_PKT)
#define ENET_RMON_T_MC_PKT_REG(base)             ((base)->RMON_T_MC_PKT)
#define ENET_RMON_T_CRC_ALIGN_REG(base)          ((base)->RMON_T_CRC_ALIGN)
#define ENET_RMON_T_UNDERSIZE_REG(base)          ((base)->RMON_T_UNDERSIZE)
#define ENET_RMON_T_OVERSIZE_REG(base)           ((base)->RMON_T_OVERSIZE)
#define ENET_RMON_T_FRAG_REG(base)               ((base)->RMON_T_FRAG)
#define ENET_RMON_T_JAB_REG(base)                ((base)->RMON_T_JAB)
#define ENET_RMON_T_COL_REG(base)                ((base)->RMON_T_COL)
#define ENET_RMON_T_P64_REG(base)                ((base)->RMON_T_P64)
#define ENET_RMON_T_P65TO127_REG(base)           ((base)->RMON_T_P65TO127)
#define ENET_RMON_T_P128TO255_REG(base)          ((base)->RMON_T_P128TO255)
#define ENET_RMON_T_P256TO511_REG(base)          ((base)->RMON_T_P256TO511)
#define ENET_RMON_T_P512TO1023_REG(base)         ((base)->RMON_T_P512TO1023)
#define ENET_RMON_T_P1024TO2047_REG(base)        ((base)->RMON_T_P1024TO2047)
#define ENET_RMON_T_P_GTE2048_REG(base)          ((base)->RMON_T_P_GTE2048)
#define ENET_RMON_T_OCTETS_REG(base)             ((base)->RMON_T_OCTETS)
#define ENET_IEEE_T_DROP_REG(base)               ((base)->IEEE_T_DROP)
#define ENET_IEEE_T_FRAME_OK_REG(base)           ((base)->IEEE_T_FRAME_OK)
#define ENET_IEEE_T_1COL_REG(base)               ((base)->IEEE_T_1COL)
#define ENET_IEEE_T_MCOL_REG(base)               ((base)->IEEE_T_MCOL)
#define ENET_IEEE_T_DEF_REG(base)                ((base)->IEEE_T_DEF)
#define ENET_IEEE_T_LCOL_REG(base)               ((base)->IEEE_T_LCOL)
#define ENET_IEEE_T_EXCOL_REG(base)              ((base)->IEEE_T_EXCOL)
#define ENET_IEEE_T_MACERR_REG(base)             ((base)->IEEE_T_MACERR)
#define ENET_IEEE_T_CSERR_REG(base)              ((base)->IEEE_T_CSERR)
#define ENET_IEEE_T_SQE_REG(base)                ((base)->IEEE_T_SQE)
#define ENET_IEEE_T_FDXFC_REG(base)              ((base)->IEEE_T_FDXFC)
#define ENET_IEEE_T_OCTETS_OK_REG(base)          ((base)->IEEE_T_OCTETS_OK)
#define ENET_RMON_R_PACKETS_REG(base)            ((base)->RMON_R_PACKETS)
#define ENET_RMON_R_BC_PKT_REG(base)             ((base)->RMON_R_BC_PKT)
#define ENET_RMON_R_MC_PKT_REG(base)             ((base)->RMON_R_MC_PKT)
#define ENET_RMON_R_CRC_ALIGN_REG(base)          ((base)->RMON_R_CRC_ALIGN)
#define ENET_RMON_R_UNDERSIZE_REG(base)          ((base)->RMON_R_UNDERSIZE)
#define ENET_RMON_R_OVERSIZE_REG(base)           ((base)->RMON_R_OVERSIZE)
#define ENET_RMON_R_FRAG_REG(base)               ((base)->RMON_R_FRAG)
#define ENET_RMON_R_JAB_REG(base)                ((base)->RMON_R_JAB)
#define ENET_RMON_R_RESVD_0_REG(base)            ((base)->RMON_R_RESVD_0)
#define ENET_RMON_R_P64_REG(base)                ((base)->RMON_R_P64)
#define ENET_RMON_R_P65TO127_REG(base)           ((base)->RMON_R_P65TO127)
#define ENET_RMON_R_P128TO255_REG(base)          ((base)->RMON_R_P128TO255)
#define ENET_RMON_R_P256TO511_REG(base)          ((base)->RMON_R_P256TO511)
#define ENET_RMON_R_P512TO1023_REG(base)         ((base)->RMON_R_P512TO1023)
#define ENET_RMON_R_P1024TO2047_REG(base)        ((base)->RMON_R_P1024TO2047)
#define ENET_RMON_R_P_GTE2048_REG(base)          ((base)->RMON_R_P_GTE2048)
#define ENET_RMON_R_OCTETS_REG(base)             ((base)->RMON_R_OCTETS)
#define ENET_IEEE_R_DROP_REG(base)               ((base)->IEEE_R_DROP)
#define ENET_IEEE_R_FRAME_OK_REG(base)           ((base)->IEEE_R_FRAME_OK)
#define ENET_IEEE_R_CRC_REG(base)                ((base)->IEEE_R_CRC)
#define ENET_IEEE_R_ALIGN_REG(base)              ((base)->IEEE_R_ALIGN)
#define ENET_IEEE_R_MACERR_REG(base)             ((base)->IEEE_R_MACERR)
#define ENET_IEEE_R_FDXFC_REG(base)              ((base)->IEEE_R_FDXFC)
#define ENET_IEEE_R_OCTETS_OK_REG(base)          ((base)->IEEE_R_OCTETS_OK)
#define ENET_ATCR_REG(base)                      ((base)->ATCR)
#define ENET_ATVR_REG(base)                      ((base)->ATVR)
#define ENET_ATOFF_REG(base)                     ((base)->ATOFF)
#define ENET_ATPER_REG(base)                     ((base)->ATPER)
#define ENET_ATCOR_REG(base)                     ((base)->ATCOR)
#define ENET_ATINC_REG(base)                     ((base)->ATINC)
#define ENET_ATSTMP_REG(base)                    ((base)->ATSTMP)
#define ENET_TGSR_REG(base)                      ((base)->TGSR)
#define ENET_TCSR_REG(base,index)                ((base)->CHANNEL[index].TCSR)
#define ENET_TCCR_REG(base,index)                ((base)->CHANNEL[index].TCCR)

/*!
 * @}
 */ /* end of group ENET_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- ENET Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ENET_Register_Masks ENET Register Masks
 * @{
 */

/*! @name EIR - Interrupt Event Register */
#define ENET_EIR_RXB1_MASK                       (0x1U)
#define ENET_EIR_RXB1_SHIFT                      (0U)
#define ENET_EIR_RXF1_MASK                       (0x2U)
#define ENET_EIR_RXF1_SHIFT                      (1U)
#define ENET_EIR_TXB1_MASK                       (0x4U)
#define ENET_EIR_TXB1_SHIFT                      (2U)
#define ENET_EIR_TXF1_MASK                       (0x8U)
#define ENET_EIR_TXF1_SHIFT                      (3U)
#define ENET_EIR_RXB2_MASK                       (0x10U)
#define ENET_EIR_RXB2_SHIFT                      (4U)
#define ENET_EIR_RXF2_MASK                       (0x20U)
#define ENET_EIR_RXF2_SHIFT                      (5U)
#define ENET_EIR_TXB2_MASK                       (0x40U)
#define ENET_EIR_TXB2_SHIFT                      (6U)
#define ENET_EIR_TXF2_MASK                       (0x80U)
#define ENET_EIR_TXF2_SHIFT                      (7U)
#define ENET_EIR_RXFLUSH_0_MASK                  (0x1000U)
#define ENET_EIR_RXFLUSH_0_SHIFT                 (12U)
#define ENET_EIR_RXFLUSH_1_MASK                  (0x2000U)
#define ENET_EIR_RXFLUSH_1_SHIFT                 (13U)
#define ENET_EIR_RXFLUSH_2_MASK                  (0x4000U)
#define ENET_EIR_RXFLUSH_2_SHIFT                 (14U)
#define ENET_EIR_TS_TIMER_MASK                   (0x8000U)
#define ENET_EIR_TS_TIMER_SHIFT                  (15U)
#define ENET_EIR_TS_AVAIL_MASK                   (0x10000U)
#define ENET_EIR_TS_AVAIL_SHIFT                  (16U)
#define ENET_EIR_WAKEUP_MASK                     (0x20000U)
#define ENET_EIR_WAKEUP_SHIFT                    (17U)
#define ENET_EIR_PLR_MASK                        (0x40000U)
#define ENET_EIR_PLR_SHIFT                       (18U)
#define ENET_EIR_UN_MASK                         (0x80000U)
#define ENET_EIR_UN_SHIFT                        (19U)
#define ENET_EIR_RL_MASK                         (0x100000U)
#define ENET_EIR_RL_SHIFT                        (20U)
#define ENET_EIR_LC_MASK                         (0x200000U)
#define ENET_EIR_LC_SHIFT                        (21U)
#define ENET_EIR_EBERR_MASK                      (0x400000U)
#define ENET_EIR_EBERR_SHIFT                     (22U)
#define ENET_EIR_MII_MASK                        (0x800000U)
#define ENET_EIR_MII_SHIFT                       (23U)
#define ENET_EIR_RXB_MASK                        (0x1000000U)
#define ENET_EIR_RXB_SHIFT                       (24U)
#define ENET_EIR_RXF_MASK                        (0x2000000U)
#define ENET_EIR_RXF_SHIFT                       (25U)
#define ENET_EIR_TXB_MASK                        (0x4000000U)
#define ENET_EIR_TXB_SHIFT                       (26U)
#define ENET_EIR_TXF_MASK                        (0x8000000U)
#define ENET_EIR_TXF_SHIFT                       (27U)
#define ENET_EIR_GRA_MASK                        (0x10000000U)
#define ENET_EIR_GRA_SHIFT                       (28U)
#define ENET_EIR_BABT_MASK                       (0x20000000U)
#define ENET_EIR_BABT_SHIFT                      (29U)
#define ENET_EIR_BABR_MASK                       (0x40000000U)
#define ENET_EIR_BABR_SHIFT                      (30U)

/*! @name EIMR - Interrupt Mask Register */
#define ENET_EIMR_RXB1_MASK                      (0x1U)
#define ENET_EIMR_RXB1_SHIFT                     (0U)
#define ENET_EIMR_RXF1_MASK                      (0x2U)
#define ENET_EIMR_RXF1_SHIFT                     (1U)
#define ENET_EIMR_TXB1_MASK                      (0x4U)
#define ENET_EIMR_TXB1_SHIFT                     (2U)
#define ENET_EIMR_TXF1_MASK                      (0x8U)
#define ENET_EIMR_TXF1_SHIFT                     (3U)
#define ENET_EIMR_RXB2_MASK                      (0x10U)
#define ENET_EIMR_RXB2_SHIFT                     (4U)
#define ENET_EIMR_RXF2_MASK                      (0x20U)
#define ENET_EIMR_RXF2_SHIFT                     (5U)
#define ENET_EIMR_TXB2_MASK                      (0x40U)
#define ENET_EIMR_TXB2_SHIFT                     (6U)
#define ENET_EIMR_TXF2_MASK                      (0x80U)
#define ENET_EIMR_TXF2_SHIFT                     (7U)
#define ENET_EIMR_RXFLUSH_0_MASK                 (0x1000U)
#define ENET_EIMR_RXFLUSH_0_SHIFT                (12U)
#define ENET_EIMR_RXFLUSH_1_MASK                 (0x2000U)
#define ENET_EIMR_RXFLUSH_1_SHIFT                (13U)
#define ENET_EIMR_RXFLUSH_2_MASK                 (0x4000U)
#define ENET_EIMR_RXFLUSH_2_SHIFT                (14U)
#define ENET_EIMR_TS_TIMER_MASK                  (0x8000U)
#define ENET_EIMR_TS_TIMER_SHIFT                 (15U)
#define ENET_EIMR_TS_AVAIL_MASK                  (0x10000U)
#define ENET_EIMR_TS_AVAIL_SHIFT                 (16U)
#define ENET_EIMR_WAKEUP_MASK                    (0x20000U)
#define ENET_EIMR_WAKEUP_SHIFT                   (17U)
#define ENET_EIMR_PLR_MASK                       (0x40000U)
#define ENET_EIMR_PLR_SHIFT                      (18U)
#define ENET_EIMR_UN_MASK                        (0x80000U)
#define ENET_EIMR_UN_SHIFT                       (19U)
#define ENET_EIMR_RL_MASK                        (0x100000U)
#define ENET_EIMR_RL_SHIFT                       (20U)
#define ENET_EIMR_LC_MASK                        (0x200000U)
#define ENET_EIMR_LC_SHIFT                       (21U)
#define ENET_EIMR_EBERR_MASK                     (0x400000U)
#define ENET_EIMR_EBERR_SHIFT                    (22U)
#define ENET_EIMR_MII_MASK                       (0x800000U)
#define ENET_EIMR_MII_SHIFT                      (23U)
#define ENET_EIMR_RXB_MASK                       (0x1000000U)
#define ENET_EIMR_RXB_SHIFT                      (24U)
#define ENET_EIMR_RXF_MASK                       (0x2000000U)
#define ENET_EIMR_RXF_SHIFT                      (25U)
#define ENET_EIMR_TXB_MASK                       (0x4000000U)
#define ENET_EIMR_TXB_SHIFT                      (26U)
#define ENET_EIMR_TXF_MASK                       (0x8000000U)
#define ENET_EIMR_TXF_SHIFT                      (27U)
#define ENET_EIMR_GRA_MASK                       (0x10000000U)
#define ENET_EIMR_GRA_SHIFT                      (28U)
#define ENET_EIMR_BABT_MASK                      (0x20000000U)
#define ENET_EIMR_BABT_SHIFT                     (29U)
#define ENET_EIMR_BABR_MASK                      (0x40000000U)
#define ENET_EIMR_BABR_SHIFT                     (30U)

/*! @name RDAR - Receive Descriptor Active Register - Ring 0 */
#define ENET_RDAR_RDAR_MASK                      (0x1000000U)
#define ENET_RDAR_RDAR_SHIFT                     (24U)

/*! @name TDAR - Transmit Descriptor Active Register - Ring 0 */
#define ENET_TDAR_TDAR_MASK                      (0x1000000U)
#define ENET_TDAR_TDAR_SHIFT                     (24U)

/*! @name ECR - Ethernet Control Register */
#define ENET_ECR_RESET_MASK                      (0x1U)
#define ENET_ECR_RESET_SHIFT                     (0U)
#define ENET_ECR_ETHEREN_MASK                    (0x2U)
#define ENET_ECR_ETHEREN_SHIFT                   (1U)
#define ENET_ECR_MAGICEN_MASK                    (0x4U)
#define ENET_ECR_MAGICEN_SHIFT                   (2U)
#define ENET_ECR_SLEEP_MASK                      (0x8U)
#define ENET_ECR_SLEEP_SHIFT                     (3U)
#define ENET_ECR_EN1588_MASK                     (0x10U)
#define ENET_ECR_EN1588_SHIFT                    (4U)
#define ENET_ECR_SPEED_MASK                      (0x20U)
#define ENET_ECR_SPEED_SHIFT                     (5U)
#define ENET_ECR_DBGEN_MASK                      (0x40U)
#define ENET_ECR_DBGEN_SHIFT                     (6U)
#define ENET_ECR_DBSWP_MASK                      (0x100U)
#define ENET_ECR_DBSWP_SHIFT                     (8U)
#define ENET_ECR_SVLANEN_MASK                    (0x200U)
#define ENET_ECR_SVLANEN_SHIFT                   (9U)
#define ENET_ECR_VLANUSE2ND_MASK                 (0x400U)
#define ENET_ECR_VLANUSE2ND_SHIFT                (10U)
#define ENET_ECR_SVLANDBL_MASK                   (0x800U)
#define ENET_ECR_SVLANDBL_SHIFT                  (11U)

/*! @name MMFR - MII Management Frame Register */
#define ENET_MMFR_DATA_MASK                      (0xFFFFU)
#define ENET_MMFR_DATA_SHIFT                     (0U)
#define ENET_MMFR_DATA(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_MMFR_DATA_SHIFT)) & ENET_MMFR_DATA_MASK)
#define ENET_MMFR_TA_MASK                        (0x30000U)
#define ENET_MMFR_TA_SHIFT                       (16U)
#define ENET_MMFR_TA(x)                          (((uint32_t)(((uint32_t)(x)) << ENET_MMFR_TA_SHIFT)) & ENET_MMFR_TA_MASK)
#define ENET_MMFR_RA_MASK                        (0x7C0000U)
#define ENET_MMFR_RA_SHIFT                       (18U)
#define ENET_MMFR_RA(x)                          (((uint32_t)(((uint32_t)(x)) << ENET_MMFR_RA_SHIFT)) & ENET_MMFR_RA_MASK)
#define ENET_MMFR_PA_MASK                        (0xF800000U)
#define ENET_MMFR_PA_SHIFT                       (23U)
#define ENET_MMFR_PA(x)                          (((uint32_t)(((uint32_t)(x)) << ENET_MMFR_PA_SHIFT)) & ENET_MMFR_PA_MASK)
#define ENET_MMFR_OP_MASK                        (0x30000000U)
#define ENET_MMFR_OP_SHIFT                       (28U)
#define ENET_MMFR_OP(x)                          (((uint32_t)(((uint32_t)(x)) << ENET_MMFR_OP_SHIFT)) & ENET_MMFR_OP_MASK)
#define ENET_MMFR_ST_MASK                        (0xC0000000U)
#define ENET_MMFR_ST_SHIFT                       (30U)
#define ENET_MMFR_ST(x)                          (((uint32_t)(((uint32_t)(x)) << ENET_MMFR_ST_SHIFT)) & ENET_MMFR_ST_MASK)

/*! @name MSCR - MII Speed Control Register */
#define ENET_MSCR_MII_SPEED_MASK                 (0x7EU)
#define ENET_MSCR_MII_SPEED_SHIFT                (1U)
#define ENET_MSCR_MII_SPEED(x)                   (((uint32_t)(((uint32_t)(x)) << ENET_MSCR_MII_SPEED_SHIFT)) & ENET_MSCR_MII_SPEED_MASK)
#define ENET_MSCR_DIS_PRE_MASK                   (0x80U)
#define ENET_MSCR_DIS_PRE_SHIFT                  (7U)
#define ENET_MSCR_HOLDTIME_MASK                  (0x700U)
#define ENET_MSCR_HOLDTIME_SHIFT                 (8U)
#define ENET_MSCR_HOLDTIME(x)                    (((uint32_t)(((uint32_t)(x)) << ENET_MSCR_HOLDTIME_SHIFT)) & ENET_MSCR_HOLDTIME_MASK)

/*! @name MIBC - MIB Control Register */
#define ENET_MIBC_MIB_CLEAR_MASK                 (0x20000000U)
#define ENET_MIBC_MIB_CLEAR_SHIFT                (29U)
#define ENET_MIBC_MIB_IDLE_MASK                  (0x40000000U)
#define ENET_MIBC_MIB_IDLE_SHIFT                 (30U)
#define ENET_MIBC_MIB_DIS_MASK                   (0x80000000U)
#define ENET_MIBC_MIB_DIS_SHIFT                  (31U)

/*! @name RCR - Receive Control Register */
#define ENET_RCR_LOOP_MASK                       (0x1U)
#define ENET_RCR_LOOP_SHIFT                      (0U)
#define ENET_RCR_DRT_MASK                        (0x2U)
#define ENET_RCR_DRT_SHIFT                       (1U)
#define ENET_RCR_MII_MODE_MASK                   (0x4U)
#define ENET_RCR_MII_MODE_SHIFT                  (2U)
#define ENET_RCR_PROM_MASK                       (0x8U)
#define ENET_RCR_PROM_SHIFT                      (3U)
#define ENET_RCR_BC_REJ_MASK                     (0x10U)
#define ENET_RCR_BC_REJ_SHIFT                    (4U)
#define ENET_RCR_FCE_MASK                        (0x20U)
#define ENET_RCR_FCE_SHIFT                       (5U)
#define ENET_RCR_RGMII_EN_MASK                   (0x40U)
#define ENET_RCR_RGMII_EN_SHIFT                  (6U)
#define ENET_RCR_RMII_MODE_MASK                  (0x100U)
#define ENET_RCR_RMII_MODE_SHIFT                 (8U)
#define ENET_RCR_RMII_10T_MASK                   (0x200U)
#define ENET_RCR_RMII_10T_SHIFT                  (9U)
#define ENET_RCR_PADEN_MASK                      (0x1000U)
#define ENET_RCR_PADEN_SHIFT                     (12U)
#define ENET_RCR_PAUFWD_MASK                     (0x2000U)
#define ENET_RCR_PAUFWD_SHIFT                    (13U)
#define ENET_RCR_CRCFWD_MASK                     (0x4000U)
#define ENET_RCR_CRCFWD_SHIFT                    (14U)
#define ENET_RCR_CFEN_MASK                       (0x8000U)
#define ENET_RCR_CFEN_SHIFT                      (15U)
#define ENET_RCR_MAX_FL_MASK                     (0x3FFF0000U)
#define ENET_RCR_MAX_FL_SHIFT                    (16U)
#define ENET_RCR_MAX_FL(x)                       (((uint32_t)(((uint32_t)(x)) << ENET_RCR_MAX_FL_SHIFT)) & ENET_RCR_MAX_FL_MASK)
#define ENET_RCR_NLC_MASK                        (0x40000000U)
#define ENET_RCR_NLC_SHIFT                       (30U)
#define ENET_RCR_GRS_MASK                        (0x80000000U)
#define ENET_RCR_GRS_SHIFT                       (31U)

/*! @name TCR - Transmit Control Register */
#define ENET_TCR_GTS_MASK                        (0x1U)
#define ENET_TCR_GTS_SHIFT                       (0U)
#define ENET_TCR_FDEN_MASK                       (0x4U)
#define ENET_TCR_FDEN_SHIFT                      (2U)
#define ENET_TCR_TFC_PAUSE_MASK                  (0x8U)
#define ENET_TCR_TFC_PAUSE_SHIFT                 (3U)
#define ENET_TCR_RFC_PAUSE_MASK                  (0x10U)
#define ENET_TCR_RFC_PAUSE_SHIFT                 (4U)
#define ENET_TCR_ADDSEL_MASK                     (0xE0U)
#define ENET_TCR_ADDSEL_SHIFT                    (5U)
#define ENET_TCR_ADDSEL(x)                       (((uint32_t)(((uint32_t)(x)) << ENET_TCR_ADDSEL_SHIFT)) & ENET_TCR_ADDSEL_MASK)
#define ENET_TCR_ADDINS_MASK                     (0x100U)
#define ENET_TCR_ADDINS_SHIFT                    (8U)
#define ENET_TCR_CRCFWD_MASK                     (0x200U)
#define ENET_TCR_CRCFWD_SHIFT                    (9U)

/*! @name PALR - Physical Address Lower Register */
#define ENET_PALR_PADDR1_MASK                    (0xFFFFFFFFU)
#define ENET_PALR_PADDR1_SHIFT                   (0U)
#define ENET_PALR_PADDR1(x)                      (((uint32_t)(((uint32_t)(x)) << ENET_PALR_PADDR1_SHIFT)) & ENET_PALR_PADDR1_MASK)

/*! @name PAUR - Physical Address Upper Register */
#define ENET_PAUR_TYPE_MASK                      (0xFFFFU)
#define ENET_PAUR_TYPE_SHIFT                     (0U)
#define ENET_PAUR_TYPE(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_PAUR_TYPE_SHIFT)) & ENET_PAUR_TYPE_MASK)
#define ENET_PAUR_PADDR2_MASK                    (0xFFFF0000U)
#define ENET_PAUR_PADDR2_SHIFT                   (16U)
#define ENET_PAUR_PADDR2(x)                      (((uint32_t)(((uint32_t)(x)) << ENET_PAUR_PADDR2_SHIFT)) & ENET_PAUR_PADDR2_MASK)

/*! @name OPD - Opcode/Pause Duration Register */
#define ENET_OPD_PAUSE_DUR_MASK                  (0xFFFFU)
#define ENET_OPD_PAUSE_DUR_SHIFT                 (0U)
#define ENET_OPD_PAUSE_DUR(x)                    (((uint32_t)(((uint32_t)(x)) << ENET_OPD_PAUSE_DUR_SHIFT)) & ENET_OPD_PAUSE_DUR_MASK)
#define ENET_OPD_OPCODE_MASK                     (0xFFFF0000U)
#define ENET_OPD_OPCODE_SHIFT                    (16U)
#define ENET_OPD_OPCODE(x)                       (((uint32_t)(((uint32_t)(x)) << ENET_OPD_OPCODE_SHIFT)) & ENET_OPD_OPCODE_MASK)

/*! @name TXIC - Transmit Interrupt Coalescing Register */
#define ENET_TXIC_ICTT_MASK                      (0xFFFFU)
#define ENET_TXIC_ICTT_SHIFT                     (0U)
#define ENET_TXIC_ICTT(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_TXIC_ICTT_SHIFT)) & ENET_TXIC_ICTT_MASK)
#define ENET_TXIC_ICFT_MASK                      (0xFF00000U)
#define ENET_TXIC_ICFT_SHIFT                     (20U)
#define ENET_TXIC_ICFT(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_TXIC_ICFT_SHIFT)) & ENET_TXIC_ICFT_MASK)
#define ENET_TXIC_ICCS_MASK                      (0x40000000U)
#define ENET_TXIC_ICCS_SHIFT                     (30U)
#define ENET_TXIC_ICEN_MASK                      (0x80000000U)
#define ENET_TXIC_ICEN_SHIFT                     (31U)

/* The count of ENET_TXIC */
#define ENET_TXIC_COUNT                          (3U)

/*! @name RXIC - Receive Interrupt Coalescing Register */
#define ENET_RXIC_ICTT_MASK                      (0xFFFFU)
#define ENET_RXIC_ICTT_SHIFT                     (0U)
#define ENET_RXIC_ICTT(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_RXIC_ICTT_SHIFT)) & ENET_RXIC_ICTT_MASK)
#define ENET_RXIC_ICFT_MASK                      (0xFF00000U)
#define ENET_RXIC_ICFT_SHIFT                     (20U)
#define ENET_RXIC_ICFT(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_RXIC_ICFT_SHIFT)) & ENET_RXIC_ICFT_MASK)
#define ENET_RXIC_ICCS_MASK                      (0x40000000U)
#define ENET_RXIC_ICCS_SHIFT                     (30U)
#define ENET_RXIC_ICEN_MASK                      (0x80000000U)
#define ENET_RXIC_ICEN_SHIFT                     (31U)

/* The count of ENET_RXIC */
#define ENET_RXIC_COUNT                          (3U)

/*! @name IAUR - Descriptor Individual Upper Address Register */
#define ENET_IAUR_IADDR1_MASK                    (0xFFFFFFFFU)
#define ENET_IAUR_IADDR1_SHIFT                   (0U)
#define ENET_IAUR_IADDR1(x)                      (((uint32_t)(((uint32_t)(x)) << ENET_IAUR_IADDR1_SHIFT)) & ENET_IAUR_IADDR1_MASK)

/*! @name IALR - Descriptor Individual Lower Address Register */
#define ENET_IALR_IADDR2_MASK                    (0xFFFFFFFFU)
#define ENET_IALR_IADDR2_SHIFT                   (0U)
#define ENET_IALR_IADDR2(x)                      (((uint32_t)(((uint32_t)(x)) << ENET_IALR_IADDR2_SHIFT)) & ENET_IALR_IADDR2_MASK)

/*! @name GAUR - Descriptor Group Upper Address Register */
#define ENET_GAUR_GADDR1_MASK                    (0xFFFFFFFFU)
#define ENET_GAUR_GADDR1_SHIFT                   (0U)
#define ENET_GAUR_GADDR1(x)                      (((uint32_t)(((uint32_t)(x)) << ENET_GAUR_GADDR1_SHIFT)) & ENET_GAUR_GADDR1_MASK)

/*! @name GALR - Descriptor Group Lower Address Register */
#define ENET_GALR_GADDR2_MASK                    (0xFFFFFFFFU)
#define ENET_GALR_GADDR2_SHIFT                   (0U)
#define ENET_GALR_GADDR2(x)                      (((uint32_t)(((uint32_t)(x)) << ENET_GALR_GADDR2_SHIFT)) & ENET_GALR_GADDR2_MASK)

/*! @name TFWR - Transmit FIFO Watermark Register */
#define ENET_TFWR_TFWR_MASK                      (0x3FU)
#define ENET_TFWR_TFWR_SHIFT                     (0U)
#define ENET_TFWR_TFWR(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_TFWR_TFWR_SHIFT)) & ENET_TFWR_TFWR_MASK)
#define ENET_TFWR_STRFWD_MASK                    (0x100U)
#define ENET_TFWR_STRFWD_SHIFT                   (8U)

/*! @name RDSR1 - Receive Descriptor Ring 1 Start Register */
#define ENET_RDSR1_R_DES_START_MASK              (0xFFFFFFF8U)
#define ENET_RDSR1_R_DES_START_SHIFT             (3U)
#define ENET_RDSR1_R_DES_START(x)                (((uint32_t)(((uint32_t)(x)) << ENET_RDSR1_R_DES_START_SHIFT)) & ENET_RDSR1_R_DES_START_MASK)

/*! @name TDSR1 - Transmit Buffer Descriptor Ring 1 Start Register */
#define ENET_TDSR1_X_DES_START_MASK              (0xFFFFFFF8U)
#define ENET_TDSR1_X_DES_START_SHIFT             (3U)
#define ENET_TDSR1_X_DES_START(x)                (((uint32_t)(((uint32_t)(x)) << ENET_TDSR1_X_DES_START_SHIFT)) & ENET_TDSR1_X_DES_START_MASK)

/*! @name MRBR1 - Maximum Receive Buffer Size Register - Ring 1 */
#define ENET_MRBR1_R_BUF_SIZE_MASK               (0x7F0U)
#define ENET_MRBR1_R_BUF_SIZE_SHIFT              (4U)
#define ENET_MRBR1_R_BUF_SIZE(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_MRBR1_R_BUF_SIZE_SHIFT)) & ENET_MRBR1_R_BUF_SIZE_MASK)

/*! @name RDSR2 - Receive Descriptor Ring 2 Start Register */
#define ENET_RDSR2_R_DES_START_MASK              (0xFFFFFFF8U)
#define ENET_RDSR2_R_DES_START_SHIFT             (3U)
#define ENET_RDSR2_R_DES_START(x)                (((uint32_t)(((uint32_t)(x)) << ENET_RDSR2_R_DES_START_SHIFT)) & ENET_RDSR2_R_DES_START_MASK)

/*! @name TDSR2 - Transmit Buffer Descriptor Ring 2 Start Register */
#define ENET_TDSR2_X_DES_START_MASK              (0xFFFFFFF8U)
#define ENET_TDSR2_X_DES_START_SHIFT             (3U)
#define ENET_TDSR2_X_DES_START(x)                (((uint32_t)(((uint32_t)(x)) << ENET_TDSR2_X_DES_START_SHIFT)) & ENET_TDSR2_X_DES_START_MASK)

/*! @name MRBR2 - Maximum Receive Buffer Size Register - Ring 2 */
#define ENET_MRBR2_R_BUF_SIZE_MASK               (0x7F0U)
#define ENET_MRBR2_R_BUF_SIZE_SHIFT              (4U)
#define ENET_MRBR2_R_BUF_SIZE(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_MRBR2_R_BUF_SIZE_SHIFT)) & ENET_MRBR2_R_BUF_SIZE_MASK)

/*! @name RDSR - Receive Descriptor Ring 0 Start Register */
#define ENET_RDSR_R_DES_START_MASK               (0xFFFFFFF8U)
#define ENET_RDSR_R_DES_START_SHIFT              (3U)
#define ENET_RDSR_R_DES_START(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_RDSR_R_DES_START_SHIFT)) & ENET_RDSR_R_DES_START_MASK)

/*! @name TDSR - Transmit Buffer Descriptor Ring 0 Start Register */
#define ENET_TDSR_X_DES_START_MASK               (0xFFFFFFF8U)
#define ENET_TDSR_X_DES_START_SHIFT              (3U)
#define ENET_TDSR_X_DES_START(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_TDSR_X_DES_START_SHIFT)) & ENET_TDSR_X_DES_START_MASK)

/*! @name MRBR - Maximum Receive Buffer Size Register - Ring 0 */
#define ENET_MRBR_R_BUF_SIZE_MASK                (0x7F0U)
#define ENET_MRBR_R_BUF_SIZE_SHIFT               (4U)
#define ENET_MRBR_R_BUF_SIZE(x)                  (((uint32_t)(((uint32_t)(x)) << ENET_MRBR_R_BUF_SIZE_SHIFT)) & ENET_MRBR_R_BUF_SIZE_MASK)

/*! @name RSFL - Receive FIFO Section Full Threshold */
#define ENET_RSFL_RX_SECTION_FULL_MASK           (0x3FFU)
#define ENET_RSFL_RX_SECTION_FULL_SHIFT          (0U)
#define ENET_RSFL_RX_SECTION_FULL(x)             (((uint32_t)(((uint32_t)(x)) << ENET_RSFL_RX_SECTION_FULL_SHIFT)) & ENET_RSFL_RX_SECTION_FULL_MASK)

/*! @name RSEM - Receive FIFO Section Empty Threshold */
#define ENET_RSEM_RX_SECTION_EMPTY_MASK          (0x3FFU)
#define ENET_RSEM_RX_SECTION_EMPTY_SHIFT         (0U)
#define ENET_RSEM_RX_SECTION_EMPTY(x)            (((uint32_t)(((uint32_t)(x)) << ENET_RSEM_RX_SECTION_EMPTY_SHIFT)) & ENET_RSEM_RX_SECTION_EMPTY_MASK)
#define ENET_RSEM_STAT_SECTION_EMPTY_MASK        (0x1F0000U)
#define ENET_RSEM_STAT_SECTION_EMPTY_SHIFT       (16U)
#define ENET_RSEM_STAT_SECTION_EMPTY(x)          (((uint32_t)(((uint32_t)(x)) << ENET_RSEM_STAT_SECTION_EMPTY_SHIFT)) & ENET_RSEM_STAT_SECTION_EMPTY_MASK)

/*! @name RAEM - Receive FIFO Almost Empty Threshold */
#define ENET_RAEM_RX_ALMOST_EMPTY_MASK           (0x3FFU)
#define ENET_RAEM_RX_ALMOST_EMPTY_SHIFT          (0U)
#define ENET_RAEM_RX_ALMOST_EMPTY(x)             (((uint32_t)(((uint32_t)(x)) << ENET_RAEM_RX_ALMOST_EMPTY_SHIFT)) & ENET_RAEM_RX_ALMOST_EMPTY_MASK)

/*! @name RAFL - Receive FIFO Almost Full Threshold */
#define ENET_RAFL_RX_ALMOST_FULL_MASK            (0x3FFU)
#define ENET_RAFL_RX_ALMOST_FULL_SHIFT           (0U)
#define ENET_RAFL_RX_ALMOST_FULL(x)              (((uint32_t)(((uint32_t)(x)) << ENET_RAFL_RX_ALMOST_FULL_SHIFT)) & ENET_RAFL_RX_ALMOST_FULL_MASK)

/*! @name TSEM - Transmit FIFO Section Empty Threshold */
#define ENET_TSEM_TX_SECTION_EMPTY_MASK          (0x3FFU)
#define ENET_TSEM_TX_SECTION_EMPTY_SHIFT         (0U)
#define ENET_TSEM_TX_SECTION_EMPTY(x)            (((uint32_t)(((uint32_t)(x)) << ENET_TSEM_TX_SECTION_EMPTY_SHIFT)) & ENET_TSEM_TX_SECTION_EMPTY_MASK)

/*! @name TAEM - Transmit FIFO Almost Empty Threshold */
#define ENET_TAEM_TX_ALMOST_EMPTY_MASK           (0x3FFU)
#define ENET_TAEM_TX_ALMOST_EMPTY_SHIFT          (0U)
#define ENET_TAEM_TX_ALMOST_EMPTY(x)             (((uint32_t)(((uint32_t)(x)) << ENET_TAEM_TX_ALMOST_EMPTY_SHIFT)) & ENET_TAEM_TX_ALMOST_EMPTY_MASK)

/*! @name TAFL - Transmit FIFO Almost Full Threshold */
#define ENET_TAFL_TX_ALMOST_FULL_MASK            (0x3FFU)
#define ENET_TAFL_TX_ALMOST_FULL_SHIFT           (0U)
#define ENET_TAFL_TX_ALMOST_FULL(x)              (((uint32_t)(((uint32_t)(x)) << ENET_TAFL_TX_ALMOST_FULL_SHIFT)) & ENET_TAFL_TX_ALMOST_FULL_MASK)

/*! @name TIPG - Transmit Inter-Packet Gap */
#define ENET_TIPG_IPG_MASK                       (0x1FU)
#define ENET_TIPG_IPG_SHIFT                      (0U)
#define ENET_TIPG_IPG(x)                         (((uint32_t)(((uint32_t)(x)) << ENET_TIPG_IPG_SHIFT)) & ENET_TIPG_IPG_MASK)

/*! @name FTRL - Frame Truncation Length */
#define ENET_FTRL_TRUNC_FL_MASK                  (0x3FFFU)
#define ENET_FTRL_TRUNC_FL_SHIFT                 (0U)
#define ENET_FTRL_TRUNC_FL(x)                    (((uint32_t)(((uint32_t)(x)) << ENET_FTRL_TRUNC_FL_SHIFT)) & ENET_FTRL_TRUNC_FL_MASK)

/*! @name TACC - Transmit Accelerator Function Configuration */
#define ENET_TACC_SHIFT16_MASK                   (0x1U)
#define ENET_TACC_SHIFT16_SHIFT                  (0U)
#define ENET_TACC_IPCHK_MASK                     (0x8U)
#define ENET_TACC_IPCHK_SHIFT                    (3U)
#define ENET_TACC_PROCHK_MASK                    (0x10U)
#define ENET_TACC_PROCHK_SHIFT                   (4U)

/*! @name RACC - Receive Accelerator Function Configuration */
#define ENET_RACC_PADREM_MASK                    (0x1U)
#define ENET_RACC_PADREM_SHIFT                   (0U)
#define ENET_RACC_IPDIS_MASK                     (0x2U)
#define ENET_RACC_IPDIS_SHIFT                    (1U)
#define ENET_RACC_PRODIS_MASK                    (0x4U)
#define ENET_RACC_PRODIS_SHIFT                   (2U)
#define ENET_RACC_LINEDIS_MASK                   (0x40U)
#define ENET_RACC_LINEDIS_SHIFT                  (6U)
#define ENET_RACC_SHIFT16_MASK                   (0x80U)
#define ENET_RACC_SHIFT16_SHIFT                  (7U)

/*! @name RCMR - Receive Classification Match Register for Class n */
#define ENET_RCMR_CMP0_MASK                      (0x7U)
#define ENET_RCMR_CMP0_SHIFT                     (0U)
#define ENET_RCMR_CMP0(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_RCMR_CMP0_SHIFT)) & ENET_RCMR_CMP0_MASK)
#define ENET_RCMR_CMP1_MASK                      (0x70U)
#define ENET_RCMR_CMP1_SHIFT                     (4U)
#define ENET_RCMR_CMP1(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_RCMR_CMP1_SHIFT)) & ENET_RCMR_CMP1_MASK)
#define ENET_RCMR_CMP2_MASK                      (0x700U)
#define ENET_RCMR_CMP2_SHIFT                     (8U)
#define ENET_RCMR_CMP2(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_RCMR_CMP2_SHIFT)) & ENET_RCMR_CMP2_MASK)
#define ENET_RCMR_CMP3_MASK                      (0x7000U)
#define ENET_RCMR_CMP3_SHIFT                     (12U)
#define ENET_RCMR_CMP3(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_RCMR_CMP3_SHIFT)) & ENET_RCMR_CMP3_MASK)
#define ENET_RCMR_MATCHEN_MASK                   (0x10000U)
#define ENET_RCMR_MATCHEN_SHIFT                  (16U)

/* The count of ENET_RCMR */
#define ENET_RCMR_COUNT                          (2U)

/*! @name DMACFG - DMA Class Based Configuration */
#define ENET_DMACFG_IDLE_SLOPE_MASK              (0xFFFFU)
#define ENET_DMACFG_IDLE_SLOPE_SHIFT             (0U)
#define ENET_DMACFG_IDLE_SLOPE(x)                (((uint32_t)(((uint32_t)(x)) << ENET_DMACFG_IDLE_SLOPE_SHIFT)) & ENET_DMACFG_IDLE_SLOPE_MASK)
#define ENET_DMACFG_DMA_CLASS_EN_MASK            (0x10000U)
#define ENET_DMACFG_DMA_CLASS_EN_SHIFT           (16U)
#define ENET_DMACFG_CALC_NOIPG_MASK              (0x20000U)
#define ENET_DMACFG_CALC_NOIPG_SHIFT             (17U)

/* The count of ENET_DMACFG */
#define ENET_DMACFG_COUNT                        (2U)

/*! @name RDAR1 - Receive Descriptor Active Register - Ring 1 */
#define ENET_RDAR1_RDAR_MASK                     (0x1000000U)
#define ENET_RDAR1_RDAR_SHIFT                    (24U)

/*! @name TDAR1 - Transmit Descriptor Active Register - Ring 1 */
#define ENET_TDAR1_TDAR_MASK                     (0x1000000U)
#define ENET_TDAR1_TDAR_SHIFT                    (24U)

/*! @name RDAR2 - Receive Descriptor Active Register - Ring 2 */
#define ENET_RDAR2_RDAR_MASK                     (0x1000000U)
#define ENET_RDAR2_RDAR_SHIFT                    (24U)

/*! @name TDAR2 - Transmit Descriptor Active Register - Ring 2 */
#define ENET_TDAR2_TDAR_MASK                     (0x1000000U)
#define ENET_TDAR2_TDAR_SHIFT                    (24U)

/*! @name QOS - QOS Scheme */
#define ENET_QOS_TX_SCHEME_MASK                  (0x7U)
#define ENET_QOS_TX_SCHEME_SHIFT                 (0U)
#define ENET_QOS_TX_SCHEME(x)                    (((uint32_t)(((uint32_t)(x)) << ENET_QOS_TX_SCHEME_SHIFT)) & ENET_QOS_TX_SCHEME_MASK)
#define ENET_QOS_RX_FLUSH0_MASK                  (0x8U)
#define ENET_QOS_RX_FLUSH0_SHIFT                 (3U)
#define ENET_QOS_RX_FLUSH1_MASK                  (0x10U)
#define ENET_QOS_RX_FLUSH1_SHIFT                 (4U)
#define ENET_QOS_RX_FLUSH2_MASK                  (0x20U)
#define ENET_QOS_RX_FLUSH2_SHIFT                 (5U)

/*! @name RMON_T_PACKETS - Tx Packet Count Statistic Register */
#define ENET_RMON_T_PACKETS_TXPKTS_MASK          (0xFFFFU)
#define ENET_RMON_T_PACKETS_TXPKTS_SHIFT         (0U)
#define ENET_RMON_T_PACKETS_TXPKTS(x)            (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_PACKETS_TXPKTS_SHIFT)) & ENET_RMON_T_PACKETS_TXPKTS_MASK)

/*! @name RMON_T_BC_PKT - Tx Broadcast Packets Statistic Register */
#define ENET_RMON_T_BC_PKT_TXPKTS_MASK           (0xFFFFU)
#define ENET_RMON_T_BC_PKT_TXPKTS_SHIFT          (0U)
#define ENET_RMON_T_BC_PKT_TXPKTS(x)             (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_BC_PKT_TXPKTS_SHIFT)) & ENET_RMON_T_BC_PKT_TXPKTS_MASK)

/*! @name RMON_T_MC_PKT - Tx Multicast Packets Statistic Register */
#define ENET_RMON_T_MC_PKT_TXPKTS_MASK           (0xFFFFU)
#define ENET_RMON_T_MC_PKT_TXPKTS_SHIFT          (0U)
#define ENET_RMON_T_MC_PKT_TXPKTS(x)             (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_MC_PKT_TXPKTS_SHIFT)) & ENET_RMON_T_MC_PKT_TXPKTS_MASK)

/*! @name RMON_T_CRC_ALIGN - Tx Packets with CRC/Align Error Statistic Register */
#define ENET_RMON_T_CRC_ALIGN_TXPKTS_MASK        (0xFFFFU)
#define ENET_RMON_T_CRC_ALIGN_TXPKTS_SHIFT       (0U)
#define ENET_RMON_T_CRC_ALIGN_TXPKTS(x)          (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_CRC_ALIGN_TXPKTS_SHIFT)) & ENET_RMON_T_CRC_ALIGN_TXPKTS_MASK)

/*! @name RMON_T_UNDERSIZE - Tx Packets Less Than Bytes and Good CRC Statistic Register */
#define ENET_RMON_T_UNDERSIZE_TXPKTS_MASK        (0xFFFFU)
#define ENET_RMON_T_UNDERSIZE_TXPKTS_SHIFT       (0U)
#define ENET_RMON_T_UNDERSIZE_TXPKTS(x)          (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_UNDERSIZE_TXPKTS_SHIFT)) & ENET_RMON_T_UNDERSIZE_TXPKTS_MASK)

/*! @name RMON_T_OVERSIZE - Tx Packets GT MAX_FL bytes and Good CRC Statistic Register */
#define ENET_RMON_T_OVERSIZE_TXPKTS_MASK         (0xFFFFU)
#define ENET_RMON_T_OVERSIZE_TXPKTS_SHIFT        (0U)
#define ENET_RMON_T_OVERSIZE_TXPKTS(x)           (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_OVERSIZE_TXPKTS_SHIFT)) & ENET_RMON_T_OVERSIZE_TXPKTS_MASK)

/*! @name RMON_T_FRAG - Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register */
#define ENET_RMON_T_FRAG_TXPKTS_MASK             (0xFFFFU)
#define ENET_RMON_T_FRAG_TXPKTS_SHIFT            (0U)
#define ENET_RMON_T_FRAG_TXPKTS(x)               (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_FRAG_TXPKTS_SHIFT)) & ENET_RMON_T_FRAG_TXPKTS_MASK)

/*! @name RMON_T_JAB - Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register */
#define ENET_RMON_T_JAB_TXPKTS_MASK              (0xFFFFU)
#define ENET_RMON_T_JAB_TXPKTS_SHIFT             (0U)
#define ENET_RMON_T_JAB_TXPKTS(x)                (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_JAB_TXPKTS_SHIFT)) & ENET_RMON_T_JAB_TXPKTS_MASK)

/*! @name RMON_T_COL - Tx Collision Count Statistic Register */
#define ENET_RMON_T_COL_TXPKTS_MASK              (0xFFFFU)
#define ENET_RMON_T_COL_TXPKTS_SHIFT             (0U)
#define ENET_RMON_T_COL_TXPKTS(x)                (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_COL_TXPKTS_SHIFT)) & ENET_RMON_T_COL_TXPKTS_MASK)

/*! @name RMON_T_P64 - Tx 64-Byte Packets Statistic Register */
#define ENET_RMON_T_P64_TXPKTS_MASK              (0xFFFFU)
#define ENET_RMON_T_P64_TXPKTS_SHIFT             (0U)
#define ENET_RMON_T_P64_TXPKTS(x)                (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_P64_TXPKTS_SHIFT)) & ENET_RMON_T_P64_TXPKTS_MASK)

/*! @name RMON_T_P65TO127 - Tx 65- to 127-byte Packets Statistic Register */
#define ENET_RMON_T_P65TO127_TXPKTS_MASK         (0xFFFFU)
#define ENET_RMON_T_P65TO127_TXPKTS_SHIFT        (0U)
#define ENET_RMON_T_P65TO127_TXPKTS(x)           (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_P65TO127_TXPKTS_SHIFT)) & ENET_RMON_T_P65TO127_TXPKTS_MASK)

/*! @name RMON_T_P128TO255 - Tx 128- to 255-byte Packets Statistic Register */
#define ENET_RMON_T_P128TO255_TXPKTS_MASK        (0xFFFFU)
#define ENET_RMON_T_P128TO255_TXPKTS_SHIFT       (0U)
#define ENET_RMON_T_P128TO255_TXPKTS(x)          (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_P128TO255_TXPKTS_SHIFT)) & ENET_RMON_T_P128TO255_TXPKTS_MASK)

/*! @name RMON_T_P256TO511 - Tx 256- to 511-byte Packets Statistic Register */
#define ENET_RMON_T_P256TO511_TXPKTS_MASK        (0xFFFFU)
#define ENET_RMON_T_P256TO511_TXPKTS_SHIFT       (0U)
#define ENET_RMON_T_P256TO511_TXPKTS(x)          (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_P256TO511_TXPKTS_SHIFT)) & ENET_RMON_T_P256TO511_TXPKTS_MASK)

/*! @name RMON_T_P512TO1023 - Tx 512- to 1023-byte Packets Statistic Register */
#define ENET_RMON_T_P512TO1023_TXPKTS_MASK       (0xFFFFU)
#define ENET_RMON_T_P512TO1023_TXPKTS_SHIFT      (0U)
#define ENET_RMON_T_P512TO1023_TXPKTS(x)         (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_P512TO1023_TXPKTS_SHIFT)) & ENET_RMON_T_P512TO1023_TXPKTS_MASK)

/*! @name RMON_T_P1024TO2047 - Tx 1024- to 2047-byte Packets Statistic Register */
#define ENET_RMON_T_P1024TO2047_TXPKTS_MASK      (0xFFFFU)
#define ENET_RMON_T_P1024TO2047_TXPKTS_SHIFT     (0U)
#define ENET_RMON_T_P1024TO2047_TXPKTS(x)        (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_P1024TO2047_TXPKTS_SHIFT)) & ENET_RMON_T_P1024TO2047_TXPKTS_MASK)

/*! @name RMON_T_P_GTE2048 - Tx Packets Greater Than 2048 Bytes Statistic Register */
#define ENET_RMON_T_P_GTE2048_TXPKTS_MASK        (0xFFFFU)
#define ENET_RMON_T_P_GTE2048_TXPKTS_SHIFT       (0U)
#define ENET_RMON_T_P_GTE2048_TXPKTS(x)          (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_P_GTE2048_TXPKTS_SHIFT)) & ENET_RMON_T_P_GTE2048_TXPKTS_MASK)

/*! @name RMON_T_OCTETS - Tx Octets Statistic Register */
#define ENET_RMON_T_OCTETS_TXOCTS_MASK           (0xFFFFFFFFU)
#define ENET_RMON_T_OCTETS_TXOCTS_SHIFT          (0U)
#define ENET_RMON_T_OCTETS_TXOCTS(x)             (((uint32_t)(((uint32_t)(x)) << ENET_RMON_T_OCTETS_TXOCTS_SHIFT)) & ENET_RMON_T_OCTETS_TXOCTS_MASK)

/*! @name IEEE_T_FRAME_OK - Frames Transmitted OK Statistic Register */
#define ENET_IEEE_T_FRAME_OK_COUNT_MASK          (0xFFFFU)
#define ENET_IEEE_T_FRAME_OK_COUNT_SHIFT         (0U)
#define ENET_IEEE_T_FRAME_OK_COUNT(x)            (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_FRAME_OK_COUNT_SHIFT)) & ENET_IEEE_T_FRAME_OK_COUNT_MASK)

/*! @name IEEE_T_1COL - Frames Transmitted with Single Collision Statistic Register */
#define ENET_IEEE_T_1COL_COUNT_MASK              (0xFFFFU)
#define ENET_IEEE_T_1COL_COUNT_SHIFT             (0U)
#define ENET_IEEE_T_1COL_COUNT(x)                (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_1COL_COUNT_SHIFT)) & ENET_IEEE_T_1COL_COUNT_MASK)

/*! @name IEEE_T_MCOL - Frames Transmitted with Multiple Collisions Statistic Register */
#define ENET_IEEE_T_MCOL_COUNT_MASK              (0xFFFFU)
#define ENET_IEEE_T_MCOL_COUNT_SHIFT             (0U)
#define ENET_IEEE_T_MCOL_COUNT(x)                (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_MCOL_COUNT_SHIFT)) & ENET_IEEE_T_MCOL_COUNT_MASK)

/*! @name IEEE_T_DEF - Frames Transmitted after Deferral Delay Statistic Register */
#define ENET_IEEE_T_DEF_COUNT_MASK               (0xFFFFU)
#define ENET_IEEE_T_DEF_COUNT_SHIFT              (0U)
#define ENET_IEEE_T_DEF_COUNT(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_DEF_COUNT_SHIFT)) & ENET_IEEE_T_DEF_COUNT_MASK)

/*! @name IEEE_T_LCOL - Frames Transmitted with Late Collision Statistic Register */
#define ENET_IEEE_T_LCOL_COUNT_MASK              (0xFFFFU)
#define ENET_IEEE_T_LCOL_COUNT_SHIFT             (0U)
#define ENET_IEEE_T_LCOL_COUNT(x)                (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_LCOL_COUNT_SHIFT)) & ENET_IEEE_T_LCOL_COUNT_MASK)

/*! @name IEEE_T_EXCOL - Frames Transmitted with Excessive Collisions Statistic Register */
#define ENET_IEEE_T_EXCOL_COUNT_MASK             (0xFFFFU)
#define ENET_IEEE_T_EXCOL_COUNT_SHIFT            (0U)
#define ENET_IEEE_T_EXCOL_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_EXCOL_COUNT_SHIFT)) & ENET_IEEE_T_EXCOL_COUNT_MASK)

/*! @name IEEE_T_MACERR - Frames Transmitted with Tx FIFO Underrun Statistic Register */
#define ENET_IEEE_T_MACERR_COUNT_MASK            (0xFFFFU)
#define ENET_IEEE_T_MACERR_COUNT_SHIFT           (0U)
#define ENET_IEEE_T_MACERR_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_MACERR_COUNT_SHIFT)) & ENET_IEEE_T_MACERR_COUNT_MASK)

/*! @name IEEE_T_CSERR - Frames Transmitted with Carrier Sense Error Statistic Register */
#define ENET_IEEE_T_CSERR_COUNT_MASK             (0xFFFFU)
#define ENET_IEEE_T_CSERR_COUNT_SHIFT            (0U)
#define ENET_IEEE_T_CSERR_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_CSERR_COUNT_SHIFT)) & ENET_IEEE_T_CSERR_COUNT_MASK)

/*! @name IEEE_T_SQE - Reserved Statistic Register */
#define ENET_IEEE_T_SQE_COUNT_MASK               (0xFFFFU)
#define ENET_IEEE_T_SQE_COUNT_SHIFT              (0U)
#define ENET_IEEE_T_SQE_COUNT(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_SQE_COUNT_SHIFT)) & ENET_IEEE_T_SQE_COUNT_MASK)

/*! @name IEEE_T_FDXFC - Flow Control Pause Frames Transmitted Statistic Register */
#define ENET_IEEE_T_FDXFC_COUNT_MASK             (0xFFFFU)
#define ENET_IEEE_T_FDXFC_COUNT_SHIFT            (0U)
#define ENET_IEEE_T_FDXFC_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_FDXFC_COUNT_SHIFT)) & ENET_IEEE_T_FDXFC_COUNT_MASK)

/*! @name IEEE_T_OCTETS_OK - Octet Count for Frames Transmitted w/o Error Statistic Register */
#define ENET_IEEE_T_OCTETS_OK_COUNT_MASK         (0xFFFFFFFFU)
#define ENET_IEEE_T_OCTETS_OK_COUNT_SHIFT        (0U)
#define ENET_IEEE_T_OCTETS_OK_COUNT(x)           (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_T_OCTETS_OK_COUNT_SHIFT)) & ENET_IEEE_T_OCTETS_OK_COUNT_MASK)

/*! @name RMON_R_PACKETS - Rx Packet Count Statistic Register */
#define ENET_RMON_R_PACKETS_COUNT_MASK           (0xFFFFU)
#define ENET_RMON_R_PACKETS_COUNT_SHIFT          (0U)
#define ENET_RMON_R_PACKETS_COUNT(x)             (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_PACKETS_COUNT_SHIFT)) & ENET_RMON_R_PACKETS_COUNT_MASK)

/*! @name RMON_R_BC_PKT - Rx Broadcast Packets Statistic Register */
#define ENET_RMON_R_BC_PKT_COUNT_MASK            (0xFFFFU)
#define ENET_RMON_R_BC_PKT_COUNT_SHIFT           (0U)
#define ENET_RMON_R_BC_PKT_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_BC_PKT_COUNT_SHIFT)) & ENET_RMON_R_BC_PKT_COUNT_MASK)

/*! @name RMON_R_MC_PKT - Rx Multicast Packets Statistic Register */
#define ENET_RMON_R_MC_PKT_COUNT_MASK            (0xFFFFU)
#define ENET_RMON_R_MC_PKT_COUNT_SHIFT           (0U)
#define ENET_RMON_R_MC_PKT_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_MC_PKT_COUNT_SHIFT)) & ENET_RMON_R_MC_PKT_COUNT_MASK)

/*! @name RMON_R_CRC_ALIGN - Rx Packets with CRC/Align Error Statistic Register */
#define ENET_RMON_R_CRC_ALIGN_COUNT_MASK         (0xFFFFU)
#define ENET_RMON_R_CRC_ALIGN_COUNT_SHIFT        (0U)
#define ENET_RMON_R_CRC_ALIGN_COUNT(x)           (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_CRC_ALIGN_COUNT_SHIFT)) & ENET_RMON_R_CRC_ALIGN_COUNT_MASK)

/*! @name RMON_R_UNDERSIZE - Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register */
#define ENET_RMON_R_UNDERSIZE_COUNT_MASK         (0xFFFFU)
#define ENET_RMON_R_UNDERSIZE_COUNT_SHIFT        (0U)
#define ENET_RMON_R_UNDERSIZE_COUNT(x)           (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_UNDERSIZE_COUNT_SHIFT)) & ENET_RMON_R_UNDERSIZE_COUNT_MASK)

/*! @name RMON_R_OVERSIZE - Rx Packets Greater Than MAX_FL and Good CRC Statistic Register */
#define ENET_RMON_R_OVERSIZE_COUNT_MASK          (0xFFFFU)
#define ENET_RMON_R_OVERSIZE_COUNT_SHIFT         (0U)
#define ENET_RMON_R_OVERSIZE_COUNT(x)            (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_OVERSIZE_COUNT_SHIFT)) & ENET_RMON_R_OVERSIZE_COUNT_MASK)

/*! @name RMON_R_FRAG - Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register */
#define ENET_RMON_R_FRAG_COUNT_MASK              (0xFFFFU)
#define ENET_RMON_R_FRAG_COUNT_SHIFT             (0U)
#define ENET_RMON_R_FRAG_COUNT(x)                (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_FRAG_COUNT_SHIFT)) & ENET_RMON_R_FRAG_COUNT_MASK)

/*! @name RMON_R_JAB - Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register */
#define ENET_RMON_R_JAB_COUNT_MASK               (0xFFFFU)
#define ENET_RMON_R_JAB_COUNT_SHIFT              (0U)
#define ENET_RMON_R_JAB_COUNT(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_JAB_COUNT_SHIFT)) & ENET_RMON_R_JAB_COUNT_MASK)

/*! @name RMON_R_P64 - Rx 64-Byte Packets Statistic Register */
#define ENET_RMON_R_P64_COUNT_MASK               (0xFFFFU)
#define ENET_RMON_R_P64_COUNT_SHIFT              (0U)
#define ENET_RMON_R_P64_COUNT(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_P64_COUNT_SHIFT)) & ENET_RMON_R_P64_COUNT_MASK)

/*! @name RMON_R_P65TO127 - Rx 65- to 127-Byte Packets Statistic Register */
#define ENET_RMON_R_P65TO127_COUNT_MASK          (0xFFFFU)
#define ENET_RMON_R_P65TO127_COUNT_SHIFT         (0U)
#define ENET_RMON_R_P65TO127_COUNT(x)            (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_P65TO127_COUNT_SHIFT)) & ENET_RMON_R_P65TO127_COUNT_MASK)

/*! @name RMON_R_P128TO255 - Rx 128- to 255-Byte Packets Statistic Register */
#define ENET_RMON_R_P128TO255_COUNT_MASK         (0xFFFFU)
#define ENET_RMON_R_P128TO255_COUNT_SHIFT        (0U)
#define ENET_RMON_R_P128TO255_COUNT(x)           (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_P128TO255_COUNT_SHIFT)) & ENET_RMON_R_P128TO255_COUNT_MASK)

/*! @name RMON_R_P256TO511 - Rx 256- to 511-Byte Packets Statistic Register */
#define ENET_RMON_R_P256TO511_COUNT_MASK         (0xFFFFU)
#define ENET_RMON_R_P256TO511_COUNT_SHIFT        (0U)
#define ENET_RMON_R_P256TO511_COUNT(x)           (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_P256TO511_COUNT_SHIFT)) & ENET_RMON_R_P256TO511_COUNT_MASK)

/*! @name RMON_R_P512TO1023 - Rx 512- to 1023-Byte Packets Statistic Register */
#define ENET_RMON_R_P512TO1023_COUNT_MASK        (0xFFFFU)
#define ENET_RMON_R_P512TO1023_COUNT_SHIFT       (0U)
#define ENET_RMON_R_P512TO1023_COUNT(x)          (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_P512TO1023_COUNT_SHIFT)) & ENET_RMON_R_P512TO1023_COUNT_MASK)

/*! @name RMON_R_P1024TO2047 - Rx 1024- to 2047-Byte Packets Statistic Register */
#define ENET_RMON_R_P1024TO2047_COUNT_MASK       (0xFFFFU)
#define ENET_RMON_R_P1024TO2047_COUNT_SHIFT      (0U)
#define ENET_RMON_R_P1024TO2047_COUNT(x)         (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_P1024TO2047_COUNT_SHIFT)) & ENET_RMON_R_P1024TO2047_COUNT_MASK)

/*! @name RMON_R_P_GTE2048 - Rx Packets Greater than 2048 Bytes Statistic Register */
#define ENET_RMON_R_P_GTE2048_COUNT_MASK         (0xFFFFU)
#define ENET_RMON_R_P_GTE2048_COUNT_SHIFT        (0U)
#define ENET_RMON_R_P_GTE2048_COUNT(x)           (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_P_GTE2048_COUNT_SHIFT)) & ENET_RMON_R_P_GTE2048_COUNT_MASK)

/*! @name RMON_R_OCTETS - Rx Octets Statistic Register */
#define ENET_RMON_R_OCTETS_COUNT_MASK            (0xFFFFFFFFU)
#define ENET_RMON_R_OCTETS_COUNT_SHIFT           (0U)
#define ENET_RMON_R_OCTETS_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << ENET_RMON_R_OCTETS_COUNT_SHIFT)) & ENET_RMON_R_OCTETS_COUNT_MASK)

/*! @name IEEE_R_DROP - Frames not Counted Correctly Statistic Register */
#define ENET_IEEE_R_DROP_COUNT_MASK              (0xFFFFU)
#define ENET_IEEE_R_DROP_COUNT_SHIFT             (0U)
#define ENET_IEEE_R_DROP_COUNT(x)                (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_R_DROP_COUNT_SHIFT)) & ENET_IEEE_R_DROP_COUNT_MASK)

/*! @name IEEE_R_FRAME_OK - Frames Received OK Statistic Register */
#define ENET_IEEE_R_FRAME_OK_COUNT_MASK          (0xFFFFU)
#define ENET_IEEE_R_FRAME_OK_COUNT_SHIFT         (0U)
#define ENET_IEEE_R_FRAME_OK_COUNT(x)            (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_R_FRAME_OK_COUNT_SHIFT)) & ENET_IEEE_R_FRAME_OK_COUNT_MASK)

/*! @name IEEE_R_CRC - Frames Received with CRC Error Statistic Register */
#define ENET_IEEE_R_CRC_COUNT_MASK               (0xFFFFU)
#define ENET_IEEE_R_CRC_COUNT_SHIFT              (0U)
#define ENET_IEEE_R_CRC_COUNT(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_R_CRC_COUNT_SHIFT)) & ENET_IEEE_R_CRC_COUNT_MASK)

/*! @name IEEE_R_ALIGN - Frames Received with Alignment Error Statistic Register */
#define ENET_IEEE_R_ALIGN_COUNT_MASK             (0xFFFFU)
#define ENET_IEEE_R_ALIGN_COUNT_SHIFT            (0U)
#define ENET_IEEE_R_ALIGN_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_R_ALIGN_COUNT_SHIFT)) & ENET_IEEE_R_ALIGN_COUNT_MASK)

/*! @name IEEE_R_MACERR - Receive FIFO Overflow Count Statistic Register */
#define ENET_IEEE_R_MACERR_COUNT_MASK            (0xFFFFU)
#define ENET_IEEE_R_MACERR_COUNT_SHIFT           (0U)
#define ENET_IEEE_R_MACERR_COUNT(x)              (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_R_MACERR_COUNT_SHIFT)) & ENET_IEEE_R_MACERR_COUNT_MASK)

/*! @name IEEE_R_FDXFC - Flow Control Pause Frames Received Statistic Register */
#define ENET_IEEE_R_FDXFC_COUNT_MASK             (0xFFFFU)
#define ENET_IEEE_R_FDXFC_COUNT_SHIFT            (0U)
#define ENET_IEEE_R_FDXFC_COUNT(x)               (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_R_FDXFC_COUNT_SHIFT)) & ENET_IEEE_R_FDXFC_COUNT_MASK)

/*! @name IEEE_R_OCTETS_OK - Octet Count for Frames Received without Error Statistic Register */
#define ENET_IEEE_R_OCTETS_OK_COUNT_MASK         (0xFFFFFFFFU)
#define ENET_IEEE_R_OCTETS_OK_COUNT_SHIFT        (0U)
#define ENET_IEEE_R_OCTETS_OK_COUNT(x)           (((uint32_t)(((uint32_t)(x)) << ENET_IEEE_R_OCTETS_OK_COUNT_SHIFT)) & ENET_IEEE_R_OCTETS_OK_COUNT_MASK)

/*! @name ATCR - Adjustable Timer Control Register */
#define ENET_ATCR_EN_MASK                        (0x1U)
#define ENET_ATCR_EN_SHIFT                       (0U)
#define ENET_ATCR_OFFEN_MASK                     (0x4U)
#define ENET_ATCR_OFFEN_SHIFT                    (2U)
#define ENET_ATCR_OFFRST_MASK                    (0x8U)
#define ENET_ATCR_OFFRST_SHIFT                   (3U)
#define ENET_ATCR_PEREN_MASK                     (0x10U)
#define ENET_ATCR_PEREN_SHIFT                    (4U)
#define ENET_ATCR_PINPER_MASK                    (0x80U)
#define ENET_ATCR_PINPER_SHIFT                   (7U)
#define ENET_ATCR_RESTART_MASK                   (0x200U)
#define ENET_ATCR_RESTART_SHIFT                  (9U)
#define ENET_ATCR_CAPTURE_MASK                   (0x800U)
#define ENET_ATCR_CAPTURE_SHIFT                  (11U)
#define ENET_ATCR_SLAVE_MASK                     (0x2000U)
#define ENET_ATCR_SLAVE_SHIFT                    (13U)

/*! @name ATVR - Timer Value Register */
#define ENET_ATVR_ATIME_MASK                     (0xFFFFFFFFU)
#define ENET_ATVR_ATIME_SHIFT                    (0U)
#define ENET_ATVR_ATIME(x)                       (((uint32_t)(((uint32_t)(x)) << ENET_ATVR_ATIME_SHIFT)) & ENET_ATVR_ATIME_MASK)

/*! @name ATOFF - Timer Offset Register */
#define ENET_ATOFF_OFFSET_MASK                   (0xFFFFFFFFU)
#define ENET_ATOFF_OFFSET_SHIFT                  (0U)
#define ENET_ATOFF_OFFSET(x)                     (((uint32_t)(((uint32_t)(x)) << ENET_ATOFF_OFFSET_SHIFT)) & ENET_ATOFF_OFFSET_MASK)

/*! @name ATPER - Timer Period Register */
#define ENET_ATPER_PERIOD_MASK                   (0xFFFFFFFFU)
#define ENET_ATPER_PERIOD_SHIFT                  (0U)
#define ENET_ATPER_PERIOD(x)                     (((uint32_t)(((uint32_t)(x)) << ENET_ATPER_PERIOD_SHIFT)) & ENET_ATPER_PERIOD_MASK)

/*! @name ATCOR - Timer Correction Register */
#define ENET_ATCOR_COR_MASK                      (0x7FFFFFFFU)
#define ENET_ATCOR_COR_SHIFT                     (0U)
#define ENET_ATCOR_COR(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_ATCOR_COR_SHIFT)) & ENET_ATCOR_COR_MASK)

/*! @name ATINC - Time-Stamping Clock Period Register */
#define ENET_ATINC_INC_MASK                      (0x7FU)
#define ENET_ATINC_INC_SHIFT                     (0U)
#define ENET_ATINC_INC(x)                        (((uint32_t)(((uint32_t)(x)) << ENET_ATINC_INC_SHIFT)) & ENET_ATINC_INC_MASK)
#define ENET_ATINC_INC_CORR_MASK                 (0x7F00U)
#define ENET_ATINC_INC_CORR_SHIFT                (8U)
#define ENET_ATINC_INC_CORR(x)                   (((uint32_t)(((uint32_t)(x)) << ENET_ATINC_INC_CORR_SHIFT)) & ENET_ATINC_INC_CORR_MASK)

/*! @name ATSTMP - Timestamp of Last Transmitted Frame */
#define ENET_ATSTMP_TIMESTAMP_MASK               (0xFFFFFFFFU)
#define ENET_ATSTMP_TIMESTAMP_SHIFT              (0U)
#define ENET_ATSTMP_TIMESTAMP(x)                 (((uint32_t)(((uint32_t)(x)) << ENET_ATSTMP_TIMESTAMP_SHIFT)) & ENET_ATSTMP_TIMESTAMP_MASK)

/*! @name TGSR - Timer Global Status Register */
#define ENET_TGSR_TF0_MASK                       (0x1U)
#define ENET_TGSR_TF0_SHIFT                      (0U)
#define ENET_TGSR_TF1_MASK                       (0x2U)
#define ENET_TGSR_TF1_SHIFT                      (1U)
#define ENET_TGSR_TF2_MASK                       (0x4U)
#define ENET_TGSR_TF2_SHIFT                      (2U)
#define ENET_TGSR_TF3_MASK                       (0x8U)
#define ENET_TGSR_TF3_SHIFT                      (3U)

/*! @name TCSR - Timer Control Status Register */
#define ENET_TCSR_TDRE_MASK                      (0x1U)
#define ENET_TCSR_TDRE_SHIFT                     (0U)
#define ENET_TCSR_TMODE_MASK                     (0x3CU)
#define ENET_TCSR_TMODE_SHIFT                    (2U)
#define ENET_TCSR_TMODE(x)                       (((uint32_t)(((uint32_t)(x)) << ENET_TCSR_TMODE_SHIFT)) & ENET_TCSR_TMODE_MASK)
#define ENET_TCSR_TIE_MASK                       (0x40U)
#define ENET_TCSR_TIE_SHIFT                      (6U)
#define ENET_TCSR_TF_MASK                        (0x80U)
#define ENET_TCSR_TF_SHIFT                       (7U)

/* The count of ENET_TCSR */
#define ENET_TCSR_COUNT                          (4U)

/*! @name TCCR - Timer Compare Capture Register */
#define ENET_TCCR_TCC_MASK                       (0xFFFFFFFFU)
#define ENET_TCCR_TCC_SHIFT                      (0U)
#define ENET_TCCR_TCC(x)                         (((uint32_t)(((uint32_t)(x)) << ENET_TCCR_TCC_SHIFT)) & ENET_TCCR_TCC_MASK)

/* The count of ENET_TCCR */
#define ENET_TCCR_COUNT                          (4U)


/*!
 * @}
 */ /* end of group ENET_Register_Masks */


/* ENET - Peripheral instance base addresses */
/** Peripheral ENET1 base pointer */
#define ENET1_BASE_PTR                           ((ENET_MemMapPtr)0x30BE0000u)
/** Peripheral ENET2 base pointer */
#define ENET2_BASE_PTR                           ((ENET_MemMapPtr)0x30BF0000u)
/** Array initializer of ENET peripheral base pointers */
#define ENET_BASE_PTRS                           { ENET1_BASE_PTR, ENET2_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- ENET - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ENET_Register_Accessor_Macros ENET - Register accessor macros
 * @{
 */


/* ENET - Register instance definitions */
/* ENET1 */
#define ENET1_EIR                                ENET_EIR_REG(ENET1_BASE_PTR)
#define ENET1_EIMR                               ENET_EIMR_REG(ENET1_BASE_PTR)
#define ENET1_RDAR                               ENET_RDAR_REG(ENET1_BASE_PTR)
#define ENET1_TDAR                               ENET_TDAR_REG(ENET1_BASE_PTR)
#define ENET1_ECR                                ENET_ECR_REG(ENET1_BASE_PTR)
#define ENET1_MMFR                               ENET_MMFR_REG(ENET1_BASE_PTR)
#define ENET1_MSCR                               ENET_MSCR_REG(ENET1_BASE_PTR)
#define ENET1_MIBC                               ENET_MIBC_REG(ENET1_BASE_PTR)
#define ENET1_RCR                                ENET_RCR_REG(ENET1_BASE_PTR)
#define ENET1_TCR                                ENET_TCR_REG(ENET1_BASE_PTR)
#define ENET1_PALR                               ENET_PALR_REG(ENET1_BASE_PTR)
#define ENET1_PAUR                               ENET_PAUR_REG(ENET1_BASE_PTR)
#define ENET1_OPD                                ENET_OPD_REG(ENET1_BASE_PTR)
#define ENET1_TXIC0                              ENET_TXIC_REG(ENET1_BASE_PTR,0)
#define ENET1_TXIC1                              ENET_TXIC_REG(ENET1_BASE_PTR,1)
#define ENET1_TXIC2                              ENET_TXIC_REG(ENET1_BASE_PTR,2)
#define ENET1_RXIC0                              ENET_RXIC_REG(ENET1_BASE_PTR,0)
#define ENET1_RXIC1                              ENET_RXIC_REG(ENET1_BASE_PTR,1)
#define ENET1_RXIC2                              ENET_RXIC_REG(ENET1_BASE_PTR,2)
#define ENET1_IAUR                               ENET_IAUR_REG(ENET1_BASE_PTR)
#define ENET1_IALR                               ENET_IALR_REG(ENET1_BASE_PTR)
#define ENET1_GAUR                               ENET_GAUR_REG(ENET1_BASE_PTR)
#define ENET1_GALR                               ENET_GALR_REG(ENET1_BASE_PTR)
#define ENET1_TFWR                               ENET_TFWR_REG(ENET1_BASE_PTR)
#define ENET1_RDSR1                              ENET_RDSR1_REG(ENET1_BASE_PTR)
#define ENET1_TDSR1                              ENET_TDSR1_REG(ENET1_BASE_PTR)
#define ENET1_MRBR1                              ENET_MRBR1_REG(ENET1_BASE_PTR)
#define ENET1_RDSR2                              ENET_RDSR2_REG(ENET1_BASE_PTR)
#define ENET1_TDSR2                              ENET_TDSR2_REG(ENET1_BASE_PTR)
#define ENET1_MRBR2                              ENET_MRBR2_REG(ENET1_BASE_PTR)
#define ENET1_RDSR                               ENET_RDSR_REG(ENET1_BASE_PTR)
#define ENET1_TDSR                               ENET_TDSR_REG(ENET1_BASE_PTR)
#define ENET1_MRBR                               ENET_MRBR_REG(ENET1_BASE_PTR)
#define ENET1_RSFL                               ENET_RSFL_REG(ENET1_BASE_PTR)
#define ENET1_RSEM                               ENET_RSEM_REG(ENET1_BASE_PTR)
#define ENET1_RAEM                               ENET_RAEM_REG(ENET1_BASE_PTR)
#define ENET1_RAFL                               ENET_RAFL_REG(ENET1_BASE_PTR)
#define ENET1_TSEM                               ENET_TSEM_REG(ENET1_BASE_PTR)
#define ENET1_TAEM                               ENET_TAEM_REG(ENET1_BASE_PTR)
#define ENET1_TAFL                               ENET_TAFL_REG(ENET1_BASE_PTR)
#define ENET1_TIPG                               ENET_TIPG_REG(ENET1_BASE_PTR)
#define ENET1_FTRL                               ENET_FTRL_REG(ENET1_BASE_PTR)
#define ENET1_TACC                               ENET_TACC_REG(ENET1_BASE_PTR)
#define ENET1_RACC                               ENET_RACC_REG(ENET1_BASE_PTR)
#define ENET1_RCMR1                              ENET_RCMR_REG(ENET1_BASE_PTR,0)
#define ENET1_RCMR2                              ENET_RCMR_REG(ENET1_BASE_PTR,1)
#define ENET1_DMA1CFG                            ENET_DMACFG_REG(ENET1_BASE_PTR,0)
#define ENET1_DMA2CFG                            ENET_DMACFG_REG(ENET1_BASE_PTR,1)
#define ENET1_RDAR1                              ENET_RDAR1_REG(ENET1_BASE_PTR)
#define ENET1_TDAR1                              ENET_TDAR1_REG(ENET1_BASE_PTR)
#define ENET1_RDAR2                              ENET_RDAR2_REG(ENET1_BASE_PTR)
#define ENET1_TDAR2                              ENET_TDAR2_REG(ENET1_BASE_PTR)
#define ENET1_QOS                                ENET_QOS_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_DROP                        ENET_RMON_T_DROP_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_PACKETS                     ENET_RMON_T_PACKETS_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_BC_PKT                      ENET_RMON_T_BC_PKT_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_MC_PKT                      ENET_RMON_T_MC_PKT_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_CRC_ALIGN                   ENET_RMON_T_CRC_ALIGN_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_UNDERSIZE                   ENET_RMON_T_UNDERSIZE_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_OVERSIZE                    ENET_RMON_T_OVERSIZE_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_FRAG                        ENET_RMON_T_FRAG_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_JAB                         ENET_RMON_T_JAB_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_COL                         ENET_RMON_T_COL_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_P64                         ENET_RMON_T_P64_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_P65TO127                    ENET_RMON_T_P65TO127_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_P128TO255                   ENET_RMON_T_P128TO255_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_P256TO511                   ENET_RMON_T_P256TO511_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_P512TO1023                  ENET_RMON_T_P512TO1023_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_P1024TO2047                 ENET_RMON_T_P1024TO2047_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_P_GTE2048                   ENET_RMON_T_P_GTE2048_REG(ENET1_BASE_PTR)
#define ENET1_RMON_T_OCTETS                      ENET_RMON_T_OCTETS_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_DROP                        ENET_IEEE_T_DROP_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_FRAME_OK                    ENET_IEEE_T_FRAME_OK_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_1COL                        ENET_IEEE_T_1COL_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_MCOL                        ENET_IEEE_T_MCOL_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_DEF                         ENET_IEEE_T_DEF_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_LCOL                        ENET_IEEE_T_LCOL_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_EXCOL                       ENET_IEEE_T_EXCOL_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_MACERR                      ENET_IEEE_T_MACERR_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_CSERR                       ENET_IEEE_T_CSERR_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_SQE                         ENET_IEEE_T_SQE_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_FDXFC                       ENET_IEEE_T_FDXFC_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_T_OCTETS_OK                   ENET_IEEE_T_OCTETS_OK_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_PACKETS                     ENET_RMON_R_PACKETS_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_BC_PKT                      ENET_RMON_R_BC_PKT_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_MC_PKT                      ENET_RMON_R_MC_PKT_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_CRC_ALIGN                   ENET_RMON_R_CRC_ALIGN_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_UNDERSIZE                   ENET_RMON_R_UNDERSIZE_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_OVERSIZE                    ENET_RMON_R_OVERSIZE_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_FRAG                        ENET_RMON_R_FRAG_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_JAB                         ENET_RMON_R_JAB_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_RESVD_0                     ENET_RMON_R_RESVD_0_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_P64                         ENET_RMON_R_P64_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_P65TO127                    ENET_RMON_R_P65TO127_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_P128TO255                   ENET_RMON_R_P128TO255_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_P256TO511                   ENET_RMON_R_P256TO511_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_P512TO1023                  ENET_RMON_R_P512TO1023_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_P1024TO2047                 ENET_RMON_R_P1024TO2047_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_P_GTE2048                   ENET_RMON_R_P_GTE2048_REG(ENET1_BASE_PTR)
#define ENET1_RMON_R_OCTETS                      ENET_RMON_R_OCTETS_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_R_DROP                        ENET_IEEE_R_DROP_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_R_FRAME_OK                    ENET_IEEE_R_FRAME_OK_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_R_CRC                         ENET_IEEE_R_CRC_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_R_ALIGN                       ENET_IEEE_R_ALIGN_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_R_MACERR                      ENET_IEEE_R_MACERR_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_R_FDXFC                       ENET_IEEE_R_FDXFC_REG(ENET1_BASE_PTR)
#define ENET1_IEEE_R_OCTETS_OK                   ENET_IEEE_R_OCTETS_OK_REG(ENET1_BASE_PTR)
#define ENET1_ATCR                               ENET_ATCR_REG(ENET1_BASE_PTR)
#define ENET1_ATVR                               ENET_ATVR_REG(ENET1_BASE_PTR)
#define ENET1_ATOFF                              ENET_ATOFF_REG(ENET1_BASE_PTR)
#define ENET1_ATPER                              ENET_ATPER_REG(ENET1_BASE_PTR)
#define ENET1_ATCOR                              ENET_ATCOR_REG(ENET1_BASE_PTR)
#define ENET1_ATINC                              ENET_ATINC_REG(ENET1_BASE_PTR)
#define ENET1_ATSTMP                             ENET_ATSTMP_REG(ENET1_BASE_PTR)
#define ENET1_TGSR                               ENET_TGSR_REG(ENET1_BASE_PTR)
#define ENET1_TCSR0                              ENET_TCSR_REG(ENET1_BASE_PTR,0)
#define ENET1_TCCR0                              ENET_TCCR_REG(ENET1_BASE_PTR,0)
#define ENET1_TCSR1                              ENET_TCSR_REG(ENET1_BASE_PTR,1)
#define ENET1_TCCR1                              ENET_TCCR_REG(ENET1_BASE_PTR,1)
#define ENET1_TCSR2                              ENET_TCSR_REG(ENET1_BASE_PTR,2)
#define ENET1_TCCR2                              ENET_TCCR_REG(ENET1_BASE_PTR,2)
#define ENET1_TCSR3                              ENET_TCSR_REG(ENET1_BASE_PTR,3)
#define ENET1_TCCR3                              ENET_TCCR_REG(ENET1_BASE_PTR,3)
/* ENET2 */
#define ENET2_EIR                                ENET_EIR_REG(ENET2_BASE_PTR)
#define ENET2_EIMR                               ENET_EIMR_REG(ENET2_BASE_PTR)
#define ENET2_RDAR                               ENET_RDAR_REG(ENET2_BASE_PTR)
#define ENET2_TDAR                               ENET_TDAR_REG(ENET2_BASE_PTR)
#define ENET2_ECR                                ENET_ECR_REG(ENET2_BASE_PTR)
#define ENET2_MMFR                               ENET_MMFR_REG(ENET2_BASE_PTR)
#define ENET2_MSCR                               ENET_MSCR_REG(ENET2_BASE_PTR)
#define ENET2_MIBC                               ENET_MIBC_REG(ENET2_BASE_PTR)
#define ENET2_RCR                                ENET_RCR_REG(ENET2_BASE_PTR)
#define ENET2_TCR                                ENET_TCR_REG(ENET2_BASE_PTR)
#define ENET2_PALR                               ENET_PALR_REG(ENET2_BASE_PTR)
#define ENET2_PAUR                               ENET_PAUR_REG(ENET2_BASE_PTR)
#define ENET2_OPD                                ENET_OPD_REG(ENET2_BASE_PTR)
#define ENET2_TXIC0                              ENET_TXIC_REG(ENET2_BASE_PTR,0)
#define ENET2_TXIC1                              ENET_TXIC_REG(ENET2_BASE_PTR,1)
#define ENET2_TXIC2                              ENET_TXIC_REG(ENET2_BASE_PTR,2)
#define ENET2_RXIC0                              ENET_RXIC_REG(ENET2_BASE_PTR,0)
#define ENET2_RXIC1                              ENET_RXIC_REG(ENET2_BASE_PTR,1)
#define ENET2_RXIC2                              ENET_RXIC_REG(ENET2_BASE_PTR,2)
#define ENET2_IAUR                               ENET_IAUR_REG(ENET2_BASE_PTR)
#define ENET2_IALR                               ENET_IALR_REG(ENET2_BASE_PTR)
#define ENET2_GAUR                               ENET_GAUR_REG(ENET2_BASE_PTR)
#define ENET2_GALR                               ENET_GALR_REG(ENET2_BASE_PTR)
#define ENET2_TFWR                               ENET_TFWR_REG(ENET2_BASE_PTR)
#define ENET2_RDSR1                              ENET_RDSR1_REG(ENET2_BASE_PTR)
#define ENET2_TDSR1                              ENET_TDSR1_REG(ENET2_BASE_PTR)
#define ENET2_MRBR1                              ENET_MRBR1_REG(ENET2_BASE_PTR)
#define ENET2_RDSR2                              ENET_RDSR2_REG(ENET2_BASE_PTR)
#define ENET2_TDSR2                              ENET_TDSR2_REG(ENET2_BASE_PTR)
#define ENET2_MRBR2                              ENET_MRBR2_REG(ENET2_BASE_PTR)
#define ENET2_RDSR                               ENET_RDSR_REG(ENET2_BASE_PTR)
#define ENET2_TDSR                               ENET_TDSR_REG(ENET2_BASE_PTR)
#define ENET2_MRBR                               ENET_MRBR_REG(ENET2_BASE_PTR)
#define ENET2_RSFL                               ENET_RSFL_REG(ENET2_BASE_PTR)
#define ENET2_RSEM                               ENET_RSEM_REG(ENET2_BASE_PTR)
#define ENET2_RAEM                               ENET_RAEM_REG(ENET2_BASE_PTR)
#define ENET2_RAFL                               ENET_RAFL_REG(ENET2_BASE_PTR)
#define ENET2_TSEM                               ENET_TSEM_REG(ENET2_BASE_PTR)
#define ENET2_TAEM                               ENET_TAEM_REG(ENET2_BASE_PTR)
#define ENET2_TAFL                               ENET_TAFL_REG(ENET2_BASE_PTR)
#define ENET2_TIPG                               ENET_TIPG_REG(ENET2_BASE_PTR)
#define ENET2_FTRL                               ENET_FTRL_REG(ENET2_BASE_PTR)
#define ENET2_TACC                               ENET_TACC_REG(ENET2_BASE_PTR)
#define ENET2_RACC                               ENET_RACC_REG(ENET2_BASE_PTR)
#define ENET2_RCMR1                              ENET_RCMR_REG(ENET2_BASE_PTR,0)
#define ENET2_RCMR2                              ENET_RCMR_REG(ENET2_BASE_PTR,1)
#define ENET2_DMA1CFG                            ENET_DMACFG_REG(ENET2_BASE_PTR,0)
#define ENET2_DMA2CFG                            ENET_DMACFG_REG(ENET2_BASE_PTR,1)
#define ENET2_RDAR1                              ENET_RDAR1_REG(ENET2_BASE_PTR)
#define ENET2_TDAR1                              ENET_TDAR1_REG(ENET2_BASE_PTR)
#define ENET2_RDAR2                              ENET_RDAR2_REG(ENET2_BASE_PTR)
#define ENET2_TDAR2                              ENET_TDAR2_REG(ENET2_BASE_PTR)
#define ENET2_QOS                                ENET_QOS_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_DROP                        ENET_RMON_T_DROP_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_PACKETS                     ENET_RMON_T_PACKETS_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_BC_PKT                      ENET_RMON_T_BC_PKT_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_MC_PKT                      ENET_RMON_T_MC_PKT_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_CRC_ALIGN                   ENET_RMON_T_CRC_ALIGN_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_UNDERSIZE                   ENET_RMON_T_UNDERSIZE_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_OVERSIZE                    ENET_RMON_T_OVERSIZE_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_FRAG                        ENET_RMON_T_FRAG_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_JAB                         ENET_RMON_T_JAB_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_COL                         ENET_RMON_T_COL_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_P64                         ENET_RMON_T_P64_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_P65TO127                    ENET_RMON_T_P65TO127_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_P128TO255                   ENET_RMON_T_P128TO255_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_P256TO511                   ENET_RMON_T_P256TO511_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_P512TO1023                  ENET_RMON_T_P512TO1023_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_P1024TO2047                 ENET_RMON_T_P1024TO2047_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_P_GTE2048                   ENET_RMON_T_P_GTE2048_REG(ENET2_BASE_PTR)
#define ENET2_RMON_T_OCTETS                      ENET_RMON_T_OCTETS_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_DROP                        ENET_IEEE_T_DROP_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_FRAME_OK                    ENET_IEEE_T_FRAME_OK_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_1COL                        ENET_IEEE_T_1COL_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_MCOL                        ENET_IEEE_T_MCOL_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_DEF                         ENET_IEEE_T_DEF_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_LCOL                        ENET_IEEE_T_LCOL_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_EXCOL                       ENET_IEEE_T_EXCOL_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_MACERR                      ENET_IEEE_T_MACERR_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_CSERR                       ENET_IEEE_T_CSERR_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_SQE                         ENET_IEEE_T_SQE_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_FDXFC                       ENET_IEEE_T_FDXFC_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_T_OCTETS_OK                   ENET_IEEE_T_OCTETS_OK_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_PACKETS                     ENET_RMON_R_PACKETS_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_BC_PKT                      ENET_RMON_R_BC_PKT_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_MC_PKT                      ENET_RMON_R_MC_PKT_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_CRC_ALIGN                   ENET_RMON_R_CRC_ALIGN_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_UNDERSIZE                   ENET_RMON_R_UNDERSIZE_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_OVERSIZE                    ENET_RMON_R_OVERSIZE_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_FRAG                        ENET_RMON_R_FRAG_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_JAB                         ENET_RMON_R_JAB_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_RESVD_0                     ENET_RMON_R_RESVD_0_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_P64                         ENET_RMON_R_P64_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_P65TO127                    ENET_RMON_R_P65TO127_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_P128TO255                   ENET_RMON_R_P128TO255_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_P256TO511                   ENET_RMON_R_P256TO511_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_P512TO1023                  ENET_RMON_R_P512TO1023_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_P1024TO2047                 ENET_RMON_R_P1024TO2047_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_P_GTE2048                   ENET_RMON_R_P_GTE2048_REG(ENET2_BASE_PTR)
#define ENET2_RMON_R_OCTETS                      ENET_RMON_R_OCTETS_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_R_DROP                        ENET_IEEE_R_DROP_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_R_FRAME_OK                    ENET_IEEE_R_FRAME_OK_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_R_CRC                         ENET_IEEE_R_CRC_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_R_ALIGN                       ENET_IEEE_R_ALIGN_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_R_MACERR                      ENET_IEEE_R_MACERR_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_R_FDXFC                       ENET_IEEE_R_FDXFC_REG(ENET2_BASE_PTR)
#define ENET2_IEEE_R_OCTETS_OK                   ENET_IEEE_R_OCTETS_OK_REG(ENET2_BASE_PTR)
#define ENET2_ATCR                               ENET_ATCR_REG(ENET2_BASE_PTR)
#define ENET2_ATVR                               ENET_ATVR_REG(ENET2_BASE_PTR)
#define ENET2_ATOFF                              ENET_ATOFF_REG(ENET2_BASE_PTR)
#define ENET2_ATPER                              ENET_ATPER_REG(ENET2_BASE_PTR)
#define ENET2_ATCOR                              ENET_ATCOR_REG(ENET2_BASE_PTR)
#define ENET2_ATINC                              ENET_ATINC_REG(ENET2_BASE_PTR)
#define ENET2_ATSTMP                             ENET_ATSTMP_REG(ENET2_BASE_PTR)
#define ENET2_TGSR                               ENET_TGSR_REG(ENET2_BASE_PTR)
#define ENET2_TCSR0                              ENET_TCSR_REG(ENET2_BASE_PTR,0)
#define ENET2_TCCR0                              ENET_TCCR_REG(ENET2_BASE_PTR,0)
#define ENET2_TCSR1                              ENET_TCSR_REG(ENET2_BASE_PTR,1)
#define ENET2_TCCR1                              ENET_TCCR_REG(ENET2_BASE_PTR,1)
#define ENET2_TCSR2                              ENET_TCSR_REG(ENET2_BASE_PTR,2)
#define ENET2_TCCR2                              ENET_TCCR_REG(ENET2_BASE_PTR,2)
#define ENET2_TCSR3                              ENET_TCSR_REG(ENET2_BASE_PTR,3)
#define ENET2_TCCR3                              ENET_TCCR_REG(ENET2_BASE_PTR,3)

/* ENET - Register array accessors */
#define ENET1_TXIC(index)                        ENET_TXIC_REG(ENET1_BASE_PTR,index)
#define ENET2_TXIC(index)                        ENET_TXIC_REG(ENET2_BASE_PTR,index)
#define ENET1_RXIC(index)                        ENET_RXIC_REG(ENET1_BASE_PTR,index)
#define ENET2_RXIC(index)                        ENET_RXIC_REG(ENET2_BASE_PTR,index)
#define ENET1_RCMR(index)                        ENET_RCMR_REG(ENET1_BASE_PTR,index)
#define ENET2_RCMR(index)                        ENET_RCMR_REG(ENET2_BASE_PTR,index)
#define ENET1_DMACFG(index)                      ENET_DMACFG_REG(ENET1_BASE_PTR,index)
#define ENET2_DMACFG(index)                      ENET_DMACFG_REG(ENET2_BASE_PTR,index)
#define ENET1_TCSR(index)                        ENET_TCSR_REG(ENET1_BASE_PTR,index)
#define ENET2_TCSR(index)                        ENET_TCSR_REG(ENET2_BASE_PTR,index)
#define ENET1_TCCR(index)                        ENET_TCCR_REG(ENET1_BASE_PTR,index)
#define ENET2_TCCR(index)                        ENET_TCCR_REG(ENET2_BASE_PTR,index)

/*!
 * @}
 */ /* end of group ENET_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group ENET_Peripheral */


/* ----------------------------------------------------------------------------
   -- EPDC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup EPDC_Peripheral EPDC
 * @{
 */

/** EPDC - Peripheral register structure */
typedef struct EPDC_MemMap {
  uint32_t CTRL;                                   /**< EPDC Control Register, offset: 0x0 */
  uint32_t CTRL_SET;                               /**< EPDC Control Register, offset: 0x4 */
  uint32_t CTRL_CLR;                               /**< EPDC Control Register, offset: 0x8 */
  uint32_t CTRL_TOG;                               /**< EPDC Control Register, offset: 0xC */
  uint32_t WB_ADDR_TCE;                            /**< EPDC Working Buffer Address for TCE, offset: 0x10 */
  uint8_t RESERVED_0[12];
  uint32_t WVADDR;                                 /**< EPDC Waveform Address Pointer, offset: 0x20 */
  uint8_t RESERVED_1[12];
  uint32_t WB_ADDR;                                /**< EPDC Working Buffer Address, offset: 0x30 */
  uint8_t RESERVED_2[12];
  uint32_t RES;                                    /**< EPDC Screen Resolution, offset: 0x40 */
  uint8_t RESERVED_3[12];
  uint32_t FORMAT;                                 /**< EPDC Format Control Register, offset: 0x50 */
  uint32_t FORMAT_SET;                             /**< EPDC Format Control Register, offset: 0x54 */
  uint32_t FORMAT_CLR;                             /**< EPDC Format Control Register, offset: 0x58 */
  uint32_t FORMAT_TOG;                             /**< EPDC Format Control Register, offset: 0x5C */
  uint32_t WB_FIELD0;                              /**< Working Buffer Field Setting, offset: 0x60 */
  uint8_t RESERVED_4[12];
  uint32_t WB_FIELD1;                              /**< Working Buffer Field Setting, offset: 0x70 */
  uint8_t RESERVED_5[12];
  uint32_t WB_FIELD2;                              /**< Working Buffer Field Setting, offset: 0x80 */
  uint8_t RESERVED_6[12];
  uint32_t WB_FIELD3;                              /**< Working Buffer Field Setting, offset: 0x90 */
  uint8_t RESERVED_7[12];
  uint32_t FIFOCTRL;                               /**< EPDC FIFO control register, offset: 0xA0 */
  uint32_t FIFOCTRL_SET;                           /**< EPDC FIFO control register, offset: 0xA4 */
  uint32_t FIFOCTRL_CLR;                           /**< EPDC FIFO control register, offset: 0xA8 */
  uint32_t FIFOCTRL_TOG;                           /**< EPDC FIFO control register, offset: 0xAC */
  uint8_t RESERVED_8[80];
  uint32_t UPD_ADDR;                               /**< EPDC Update Region Address, offset: 0x100 */
  uint8_t RESERVED_9[12];
  uint32_t UPD_STRIDE;                             /**< EPDC Update Region Stride, offset: 0x110 */
  uint8_t RESERVED_10[12];
  uint32_t UPD_CORD;                               /**< EPDC Update Command Co-ordinate, offset: 0x120 */
  uint8_t RESERVED_11[28];
  uint32_t UPD_SIZE;                               /**< EPDC Update Command Size, offset: 0x140 */
  uint8_t RESERVED_12[28];
  uint32_t UPD_CTRL;                               /**< EPDC Update Command Control, offset: 0x160 */
  uint32_t UPD_CTRL_SET;                           /**< EPDC Update Command Control, offset: 0x164 */
  uint32_t UPD_CTRL_CLR;                           /**< EPDC Update Command Control, offset: 0x168 */
  uint32_t UPD_CTRL_TOG;                           /**< EPDC Update Command Control, offset: 0x16C */
  uint8_t RESERVED_13[16];
  uint32_t UPD_FIXED;                              /**< EPDC Update Fixed Pixel Control, offset: 0x180 */
  uint32_t UPD_FIXED_SET;                          /**< EPDC Update Fixed Pixel Control, offset: 0x184 */
  uint32_t UPD_FIXED_CLR;                          /**< EPDC Update Fixed Pixel Control, offset: 0x188 */
  uint32_t UPD_FIXED_TOG;                          /**< EPDC Update Fixed Pixel Control, offset: 0x18C */
  uint8_t RESERVED_14[16];
  uint32_t TEMP;                                   /**< EPDC Temperature Register, offset: 0x1A0 */
  uint8_t RESERVED_15[28];
  uint32_t AUTOWV_LUT;                             /**< Waveform Mode Lookup Table Control Register., offset: 0x1C0 */
  uint8_t RESERVED_16[28];
  uint32_t LUT_STANDBY1;                           /**< EPDC LUT Standby Register for LUT 31~0, offset: 0x1E0 */
  uint32_t LUT_STANDBY1_SET;                       /**< EPDC LUT Standby Register for LUT 31~0, offset: 0x1E4 */
  uint32_t LUT_STANDBY1_CLR;                       /**< EPDC LUT Standby Register for LUT 31~0, offset: 0x1E8 */
  uint32_t LUT_STANDBY1_TOG;                       /**< EPDC LUT Standby Register for LUT 31~0, offset: 0x1EC */
  uint32_t LUT_STANDBY2;                           /**< EPDC LUT Standby Registerr for LUT 63~32, offset: 0x1F0 */
  uint32_t LUT_STANDBY2_SET;                       /**< EPDC LUT Standby Registerr for LUT 63~32, offset: 0x1F4 */
  uint32_t LUT_STANDBY2_CLR;                       /**< EPDC LUT Standby Registerr for LUT 63~32, offset: 0x1F8 */
  uint32_t LUT_STANDBY2_TOG;                       /**< EPDC LUT Standby Registerr for LUT 63~32, offset: 0x1FC */
  uint32_t TCE_CTRL;                               /**< EPDC Timing Control Engine Control Register, offset: 0x200 */
  uint32_t TCE_CTRL_SET;                           /**< EPDC Timing Control Engine Control Register, offset: 0x204 */
  uint32_t TCE_CTRL_CLR;                           /**< EPDC Timing Control Engine Control Register, offset: 0x208 */
  uint32_t TCE_CTRL_TOG;                           /**< EPDC Timing Control Engine Control Register, offset: 0x20C */
  uint8_t RESERVED_17[16];
  uint32_t TCE_SDCFG;                              /**< EPDC Timing Control Engine Source-Driver Config Register, offset: 0x220 */
  uint32_t TCE_SDCFG_SET;                          /**< EPDC Timing Control Engine Source-Driver Config Register, offset: 0x224 */
  uint32_t TCE_SDCFG_CLR;                          /**< EPDC Timing Control Engine Source-Driver Config Register, offset: 0x228 */
  uint32_t TCE_SDCFG_TOG;                          /**< EPDC Timing Control Engine Source-Driver Config Register, offset: 0x22C */
  uint8_t RESERVED_18[16];
  uint32_t TCE_GDCFG;                              /**< EPDC Timing Control Engine Gate-Driver Config Register, offset: 0x240 */
  uint32_t TCE_GDCFG_SET;                          /**< EPDC Timing Control Engine Gate-Driver Config Register, offset: 0x244 */
  uint32_t TCE_GDCFG_CLR;                          /**< EPDC Timing Control Engine Gate-Driver Config Register, offset: 0x248 */
  uint32_t TCE_GDCFG_TOG;                          /**< EPDC Timing Control Engine Gate-Driver Config Register, offset: 0x24C */
  uint8_t RESERVED_19[16];
  uint32_t TCE_HSCAN1;                             /**< EPDC Timing Control Engine Horizontal Timing Register 1, offset: 0x260 */
  uint32_t TCE_HSCAN1_SET;                         /**< EPDC Timing Control Engine Horizontal Timing Register 1, offset: 0x264 */
  uint32_t TCE_HSCAN1_CLR;                         /**< EPDC Timing Control Engine Horizontal Timing Register 1, offset: 0x268 */
  uint32_t TCE_HSCAN1_TOG;                         /**< EPDC Timing Control Engine Horizontal Timing Register 1, offset: 0x26C */
  uint8_t RESERVED_20[16];
  uint32_t TCE_HSCAN2;                             /**< EPDC Timing Control Engine Horizontal Timing Register 2, offset: 0x280 */
  uint32_t TCE_HSCAN2_SET;                         /**< EPDC Timing Control Engine Horizontal Timing Register 2, offset: 0x284 */
  uint32_t TCE_HSCAN2_CLR;                         /**< EPDC Timing Control Engine Horizontal Timing Register 2, offset: 0x288 */
  uint32_t TCE_HSCAN2_TOG;                         /**< EPDC Timing Control Engine Horizontal Timing Register 2, offset: 0x28C */
  uint8_t RESERVED_21[16];
  uint32_t TCE_VSCAN;                              /**< EPDC Timing Control Engine Vertical Timing Register, offset: 0x2A0 */
  uint32_t TCE_VSCAN_SET;                          /**< EPDC Timing Control Engine Vertical Timing Register, offset: 0x2A4 */
  uint32_t TCE_VSCAN_CLR;                          /**< EPDC Timing Control Engine Vertical Timing Register, offset: 0x2A8 */
  uint32_t TCE_VSCAN_TOG;                          /**< EPDC Timing Control Engine Vertical Timing Register, offset: 0x2AC */
  uint8_t RESERVED_22[16];
  uint32_t TCE_OE;                                 /**< EPDC Timing Control Engine OE timing control Register, offset: 0x2C0 */
  uint32_t TCE_OE_SET;                             /**< EPDC Timing Control Engine OE timing control Register, offset: 0x2C4 */
  uint32_t TCE_OE_CLR;                             /**< EPDC Timing Control Engine OE timing control Register, offset: 0x2C8 */
  uint32_t TCE_OE_TOG;                             /**< EPDC Timing Control Engine OE timing control Register, offset: 0x2CC */
  uint8_t RESERVED_23[16];
  uint32_t TCE_POLARITY;                           /**< EPDC Timing Control Engine Driver Polarity Register, offset: 0x2E0 */
  uint32_t TCE_POLARITY_SET;                       /**< EPDC Timing Control Engine Driver Polarity Register, offset: 0x2E4 */
  uint32_t TCE_POLARITY_CLR;                       /**< EPDC Timing Control Engine Driver Polarity Register, offset: 0x2E8 */
  uint32_t TCE_POLARITY_TOG;                       /**< EPDC Timing Control Engine Driver Polarity Register, offset: 0x2EC */
  uint8_t RESERVED_24[16];
  uint32_t TCE_TIMING1;                            /**< EPDC Timing Control Engine Timing Register 1, offset: 0x300 */
  uint32_t TCE_TIMING1_SET;                        /**< EPDC Timing Control Engine Timing Register 1, offset: 0x304 */
  uint32_t TCE_TIMING1_CLR;                        /**< EPDC Timing Control Engine Timing Register 1, offset: 0x308 */
  uint32_t TCE_TIMING1_TOG;                        /**< EPDC Timing Control Engine Timing Register 1, offset: 0x30C */
  uint32_t TCE_TIMING2;                            /**< EPDC Timing Control Engine Timing Register 2, offset: 0x310 */
  uint32_t TCE_TIMING2_SET;                        /**< EPDC Timing Control Engine Timing Register 2, offset: 0x314 */
  uint32_t TCE_TIMING2_CLR;                        /**< EPDC Timing Control Engine Timing Register 2, offset: 0x318 */
  uint32_t TCE_TIMING2_TOG;                        /**< EPDC Timing Control Engine Timing Register 2, offset: 0x31C */
  uint32_t TCE_TIMING3;                            /**< EPDC Timing Control Engine Timing Register 3, offset: 0x320 */
  uint32_t TCE_TIMING3_SET;                        /**< EPDC Timing Control Engine Timing Register 3, offset: 0x324 */
  uint32_t TCE_TIMING3_CLR;                        /**< EPDC Timing Control Engine Timing Register 3, offset: 0x328 */
  uint32_t TCE_TIMING3_TOG;                        /**< EPDC Timing Control Engine Timing Register 3, offset: 0x32C */
  uint8_t RESERVED_25[80];
  uint32_t PIGEON_CTRL0;                           /**< EPDC Pigeon Mode Control Register 0, offset: 0x380 */
  uint32_t PIGEON_CTRL0_SET;                       /**< EPDC Pigeon Mode Control Register 0, offset: 0x384 */
  uint32_t PIGEON_CTRL0_CLR;                       /**< EPDC Pigeon Mode Control Register 0, offset: 0x388 */
  uint32_t PIGEON_CTRL0_TOG;                       /**< EPDC Pigeon Mode Control Register 0, offset: 0x38C */
  uint32_t PIGEON_CTRL1;                           /**< EPDC Pigeon Mode Control Register 1, offset: 0x390 */
  uint32_t PIGEON_CTRL1_SET;                       /**< EPDC Pigeon Mode Control Register 1, offset: 0x394 */
  uint32_t PIGEON_CTRL1_CLR;                       /**< EPDC Pigeon Mode Control Register 1, offset: 0x398 */
  uint32_t PIGEON_CTRL1_TOG;                       /**< EPDC Pigeon Mode Control Register 1, offset: 0x39C */
  uint8_t RESERVED_26[32];
  uint32_t IRQ_MASK1;                              /**< EPDC IRQ Mask Register for LUT 0~31, offset: 0x3C0 */
  uint32_t IRQ_MASK1_SET;                          /**< EPDC IRQ Mask Register for LUT 0~31, offset: 0x3C4 */
  uint32_t IRQ_MASK1_CLR;                          /**< EPDC IRQ Mask Register for LUT 0~31, offset: 0x3C8 */
  uint32_t IRQ_MASK1_TOG;                          /**< EPDC IRQ Mask Register for LUT 0~31, offset: 0x3CC */
  uint32_t IRQ_MASK2;                              /**< EPDC IRQ Mask Register for LUT 32~63, offset: 0x3D0 */
  uint32_t IRQ_MASK2_SET;                          /**< EPDC IRQ Mask Register for LUT 32~63, offset: 0x3D4 */
  uint32_t IRQ_MASK2_CLR;                          /**< EPDC IRQ Mask Register for LUT 32~63, offset: 0x3D8 */
  uint32_t IRQ_MASK2_TOG;                          /**< EPDC IRQ Mask Register for LUT 32~63, offset: 0x3DC */
  uint32_t IRQ1;                                   /**< EPDC Interrupt Register for LUT 0~31, offset: 0x3E0 */
  uint32_t IRQ1_SET;                               /**< EPDC Interrupt Register for LUT 0~31, offset: 0x3E4 */
  uint32_t IRQ1_CLR;                               /**< EPDC Interrupt Register for LUT 0~31, offset: 0x3E8 */
  uint32_t IRQ1_TOG;                               /**< EPDC Interrupt Register for LUT 0~31, offset: 0x3EC */
  uint32_t IRQ2;                                   /**< EPDC Interrupt Registerr for LUT 32~63, offset: 0x3F0 */
  uint32_t IRQ2_SET;                               /**< EPDC Interrupt Registerr for LUT 32~63, offset: 0x3F4 */
  uint32_t IRQ2_CLR;                               /**< EPDC Interrupt Registerr for LUT 32~63, offset: 0x3F8 */
  uint32_t IRQ2_TOG;                               /**< EPDC Interrupt Registerr for LUT 32~63, offset: 0x3FC */
  uint32_t IRQ_MASK;                               /**< EPDC IRQ Mask Register, offset: 0x400 */
  uint32_t IRQ_MASK_SET;                           /**< EPDC IRQ Mask Register, offset: 0x404 */
  uint32_t IRQ_MASK_CLR;                           /**< EPDC IRQ Mask Register, offset: 0x408 */
  uint32_t IRQ_MASK_TOG;                           /**< EPDC IRQ Mask Register, offset: 0x40C */
  uint8_t RESERVED_27[16];
  uint32_t IRQ;                                    /**< EPDC Interrupt Register, offset: 0x420 */
  uint32_t IRQ_SET;                                /**< EPDC Interrupt Register, offset: 0x424 */
  uint32_t IRQ_CLR;                                /**< EPDC Interrupt Register, offset: 0x428 */
  uint32_t IRQ_TOG;                                /**< EPDC Interrupt Register, offset: 0x42C */
  uint8_t RESERVED_28[16];
  uint32_t STATUS_LUTS1;                           /**< EPDC Status Register - LUTs, offset: 0x440 */
  uint32_t STATUS_LUTS1_SET;                       /**< EPDC Status Register - LUTs, offset: 0x444 */
  uint32_t STATUS_LUTS1_CLR;                       /**< EPDC Status Register - LUTs, offset: 0x448 */
  uint32_t STATUS_LUTS1_TOG;                       /**< EPDC Status Register - LUTs, offset: 0x44C */
  uint32_t STATUS_LUTS2;                           /**< EPDC Status Register - LUTs, offset: 0x450 */
  uint32_t STATUS_LUTS2_SET;                       /**< EPDC Status Register - LUTs, offset: 0x454 */
  uint32_t STATUS_LUTS2_CLR;                       /**< EPDC Status Register - LUTs, offset: 0x458 */
  uint32_t STATUS_LUTS2_TOG;                       /**< EPDC Status Register - LUTs, offset: 0x45C */
  uint32_t STATUS_NEXTLUT;                         /**< EPDC Status Register - Next Available LUT, offset: 0x460 */
  uint8_t RESERVED_29[28];
  uint32_t STATUS_COL1;                            /**< EPDC LUT Collision Status, offset: 0x480 */
  uint32_t STATUS_COL1_SET;                        /**< EPDC LUT Collision Status, offset: 0x484 */
  uint32_t STATUS_COL1_CLR;                        /**< EPDC LUT Collision Status, offset: 0x488 */
  uint32_t STATUS_COL1_TOG;                        /**< EPDC LUT Collision Status, offset: 0x48C */
  uint32_t STATUS_COL2;                            /**< EPDC LUT Collision Status, offset: 0x490 */
  uint32_t STATUS_COL2_SET;                        /**< EPDC LUT Collision Status, offset: 0x494 */
  uint32_t STATUS_COL2_CLR;                        /**< EPDC LUT Collision Status, offset: 0x498 */
  uint32_t STATUS_COL2_TOG;                        /**< EPDC LUT Collision Status, offset: 0x49C */
  uint32_t STATUS;                                 /**< EPDC General Status Register, offset: 0x4A0 */
  uint32_t STATUS_SET;                             /**< EPDC General Status Register, offset: 0x4A4 */
  uint32_t STATUS_CLR;                             /**< EPDC General Status Register, offset: 0x4A8 */
  uint32_t STATUS_TOG;                             /**< EPDC General Status Register, offset: 0x4AC */
  uint8_t RESERVED_30[16];
  uint32_t UPD_COL_CORD;                           /**< EPDC Collision Region Co-ordinate, offset: 0x4C0 */
  uint8_t RESERVED_31[28];
  uint32_t UPD_COL_SIZE;                           /**< EPDC Collision Region Size, offset: 0x4E0 */
  uint8_t RESERVED_32[284];
  uint32_t HIST1_PARAM;                            /**< 1-level Histogram Parameter Register., offset: 0x600 */
  uint8_t RESERVED_33[12];
  uint32_t HIST2_PARAM;                            /**< 2-level Histogram Parameter Register., offset: 0x610 */
  uint8_t RESERVED_34[12];
  uint32_t HIST4_PARAM;                            /**< 4-level Histogram Parameter Register., offset: 0x620 */
  uint8_t RESERVED_35[12];
  uint32_t HIST8_PARAM0;                           /**< 8-level Histogram Parameter 0 Register., offset: 0x630 */
  uint8_t RESERVED_36[12];
  uint32_t HIST8_PARAM1;                           /**< 8-level Histogram Parameter 1 Register., offset: 0x640 */
  uint8_t RESERVED_37[12];
  uint32_t HIST16_PARAM0;                          /**< 16-level Histogram Parameter 0 Register., offset: 0x650 */
  uint8_t RESERVED_38[12];
  uint32_t HIST16_PARAM1;                          /**< 16-level Histogram Parameter Register., offset: 0x660 */
  uint8_t RESERVED_39[12];
  uint32_t HIST16_PARAM2;                          /**< 16-level Histogram Parameter Register., offset: 0x670 */
  uint8_t RESERVED_40[12];
  uint32_t HIST16_PARAM3;                          /**< 16-level Histogram Parameter Register., offset: 0x680 */
  uint8_t RESERVED_41[124];
  uint32_t GPIO;                                   /**< EPDC General Purpose I/O Debug register, offset: 0x700 */
  uint32_t GPIO_SET;                               /**< EPDC General Purpose I/O Debug register, offset: 0x704 */
  uint32_t GPIO_CLR;                               /**< EPDC General Purpose I/O Debug register, offset: 0x708 */
  uint32_t GPIO_TOG;                               /**< EPDC General Purpose I/O Debug register, offset: 0x70C */
  uint8_t RESERVED_42[224];
  uint32_t VERSION;                                /**< EPDC Version Register, offset: 0x7F0 */
  uint8_t RESERVED_43[12];
  uint32_t PIGEON_0_0;                             /**< Panel Interface Signal Generator Register 0_0, offset: 0x800 */
  uint8_t RESERVED_44[12];
  uint32_t PIGEON_0_1;                             /**< Panel Interface Signal Generator Register 0_1, offset: 0x810 */
  uint8_t RESERVED_45[12];
  uint32_t PIGEON_0_2;                             /**< Panel Interface Signal Generator Register 0_1, offset: 0x820 */
  uint8_t RESERVED_46[28];
  uint32_t PIGEON_1_0;                             /**< Panel Interface Signal Generator Register 1_0, offset: 0x840 */
  uint8_t RESERVED_47[12];
  uint32_t PIGEON_1_1;                             /**< Panel Interface Signal Generator Register 1_1, offset: 0x850 */
  uint8_t RESERVED_48[12];
  uint32_t PIGEON_1_2;                             /**< Panel Interface Signal Generator Register 1_1, offset: 0x860 */
  uint8_t RESERVED_49[28];
  uint32_t PIGEON_2_0;                             /**< Panel Interface Signal Generator Register 2_0, offset: 0x880 */
  uint8_t RESERVED_50[12];
  uint32_t PIGEON_2_1;                             /**< Panel Interface Signal Generator Register 2_1, offset: 0x890 */
  uint8_t RESERVED_51[12];
  uint32_t PIGEON_2_2;                             /**< Panel Interface Signal Generator Register 2_1, offset: 0x8A0 */
  uint8_t RESERVED_52[28];
  uint32_t PIGEON_3_0;                             /**< Panel Interface Signal Generator Register 3_0, offset: 0x8C0 */
  uint8_t RESERVED_53[12];
  uint32_t PIGEON_3_1;                             /**< Panel Interface Signal Generator Register 3_1, offset: 0x8D0 */
  uint8_t RESERVED_54[12];
  uint32_t PIGEON_3_2;                             /**< Panel Interface Signal Generator Register 3_1, offset: 0x8E0 */
  uint8_t RESERVED_55[28];
  uint32_t PIGEON_4_0;                             /**< Panel Interface Signal Generator Register 4_0, offset: 0x900 */
  uint8_t RESERVED_56[12];
  uint32_t PIGEON_4_1;                             /**< Panel Interface Signal Generator Register 4_1, offset: 0x910 */
  uint8_t RESERVED_57[12];
  uint32_t PIGEON_4_2;                             /**< Panel Interface Signal Generator Register 4_1, offset: 0x920 */
  uint8_t RESERVED_58[28];
  uint32_t PIGEON_5_0;                             /**< Panel Interface Signal Generator Register 5_0, offset: 0x940 */
  uint8_t RESERVED_59[12];
  uint32_t PIGEON_5_1;                             /**< Panel Interface Signal Generator Register 5_1, offset: 0x950 */
  uint8_t RESERVED_60[12];
  uint32_t PIGEON_5_2;                             /**< Panel Interface Signal Generator Register 5_1, offset: 0x960 */
  uint8_t RESERVED_61[28];
  uint32_t PIGEON_6_0;                             /**< Panel Interface Signal Generator Register 6_0, offset: 0x980 */
  uint8_t RESERVED_62[12];
  uint32_t PIGEON_6_1;                             /**< Panel Interface Signal Generator Register 6_1, offset: 0x990 */
  uint8_t RESERVED_63[12];
  uint32_t PIGEON_6_2;                             /**< Panel Interface Signal Generator Register 6_1, offset: 0x9A0 */
  uint8_t RESERVED_64[28];
  uint32_t PIGEON_7_0;                             /**< Panel Interface Signal Generator Register 7_0, offset: 0x9C0 */
  uint8_t RESERVED_65[12];
  uint32_t PIGEON_7_1;                             /**< Panel Interface Signal Generator Register 7_1, offset: 0x9D0 */
  uint8_t RESERVED_66[12];
  uint32_t PIGEON_7_2;                             /**< Panel Interface Signal Generator Register 7_1, offset: 0x9E0 */
  uint8_t RESERVED_67[28];
  uint32_t PIGEON_8_0;                             /**< Panel Interface Signal Generator Register 8_0, offset: 0xA00 */
  uint8_t RESERVED_68[12];
  uint32_t PIGEON_8_1;                             /**< Panel Interface Signal Generator Register 8_1, offset: 0xA10 */
  uint8_t RESERVED_69[12];
  uint32_t PIGEON_8_2;                             /**< Panel Interface Signal Generator Register 8_1, offset: 0xA20 */
  uint8_t RESERVED_70[28];
  uint32_t PIGEON_9_0;                             /**< Panel Interface Signal Generator Register 9_0, offset: 0xA40 */
  uint8_t RESERVED_71[12];
  uint32_t PIGEON_9_1;                             /**< Panel Interface Signal Generator Register 9_1, offset: 0xA50 */
  uint8_t RESERVED_72[12];
  uint32_t PIGEON_9_2;                             /**< Panel Interface Signal Generator Register 9_1, offset: 0xA60 */
  uint8_t RESERVED_73[28];
  uint32_t PIGEON_10_0;                            /**< Panel Interface Signal Generator Register 10_0, offset: 0xA80 */
  uint8_t RESERVED_74[12];
  uint32_t PIGEON_10_1;                            /**< Panel Interface Signal Generator Register 10_1, offset: 0xA90 */
  uint8_t RESERVED_75[12];
  uint32_t PIGEON_10_2;                            /**< Panel Interface Signal Generator Register 10_1, offset: 0xAA0 */
  uint8_t RESERVED_76[28];
  uint32_t PIGEON_11_0;                            /**< Panel Interface Signal Generator Register 11_0, offset: 0xAC0 */
  uint8_t RESERVED_77[12];
  uint32_t PIGEON_11_1;                            /**< Panel Interface Signal Generator Register 11_1, offset: 0xAD0 */
  uint8_t RESERVED_78[12];
  uint32_t PIGEON_11_2;                            /**< Panel Interface Signal Generator Register 11_1, offset: 0xAE0 */
  uint8_t RESERVED_79[28];
  uint32_t PIGEON_12_0;                            /**< Panel Interface Signal Generator Register 12_0, offset: 0xB00 */
  uint8_t RESERVED_80[12];
  uint32_t PIGEON_12_1;                            /**< Panel Interface Signal Generator Register 12_1, offset: 0xB10 */
  uint8_t RESERVED_81[12];
  uint32_t PIGEON_12_2;                            /**< Panel Interface Signal Generator Register 12_1, offset: 0xB20 */
  uint8_t RESERVED_82[28];
  uint32_t PIGEON_13_0;                            /**< Panel Interface Signal Generator Register 13_0, offset: 0xB40 */
  uint8_t RESERVED_83[12];
  uint32_t PIGEON_13_1;                            /**< Panel Interface Signal Generator Register 13_1, offset: 0xB50 */
  uint8_t RESERVED_84[12];
  uint32_t PIGEON_13_2;                            /**< Panel Interface Signal Generator Register 13_1, offset: 0xB60 */
  uint8_t RESERVED_85[28];
  uint32_t PIGEON_14_0;                            /**< Panel Interface Signal Generator Register 14_0, offset: 0xB80 */
  uint8_t RESERVED_86[12];
  uint32_t PIGEON_14_1;                            /**< Panel Interface Signal Generator Register 14_1, offset: 0xB90 */
  uint8_t RESERVED_87[12];
  uint32_t PIGEON_14_2;                            /**< Panel Interface Signal Generator Register 14_1, offset: 0xBA0 */
  uint8_t RESERVED_88[28];
  uint32_t PIGEON_15_0;                            /**< Panel Interface Signal Generator Register 15_0, offset: 0xBC0 */
  uint8_t RESERVED_89[12];
  uint32_t PIGEON_15_1;                            /**< Panel Interface Signal Generator Register 15_1, offset: 0xBD0 */
  uint8_t RESERVED_90[12];
  uint32_t PIGEON_15_2;                            /**< Panel Interface Signal Generator Register 15_1, offset: 0xBE0 */
  uint8_t RESERVED_91[28];
  uint32_t PIGEON_16_0;                            /**< Panel Interface Signal Generator Register 16_0, offset: 0xC00 */
  uint8_t RESERVED_92[12];
  uint32_t PIGEON_16_1;                            /**< Panel Interface Signal Generator Register 16_1, offset: 0xC10 */
  uint8_t RESERVED_93[12];
  uint32_t PIGEON_16_2;                            /**< Panel Interface Signal Generator Register 16_1, offset: 0xC20 */
} volatile *EPDC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- EPDC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup EPDC_Register_Accessor_Macros EPDC - Register accessor macros
 * @{
 */


/* EPDC - Register accessors */
#define EPDC_CTRL_REG(base)                      ((base)->CTRL)
#define EPDC_CTRL_SET_REG(base)                  ((base)->CTRL_SET)
#define EPDC_CTRL_CLR_REG(base)                  ((base)->CTRL_CLR)
#define EPDC_CTRL_TOG_REG(base)                  ((base)->CTRL_TOG)
#define EPDC_WB_ADDR_TCE_REG(base)               ((base)->WB_ADDR_TCE)
#define EPDC_WVADDR_REG(base)                    ((base)->WVADDR)
#define EPDC_WB_ADDR_REG(base)                   ((base)->WB_ADDR)
#define EPDC_RES_REG(base)                       ((base)->RES)
#define EPDC_FORMAT_REG(base)                    ((base)->FORMAT)
#define EPDC_FORMAT_SET_REG(base)                ((base)->FORMAT_SET)
#define EPDC_FORMAT_CLR_REG(base)                ((base)->FORMAT_CLR)
#define EPDC_FORMAT_TOG_REG(base)                ((base)->FORMAT_TOG)
#define EPDC_WB_FIELD0_REG(base)                 ((base)->WB_FIELD0)
#define EPDC_WB_FIELD1_REG(base)                 ((base)->WB_FIELD1)
#define EPDC_WB_FIELD2_REG(base)                 ((base)->WB_FIELD2)
#define EPDC_WB_FIELD3_REG(base)                 ((base)->WB_FIELD3)
#define EPDC_FIFOCTRL_REG(base)                  ((base)->FIFOCTRL)
#define EPDC_FIFOCTRL_SET_REG(base)              ((base)->FIFOCTRL_SET)
#define EPDC_FIFOCTRL_CLR_REG(base)              ((base)->FIFOCTRL_CLR)
#define EPDC_FIFOCTRL_TOG_REG(base)              ((base)->FIFOCTRL_TOG)
#define EPDC_UPD_ADDR_REG(base)                  ((base)->UPD_ADDR)
#define EPDC_UPD_STRIDE_REG(base)                ((base)->UPD_STRIDE)
#define EPDC_UPD_CORD_REG(base)                  ((base)->UPD_CORD)
#define EPDC_UPD_SIZE_REG(base)                  ((base)->UPD_SIZE)
#define EPDC_UPD_CTRL_REG(base)                  ((base)->UPD_CTRL)
#define EPDC_UPD_CTRL_SET_REG(base)              ((base)->UPD_CTRL_SET)
#define EPDC_UPD_CTRL_CLR_REG(base)              ((base)->UPD_CTRL_CLR)
#define EPDC_UPD_CTRL_TOG_REG(base)              ((base)->UPD_CTRL_TOG)
#define EPDC_UPD_FIXED_REG(base)                 ((base)->UPD_FIXED)
#define EPDC_UPD_FIXED_SET_REG(base)             ((base)->UPD_FIXED_SET)
#define EPDC_UPD_FIXED_CLR_REG(base)             ((base)->UPD_FIXED_CLR)
#define EPDC_UPD_FIXED_TOG_REG(base)             ((base)->UPD_FIXED_TOG)
#define EPDC_TEMP_REG(base)                      ((base)->TEMP)
#define EPDC_AUTOWV_LUT_REG(base)                ((base)->AUTOWV_LUT)
#define EPDC_LUT_STANDBY1_REG(base)              ((base)->LUT_STANDBY1)
#define EPDC_LUT_STANDBY1_SET_REG(base)          ((base)->LUT_STANDBY1_SET)
#define EPDC_LUT_STANDBY1_CLR_REG(base)          ((base)->LUT_STANDBY1_CLR)
#define EPDC_LUT_STANDBY1_TOG_REG(base)          ((base)->LUT_STANDBY1_TOG)
#define EPDC_LUT_STANDBY2_REG(base)              ((base)->LUT_STANDBY2)
#define EPDC_LUT_STANDBY2_SET_REG(base)          ((base)->LUT_STANDBY2_SET)
#define EPDC_LUT_STANDBY2_CLR_REG(base)          ((base)->LUT_STANDBY2_CLR)
#define EPDC_LUT_STANDBY2_TOG_REG(base)          ((base)->LUT_STANDBY2_TOG)
#define EPDC_TCE_CTRL_REG(base)                  ((base)->TCE_CTRL)
#define EPDC_TCE_CTRL_SET_REG(base)              ((base)->TCE_CTRL_SET)
#define EPDC_TCE_CTRL_CLR_REG(base)              ((base)->TCE_CTRL_CLR)
#define EPDC_TCE_CTRL_TOG_REG(base)              ((base)->TCE_CTRL_TOG)
#define EPDC_TCE_SDCFG_REG(base)                 ((base)->TCE_SDCFG)
#define EPDC_TCE_SDCFG_SET_REG(base)             ((base)->TCE_SDCFG_SET)
#define EPDC_TCE_SDCFG_CLR_REG(base)             ((base)->TCE_SDCFG_CLR)
#define EPDC_TCE_SDCFG_TOG_REG(base)             ((base)->TCE_SDCFG_TOG)
#define EPDC_TCE_GDCFG_REG(base)                 ((base)->TCE_GDCFG)
#define EPDC_TCE_GDCFG_SET_REG(base)             ((base)->TCE_GDCFG_SET)
#define EPDC_TCE_GDCFG_CLR_REG(base)             ((base)->TCE_GDCFG_CLR)
#define EPDC_TCE_GDCFG_TOG_REG(base)             ((base)->TCE_GDCFG_TOG)
#define EPDC_TCE_HSCAN1_REG(base)                ((base)->TCE_HSCAN1)
#define EPDC_TCE_HSCAN1_SET_REG(base)            ((base)->TCE_HSCAN1_SET)
#define EPDC_TCE_HSCAN1_CLR_REG(base)            ((base)->TCE_HSCAN1_CLR)
#define EPDC_TCE_HSCAN1_TOG_REG(base)            ((base)->TCE_HSCAN1_TOG)
#define EPDC_TCE_HSCAN2_REG(base)                ((base)->TCE_HSCAN2)
#define EPDC_TCE_HSCAN2_SET_REG(base)            ((base)->TCE_HSCAN2_SET)
#define EPDC_TCE_HSCAN2_CLR_REG(base)            ((base)->TCE_HSCAN2_CLR)
#define EPDC_TCE_HSCAN2_TOG_REG(base)            ((base)->TCE_HSCAN2_TOG)
#define EPDC_TCE_VSCAN_REG(base)                 ((base)->TCE_VSCAN)
#define EPDC_TCE_VSCAN_SET_REG(base)             ((base)->TCE_VSCAN_SET)
#define EPDC_TCE_VSCAN_CLR_REG(base)             ((base)->TCE_VSCAN_CLR)
#define EPDC_TCE_VSCAN_TOG_REG(base)             ((base)->TCE_VSCAN_TOG)
#define EPDC_TCE_OE_REG(base)                    ((base)->TCE_OE)
#define EPDC_TCE_OE_SET_REG(base)                ((base)->TCE_OE_SET)
#define EPDC_TCE_OE_CLR_REG(base)                ((base)->TCE_OE_CLR)
#define EPDC_TCE_OE_TOG_REG(base)                ((base)->TCE_OE_TOG)
#define EPDC_TCE_POLARITY_REG(base)              ((base)->TCE_POLARITY)
#define EPDC_TCE_POLARITY_SET_REG(base)          ((base)->TCE_POLARITY_SET)
#define EPDC_TCE_POLARITY_CLR_REG(base)          ((base)->TCE_POLARITY_CLR)
#define EPDC_TCE_POLARITY_TOG_REG(base)          ((base)->TCE_POLARITY_TOG)
#define EPDC_TCE_TIMING1_REG(base)               ((base)->TCE_TIMING1)
#define EPDC_TCE_TIMING1_SET_REG(base)           ((base)->TCE_TIMING1_SET)
#define EPDC_TCE_TIMING1_CLR_REG(base)           ((base)->TCE_TIMING1_CLR)
#define EPDC_TCE_TIMING1_TOG_REG(base)           ((base)->TCE_TIMING1_TOG)
#define EPDC_TCE_TIMING2_REG(base)               ((base)->TCE_TIMING2)
#define EPDC_TCE_TIMING2_SET_REG(base)           ((base)->TCE_TIMING2_SET)
#define EPDC_TCE_TIMING2_CLR_REG(base)           ((base)->TCE_TIMING2_CLR)
#define EPDC_TCE_TIMING2_TOG_REG(base)           ((base)->TCE_TIMING2_TOG)
#define EPDC_TCE_TIMING3_REG(base)               ((base)->TCE_TIMING3)
#define EPDC_TCE_TIMING3_SET_REG(base)           ((base)->TCE_TIMING3_SET)
#define EPDC_TCE_TIMING3_CLR_REG(base)           ((base)->TCE_TIMING3_CLR)
#define EPDC_TCE_TIMING3_TOG_REG(base)           ((base)->TCE_TIMING3_TOG)
#define EPDC_PIGEON_CTRL0_REG(base)              ((base)->PIGEON_CTRL0)
#define EPDC_PIGEON_CTRL0_SET_REG(base)          ((base)->PIGEON_CTRL0_SET)
#define EPDC_PIGEON_CTRL0_CLR_REG(base)          ((base)->PIGEON_CTRL0_CLR)
#define EPDC_PIGEON_CTRL0_TOG_REG(base)          ((base)->PIGEON_CTRL0_TOG)
#define EPDC_PIGEON_CTRL1_REG(base)              ((base)->PIGEON_CTRL1)
#define EPDC_PIGEON_CTRL1_SET_REG(base)          ((base)->PIGEON_CTRL1_SET)
#define EPDC_PIGEON_CTRL1_CLR_REG(base)          ((base)->PIGEON_CTRL1_CLR)
#define EPDC_PIGEON_CTRL1_TOG_REG(base)          ((base)->PIGEON_CTRL1_TOG)
#define EPDC_IRQ_MASK1_REG(base)                 ((base)->IRQ_MASK1)
#define EPDC_IRQ_MASK1_SET_REG(base)             ((base)->IRQ_MASK1_SET)
#define EPDC_IRQ_MASK1_CLR_REG(base)             ((base)->IRQ_MASK1_CLR)
#define EPDC_IRQ_MASK1_TOG_REG(base)             ((base)->IRQ_MASK1_TOG)
#define EPDC_IRQ_MASK2_REG(base)                 ((base)->IRQ_MASK2)
#define EPDC_IRQ_MASK2_SET_REG(base)             ((base)->IRQ_MASK2_SET)
#define EPDC_IRQ_MASK2_CLR_REG(base)             ((base)->IRQ_MASK2_CLR)
#define EPDC_IRQ_MASK2_TOG_REG(base)             ((base)->IRQ_MASK2_TOG)
#define EPDC_IRQ1_REG(base)                      ((base)->IRQ1)
#define EPDC_IRQ1_SET_REG(base)                  ((base)->IRQ1_SET)
#define EPDC_IRQ1_CLR_REG(base)                  ((base)->IRQ1_CLR)
#define EPDC_IRQ1_TOG_REG(base)                  ((base)->IRQ1_TOG)
#define EPDC_IRQ2_REG(base)                      ((base)->IRQ2)
#define EPDC_IRQ2_SET_REG(base)                  ((base)->IRQ2_SET)
#define EPDC_IRQ2_CLR_REG(base)                  ((base)->IRQ2_CLR)
#define EPDC_IRQ2_TOG_REG(base)                  ((base)->IRQ2_TOG)
#define EPDC_IRQ_MASK_REG(base)                  ((base)->IRQ_MASK)
#define EPDC_IRQ_MASK_SET_REG(base)              ((base)->IRQ_MASK_SET)
#define EPDC_IRQ_MASK_CLR_REG(base)              ((base)->IRQ_MASK_CLR)
#define EPDC_IRQ_MASK_TOG_REG(base)              ((base)->IRQ_MASK_TOG)
#define EPDC_IRQ_REG(base)                       ((base)->IRQ)
#define EPDC_IRQ_SET_REG(base)                   ((base)->IRQ_SET)
#define EPDC_IRQ_CLR_REG(base)                   ((base)->IRQ_CLR)
#define EPDC_IRQ_TOG_REG(base)                   ((base)->IRQ_TOG)
#define EPDC_STATUS_LUTS1_REG(base)              ((base)->STATUS_LUTS1)
#define EPDC_STATUS_LUTS1_SET_REG(base)          ((base)->STATUS_LUTS1_SET)
#define EPDC_STATUS_LUTS1_CLR_REG(base)          ((base)->STATUS_LUTS1_CLR)
#define EPDC_STATUS_LUTS1_TOG_REG(base)          ((base)->STATUS_LUTS1_TOG)
#define EPDC_STATUS_LUTS2_REG(base)              ((base)->STATUS_LUTS2)
#define EPDC_STATUS_LUTS2_SET_REG(base)          ((base)->STATUS_LUTS2_SET)
#define EPDC_STATUS_LUTS2_CLR_REG(base)          ((base)->STATUS_LUTS2_CLR)
#define EPDC_STATUS_LUTS2_TOG_REG(base)          ((base)->STATUS_LUTS2_TOG)
#define EPDC_STATUS_NEXTLUT_REG(base)            ((base)->STATUS_NEXTLUT)
#define EPDC_STATUS_COL1_REG(base)               ((base)->STATUS_COL1)
#define EPDC_STATUS_COL1_SET_REG(base)           ((base)->STATUS_COL1_SET)
#define EPDC_STATUS_COL1_CLR_REG(base)           ((base)->STATUS_COL1_CLR)
#define EPDC_STATUS_COL1_TOG_REG(base)           ((base)->STATUS_COL1_TOG)
#define EPDC_STATUS_COL2_REG(base)               ((base)->STATUS_COL2)
#define EPDC_STATUS_COL2_SET_REG(base)           ((base)->STATUS_COL2_SET)
#define EPDC_STATUS_COL2_CLR_REG(base)           ((base)->STATUS_COL2_CLR)
#define EPDC_STATUS_COL2_TOG_REG(base)           ((base)->STATUS_COL2_TOG)
#define EPDC_STATUS_REG(base)                    ((base)->STATUS)
#define EPDC_STATUS_SET_REG(base)                ((base)->STATUS_SET)
#define EPDC_STATUS_CLR_REG(base)                ((base)->STATUS_CLR)
#define EPDC_STATUS_TOG_REG(base)                ((base)->STATUS_TOG)
#define EPDC_UPD_COL_CORD_REG(base)              ((base)->UPD_COL_CORD)
#define EPDC_UPD_COL_SIZE_REG(base)              ((base)->UPD_COL_SIZE)
#define EPDC_HIST1_PARAM_REG(base)               ((base)->HIST1_PARAM)
#define EPDC_HIST2_PARAM_REG(base)               ((base)->HIST2_PARAM)
#define EPDC_HIST4_PARAM_REG(base)               ((base)->HIST4_PARAM)
#define EPDC_HIST8_PARAM0_REG(base)              ((base)->HIST8_PARAM0)
#define EPDC_HIST8_PARAM1_REG(base)              ((base)->HIST8_PARAM1)
#define EPDC_HIST16_PARAM0_REG(base)             ((base)->HIST16_PARAM0)
#define EPDC_HIST16_PARAM1_REG(base)             ((base)->HIST16_PARAM1)
#define EPDC_HIST16_PARAM2_REG(base)             ((base)->HIST16_PARAM2)
#define EPDC_HIST16_PARAM3_REG(base)             ((base)->HIST16_PARAM3)
#define EPDC_GPIO_REG(base)                      ((base)->GPIO)
#define EPDC_GPIO_SET_REG(base)                  ((base)->GPIO_SET)
#define EPDC_GPIO_CLR_REG(base)                  ((base)->GPIO_CLR)
#define EPDC_GPIO_TOG_REG(base)                  ((base)->GPIO_TOG)
#define EPDC_VERSION_REG(base)                   ((base)->VERSION)
#define EPDC_PIGEON_0_0_REG(base)                ((base)->PIGEON_0_0)
#define EPDC_PIGEON_0_1_REG(base)                ((base)->PIGEON_0_1)
#define EPDC_PIGEON_0_2_REG(base)                ((base)->PIGEON_0_2)
#define EPDC_PIGEON_1_0_REG(base)                ((base)->PIGEON_1_0)
#define EPDC_PIGEON_1_1_REG(base)                ((base)->PIGEON_1_1)
#define EPDC_PIGEON_1_2_REG(base)                ((base)->PIGEON_1_2)
#define EPDC_PIGEON_2_0_REG(base)                ((base)->PIGEON_2_0)
#define EPDC_PIGEON_2_1_REG(base)                ((base)->PIGEON_2_1)
#define EPDC_PIGEON_2_2_REG(base)                ((base)->PIGEON_2_2)
#define EPDC_PIGEON_3_0_REG(base)                ((base)->PIGEON_3_0)
#define EPDC_PIGEON_3_1_REG(base)                ((base)->PIGEON_3_1)
#define EPDC_PIGEON_3_2_REG(base)                ((base)->PIGEON_3_2)
#define EPDC_PIGEON_4_0_REG(base)                ((base)->PIGEON_4_0)
#define EPDC_PIGEON_4_1_REG(base)                ((base)->PIGEON_4_1)
#define EPDC_PIGEON_4_2_REG(base)                ((base)->PIGEON_4_2)
#define EPDC_PIGEON_5_0_REG(base)                ((base)->PIGEON_5_0)
#define EPDC_PIGEON_5_1_REG(base)                ((base)->PIGEON_5_1)
#define EPDC_PIGEON_5_2_REG(base)                ((base)->PIGEON_5_2)
#define EPDC_PIGEON_6_0_REG(base)                ((base)->PIGEON_6_0)
#define EPDC_PIGEON_6_1_REG(base)                ((base)->PIGEON_6_1)
#define EPDC_PIGEON_6_2_REG(base)                ((base)->PIGEON_6_2)
#define EPDC_PIGEON_7_0_REG(base)                ((base)->PIGEON_7_0)
#define EPDC_PIGEON_7_1_REG(base)                ((base)->PIGEON_7_1)
#define EPDC_PIGEON_7_2_REG(base)                ((base)->PIGEON_7_2)
#define EPDC_PIGEON_8_0_REG(base)                ((base)->PIGEON_8_0)
#define EPDC_PIGEON_8_1_REG(base)                ((base)->PIGEON_8_1)
#define EPDC_PIGEON_8_2_REG(base)                ((base)->PIGEON_8_2)
#define EPDC_PIGEON_9_0_REG(base)                ((base)->PIGEON_9_0)
#define EPDC_PIGEON_9_1_REG(base)                ((base)->PIGEON_9_1)
#define EPDC_PIGEON_9_2_REG(base)                ((base)->PIGEON_9_2)
#define EPDC_PIGEON_10_0_REG(base)               ((base)->PIGEON_10_0)
#define EPDC_PIGEON_10_1_REG(base)               ((base)->PIGEON_10_1)
#define EPDC_PIGEON_10_2_REG(base)               ((base)->PIGEON_10_2)
#define EPDC_PIGEON_11_0_REG(base)               ((base)->PIGEON_11_0)
#define EPDC_PIGEON_11_1_REG(base)               ((base)->PIGEON_11_1)
#define EPDC_PIGEON_11_2_REG(base)               ((base)->PIGEON_11_2)
#define EPDC_PIGEON_12_0_REG(base)               ((base)->PIGEON_12_0)
#define EPDC_PIGEON_12_1_REG(base)               ((base)->PIGEON_12_1)
#define EPDC_PIGEON_12_2_REG(base)               ((base)->PIGEON_12_2)
#define EPDC_PIGEON_13_0_REG(base)               ((base)->PIGEON_13_0)
#define EPDC_PIGEON_13_1_REG(base)               ((base)->PIGEON_13_1)
#define EPDC_PIGEON_13_2_REG(base)               ((base)->PIGEON_13_2)
#define EPDC_PIGEON_14_0_REG(base)               ((base)->PIGEON_14_0)
#define EPDC_PIGEON_14_1_REG(base)               ((base)->PIGEON_14_1)
#define EPDC_PIGEON_14_2_REG(base)               ((base)->PIGEON_14_2)
#define EPDC_PIGEON_15_0_REG(base)               ((base)->PIGEON_15_0)
#define EPDC_PIGEON_15_1_REG(base)               ((base)->PIGEON_15_1)
#define EPDC_PIGEON_15_2_REG(base)               ((base)->PIGEON_15_2)
#define EPDC_PIGEON_16_0_REG(base)               ((base)->PIGEON_16_0)
#define EPDC_PIGEON_16_1_REG(base)               ((base)->PIGEON_16_1)
#define EPDC_PIGEON_16_2_REG(base)               ((base)->PIGEON_16_2)

/*!
 * @}
 */ /* end of group EPDC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- EPDC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup EPDC_Register_Masks EPDC Register Masks
 * @{
 */

/*! @name CTRL - EPDC Control Register */
#define EPDC_CTRL_LUT_DATA_SWIZZLE_MASK          (0x30U)
#define EPDC_CTRL_LUT_DATA_SWIZZLE_SHIFT         (4U)
#define EPDC_CTRL_LUT_DATA_SWIZZLE(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_CTRL_LUT_DATA_SWIZZLE_SHIFT)) & EPDC_CTRL_LUT_DATA_SWIZZLE_MASK)
#define EPDC_CTRL_UPD_DATA_SWIZZLE_MASK          (0xC0U)
#define EPDC_CTRL_UPD_DATA_SWIZZLE_SHIFT         (6U)
#define EPDC_CTRL_UPD_DATA_SWIZZLE(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_CTRL_UPD_DATA_SWIZZLE_SHIFT)) & EPDC_CTRL_UPD_DATA_SWIZZLE_MASK)
#define EPDC_CTRL_CLKGATE_MASK                   (0x40000000U)
#define EPDC_CTRL_CLKGATE_SHIFT                  (30U)
#define EPDC_CTRL_SFTRST_MASK                    (0x80000000U)
#define EPDC_CTRL_SFTRST_SHIFT                   (31U)

/*! @name CTRL_SET - EPDC Control Register */
#define EPDC_CTRL_SET_LUT_DATA_SWIZZLE_MASK      (0x30U)
#define EPDC_CTRL_SET_LUT_DATA_SWIZZLE_SHIFT     (4U)
#define EPDC_CTRL_SET_LUT_DATA_SWIZZLE(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_CTRL_SET_LUT_DATA_SWIZZLE_SHIFT)) & EPDC_CTRL_SET_LUT_DATA_SWIZZLE_MASK)
#define EPDC_CTRL_SET_UPD_DATA_SWIZZLE_MASK      (0xC0U)
#define EPDC_CTRL_SET_UPD_DATA_SWIZZLE_SHIFT     (6U)
#define EPDC_CTRL_SET_UPD_DATA_SWIZZLE(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_CTRL_SET_UPD_DATA_SWIZZLE_SHIFT)) & EPDC_CTRL_SET_UPD_DATA_SWIZZLE_MASK)
#define EPDC_CTRL_SET_CLKGATE_MASK               (0x40000000U)
#define EPDC_CTRL_SET_CLKGATE_SHIFT              (30U)
#define EPDC_CTRL_SET_SFTRST_MASK                (0x80000000U)
#define EPDC_CTRL_SET_SFTRST_SHIFT               (31U)

/*! @name CTRL_CLR - EPDC Control Register */
#define EPDC_CTRL_CLR_LUT_DATA_SWIZZLE_MASK      (0x30U)
#define EPDC_CTRL_CLR_LUT_DATA_SWIZZLE_SHIFT     (4U)
#define EPDC_CTRL_CLR_LUT_DATA_SWIZZLE(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_CTRL_CLR_LUT_DATA_SWIZZLE_SHIFT)) & EPDC_CTRL_CLR_LUT_DATA_SWIZZLE_MASK)
#define EPDC_CTRL_CLR_UPD_DATA_SWIZZLE_MASK      (0xC0U)
#define EPDC_CTRL_CLR_UPD_DATA_SWIZZLE_SHIFT     (6U)
#define EPDC_CTRL_CLR_UPD_DATA_SWIZZLE(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_CTRL_CLR_UPD_DATA_SWIZZLE_SHIFT)) & EPDC_CTRL_CLR_UPD_DATA_SWIZZLE_MASK)
#define EPDC_CTRL_CLR_CLKGATE_MASK               (0x40000000U)
#define EPDC_CTRL_CLR_CLKGATE_SHIFT              (30U)
#define EPDC_CTRL_CLR_SFTRST_MASK                (0x80000000U)
#define EPDC_CTRL_CLR_SFTRST_SHIFT               (31U)

/*! @name CTRL_TOG - EPDC Control Register */
#define EPDC_CTRL_TOG_LUT_DATA_SWIZZLE_MASK      (0x30U)
#define EPDC_CTRL_TOG_LUT_DATA_SWIZZLE_SHIFT     (4U)
#define EPDC_CTRL_TOG_LUT_DATA_SWIZZLE(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_CTRL_TOG_LUT_DATA_SWIZZLE_SHIFT)) & EPDC_CTRL_TOG_LUT_DATA_SWIZZLE_MASK)
#define EPDC_CTRL_TOG_UPD_DATA_SWIZZLE_MASK      (0xC0U)
#define EPDC_CTRL_TOG_UPD_DATA_SWIZZLE_SHIFT     (6U)
#define EPDC_CTRL_TOG_UPD_DATA_SWIZZLE(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_CTRL_TOG_UPD_DATA_SWIZZLE_SHIFT)) & EPDC_CTRL_TOG_UPD_DATA_SWIZZLE_MASK)
#define EPDC_CTRL_TOG_CLKGATE_MASK               (0x40000000U)
#define EPDC_CTRL_TOG_CLKGATE_SHIFT              (30U)
#define EPDC_CTRL_TOG_SFTRST_MASK                (0x80000000U)
#define EPDC_CTRL_TOG_SFTRST_SHIFT               (31U)

/*! @name WB_ADDR_TCE - EPDC Working Buffer Address for TCE */
#define EPDC_WB_ADDR_TCE_ADDR_MASK               (0xFFFFFFFFU)
#define EPDC_WB_ADDR_TCE_ADDR_SHIFT              (0U)
#define EPDC_WB_ADDR_TCE_ADDR(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_WB_ADDR_TCE_ADDR_SHIFT)) & EPDC_WB_ADDR_TCE_ADDR_MASK)

/*! @name WVADDR - EPDC Waveform Address Pointer */
#define EPDC_WVADDR_ADDR_MASK                    (0xFFFFFFFFU)
#define EPDC_WVADDR_ADDR_SHIFT                   (0U)
#define EPDC_WVADDR_ADDR(x)                      (((uint32_t)(((uint32_t)(x)) << EPDC_WVADDR_ADDR_SHIFT)) & EPDC_WVADDR_ADDR_MASK)

/*! @name WB_ADDR - EPDC Working Buffer Address */
#define EPDC_WB_ADDR_ADDR_MASK                   (0xFFFFFFFFU)
#define EPDC_WB_ADDR_ADDR_SHIFT                  (0U)
#define EPDC_WB_ADDR_ADDR(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_WB_ADDR_ADDR_SHIFT)) & EPDC_WB_ADDR_ADDR_MASK)

/*! @name RES - EPDC Screen Resolution */
#define EPDC_RES_HORIZONTAL_MASK                 (0x1FFFU)
#define EPDC_RES_HORIZONTAL_SHIFT                (0U)
#define EPDC_RES_HORIZONTAL(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_RES_HORIZONTAL_SHIFT)) & EPDC_RES_HORIZONTAL_MASK)
#define EPDC_RES_VERTICAL_MASK                   (0x1FFF0000U)
#define EPDC_RES_VERTICAL_SHIFT                  (16U)
#define EPDC_RES_VERTICAL(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_RES_VERTICAL_SHIFT)) & EPDC_RES_VERTICAL_MASK)

/*! @name FORMAT - EPDC Format Control Register */
#define EPDC_FORMAT_TFT_PIXEL_FORMAT_MASK        (0x3U)
#define EPDC_FORMAT_TFT_PIXEL_FORMAT_SHIFT       (0U)
#define EPDC_FORMAT_TFT_PIXEL_FORMAT(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_TFT_PIXEL_FORMAT_SHIFT)) & EPDC_FORMAT_TFT_PIXEL_FORMAT_MASK)
#define EPDC_FORMAT_BUF_PIXEL_FORMAT_MASK        (0x700U)
#define EPDC_FORMAT_BUF_PIXEL_FORMAT_SHIFT       (8U)
#define EPDC_FORMAT_BUF_PIXEL_FORMAT(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_BUF_PIXEL_FORMAT_SHIFT)) & EPDC_FORMAT_BUF_PIXEL_FORMAT_MASK)
#define EPDC_FORMAT_WB_COMPRESS_MASK             (0x800U)
#define EPDC_FORMAT_WB_COMPRESS_SHIFT            (11U)
#define EPDC_FORMAT_WB_TYPE_MASK                 (0x3000U)
#define EPDC_FORMAT_WB_TYPE_SHIFT                (12U)
#define EPDC_FORMAT_WB_TYPE(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_WB_TYPE_SHIFT)) & EPDC_FORMAT_WB_TYPE_MASK)
#define EPDC_FORMAT_WB_ADDR_NO_COPY_MASK         (0x4000U)
#define EPDC_FORMAT_WB_ADDR_NO_COPY_SHIFT        (14U)
#define EPDC_FORMAT_DEFAULT_TFT_PIXEL_MASK       (0xFF0000U)
#define EPDC_FORMAT_DEFAULT_TFT_PIXEL_SHIFT      (16U)
#define EPDC_FORMAT_DEFAULT_TFT_PIXEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_DEFAULT_TFT_PIXEL_SHIFT)) & EPDC_FORMAT_DEFAULT_TFT_PIXEL_MASK)
#define EPDC_FORMAT_BUF_PIXEL_SCALE_MASK         (0x1000000U)
#define EPDC_FORMAT_BUF_PIXEL_SCALE_SHIFT        (24U)

/*! @name FORMAT_SET - EPDC Format Control Register */
#define EPDC_FORMAT_SET_TFT_PIXEL_FORMAT_MASK    (0x3U)
#define EPDC_FORMAT_SET_TFT_PIXEL_FORMAT_SHIFT   (0U)
#define EPDC_FORMAT_SET_TFT_PIXEL_FORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_SET_TFT_PIXEL_FORMAT_SHIFT)) & EPDC_FORMAT_SET_TFT_PIXEL_FORMAT_MASK)
#define EPDC_FORMAT_SET_BUF_PIXEL_FORMAT_MASK    (0x700U)
#define EPDC_FORMAT_SET_BUF_PIXEL_FORMAT_SHIFT   (8U)
#define EPDC_FORMAT_SET_BUF_PIXEL_FORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_SET_BUF_PIXEL_FORMAT_SHIFT)) & EPDC_FORMAT_SET_BUF_PIXEL_FORMAT_MASK)
#define EPDC_FORMAT_SET_WB_COMPRESS_MASK         (0x800U)
#define EPDC_FORMAT_SET_WB_COMPRESS_SHIFT        (11U)
#define EPDC_FORMAT_SET_WB_TYPE_MASK             (0x3000U)
#define EPDC_FORMAT_SET_WB_TYPE_SHIFT            (12U)
#define EPDC_FORMAT_SET_WB_TYPE(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_SET_WB_TYPE_SHIFT)) & EPDC_FORMAT_SET_WB_TYPE_MASK)
#define EPDC_FORMAT_SET_WB_ADDR_NO_COPY_MASK     (0x4000U)
#define EPDC_FORMAT_SET_WB_ADDR_NO_COPY_SHIFT    (14U)
#define EPDC_FORMAT_SET_DEFAULT_TFT_PIXEL_MASK   (0xFF0000U)
#define EPDC_FORMAT_SET_DEFAULT_TFT_PIXEL_SHIFT  (16U)
#define EPDC_FORMAT_SET_DEFAULT_TFT_PIXEL(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_SET_DEFAULT_TFT_PIXEL_SHIFT)) & EPDC_FORMAT_SET_DEFAULT_TFT_PIXEL_MASK)
#define EPDC_FORMAT_SET_BUF_PIXEL_SCALE_MASK     (0x1000000U)
#define EPDC_FORMAT_SET_BUF_PIXEL_SCALE_SHIFT    (24U)

/*! @name FORMAT_CLR - EPDC Format Control Register */
#define EPDC_FORMAT_CLR_TFT_PIXEL_FORMAT_MASK    (0x3U)
#define EPDC_FORMAT_CLR_TFT_PIXEL_FORMAT_SHIFT   (0U)
#define EPDC_FORMAT_CLR_TFT_PIXEL_FORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_CLR_TFT_PIXEL_FORMAT_SHIFT)) & EPDC_FORMAT_CLR_TFT_PIXEL_FORMAT_MASK)
#define EPDC_FORMAT_CLR_BUF_PIXEL_FORMAT_MASK    (0x700U)
#define EPDC_FORMAT_CLR_BUF_PIXEL_FORMAT_SHIFT   (8U)
#define EPDC_FORMAT_CLR_BUF_PIXEL_FORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_CLR_BUF_PIXEL_FORMAT_SHIFT)) & EPDC_FORMAT_CLR_BUF_PIXEL_FORMAT_MASK)
#define EPDC_FORMAT_CLR_WB_COMPRESS_MASK         (0x800U)
#define EPDC_FORMAT_CLR_WB_COMPRESS_SHIFT        (11U)
#define EPDC_FORMAT_CLR_WB_TYPE_MASK             (0x3000U)
#define EPDC_FORMAT_CLR_WB_TYPE_SHIFT            (12U)
#define EPDC_FORMAT_CLR_WB_TYPE(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_CLR_WB_TYPE_SHIFT)) & EPDC_FORMAT_CLR_WB_TYPE_MASK)
#define EPDC_FORMAT_CLR_WB_ADDR_NO_COPY_MASK     (0x4000U)
#define EPDC_FORMAT_CLR_WB_ADDR_NO_COPY_SHIFT    (14U)
#define EPDC_FORMAT_CLR_DEFAULT_TFT_PIXEL_MASK   (0xFF0000U)
#define EPDC_FORMAT_CLR_DEFAULT_TFT_PIXEL_SHIFT  (16U)
#define EPDC_FORMAT_CLR_DEFAULT_TFT_PIXEL(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_CLR_DEFAULT_TFT_PIXEL_SHIFT)) & EPDC_FORMAT_CLR_DEFAULT_TFT_PIXEL_MASK)
#define EPDC_FORMAT_CLR_BUF_PIXEL_SCALE_MASK     (0x1000000U)
#define EPDC_FORMAT_CLR_BUF_PIXEL_SCALE_SHIFT    (24U)

/*! @name FORMAT_TOG - EPDC Format Control Register */
#define EPDC_FORMAT_TOG_TFT_PIXEL_FORMAT_MASK    (0x3U)
#define EPDC_FORMAT_TOG_TFT_PIXEL_FORMAT_SHIFT   (0U)
#define EPDC_FORMAT_TOG_TFT_PIXEL_FORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_TOG_TFT_PIXEL_FORMAT_SHIFT)) & EPDC_FORMAT_TOG_TFT_PIXEL_FORMAT_MASK)
#define EPDC_FORMAT_TOG_BUF_PIXEL_FORMAT_MASK    (0x700U)
#define EPDC_FORMAT_TOG_BUF_PIXEL_FORMAT_SHIFT   (8U)
#define EPDC_FORMAT_TOG_BUF_PIXEL_FORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_TOG_BUF_PIXEL_FORMAT_SHIFT)) & EPDC_FORMAT_TOG_BUF_PIXEL_FORMAT_MASK)
#define EPDC_FORMAT_TOG_WB_COMPRESS_MASK         (0x800U)
#define EPDC_FORMAT_TOG_WB_COMPRESS_SHIFT        (11U)
#define EPDC_FORMAT_TOG_WB_TYPE_MASK             (0x3000U)
#define EPDC_FORMAT_TOG_WB_TYPE_SHIFT            (12U)
#define EPDC_FORMAT_TOG_WB_TYPE(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_TOG_WB_TYPE_SHIFT)) & EPDC_FORMAT_TOG_WB_TYPE_MASK)
#define EPDC_FORMAT_TOG_WB_ADDR_NO_COPY_MASK     (0x4000U)
#define EPDC_FORMAT_TOG_WB_ADDR_NO_COPY_SHIFT    (14U)
#define EPDC_FORMAT_TOG_DEFAULT_TFT_PIXEL_MASK   (0xFF0000U)
#define EPDC_FORMAT_TOG_DEFAULT_TFT_PIXEL_SHIFT  (16U)
#define EPDC_FORMAT_TOG_DEFAULT_TFT_PIXEL(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_FORMAT_TOG_DEFAULT_TFT_PIXEL_SHIFT)) & EPDC_FORMAT_TOG_DEFAULT_TFT_PIXEL_MASK)
#define EPDC_FORMAT_TOG_BUF_PIXEL_SCALE_MASK     (0x1000000U)
#define EPDC_FORMAT_TOG_BUF_PIXEL_SCALE_SHIFT    (24U)

/*! @name WB_FIELD0 - Working Buffer Field Setting */
#define EPDC_WB_FIELD0_LEN_MASK                  (0xFU)
#define EPDC_WB_FIELD0_LEN_SHIFT                 (0U)
#define EPDC_WB_FIELD0_LEN(x)                    (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD0_LEN_SHIFT)) & EPDC_WB_FIELD0_LEN_MASK)
#define EPDC_WB_FIELD0_TO_MASK                   (0xF0U)
#define EPDC_WB_FIELD0_TO_SHIFT                  (4U)
#define EPDC_WB_FIELD0_TO(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD0_TO_SHIFT)) & EPDC_WB_FIELD0_TO_MASK)
#define EPDC_WB_FIELD0_FROM_MASK                 (0x1F00U)
#define EPDC_WB_FIELD0_FROM_SHIFT                (8U)
#define EPDC_WB_FIELD0_FROM(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD0_FROM_SHIFT)) & EPDC_WB_FIELD0_FROM_MASK)
#define EPDC_WB_FIELD0_USAGE_MASK                (0xE000U)
#define EPDC_WB_FIELD0_USAGE_SHIFT               (13U)
#define EPDC_WB_FIELD0_USAGE(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD0_USAGE_SHIFT)) & EPDC_WB_FIELD0_USAGE_MASK)
#define EPDC_WB_FIELD0_USE_FIXED_MASK            (0x30000U)
#define EPDC_WB_FIELD0_USE_FIXED_SHIFT           (16U)
#define EPDC_WB_FIELD0_USE_FIXED(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD0_USE_FIXED_SHIFT)) & EPDC_WB_FIELD0_USE_FIXED_MASK)
#define EPDC_WB_FIELD0_FIXED_MASK                (0xFF000000U)
#define EPDC_WB_FIELD0_FIXED_SHIFT               (24U)
#define EPDC_WB_FIELD0_FIXED(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD0_FIXED_SHIFT)) & EPDC_WB_FIELD0_FIXED_MASK)

/*! @name WB_FIELD1 - Working Buffer Field Setting */
#define EPDC_WB_FIELD1_LEN_MASK                  (0xFU)
#define EPDC_WB_FIELD1_LEN_SHIFT                 (0U)
#define EPDC_WB_FIELD1_LEN(x)                    (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD1_LEN_SHIFT)) & EPDC_WB_FIELD1_LEN_MASK)
#define EPDC_WB_FIELD1_TO_MASK                   (0xF0U)
#define EPDC_WB_FIELD1_TO_SHIFT                  (4U)
#define EPDC_WB_FIELD1_TO(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD1_TO_SHIFT)) & EPDC_WB_FIELD1_TO_MASK)
#define EPDC_WB_FIELD1_FROM_MASK                 (0x1F00U)
#define EPDC_WB_FIELD1_FROM_SHIFT                (8U)
#define EPDC_WB_FIELD1_FROM(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD1_FROM_SHIFT)) & EPDC_WB_FIELD1_FROM_MASK)
#define EPDC_WB_FIELD1_USAGE_MASK                (0xE000U)
#define EPDC_WB_FIELD1_USAGE_SHIFT               (13U)
#define EPDC_WB_FIELD1_USAGE(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD1_USAGE_SHIFT)) & EPDC_WB_FIELD1_USAGE_MASK)
#define EPDC_WB_FIELD1_USE_FIXED_MASK            (0x30000U)
#define EPDC_WB_FIELD1_USE_FIXED_SHIFT           (16U)
#define EPDC_WB_FIELD1_USE_FIXED(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD1_USE_FIXED_SHIFT)) & EPDC_WB_FIELD1_USE_FIXED_MASK)
#define EPDC_WB_FIELD1_FIXED_MASK                (0xFF000000U)
#define EPDC_WB_FIELD1_FIXED_SHIFT               (24U)
#define EPDC_WB_FIELD1_FIXED(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD1_FIXED_SHIFT)) & EPDC_WB_FIELD1_FIXED_MASK)

/*! @name WB_FIELD2 - Working Buffer Field Setting */
#define EPDC_WB_FIELD2_LEN_MASK                  (0xFU)
#define EPDC_WB_FIELD2_LEN_SHIFT                 (0U)
#define EPDC_WB_FIELD2_LEN(x)                    (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD2_LEN_SHIFT)) & EPDC_WB_FIELD2_LEN_MASK)
#define EPDC_WB_FIELD2_TO_MASK                   (0xF0U)
#define EPDC_WB_FIELD2_TO_SHIFT                  (4U)
#define EPDC_WB_FIELD2_TO(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD2_TO_SHIFT)) & EPDC_WB_FIELD2_TO_MASK)
#define EPDC_WB_FIELD2_FROM_MASK                 (0x1F00U)
#define EPDC_WB_FIELD2_FROM_SHIFT                (8U)
#define EPDC_WB_FIELD2_FROM(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD2_FROM_SHIFT)) & EPDC_WB_FIELD2_FROM_MASK)
#define EPDC_WB_FIELD2_USAGE_MASK                (0xE000U)
#define EPDC_WB_FIELD2_USAGE_SHIFT               (13U)
#define EPDC_WB_FIELD2_USAGE(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD2_USAGE_SHIFT)) & EPDC_WB_FIELD2_USAGE_MASK)
#define EPDC_WB_FIELD2_USE_FIXED_MASK            (0x30000U)
#define EPDC_WB_FIELD2_USE_FIXED_SHIFT           (16U)
#define EPDC_WB_FIELD2_USE_FIXED(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD2_USE_FIXED_SHIFT)) & EPDC_WB_FIELD2_USE_FIXED_MASK)
#define EPDC_WB_FIELD2_FIXED_MASK                (0xFF000000U)
#define EPDC_WB_FIELD2_FIXED_SHIFT               (24U)
#define EPDC_WB_FIELD2_FIXED(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD2_FIXED_SHIFT)) & EPDC_WB_FIELD2_FIXED_MASK)

/*! @name WB_FIELD3 - Working Buffer Field Setting */
#define EPDC_WB_FIELD3_LEN_MASK                  (0xFU)
#define EPDC_WB_FIELD3_LEN_SHIFT                 (0U)
#define EPDC_WB_FIELD3_LEN(x)                    (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD3_LEN_SHIFT)) & EPDC_WB_FIELD3_LEN_MASK)
#define EPDC_WB_FIELD3_TO_MASK                   (0xF0U)
#define EPDC_WB_FIELD3_TO_SHIFT                  (4U)
#define EPDC_WB_FIELD3_TO(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD3_TO_SHIFT)) & EPDC_WB_FIELD3_TO_MASK)
#define EPDC_WB_FIELD3_FROM_MASK                 (0x1F00U)
#define EPDC_WB_FIELD3_FROM_SHIFT                (8U)
#define EPDC_WB_FIELD3_FROM(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD3_FROM_SHIFT)) & EPDC_WB_FIELD3_FROM_MASK)
#define EPDC_WB_FIELD3_USAGE_MASK                (0xE000U)
#define EPDC_WB_FIELD3_USAGE_SHIFT               (13U)
#define EPDC_WB_FIELD3_USAGE(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD3_USAGE_SHIFT)) & EPDC_WB_FIELD3_USAGE_MASK)
#define EPDC_WB_FIELD3_USE_FIXED_MASK            (0x30000U)
#define EPDC_WB_FIELD3_USE_FIXED_SHIFT           (16U)
#define EPDC_WB_FIELD3_USE_FIXED(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD3_USE_FIXED_SHIFT)) & EPDC_WB_FIELD3_USE_FIXED_MASK)
#define EPDC_WB_FIELD3_FIXED_MASK                (0xFF000000U)
#define EPDC_WB_FIELD3_FIXED_SHIFT               (24U)
#define EPDC_WB_FIELD3_FIXED(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_WB_FIELD3_FIXED_SHIFT)) & EPDC_WB_FIELD3_FIXED_MASK)

/*! @name FIFOCTRL - EPDC FIFO control register */
#define EPDC_FIFOCTRL_FIFO_L_LEVEL_MASK          (0xFFU)
#define EPDC_FIFOCTRL_FIFO_L_LEVEL_SHIFT         (0U)
#define EPDC_FIFOCTRL_FIFO_L_LEVEL(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_FIFO_L_LEVEL_SHIFT)) & EPDC_FIFOCTRL_FIFO_L_LEVEL_MASK)
#define EPDC_FIFOCTRL_FIFO_H_LEVEL_MASK          (0xFF00U)
#define EPDC_FIFOCTRL_FIFO_H_LEVEL_SHIFT         (8U)
#define EPDC_FIFOCTRL_FIFO_H_LEVEL(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_FIFO_H_LEVEL_SHIFT)) & EPDC_FIFOCTRL_FIFO_H_LEVEL_MASK)
#define EPDC_FIFOCTRL_FIFO_INIT_LEVEL_MASK       (0xFF0000U)
#define EPDC_FIFOCTRL_FIFO_INIT_LEVEL_SHIFT      (16U)
#define EPDC_FIFOCTRL_FIFO_INIT_LEVEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_FIFO_INIT_LEVEL_SHIFT)) & EPDC_FIFOCTRL_FIFO_INIT_LEVEL_MASK)
#define EPDC_FIFOCTRL_ENABLE_PRIORITY_MASK       (0x80000000U)
#define EPDC_FIFOCTRL_ENABLE_PRIORITY_SHIFT      (31U)

/*! @name FIFOCTRL_SET - EPDC FIFO control register */
#define EPDC_FIFOCTRL_SET_FIFO_L_LEVEL_MASK      (0xFFU)
#define EPDC_FIFOCTRL_SET_FIFO_L_LEVEL_SHIFT     (0U)
#define EPDC_FIFOCTRL_SET_FIFO_L_LEVEL(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_SET_FIFO_L_LEVEL_SHIFT)) & EPDC_FIFOCTRL_SET_FIFO_L_LEVEL_MASK)
#define EPDC_FIFOCTRL_SET_FIFO_H_LEVEL_MASK      (0xFF00U)
#define EPDC_FIFOCTRL_SET_FIFO_H_LEVEL_SHIFT     (8U)
#define EPDC_FIFOCTRL_SET_FIFO_H_LEVEL(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_SET_FIFO_H_LEVEL_SHIFT)) & EPDC_FIFOCTRL_SET_FIFO_H_LEVEL_MASK)
#define EPDC_FIFOCTRL_SET_FIFO_INIT_LEVEL_MASK   (0xFF0000U)
#define EPDC_FIFOCTRL_SET_FIFO_INIT_LEVEL_SHIFT  (16U)
#define EPDC_FIFOCTRL_SET_FIFO_INIT_LEVEL(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_SET_FIFO_INIT_LEVEL_SHIFT)) & EPDC_FIFOCTRL_SET_FIFO_INIT_LEVEL_MASK)
#define EPDC_FIFOCTRL_SET_ENABLE_PRIORITY_MASK   (0x80000000U)
#define EPDC_FIFOCTRL_SET_ENABLE_PRIORITY_SHIFT  (31U)

/*! @name FIFOCTRL_CLR - EPDC FIFO control register */
#define EPDC_FIFOCTRL_CLR_FIFO_L_LEVEL_MASK      (0xFFU)
#define EPDC_FIFOCTRL_CLR_FIFO_L_LEVEL_SHIFT     (0U)
#define EPDC_FIFOCTRL_CLR_FIFO_L_LEVEL(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_CLR_FIFO_L_LEVEL_SHIFT)) & EPDC_FIFOCTRL_CLR_FIFO_L_LEVEL_MASK)
#define EPDC_FIFOCTRL_CLR_FIFO_H_LEVEL_MASK      (0xFF00U)
#define EPDC_FIFOCTRL_CLR_FIFO_H_LEVEL_SHIFT     (8U)
#define EPDC_FIFOCTRL_CLR_FIFO_H_LEVEL(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_CLR_FIFO_H_LEVEL_SHIFT)) & EPDC_FIFOCTRL_CLR_FIFO_H_LEVEL_MASK)
#define EPDC_FIFOCTRL_CLR_FIFO_INIT_LEVEL_MASK   (0xFF0000U)
#define EPDC_FIFOCTRL_CLR_FIFO_INIT_LEVEL_SHIFT  (16U)
#define EPDC_FIFOCTRL_CLR_FIFO_INIT_LEVEL(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_CLR_FIFO_INIT_LEVEL_SHIFT)) & EPDC_FIFOCTRL_CLR_FIFO_INIT_LEVEL_MASK)
#define EPDC_FIFOCTRL_CLR_ENABLE_PRIORITY_MASK   (0x80000000U)
#define EPDC_FIFOCTRL_CLR_ENABLE_PRIORITY_SHIFT  (31U)

/*! @name FIFOCTRL_TOG - EPDC FIFO control register */
#define EPDC_FIFOCTRL_TOG_FIFO_L_LEVEL_MASK      (0xFFU)
#define EPDC_FIFOCTRL_TOG_FIFO_L_LEVEL_SHIFT     (0U)
#define EPDC_FIFOCTRL_TOG_FIFO_L_LEVEL(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_TOG_FIFO_L_LEVEL_SHIFT)) & EPDC_FIFOCTRL_TOG_FIFO_L_LEVEL_MASK)
#define EPDC_FIFOCTRL_TOG_FIFO_H_LEVEL_MASK      (0xFF00U)
#define EPDC_FIFOCTRL_TOG_FIFO_H_LEVEL_SHIFT     (8U)
#define EPDC_FIFOCTRL_TOG_FIFO_H_LEVEL(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_TOG_FIFO_H_LEVEL_SHIFT)) & EPDC_FIFOCTRL_TOG_FIFO_H_LEVEL_MASK)
#define EPDC_FIFOCTRL_TOG_FIFO_INIT_LEVEL_MASK   (0xFF0000U)
#define EPDC_FIFOCTRL_TOG_FIFO_INIT_LEVEL_SHIFT  (16U)
#define EPDC_FIFOCTRL_TOG_FIFO_INIT_LEVEL(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_FIFOCTRL_TOG_FIFO_INIT_LEVEL_SHIFT)) & EPDC_FIFOCTRL_TOG_FIFO_INIT_LEVEL_MASK)
#define EPDC_FIFOCTRL_TOG_ENABLE_PRIORITY_MASK   (0x80000000U)
#define EPDC_FIFOCTRL_TOG_ENABLE_PRIORITY_SHIFT  (31U)

/*! @name UPD_ADDR - EPDC Update Region Address */
#define EPDC_UPD_ADDR_ADDR_MASK                  (0xFFFFFFFFU)
#define EPDC_UPD_ADDR_ADDR_SHIFT                 (0U)
#define EPDC_UPD_ADDR_ADDR(x)                    (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_ADDR_ADDR_SHIFT)) & EPDC_UPD_ADDR_ADDR_MASK)

/*! @name UPD_STRIDE - EPDC Update Region Stride */
#define EPDC_UPD_STRIDE_STRIDE_MASK              (0xFFFFFFFFU)
#define EPDC_UPD_STRIDE_STRIDE_SHIFT             (0U)
#define EPDC_UPD_STRIDE_STRIDE(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_STRIDE_STRIDE_SHIFT)) & EPDC_UPD_STRIDE_STRIDE_MASK)

/*! @name UPD_CORD - EPDC Update Command Co-ordinate */
#define EPDC_UPD_CORD_XCORD_MASK                 (0x1FFFU)
#define EPDC_UPD_CORD_XCORD_SHIFT                (0U)
#define EPDC_UPD_CORD_XCORD(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CORD_XCORD_SHIFT)) & EPDC_UPD_CORD_XCORD_MASK)
#define EPDC_UPD_CORD_YCORD_MASK                 (0x1FFF0000U)
#define EPDC_UPD_CORD_YCORD_SHIFT                (16U)
#define EPDC_UPD_CORD_YCORD(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CORD_YCORD_SHIFT)) & EPDC_UPD_CORD_YCORD_MASK)

/*! @name UPD_SIZE - EPDC Update Command Size */
#define EPDC_UPD_SIZE_WIDTH_MASK                 (0x1FFFU)
#define EPDC_UPD_SIZE_WIDTH_SHIFT                (0U)
#define EPDC_UPD_SIZE_WIDTH(x)                   (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_SIZE_WIDTH_SHIFT)) & EPDC_UPD_SIZE_WIDTH_MASK)
#define EPDC_UPD_SIZE_HEIGHT_MASK                (0x1FFF0000U)
#define EPDC_UPD_SIZE_HEIGHT_SHIFT               (16U)
#define EPDC_UPD_SIZE_HEIGHT(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_SIZE_HEIGHT_SHIFT)) & EPDC_UPD_SIZE_HEIGHT_MASK)

/*! @name UPD_CTRL - EPDC Update Command Control */
#define EPDC_UPD_CTRL_UPDATE_MODE_MASK           (0x1U)
#define EPDC_UPD_CTRL_UPDATE_MODE_SHIFT          (0U)
#define EPDC_UPD_CTRL_DRY_RUN_MASK               (0x2U)
#define EPDC_UPD_CTRL_DRY_RUN_SHIFT              (1U)
#define EPDC_UPD_CTRL_AUTOWV_MASK                (0x4U)
#define EPDC_UPD_CTRL_AUTOWV_SHIFT               (2U)
#define EPDC_UPD_CTRL_PAUSE_MASK                 (0x8U)
#define EPDC_UPD_CTRL_PAUSE_SHIFT                (3U)
#define EPDC_UPD_CTRL_NO_LUT_CANCEL_MASK         (0x10U)
#define EPDC_UPD_CTRL_NO_LUT_CANCEL_SHIFT        (4U)
#define EPDC_UPD_CTRL_STANDBY_MASK               (0x20U)
#define EPDC_UPD_CTRL_STANDBY_SHIFT              (5U)
#define EPDC_UPD_CTRL_WAVEFORM_MODE_MASK         (0xFF00U)
#define EPDC_UPD_CTRL_WAVEFORM_MODE_SHIFT        (8U)
#define EPDC_UPD_CTRL_WAVEFORM_MODE(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CTRL_WAVEFORM_MODE_SHIFT)) & EPDC_UPD_CTRL_WAVEFORM_MODE_MASK)
#define EPDC_UPD_CTRL_LUT_SEL_MASK               (0x3F0000U)
#define EPDC_UPD_CTRL_LUT_SEL_SHIFT              (16U)
#define EPDC_UPD_CTRL_LUT_SEL(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CTRL_LUT_SEL_SHIFT)) & EPDC_UPD_CTRL_LUT_SEL_MASK)
#define EPDC_UPD_CTRL_USE_FIXED_MASK             (0x80000000U)
#define EPDC_UPD_CTRL_USE_FIXED_SHIFT            (31U)

/*! @name UPD_CTRL_SET - EPDC Update Command Control */
#define EPDC_UPD_CTRL_SET_UPDATE_MODE_MASK       (0x1U)
#define EPDC_UPD_CTRL_SET_UPDATE_MODE_SHIFT      (0U)
#define EPDC_UPD_CTRL_SET_DRY_RUN_MASK           (0x2U)
#define EPDC_UPD_CTRL_SET_DRY_RUN_SHIFT          (1U)
#define EPDC_UPD_CTRL_SET_AUTOWV_MASK            (0x4U)
#define EPDC_UPD_CTRL_SET_AUTOWV_SHIFT           (2U)
#define EPDC_UPD_CTRL_SET_PAUSE_MASK             (0x8U)
#define EPDC_UPD_CTRL_SET_PAUSE_SHIFT            (3U)
#define EPDC_UPD_CTRL_SET_NO_LUT_CANCEL_MASK     (0x10U)
#define EPDC_UPD_CTRL_SET_NO_LUT_CANCEL_SHIFT    (4U)
#define EPDC_UPD_CTRL_SET_STANDBY_MASK           (0x20U)
#define EPDC_UPD_CTRL_SET_STANDBY_SHIFT          (5U)
#define EPDC_UPD_CTRL_SET_WAVEFORM_MODE_MASK     (0xFF00U)
#define EPDC_UPD_CTRL_SET_WAVEFORM_MODE_SHIFT    (8U)
#define EPDC_UPD_CTRL_SET_WAVEFORM_MODE(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CTRL_SET_WAVEFORM_MODE_SHIFT)) & EPDC_UPD_CTRL_SET_WAVEFORM_MODE_MASK)
#define EPDC_UPD_CTRL_SET_LUT_SEL_MASK           (0x3F0000U)
#define EPDC_UPD_CTRL_SET_LUT_SEL_SHIFT          (16U)
#define EPDC_UPD_CTRL_SET_LUT_SEL(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CTRL_SET_LUT_SEL_SHIFT)) & EPDC_UPD_CTRL_SET_LUT_SEL_MASK)
#define EPDC_UPD_CTRL_SET_USE_FIXED_MASK         (0x80000000U)
#define EPDC_UPD_CTRL_SET_USE_FIXED_SHIFT        (31U)

/*! @name UPD_CTRL_CLR - EPDC Update Command Control */
#define EPDC_UPD_CTRL_CLR_UPDATE_MODE_MASK       (0x1U)
#define EPDC_UPD_CTRL_CLR_UPDATE_MODE_SHIFT      (0U)
#define EPDC_UPD_CTRL_CLR_DRY_RUN_MASK           (0x2U)
#define EPDC_UPD_CTRL_CLR_DRY_RUN_SHIFT          (1U)
#define EPDC_UPD_CTRL_CLR_AUTOWV_MASK            (0x4U)
#define EPDC_UPD_CTRL_CLR_AUTOWV_SHIFT           (2U)
#define EPDC_UPD_CTRL_CLR_PAUSE_MASK             (0x8U)
#define EPDC_UPD_CTRL_CLR_PAUSE_SHIFT            (3U)
#define EPDC_UPD_CTRL_CLR_NO_LUT_CANCEL_MASK     (0x10U)
#define EPDC_UPD_CTRL_CLR_NO_LUT_CANCEL_SHIFT    (4U)
#define EPDC_UPD_CTRL_CLR_STANDBY_MASK           (0x20U)
#define EPDC_UPD_CTRL_CLR_STANDBY_SHIFT          (5U)
#define EPDC_UPD_CTRL_CLR_WAVEFORM_MODE_MASK     (0xFF00U)
#define EPDC_UPD_CTRL_CLR_WAVEFORM_MODE_SHIFT    (8U)
#define EPDC_UPD_CTRL_CLR_WAVEFORM_MODE(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CTRL_CLR_WAVEFORM_MODE_SHIFT)) & EPDC_UPD_CTRL_CLR_WAVEFORM_MODE_MASK)
#define EPDC_UPD_CTRL_CLR_LUT_SEL_MASK           (0x3F0000U)
#define EPDC_UPD_CTRL_CLR_LUT_SEL_SHIFT          (16U)
#define EPDC_UPD_CTRL_CLR_LUT_SEL(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CTRL_CLR_LUT_SEL_SHIFT)) & EPDC_UPD_CTRL_CLR_LUT_SEL_MASK)
#define EPDC_UPD_CTRL_CLR_USE_FIXED_MASK         (0x80000000U)
#define EPDC_UPD_CTRL_CLR_USE_FIXED_SHIFT        (31U)

/*! @name UPD_CTRL_TOG - EPDC Update Command Control */
#define EPDC_UPD_CTRL_TOG_UPDATE_MODE_MASK       (0x1U)
#define EPDC_UPD_CTRL_TOG_UPDATE_MODE_SHIFT      (0U)
#define EPDC_UPD_CTRL_TOG_DRY_RUN_MASK           (0x2U)
#define EPDC_UPD_CTRL_TOG_DRY_RUN_SHIFT          (1U)
#define EPDC_UPD_CTRL_TOG_AUTOWV_MASK            (0x4U)
#define EPDC_UPD_CTRL_TOG_AUTOWV_SHIFT           (2U)
#define EPDC_UPD_CTRL_TOG_PAUSE_MASK             (0x8U)
#define EPDC_UPD_CTRL_TOG_PAUSE_SHIFT            (3U)
#define EPDC_UPD_CTRL_TOG_NO_LUT_CANCEL_MASK     (0x10U)
#define EPDC_UPD_CTRL_TOG_NO_LUT_CANCEL_SHIFT    (4U)
#define EPDC_UPD_CTRL_TOG_STANDBY_MASK           (0x20U)
#define EPDC_UPD_CTRL_TOG_STANDBY_SHIFT          (5U)
#define EPDC_UPD_CTRL_TOG_WAVEFORM_MODE_MASK     (0xFF00U)
#define EPDC_UPD_CTRL_TOG_WAVEFORM_MODE_SHIFT    (8U)
#define EPDC_UPD_CTRL_TOG_WAVEFORM_MODE(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CTRL_TOG_WAVEFORM_MODE_SHIFT)) & EPDC_UPD_CTRL_TOG_WAVEFORM_MODE_MASK)
#define EPDC_UPD_CTRL_TOG_LUT_SEL_MASK           (0x3F0000U)
#define EPDC_UPD_CTRL_TOG_LUT_SEL_SHIFT          (16U)
#define EPDC_UPD_CTRL_TOG_LUT_SEL(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_CTRL_TOG_LUT_SEL_SHIFT)) & EPDC_UPD_CTRL_TOG_LUT_SEL_MASK)
#define EPDC_UPD_CTRL_TOG_USE_FIXED_MASK         (0x80000000U)
#define EPDC_UPD_CTRL_TOG_USE_FIXED_SHIFT        (31U)

/*! @name UPD_FIXED - EPDC Update Fixed Pixel Control */
#define EPDC_UPD_FIXED_FIXCP_MASK                (0xFFU)
#define EPDC_UPD_FIXED_FIXCP_SHIFT               (0U)
#define EPDC_UPD_FIXED_FIXCP(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_FIXED_FIXCP_SHIFT)) & EPDC_UPD_FIXED_FIXCP_MASK)
#define EPDC_UPD_FIXED_FIXNP_MASK                (0xFF00U)
#define EPDC_UPD_FIXED_FIXNP_SHIFT               (8U)
#define EPDC_UPD_FIXED_FIXNP(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_FIXED_FIXNP_SHIFT)) & EPDC_UPD_FIXED_FIXNP_MASK)
#define EPDC_UPD_FIXED_FIXCP_EN_MASK             (0x40000000U)
#define EPDC_UPD_FIXED_FIXCP_EN_SHIFT            (30U)
#define EPDC_UPD_FIXED_FIXNP_EN_MASK             (0x80000000U)
#define EPDC_UPD_FIXED_FIXNP_EN_SHIFT            (31U)

/*! @name UPD_FIXED_SET - EPDC Update Fixed Pixel Control */
#define EPDC_UPD_FIXED_SET_FIXCP_MASK            (0xFFU)
#define EPDC_UPD_FIXED_SET_FIXCP_SHIFT           (0U)
#define EPDC_UPD_FIXED_SET_FIXCP(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_FIXED_SET_FIXCP_SHIFT)) & EPDC_UPD_FIXED_SET_FIXCP_MASK)
#define EPDC_UPD_FIXED_SET_FIXNP_MASK            (0xFF00U)
#define EPDC_UPD_FIXED_SET_FIXNP_SHIFT           (8U)
#define EPDC_UPD_FIXED_SET_FIXNP(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_FIXED_SET_FIXNP_SHIFT)) & EPDC_UPD_FIXED_SET_FIXNP_MASK)
#define EPDC_UPD_FIXED_SET_FIXCP_EN_MASK         (0x40000000U)
#define EPDC_UPD_FIXED_SET_FIXCP_EN_SHIFT        (30U)
#define EPDC_UPD_FIXED_SET_FIXNP_EN_MASK         (0x80000000U)
#define EPDC_UPD_FIXED_SET_FIXNP_EN_SHIFT        (31U)

/*! @name UPD_FIXED_CLR - EPDC Update Fixed Pixel Control */
#define EPDC_UPD_FIXED_CLR_FIXCP_MASK            (0xFFU)
#define EPDC_UPD_FIXED_CLR_FIXCP_SHIFT           (0U)
#define EPDC_UPD_FIXED_CLR_FIXCP(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_FIXED_CLR_FIXCP_SHIFT)) & EPDC_UPD_FIXED_CLR_FIXCP_MASK)
#define EPDC_UPD_FIXED_CLR_FIXNP_MASK            (0xFF00U)
#define EPDC_UPD_FIXED_CLR_FIXNP_SHIFT           (8U)
#define EPDC_UPD_FIXED_CLR_FIXNP(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_FIXED_CLR_FIXNP_SHIFT)) & EPDC_UPD_FIXED_CLR_FIXNP_MASK)
#define EPDC_UPD_FIXED_CLR_FIXCP_EN_MASK         (0x40000000U)
#define EPDC_UPD_FIXED_CLR_FIXCP_EN_SHIFT        (30U)
#define EPDC_UPD_FIXED_CLR_FIXNP_EN_MASK         (0x80000000U)
#define EPDC_UPD_FIXED_CLR_FIXNP_EN_SHIFT        (31U)

/*! @name UPD_FIXED_TOG - EPDC Update Fixed Pixel Control */
#define EPDC_UPD_FIXED_TOG_FIXCP_MASK            (0xFFU)
#define EPDC_UPD_FIXED_TOG_FIXCP_SHIFT           (0U)
#define EPDC_UPD_FIXED_TOG_FIXCP(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_FIXED_TOG_FIXCP_SHIFT)) & EPDC_UPD_FIXED_TOG_FIXCP_MASK)
#define EPDC_UPD_FIXED_TOG_FIXNP_MASK            (0xFF00U)
#define EPDC_UPD_FIXED_TOG_FIXNP_SHIFT           (8U)
#define EPDC_UPD_FIXED_TOG_FIXNP(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_FIXED_TOG_FIXNP_SHIFT)) & EPDC_UPD_FIXED_TOG_FIXNP_MASK)
#define EPDC_UPD_FIXED_TOG_FIXCP_EN_MASK         (0x40000000U)
#define EPDC_UPD_FIXED_TOG_FIXCP_EN_SHIFT        (30U)
#define EPDC_UPD_FIXED_TOG_FIXNP_EN_MASK         (0x80000000U)
#define EPDC_UPD_FIXED_TOG_FIXNP_EN_SHIFT        (31U)

/*! @name TEMP - EPDC Temperature Register */
#define EPDC_TEMP_TEMPERATURE_MASK               (0xFFFFFFFFU)
#define EPDC_TEMP_TEMPERATURE_SHIFT              (0U)
#define EPDC_TEMP_TEMPERATURE(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_TEMP_TEMPERATURE_SHIFT)) & EPDC_TEMP_TEMPERATURE_MASK)

/*! @name AUTOWV_LUT - Waveform Mode Lookup Table Control Register. */
#define EPDC_AUTOWV_LUT_ADDR_MASK                (0x7U)
#define EPDC_AUTOWV_LUT_ADDR_SHIFT               (0U)
#define EPDC_AUTOWV_LUT_ADDR(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_AUTOWV_LUT_ADDR_SHIFT)) & EPDC_AUTOWV_LUT_ADDR_MASK)
#define EPDC_AUTOWV_LUT_DATA_MASK                (0xFF0000U)
#define EPDC_AUTOWV_LUT_DATA_SHIFT               (16U)
#define EPDC_AUTOWV_LUT_DATA(x)                  (((uint32_t)(((uint32_t)(x)) << EPDC_AUTOWV_LUT_DATA_SHIFT)) & EPDC_AUTOWV_LUT_DATA_MASK)

/*! @name LUT_STANDBY1 - EPDC LUT Standby Register for LUT 31~0 */
#define EPDC_LUT_STANDBY1_LUTN_MASK              (0xFFFFFFFFU)
#define EPDC_LUT_STANDBY1_LUTN_SHIFT             (0U)
#define EPDC_LUT_STANDBY1_LUTN(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_LUT_STANDBY1_LUTN_SHIFT)) & EPDC_LUT_STANDBY1_LUTN_MASK)

/*! @name LUT_STANDBY1_SET - EPDC LUT Standby Register for LUT 31~0 */
#define EPDC_LUT_STANDBY1_SET_LUTN_MASK          (0xFFFFFFFFU)
#define EPDC_LUT_STANDBY1_SET_LUTN_SHIFT         (0U)
#define EPDC_LUT_STANDBY1_SET_LUTN(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_LUT_STANDBY1_SET_LUTN_SHIFT)) & EPDC_LUT_STANDBY1_SET_LUTN_MASK)

/*! @name LUT_STANDBY1_CLR - EPDC LUT Standby Register for LUT 31~0 */
#define EPDC_LUT_STANDBY1_CLR_LUTN_MASK          (0xFFFFFFFFU)
#define EPDC_LUT_STANDBY1_CLR_LUTN_SHIFT         (0U)
#define EPDC_LUT_STANDBY1_CLR_LUTN(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_LUT_STANDBY1_CLR_LUTN_SHIFT)) & EPDC_LUT_STANDBY1_CLR_LUTN_MASK)

/*! @name LUT_STANDBY1_TOG - EPDC LUT Standby Register for LUT 31~0 */
#define EPDC_LUT_STANDBY1_TOG_LUTN_MASK          (0xFFFFFFFFU)
#define EPDC_LUT_STANDBY1_TOG_LUTN_SHIFT         (0U)
#define EPDC_LUT_STANDBY1_TOG_LUTN(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_LUT_STANDBY1_TOG_LUTN_SHIFT)) & EPDC_LUT_STANDBY1_TOG_LUTN_MASK)

/*! @name LUT_STANDBY2 - EPDC LUT Standby Registerr for LUT 63~32 */
#define EPDC_LUT_STANDBY2_LUTN_MASK              (0xFFFFFFFFU)
#define EPDC_LUT_STANDBY2_LUTN_SHIFT             (0U)
#define EPDC_LUT_STANDBY2_LUTN(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_LUT_STANDBY2_LUTN_SHIFT)) & EPDC_LUT_STANDBY2_LUTN_MASK)

/*! @name LUT_STANDBY2_SET - EPDC LUT Standby Registerr for LUT 63~32 */
#define EPDC_LUT_STANDBY2_SET_LUTN_MASK          (0xFFFFFFFFU)
#define EPDC_LUT_STANDBY2_SET_LUTN_SHIFT         (0U)
#define EPDC_LUT_STANDBY2_SET_LUTN(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_LUT_STANDBY2_SET_LUTN_SHIFT)) & EPDC_LUT_STANDBY2_SET_LUTN_MASK)

/*! @name LUT_STANDBY2_CLR - EPDC LUT Standby Registerr for LUT 63~32 */
#define EPDC_LUT_STANDBY2_CLR_LUTN_MASK          (0xFFFFFFFFU)
#define EPDC_LUT_STANDBY2_CLR_LUTN_SHIFT         (0U)
#define EPDC_LUT_STANDBY2_CLR_LUTN(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_LUT_STANDBY2_CLR_LUTN_SHIFT)) & EPDC_LUT_STANDBY2_CLR_LUTN_MASK)

/*! @name LUT_STANDBY2_TOG - EPDC LUT Standby Registerr for LUT 63~32 */
#define EPDC_LUT_STANDBY2_TOG_LUTN_MASK          (0xFFFFFFFFU)
#define EPDC_LUT_STANDBY2_TOG_LUTN_SHIFT         (0U)
#define EPDC_LUT_STANDBY2_TOG_LUTN(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_LUT_STANDBY2_TOG_LUTN_SHIFT)) & EPDC_LUT_STANDBY2_TOG_LUTN_MASK)

/*! @name TCE_CTRL - EPDC Timing Control Engine Control Register */
#define EPDC_TCE_CTRL_PIXELS_PER_SDCLK_MASK      (0x3U)
#define EPDC_TCE_CTRL_PIXELS_PER_SDCLK_SHIFT     (0U)
#define EPDC_TCE_CTRL_PIXELS_PER_SDCLK(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_PIXELS_PER_SDCLK_SHIFT)) & EPDC_TCE_CTRL_PIXELS_PER_SDCLK_MASK)
#define EPDC_TCE_CTRL_SDDO_WIDTH_MASK            (0x4U)
#define EPDC_TCE_CTRL_SDDO_WIDTH_SHIFT           (2U)
#define EPDC_TCE_CTRL_DUAL_SCAN_MASK             (0x8U)
#define EPDC_TCE_CTRL_DUAL_SCAN_SHIFT            (3U)
#define EPDC_TCE_CTRL_SCAN_DIR_0_MASK            (0x10U)
#define EPDC_TCE_CTRL_SCAN_DIR_0_SHIFT           (4U)
#define EPDC_TCE_CTRL_SCAN_DIR_1_MASK            (0x20U)
#define EPDC_TCE_CTRL_SCAN_DIR_1_SHIFT           (5U)
#define EPDC_TCE_CTRL_LVDS_MODE_MASK             (0x40U)
#define EPDC_TCE_CTRL_LVDS_MODE_SHIFT            (6U)
#define EPDC_TCE_CTRL_LVDS_MODE_CE_MASK          (0x80U)
#define EPDC_TCE_CTRL_LVDS_MODE_CE_SHIFT         (7U)
#define EPDC_TCE_CTRL_DDR_MODE_MASK              (0x100U)
#define EPDC_TCE_CTRL_DDR_MODE_SHIFT             (8U)
#define EPDC_TCE_CTRL_VCOM_MODE_MASK             (0x200U)
#define EPDC_TCE_CTRL_VCOM_MODE_SHIFT            (9U)
#define EPDC_TCE_CTRL_VCOM_VAL_MASK              (0xC00U)
#define EPDC_TCE_CTRL_VCOM_VAL_SHIFT             (10U)
#define EPDC_TCE_CTRL_VCOM_VAL(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_VCOM_VAL_SHIFT)) & EPDC_TCE_CTRL_VCOM_VAL_MASK)
#define EPDC_TCE_CTRL_VSCAN_HOLDOFF_MASK         (0x1FF0000U)
#define EPDC_TCE_CTRL_VSCAN_HOLDOFF_SHIFT        (16U)
#define EPDC_TCE_CTRL_VSCAN_HOLDOFF(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_VSCAN_HOLDOFF_SHIFT)) & EPDC_TCE_CTRL_VSCAN_HOLDOFF_MASK)

/*! @name TCE_CTRL_SET - EPDC Timing Control Engine Control Register */
#define EPDC_TCE_CTRL_SET_PIXELS_PER_SDCLK_MASK  (0x3U)
#define EPDC_TCE_CTRL_SET_PIXELS_PER_SDCLK_SHIFT (0U)
#define EPDC_TCE_CTRL_SET_PIXELS_PER_SDCLK(x)    (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_SET_PIXELS_PER_SDCLK_SHIFT)) & EPDC_TCE_CTRL_SET_PIXELS_PER_SDCLK_MASK)
#define EPDC_TCE_CTRL_SET_SDDO_WIDTH_MASK        (0x4U)
#define EPDC_TCE_CTRL_SET_SDDO_WIDTH_SHIFT       (2U)
#define EPDC_TCE_CTRL_SET_DUAL_SCAN_MASK         (0x8U)
#define EPDC_TCE_CTRL_SET_DUAL_SCAN_SHIFT        (3U)
#define EPDC_TCE_CTRL_SET_SCAN_DIR_0_MASK        (0x10U)
#define EPDC_TCE_CTRL_SET_SCAN_DIR_0_SHIFT       (4U)
#define EPDC_TCE_CTRL_SET_SCAN_DIR_1_MASK        (0x20U)
#define EPDC_TCE_CTRL_SET_SCAN_DIR_1_SHIFT       (5U)
#define EPDC_TCE_CTRL_SET_LVDS_MODE_MASK         (0x40U)
#define EPDC_TCE_CTRL_SET_LVDS_MODE_SHIFT        (6U)
#define EPDC_TCE_CTRL_SET_LVDS_MODE_CE_MASK      (0x80U)
#define EPDC_TCE_CTRL_SET_LVDS_MODE_CE_SHIFT     (7U)
#define EPDC_TCE_CTRL_SET_DDR_MODE_MASK          (0x100U)
#define EPDC_TCE_CTRL_SET_DDR_MODE_SHIFT         (8U)
#define EPDC_TCE_CTRL_SET_VCOM_MODE_MASK         (0x200U)
#define EPDC_TCE_CTRL_SET_VCOM_MODE_SHIFT        (9U)
#define EPDC_TCE_CTRL_SET_VCOM_VAL_MASK          (0xC00U)
#define EPDC_TCE_CTRL_SET_VCOM_VAL_SHIFT         (10U)
#define EPDC_TCE_CTRL_SET_VCOM_VAL(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_SET_VCOM_VAL_SHIFT)) & EPDC_TCE_CTRL_SET_VCOM_VAL_MASK)
#define EPDC_TCE_CTRL_SET_VSCAN_HOLDOFF_MASK     (0x1FF0000U)
#define EPDC_TCE_CTRL_SET_VSCAN_HOLDOFF_SHIFT    (16U)
#define EPDC_TCE_CTRL_SET_VSCAN_HOLDOFF(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_SET_VSCAN_HOLDOFF_SHIFT)) & EPDC_TCE_CTRL_SET_VSCAN_HOLDOFF_MASK)

/*! @name TCE_CTRL_CLR - EPDC Timing Control Engine Control Register */
#define EPDC_TCE_CTRL_CLR_PIXELS_PER_SDCLK_MASK  (0x3U)
#define EPDC_TCE_CTRL_CLR_PIXELS_PER_SDCLK_SHIFT (0U)
#define EPDC_TCE_CTRL_CLR_PIXELS_PER_SDCLK(x)    (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_CLR_PIXELS_PER_SDCLK_SHIFT)) & EPDC_TCE_CTRL_CLR_PIXELS_PER_SDCLK_MASK)
#define EPDC_TCE_CTRL_CLR_SDDO_WIDTH_MASK        (0x4U)
#define EPDC_TCE_CTRL_CLR_SDDO_WIDTH_SHIFT       (2U)
#define EPDC_TCE_CTRL_CLR_DUAL_SCAN_MASK         (0x8U)
#define EPDC_TCE_CTRL_CLR_DUAL_SCAN_SHIFT        (3U)
#define EPDC_TCE_CTRL_CLR_SCAN_DIR_0_MASK        (0x10U)
#define EPDC_TCE_CTRL_CLR_SCAN_DIR_0_SHIFT       (4U)
#define EPDC_TCE_CTRL_CLR_SCAN_DIR_1_MASK        (0x20U)
#define EPDC_TCE_CTRL_CLR_SCAN_DIR_1_SHIFT       (5U)
#define EPDC_TCE_CTRL_CLR_LVDS_MODE_MASK         (0x40U)
#define EPDC_TCE_CTRL_CLR_LVDS_MODE_SHIFT        (6U)
#define EPDC_TCE_CTRL_CLR_LVDS_MODE_CE_MASK      (0x80U)
#define EPDC_TCE_CTRL_CLR_LVDS_MODE_CE_SHIFT     (7U)
#define EPDC_TCE_CTRL_CLR_DDR_MODE_MASK          (0x100U)
#define EPDC_TCE_CTRL_CLR_DDR_MODE_SHIFT         (8U)
#define EPDC_TCE_CTRL_CLR_VCOM_MODE_MASK         (0x200U)
#define EPDC_TCE_CTRL_CLR_VCOM_MODE_SHIFT        (9U)
#define EPDC_TCE_CTRL_CLR_VCOM_VAL_MASK          (0xC00U)
#define EPDC_TCE_CTRL_CLR_VCOM_VAL_SHIFT         (10U)
#define EPDC_TCE_CTRL_CLR_VCOM_VAL(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_CLR_VCOM_VAL_SHIFT)) & EPDC_TCE_CTRL_CLR_VCOM_VAL_MASK)
#define EPDC_TCE_CTRL_CLR_VSCAN_HOLDOFF_MASK     (0x1FF0000U)
#define EPDC_TCE_CTRL_CLR_VSCAN_HOLDOFF_SHIFT    (16U)
#define EPDC_TCE_CTRL_CLR_VSCAN_HOLDOFF(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_CLR_VSCAN_HOLDOFF_SHIFT)) & EPDC_TCE_CTRL_CLR_VSCAN_HOLDOFF_MASK)

/*! @name TCE_CTRL_TOG - EPDC Timing Control Engine Control Register */
#define EPDC_TCE_CTRL_TOG_PIXELS_PER_SDCLK_MASK  (0x3U)
#define EPDC_TCE_CTRL_TOG_PIXELS_PER_SDCLK_SHIFT (0U)
#define EPDC_TCE_CTRL_TOG_PIXELS_PER_SDCLK(x)    (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_TOG_PIXELS_PER_SDCLK_SHIFT)) & EPDC_TCE_CTRL_TOG_PIXELS_PER_SDCLK_MASK)
#define EPDC_TCE_CTRL_TOG_SDDO_WIDTH_MASK        (0x4U)
#define EPDC_TCE_CTRL_TOG_SDDO_WIDTH_SHIFT       (2U)
#define EPDC_TCE_CTRL_TOG_DUAL_SCAN_MASK         (0x8U)
#define EPDC_TCE_CTRL_TOG_DUAL_SCAN_SHIFT        (3U)
#define EPDC_TCE_CTRL_TOG_SCAN_DIR_0_MASK        (0x10U)
#define EPDC_TCE_CTRL_TOG_SCAN_DIR_0_SHIFT       (4U)
#define EPDC_TCE_CTRL_TOG_SCAN_DIR_1_MASK        (0x20U)
#define EPDC_TCE_CTRL_TOG_SCAN_DIR_1_SHIFT       (5U)
#define EPDC_TCE_CTRL_TOG_LVDS_MODE_MASK         (0x40U)
#define EPDC_TCE_CTRL_TOG_LVDS_MODE_SHIFT        (6U)
#define EPDC_TCE_CTRL_TOG_LVDS_MODE_CE_MASK      (0x80U)
#define EPDC_TCE_CTRL_TOG_LVDS_MODE_CE_SHIFT     (7U)
#define EPDC_TCE_CTRL_TOG_DDR_MODE_MASK          (0x100U)
#define EPDC_TCE_CTRL_TOG_DDR_MODE_SHIFT         (8U)
#define EPDC_TCE_CTRL_TOG_VCOM_MODE_MASK         (0x200U)
#define EPDC_TCE_CTRL_TOG_VCOM_MODE_SHIFT        (9U)
#define EPDC_TCE_CTRL_TOG_VCOM_VAL_MASK          (0xC00U)
#define EPDC_TCE_CTRL_TOG_VCOM_VAL_SHIFT         (10U)
#define EPDC_TCE_CTRL_TOG_VCOM_VAL(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_TOG_VCOM_VAL_SHIFT)) & EPDC_TCE_CTRL_TOG_VCOM_VAL_MASK)
#define EPDC_TCE_CTRL_TOG_VSCAN_HOLDOFF_MASK     (0x1FF0000U)
#define EPDC_TCE_CTRL_TOG_VSCAN_HOLDOFF_SHIFT    (16U)
#define EPDC_TCE_CTRL_TOG_VSCAN_HOLDOFF(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_CTRL_TOG_VSCAN_HOLDOFF_SHIFT)) & EPDC_TCE_CTRL_TOG_VSCAN_HOLDOFF_MASK)

/*! @name TCE_SDCFG - EPDC Timing Control Engine Source-Driver Config Register */
#define EPDC_TCE_SDCFG_PIXELS_PER_CE_MASK        (0x1FFFU)
#define EPDC_TCE_SDCFG_PIXELS_PER_CE_SHIFT       (0U)
#define EPDC_TCE_SDCFG_PIXELS_PER_CE(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_PIXELS_PER_CE_SHIFT)) & EPDC_TCE_SDCFG_PIXELS_PER_CE_MASK)
#define EPDC_TCE_SDCFG_SDDO_INVERT_MASK          (0x2000U)
#define EPDC_TCE_SDCFG_SDDO_INVERT_SHIFT         (13U)
#define EPDC_TCE_SDCFG_SDDO_REFORMAT_MASK        (0xC000U)
#define EPDC_TCE_SDCFG_SDDO_REFORMAT_SHIFT       (14U)
#define EPDC_TCE_SDCFG_SDDO_REFORMAT(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_SDDO_REFORMAT_SHIFT)) & EPDC_TCE_SDCFG_SDDO_REFORMAT_MASK)
#define EPDC_TCE_SDCFG_NUM_CE_MASK               (0xF0000U)
#define EPDC_TCE_SDCFG_NUM_CE_SHIFT              (16U)
#define EPDC_TCE_SDCFG_NUM_CE(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_NUM_CE_SHIFT)) & EPDC_TCE_SDCFG_NUM_CE_MASK)
#define EPDC_TCE_SDCFG_SDSHR_MASK                (0x100000U)
#define EPDC_TCE_SDCFG_SDSHR_SHIFT               (20U)
#define EPDC_TCE_SDCFG_SDCLK_HOLD_MASK           (0x200000U)
#define EPDC_TCE_SDCFG_SDCLK_HOLD_SHIFT          (21U)

/*! @name TCE_SDCFG_SET - EPDC Timing Control Engine Source-Driver Config Register */
#define EPDC_TCE_SDCFG_SET_PIXELS_PER_CE_MASK    (0x1FFFU)
#define EPDC_TCE_SDCFG_SET_PIXELS_PER_CE_SHIFT   (0U)
#define EPDC_TCE_SDCFG_SET_PIXELS_PER_CE(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_SET_PIXELS_PER_CE_SHIFT)) & EPDC_TCE_SDCFG_SET_PIXELS_PER_CE_MASK)
#define EPDC_TCE_SDCFG_SET_SDDO_INVERT_MASK      (0x2000U)
#define EPDC_TCE_SDCFG_SET_SDDO_INVERT_SHIFT     (13U)
#define EPDC_TCE_SDCFG_SET_SDDO_REFORMAT_MASK    (0xC000U)
#define EPDC_TCE_SDCFG_SET_SDDO_REFORMAT_SHIFT   (14U)
#define EPDC_TCE_SDCFG_SET_SDDO_REFORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_SET_SDDO_REFORMAT_SHIFT)) & EPDC_TCE_SDCFG_SET_SDDO_REFORMAT_MASK)
#define EPDC_TCE_SDCFG_SET_NUM_CE_MASK           (0xF0000U)
#define EPDC_TCE_SDCFG_SET_NUM_CE_SHIFT          (16U)
#define EPDC_TCE_SDCFG_SET_NUM_CE(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_SET_NUM_CE_SHIFT)) & EPDC_TCE_SDCFG_SET_NUM_CE_MASK)
#define EPDC_TCE_SDCFG_SET_SDSHR_MASK            (0x100000U)
#define EPDC_TCE_SDCFG_SET_SDSHR_SHIFT           (20U)
#define EPDC_TCE_SDCFG_SET_SDCLK_HOLD_MASK       (0x200000U)
#define EPDC_TCE_SDCFG_SET_SDCLK_HOLD_SHIFT      (21U)

/*! @name TCE_SDCFG_CLR - EPDC Timing Control Engine Source-Driver Config Register */
#define EPDC_TCE_SDCFG_CLR_PIXELS_PER_CE_MASK    (0x1FFFU)
#define EPDC_TCE_SDCFG_CLR_PIXELS_PER_CE_SHIFT   (0U)
#define EPDC_TCE_SDCFG_CLR_PIXELS_PER_CE(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_CLR_PIXELS_PER_CE_SHIFT)) & EPDC_TCE_SDCFG_CLR_PIXELS_PER_CE_MASK)
#define EPDC_TCE_SDCFG_CLR_SDDO_INVERT_MASK      (0x2000U)
#define EPDC_TCE_SDCFG_CLR_SDDO_INVERT_SHIFT     (13U)
#define EPDC_TCE_SDCFG_CLR_SDDO_REFORMAT_MASK    (0xC000U)
#define EPDC_TCE_SDCFG_CLR_SDDO_REFORMAT_SHIFT   (14U)
#define EPDC_TCE_SDCFG_CLR_SDDO_REFORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_CLR_SDDO_REFORMAT_SHIFT)) & EPDC_TCE_SDCFG_CLR_SDDO_REFORMAT_MASK)
#define EPDC_TCE_SDCFG_CLR_NUM_CE_MASK           (0xF0000U)
#define EPDC_TCE_SDCFG_CLR_NUM_CE_SHIFT          (16U)
#define EPDC_TCE_SDCFG_CLR_NUM_CE(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_CLR_NUM_CE_SHIFT)) & EPDC_TCE_SDCFG_CLR_NUM_CE_MASK)
#define EPDC_TCE_SDCFG_CLR_SDSHR_MASK            (0x100000U)
#define EPDC_TCE_SDCFG_CLR_SDSHR_SHIFT           (20U)
#define EPDC_TCE_SDCFG_CLR_SDCLK_HOLD_MASK       (0x200000U)
#define EPDC_TCE_SDCFG_CLR_SDCLK_HOLD_SHIFT      (21U)

/*! @name TCE_SDCFG_TOG - EPDC Timing Control Engine Source-Driver Config Register */
#define EPDC_TCE_SDCFG_TOG_PIXELS_PER_CE_MASK    (0x1FFFU)
#define EPDC_TCE_SDCFG_TOG_PIXELS_PER_CE_SHIFT   (0U)
#define EPDC_TCE_SDCFG_TOG_PIXELS_PER_CE(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_TOG_PIXELS_PER_CE_SHIFT)) & EPDC_TCE_SDCFG_TOG_PIXELS_PER_CE_MASK)
#define EPDC_TCE_SDCFG_TOG_SDDO_INVERT_MASK      (0x2000U)
#define EPDC_TCE_SDCFG_TOG_SDDO_INVERT_SHIFT     (13U)
#define EPDC_TCE_SDCFG_TOG_SDDO_REFORMAT_MASK    (0xC000U)
#define EPDC_TCE_SDCFG_TOG_SDDO_REFORMAT_SHIFT   (14U)
#define EPDC_TCE_SDCFG_TOG_SDDO_REFORMAT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_TOG_SDDO_REFORMAT_SHIFT)) & EPDC_TCE_SDCFG_TOG_SDDO_REFORMAT_MASK)
#define EPDC_TCE_SDCFG_TOG_NUM_CE_MASK           (0xF0000U)
#define EPDC_TCE_SDCFG_TOG_NUM_CE_SHIFT          (16U)
#define EPDC_TCE_SDCFG_TOG_NUM_CE(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_SDCFG_TOG_NUM_CE_SHIFT)) & EPDC_TCE_SDCFG_TOG_NUM_CE_MASK)
#define EPDC_TCE_SDCFG_TOG_SDSHR_MASK            (0x100000U)
#define EPDC_TCE_SDCFG_TOG_SDSHR_SHIFT           (20U)
#define EPDC_TCE_SDCFG_TOG_SDCLK_HOLD_MASK       (0x200000U)
#define EPDC_TCE_SDCFG_TOG_SDCLK_HOLD_SHIFT      (21U)

/*! @name TCE_GDCFG - EPDC Timing Control Engine Gate-Driver Config Register */
#define EPDC_TCE_GDCFG_GDSP_MODE_MASK            (0x1U)
#define EPDC_TCE_GDCFG_GDSP_MODE_SHIFT           (0U)
#define EPDC_TCE_GDCFG_GDOE_MODE_MASK            (0x2U)
#define EPDC_TCE_GDCFG_GDOE_MODE_SHIFT           (1U)
#define EPDC_TCE_GDCFG_GDRL_MASK                 (0x10U)
#define EPDC_TCE_GDCFG_GDRL_SHIFT                (4U)
#define EPDC_TCE_GDCFG_PERIOD_VSCAN_MASK         (0xFFFF0000U)
#define EPDC_TCE_GDCFG_PERIOD_VSCAN_SHIFT        (16U)
#define EPDC_TCE_GDCFG_PERIOD_VSCAN(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_GDCFG_PERIOD_VSCAN_SHIFT)) & EPDC_TCE_GDCFG_PERIOD_VSCAN_MASK)

/*! @name TCE_GDCFG_SET - EPDC Timing Control Engine Gate-Driver Config Register */
#define EPDC_TCE_GDCFG_SET_GDSP_MODE_MASK        (0x1U)
#define EPDC_TCE_GDCFG_SET_GDSP_MODE_SHIFT       (0U)
#define EPDC_TCE_GDCFG_SET_GDOE_MODE_MASK        (0x2U)
#define EPDC_TCE_GDCFG_SET_GDOE_MODE_SHIFT       (1U)
#define EPDC_TCE_GDCFG_SET_GDRL_MASK             (0x10U)
#define EPDC_TCE_GDCFG_SET_GDRL_SHIFT            (4U)
#define EPDC_TCE_GDCFG_SET_PERIOD_VSCAN_MASK     (0xFFFF0000U)
#define EPDC_TCE_GDCFG_SET_PERIOD_VSCAN_SHIFT    (16U)
#define EPDC_TCE_GDCFG_SET_PERIOD_VSCAN(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_GDCFG_SET_PERIOD_VSCAN_SHIFT)) & EPDC_TCE_GDCFG_SET_PERIOD_VSCAN_MASK)

/*! @name TCE_GDCFG_CLR - EPDC Timing Control Engine Gate-Driver Config Register */
#define EPDC_TCE_GDCFG_CLR_GDSP_MODE_MASK        (0x1U)
#define EPDC_TCE_GDCFG_CLR_GDSP_MODE_SHIFT       (0U)
#define EPDC_TCE_GDCFG_CLR_GDOE_MODE_MASK        (0x2U)
#define EPDC_TCE_GDCFG_CLR_GDOE_MODE_SHIFT       (1U)
#define EPDC_TCE_GDCFG_CLR_GDRL_MASK             (0x10U)
#define EPDC_TCE_GDCFG_CLR_GDRL_SHIFT            (4U)
#define EPDC_TCE_GDCFG_CLR_PERIOD_VSCAN_MASK     (0xFFFF0000U)
#define EPDC_TCE_GDCFG_CLR_PERIOD_VSCAN_SHIFT    (16U)
#define EPDC_TCE_GDCFG_CLR_PERIOD_VSCAN(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_GDCFG_CLR_PERIOD_VSCAN_SHIFT)) & EPDC_TCE_GDCFG_CLR_PERIOD_VSCAN_MASK)

/*! @name TCE_GDCFG_TOG - EPDC Timing Control Engine Gate-Driver Config Register */
#define EPDC_TCE_GDCFG_TOG_GDSP_MODE_MASK        (0x1U)
#define EPDC_TCE_GDCFG_TOG_GDSP_MODE_SHIFT       (0U)
#define EPDC_TCE_GDCFG_TOG_GDOE_MODE_MASK        (0x2U)
#define EPDC_TCE_GDCFG_TOG_GDOE_MODE_SHIFT       (1U)
#define EPDC_TCE_GDCFG_TOG_GDRL_MASK             (0x10U)
#define EPDC_TCE_GDCFG_TOG_GDRL_SHIFT            (4U)
#define EPDC_TCE_GDCFG_TOG_PERIOD_VSCAN_MASK     (0xFFFF0000U)
#define EPDC_TCE_GDCFG_TOG_PERIOD_VSCAN_SHIFT    (16U)
#define EPDC_TCE_GDCFG_TOG_PERIOD_VSCAN(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_GDCFG_TOG_PERIOD_VSCAN_SHIFT)) & EPDC_TCE_GDCFG_TOG_PERIOD_VSCAN_MASK)

/*! @name TCE_HSCAN1 - EPDC Timing Control Engine Horizontal Timing Register 1 */
#define EPDC_TCE_HSCAN1_LINE_SYNC_MASK           (0xFFFU)
#define EPDC_TCE_HSCAN1_LINE_SYNC_SHIFT          (0U)
#define EPDC_TCE_HSCAN1_LINE_SYNC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN1_LINE_SYNC_SHIFT)) & EPDC_TCE_HSCAN1_LINE_SYNC_MASK)
#define EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH_MASK     (0xFFF0000U)
#define EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH_SHIFT    (16U)
#define EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH_SHIFT)) & EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH_MASK)

/*! @name TCE_HSCAN1_SET - EPDC Timing Control Engine Horizontal Timing Register 1 */
#define EPDC_TCE_HSCAN1_SET_LINE_SYNC_MASK       (0xFFFU)
#define EPDC_TCE_HSCAN1_SET_LINE_SYNC_SHIFT      (0U)
#define EPDC_TCE_HSCAN1_SET_LINE_SYNC(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN1_SET_LINE_SYNC_SHIFT)) & EPDC_TCE_HSCAN1_SET_LINE_SYNC_MASK)
#define EPDC_TCE_HSCAN1_SET_LINE_SYNC_WIDTH_MASK (0xFFF0000U)
#define EPDC_TCE_HSCAN1_SET_LINE_SYNC_WIDTH_SHIFT (16U)
#define EPDC_TCE_HSCAN1_SET_LINE_SYNC_WIDTH(x)   (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN1_SET_LINE_SYNC_WIDTH_SHIFT)) & EPDC_TCE_HSCAN1_SET_LINE_SYNC_WIDTH_MASK)

/*! @name TCE_HSCAN1_CLR - EPDC Timing Control Engine Horizontal Timing Register 1 */
#define EPDC_TCE_HSCAN1_CLR_LINE_SYNC_MASK       (0xFFFU)
#define EPDC_TCE_HSCAN1_CLR_LINE_SYNC_SHIFT      (0U)
#define EPDC_TCE_HSCAN1_CLR_LINE_SYNC(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN1_CLR_LINE_SYNC_SHIFT)) & EPDC_TCE_HSCAN1_CLR_LINE_SYNC_MASK)
#define EPDC_TCE_HSCAN1_CLR_LINE_SYNC_WIDTH_MASK (0xFFF0000U)
#define EPDC_TCE_HSCAN1_CLR_LINE_SYNC_WIDTH_SHIFT (16U)
#define EPDC_TCE_HSCAN1_CLR_LINE_SYNC_WIDTH(x)   (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN1_CLR_LINE_SYNC_WIDTH_SHIFT)) & EPDC_TCE_HSCAN1_CLR_LINE_SYNC_WIDTH_MASK)

/*! @name TCE_HSCAN1_TOG - EPDC Timing Control Engine Horizontal Timing Register 1 */
#define EPDC_TCE_HSCAN1_TOG_LINE_SYNC_MASK       (0xFFFU)
#define EPDC_TCE_HSCAN1_TOG_LINE_SYNC_SHIFT      (0U)
#define EPDC_TCE_HSCAN1_TOG_LINE_SYNC(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN1_TOG_LINE_SYNC_SHIFT)) & EPDC_TCE_HSCAN1_TOG_LINE_SYNC_MASK)
#define EPDC_TCE_HSCAN1_TOG_LINE_SYNC_WIDTH_MASK (0xFFF0000U)
#define EPDC_TCE_HSCAN1_TOG_LINE_SYNC_WIDTH_SHIFT (16U)
#define EPDC_TCE_HSCAN1_TOG_LINE_SYNC_WIDTH(x)   (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN1_TOG_LINE_SYNC_WIDTH_SHIFT)) & EPDC_TCE_HSCAN1_TOG_LINE_SYNC_WIDTH_MASK)

/*! @name TCE_HSCAN2 - EPDC Timing Control Engine Horizontal Timing Register 2 */
#define EPDC_TCE_HSCAN2_LINE_BEGIN_MASK          (0xFFFU)
#define EPDC_TCE_HSCAN2_LINE_BEGIN_SHIFT         (0U)
#define EPDC_TCE_HSCAN2_LINE_BEGIN(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN2_LINE_BEGIN_SHIFT)) & EPDC_TCE_HSCAN2_LINE_BEGIN_MASK)
#define EPDC_TCE_HSCAN2_LINE_END_MASK            (0xFFF0000U)
#define EPDC_TCE_HSCAN2_LINE_END_SHIFT           (16U)
#define EPDC_TCE_HSCAN2_LINE_END(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN2_LINE_END_SHIFT)) & EPDC_TCE_HSCAN2_LINE_END_MASK)

/*! @name TCE_HSCAN2_SET - EPDC Timing Control Engine Horizontal Timing Register 2 */
#define EPDC_TCE_HSCAN2_SET_LINE_BEGIN_MASK      (0xFFFU)
#define EPDC_TCE_HSCAN2_SET_LINE_BEGIN_SHIFT     (0U)
#define EPDC_TCE_HSCAN2_SET_LINE_BEGIN(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN2_SET_LINE_BEGIN_SHIFT)) & EPDC_TCE_HSCAN2_SET_LINE_BEGIN_MASK)
#define EPDC_TCE_HSCAN2_SET_LINE_END_MASK        (0xFFF0000U)
#define EPDC_TCE_HSCAN2_SET_LINE_END_SHIFT       (16U)
#define EPDC_TCE_HSCAN2_SET_LINE_END(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN2_SET_LINE_END_SHIFT)) & EPDC_TCE_HSCAN2_SET_LINE_END_MASK)

/*! @name TCE_HSCAN2_CLR - EPDC Timing Control Engine Horizontal Timing Register 2 */
#define EPDC_TCE_HSCAN2_CLR_LINE_BEGIN_MASK      (0xFFFU)
#define EPDC_TCE_HSCAN2_CLR_LINE_BEGIN_SHIFT     (0U)
#define EPDC_TCE_HSCAN2_CLR_LINE_BEGIN(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN2_CLR_LINE_BEGIN_SHIFT)) & EPDC_TCE_HSCAN2_CLR_LINE_BEGIN_MASK)
#define EPDC_TCE_HSCAN2_CLR_LINE_END_MASK        (0xFFF0000U)
#define EPDC_TCE_HSCAN2_CLR_LINE_END_SHIFT       (16U)
#define EPDC_TCE_HSCAN2_CLR_LINE_END(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN2_CLR_LINE_END_SHIFT)) & EPDC_TCE_HSCAN2_CLR_LINE_END_MASK)

/*! @name TCE_HSCAN2_TOG - EPDC Timing Control Engine Horizontal Timing Register 2 */
#define EPDC_TCE_HSCAN2_TOG_LINE_BEGIN_MASK      (0xFFFU)
#define EPDC_TCE_HSCAN2_TOG_LINE_BEGIN_SHIFT     (0U)
#define EPDC_TCE_HSCAN2_TOG_LINE_BEGIN(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN2_TOG_LINE_BEGIN_SHIFT)) & EPDC_TCE_HSCAN2_TOG_LINE_BEGIN_MASK)
#define EPDC_TCE_HSCAN2_TOG_LINE_END_MASK        (0xFFF0000U)
#define EPDC_TCE_HSCAN2_TOG_LINE_END_SHIFT       (16U)
#define EPDC_TCE_HSCAN2_TOG_LINE_END(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_HSCAN2_TOG_LINE_END_SHIFT)) & EPDC_TCE_HSCAN2_TOG_LINE_END_MASK)

/*! @name TCE_VSCAN - EPDC Timing Control Engine Vertical Timing Register */
#define EPDC_TCE_VSCAN_FRAME_SYNC_MASK           (0xFFU)
#define EPDC_TCE_VSCAN_FRAME_SYNC_SHIFT          (0U)
#define EPDC_TCE_VSCAN_FRAME_SYNC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_FRAME_SYNC_SHIFT)) & EPDC_TCE_VSCAN_FRAME_SYNC_MASK)
#define EPDC_TCE_VSCAN_FRAME_BEGIN_MASK          (0xFF00U)
#define EPDC_TCE_VSCAN_FRAME_BEGIN_SHIFT         (8U)
#define EPDC_TCE_VSCAN_FRAME_BEGIN(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_FRAME_BEGIN_SHIFT)) & EPDC_TCE_VSCAN_FRAME_BEGIN_MASK)
#define EPDC_TCE_VSCAN_FRAME_END_MASK            (0xFF0000U)
#define EPDC_TCE_VSCAN_FRAME_END_SHIFT           (16U)
#define EPDC_TCE_VSCAN_FRAME_END(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_FRAME_END_SHIFT)) & EPDC_TCE_VSCAN_FRAME_END_MASK)

/*! @name TCE_VSCAN_SET - EPDC Timing Control Engine Vertical Timing Register */
#define EPDC_TCE_VSCAN_SET_FRAME_SYNC_MASK       (0xFFU)
#define EPDC_TCE_VSCAN_SET_FRAME_SYNC_SHIFT      (0U)
#define EPDC_TCE_VSCAN_SET_FRAME_SYNC(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_SET_FRAME_SYNC_SHIFT)) & EPDC_TCE_VSCAN_SET_FRAME_SYNC_MASK)
#define EPDC_TCE_VSCAN_SET_FRAME_BEGIN_MASK      (0xFF00U)
#define EPDC_TCE_VSCAN_SET_FRAME_BEGIN_SHIFT     (8U)
#define EPDC_TCE_VSCAN_SET_FRAME_BEGIN(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_SET_FRAME_BEGIN_SHIFT)) & EPDC_TCE_VSCAN_SET_FRAME_BEGIN_MASK)
#define EPDC_TCE_VSCAN_SET_FRAME_END_MASK        (0xFF0000U)
#define EPDC_TCE_VSCAN_SET_FRAME_END_SHIFT       (16U)
#define EPDC_TCE_VSCAN_SET_FRAME_END(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_SET_FRAME_END_SHIFT)) & EPDC_TCE_VSCAN_SET_FRAME_END_MASK)

/*! @name TCE_VSCAN_CLR - EPDC Timing Control Engine Vertical Timing Register */
#define EPDC_TCE_VSCAN_CLR_FRAME_SYNC_MASK       (0xFFU)
#define EPDC_TCE_VSCAN_CLR_FRAME_SYNC_SHIFT      (0U)
#define EPDC_TCE_VSCAN_CLR_FRAME_SYNC(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_CLR_FRAME_SYNC_SHIFT)) & EPDC_TCE_VSCAN_CLR_FRAME_SYNC_MASK)
#define EPDC_TCE_VSCAN_CLR_FRAME_BEGIN_MASK      (0xFF00U)
#define EPDC_TCE_VSCAN_CLR_FRAME_BEGIN_SHIFT     (8U)
#define EPDC_TCE_VSCAN_CLR_FRAME_BEGIN(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_CLR_FRAME_BEGIN_SHIFT)) & EPDC_TCE_VSCAN_CLR_FRAME_BEGIN_MASK)
#define EPDC_TCE_VSCAN_CLR_FRAME_END_MASK        (0xFF0000U)
#define EPDC_TCE_VSCAN_CLR_FRAME_END_SHIFT       (16U)
#define EPDC_TCE_VSCAN_CLR_FRAME_END(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_CLR_FRAME_END_SHIFT)) & EPDC_TCE_VSCAN_CLR_FRAME_END_MASK)

/*! @name TCE_VSCAN_TOG - EPDC Timing Control Engine Vertical Timing Register */
#define EPDC_TCE_VSCAN_TOG_FRAME_SYNC_MASK       (0xFFU)
#define EPDC_TCE_VSCAN_TOG_FRAME_SYNC_SHIFT      (0U)
#define EPDC_TCE_VSCAN_TOG_FRAME_SYNC(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_TOG_FRAME_SYNC_SHIFT)) & EPDC_TCE_VSCAN_TOG_FRAME_SYNC_MASK)
#define EPDC_TCE_VSCAN_TOG_FRAME_BEGIN_MASK      (0xFF00U)
#define EPDC_TCE_VSCAN_TOG_FRAME_BEGIN_SHIFT     (8U)
#define EPDC_TCE_VSCAN_TOG_FRAME_BEGIN(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_TOG_FRAME_BEGIN_SHIFT)) & EPDC_TCE_VSCAN_TOG_FRAME_BEGIN_MASK)
#define EPDC_TCE_VSCAN_TOG_FRAME_END_MASK        (0xFF0000U)
#define EPDC_TCE_VSCAN_TOG_FRAME_END_SHIFT       (16U)
#define EPDC_TCE_VSCAN_TOG_FRAME_END(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_VSCAN_TOG_FRAME_END_SHIFT)) & EPDC_TCE_VSCAN_TOG_FRAME_END_MASK)

/*! @name TCE_OE - EPDC Timing Control Engine OE timing control Register */
#define EPDC_TCE_OE_SDOEZ_DLY_MASK               (0xFFU)
#define EPDC_TCE_OE_SDOEZ_DLY_SHIFT              (0U)
#define EPDC_TCE_OE_SDOEZ_DLY(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_SDOEZ_DLY_SHIFT)) & EPDC_TCE_OE_SDOEZ_DLY_MASK)
#define EPDC_TCE_OE_SDOEZ_WIDTH_MASK             (0xFF00U)
#define EPDC_TCE_OE_SDOEZ_WIDTH_SHIFT            (8U)
#define EPDC_TCE_OE_SDOEZ_WIDTH(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_SDOEZ_WIDTH_SHIFT)) & EPDC_TCE_OE_SDOEZ_WIDTH_MASK)
#define EPDC_TCE_OE_SDOED_DLY_MASK               (0xFF0000U)
#define EPDC_TCE_OE_SDOED_DLY_SHIFT              (16U)
#define EPDC_TCE_OE_SDOED_DLY(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_SDOED_DLY_SHIFT)) & EPDC_TCE_OE_SDOED_DLY_MASK)
#define EPDC_TCE_OE_SDOED_WIDTH_MASK             (0xFF000000U)
#define EPDC_TCE_OE_SDOED_WIDTH_SHIFT            (24U)
#define EPDC_TCE_OE_SDOED_WIDTH(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_SDOED_WIDTH_SHIFT)) & EPDC_TCE_OE_SDOED_WIDTH_MASK)

/*! @name TCE_OE_SET - EPDC Timing Control Engine OE timing control Register */
#define EPDC_TCE_OE_SET_SDOEZ_DLY_MASK           (0xFFU)
#define EPDC_TCE_OE_SET_SDOEZ_DLY_SHIFT          (0U)
#define EPDC_TCE_OE_SET_SDOEZ_DLY(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_SET_SDOEZ_DLY_SHIFT)) & EPDC_TCE_OE_SET_SDOEZ_DLY_MASK)
#define EPDC_TCE_OE_SET_SDOEZ_WIDTH_MASK         (0xFF00U)
#define EPDC_TCE_OE_SET_SDOEZ_WIDTH_SHIFT        (8U)
#define EPDC_TCE_OE_SET_SDOEZ_WIDTH(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_SET_SDOEZ_WIDTH_SHIFT)) & EPDC_TCE_OE_SET_SDOEZ_WIDTH_MASK)
#define EPDC_TCE_OE_SET_SDOED_DLY_MASK           (0xFF0000U)
#define EPDC_TCE_OE_SET_SDOED_DLY_SHIFT          (16U)
#define EPDC_TCE_OE_SET_SDOED_DLY(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_SET_SDOED_DLY_SHIFT)) & EPDC_TCE_OE_SET_SDOED_DLY_MASK)
#define EPDC_TCE_OE_SET_SDOED_WIDTH_MASK         (0xFF000000U)
#define EPDC_TCE_OE_SET_SDOED_WIDTH_SHIFT        (24U)
#define EPDC_TCE_OE_SET_SDOED_WIDTH(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_SET_SDOED_WIDTH_SHIFT)) & EPDC_TCE_OE_SET_SDOED_WIDTH_MASK)

/*! @name TCE_OE_CLR - EPDC Timing Control Engine OE timing control Register */
#define EPDC_TCE_OE_CLR_SDOEZ_DLY_MASK           (0xFFU)
#define EPDC_TCE_OE_CLR_SDOEZ_DLY_SHIFT          (0U)
#define EPDC_TCE_OE_CLR_SDOEZ_DLY(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_CLR_SDOEZ_DLY_SHIFT)) & EPDC_TCE_OE_CLR_SDOEZ_DLY_MASK)
#define EPDC_TCE_OE_CLR_SDOEZ_WIDTH_MASK         (0xFF00U)
#define EPDC_TCE_OE_CLR_SDOEZ_WIDTH_SHIFT        (8U)
#define EPDC_TCE_OE_CLR_SDOEZ_WIDTH(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_CLR_SDOEZ_WIDTH_SHIFT)) & EPDC_TCE_OE_CLR_SDOEZ_WIDTH_MASK)
#define EPDC_TCE_OE_CLR_SDOED_DLY_MASK           (0xFF0000U)
#define EPDC_TCE_OE_CLR_SDOED_DLY_SHIFT          (16U)
#define EPDC_TCE_OE_CLR_SDOED_DLY(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_CLR_SDOED_DLY_SHIFT)) & EPDC_TCE_OE_CLR_SDOED_DLY_MASK)
#define EPDC_TCE_OE_CLR_SDOED_WIDTH_MASK         (0xFF000000U)
#define EPDC_TCE_OE_CLR_SDOED_WIDTH_SHIFT        (24U)
#define EPDC_TCE_OE_CLR_SDOED_WIDTH(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_CLR_SDOED_WIDTH_SHIFT)) & EPDC_TCE_OE_CLR_SDOED_WIDTH_MASK)

/*! @name TCE_OE_TOG - EPDC Timing Control Engine OE timing control Register */
#define EPDC_TCE_OE_TOG_SDOEZ_DLY_MASK           (0xFFU)
#define EPDC_TCE_OE_TOG_SDOEZ_DLY_SHIFT          (0U)
#define EPDC_TCE_OE_TOG_SDOEZ_DLY(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_TOG_SDOEZ_DLY_SHIFT)) & EPDC_TCE_OE_TOG_SDOEZ_DLY_MASK)
#define EPDC_TCE_OE_TOG_SDOEZ_WIDTH_MASK         (0xFF00U)
#define EPDC_TCE_OE_TOG_SDOEZ_WIDTH_SHIFT        (8U)
#define EPDC_TCE_OE_TOG_SDOEZ_WIDTH(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_TOG_SDOEZ_WIDTH_SHIFT)) & EPDC_TCE_OE_TOG_SDOEZ_WIDTH_MASK)
#define EPDC_TCE_OE_TOG_SDOED_DLY_MASK           (0xFF0000U)
#define EPDC_TCE_OE_TOG_SDOED_DLY_SHIFT          (16U)
#define EPDC_TCE_OE_TOG_SDOED_DLY(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_TOG_SDOED_DLY_SHIFT)) & EPDC_TCE_OE_TOG_SDOED_DLY_MASK)
#define EPDC_TCE_OE_TOG_SDOED_WIDTH_MASK         (0xFF000000U)
#define EPDC_TCE_OE_TOG_SDOED_WIDTH_SHIFT        (24U)
#define EPDC_TCE_OE_TOG_SDOED_WIDTH(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_OE_TOG_SDOED_WIDTH_SHIFT)) & EPDC_TCE_OE_TOG_SDOED_WIDTH_MASK)

/*! @name TCE_POLARITY - EPDC Timing Control Engine Driver Polarity Register */
#define EPDC_TCE_POLARITY_SDCE_POL_MASK          (0x1U)
#define EPDC_TCE_POLARITY_SDCE_POL_SHIFT         (0U)
#define EPDC_TCE_POLARITY_SDLE_POL_MASK          (0x2U)
#define EPDC_TCE_POLARITY_SDLE_POL_SHIFT         (1U)
#define EPDC_TCE_POLARITY_SDOE_POL_MASK          (0x4U)
#define EPDC_TCE_POLARITY_SDOE_POL_SHIFT         (2U)
#define EPDC_TCE_POLARITY_GDOE_POL_MASK          (0x8U)
#define EPDC_TCE_POLARITY_GDOE_POL_SHIFT         (3U)
#define EPDC_TCE_POLARITY_GDSP_POL_MASK          (0x10U)
#define EPDC_TCE_POLARITY_GDSP_POL_SHIFT         (4U)

/*! @name TCE_POLARITY_SET - EPDC Timing Control Engine Driver Polarity Register */
#define EPDC_TCE_POLARITY_SET_SDCE_POL_MASK      (0x1U)
#define EPDC_TCE_POLARITY_SET_SDCE_POL_SHIFT     (0U)
#define EPDC_TCE_POLARITY_SET_SDLE_POL_MASK      (0x2U)
#define EPDC_TCE_POLARITY_SET_SDLE_POL_SHIFT     (1U)
#define EPDC_TCE_POLARITY_SET_SDOE_POL_MASK      (0x4U)
#define EPDC_TCE_POLARITY_SET_SDOE_POL_SHIFT     (2U)
#define EPDC_TCE_POLARITY_SET_GDOE_POL_MASK      (0x8U)
#define EPDC_TCE_POLARITY_SET_GDOE_POL_SHIFT     (3U)
#define EPDC_TCE_POLARITY_SET_GDSP_POL_MASK      (0x10U)
#define EPDC_TCE_POLARITY_SET_GDSP_POL_SHIFT     (4U)

/*! @name TCE_POLARITY_CLR - EPDC Timing Control Engine Driver Polarity Register */
#define EPDC_TCE_POLARITY_CLR_SDCE_POL_MASK      (0x1U)
#define EPDC_TCE_POLARITY_CLR_SDCE_POL_SHIFT     (0U)
#define EPDC_TCE_POLARITY_CLR_SDLE_POL_MASK      (0x2U)
#define EPDC_TCE_POLARITY_CLR_SDLE_POL_SHIFT     (1U)
#define EPDC_TCE_POLARITY_CLR_SDOE_POL_MASK      (0x4U)
#define EPDC_TCE_POLARITY_CLR_SDOE_POL_SHIFT     (2U)
#define EPDC_TCE_POLARITY_CLR_GDOE_POL_MASK      (0x8U)
#define EPDC_TCE_POLARITY_CLR_GDOE_POL_SHIFT     (3U)
#define EPDC_TCE_POLARITY_CLR_GDSP_POL_MASK      (0x10U)
#define EPDC_TCE_POLARITY_CLR_GDSP_POL_SHIFT     (4U)

/*! @name TCE_POLARITY_TOG - EPDC Timing Control Engine Driver Polarity Register */
#define EPDC_TCE_POLARITY_TOG_SDCE_POL_MASK      (0x1U)
#define EPDC_TCE_POLARITY_TOG_SDCE_POL_SHIFT     (0U)
#define EPDC_TCE_POLARITY_TOG_SDLE_POL_MASK      (0x2U)
#define EPDC_TCE_POLARITY_TOG_SDLE_POL_SHIFT     (1U)
#define EPDC_TCE_POLARITY_TOG_SDOE_POL_MASK      (0x4U)
#define EPDC_TCE_POLARITY_TOG_SDOE_POL_SHIFT     (2U)
#define EPDC_TCE_POLARITY_TOG_GDOE_POL_MASK      (0x8U)
#define EPDC_TCE_POLARITY_TOG_GDOE_POL_SHIFT     (3U)
#define EPDC_TCE_POLARITY_TOG_GDSP_POL_MASK      (0x10U)
#define EPDC_TCE_POLARITY_TOG_GDSP_POL_SHIFT     (4U)

/*! @name TCE_TIMING1 - EPDC Timing Control Engine Timing Register 1 */
#define EPDC_TCE_TIMING1_SDCLK_SHIFT_MASK        (0x3U)
#define EPDC_TCE_TIMING1_SDCLK_SHIFT_SHIFT       (0U)
#define EPDC_TCE_TIMING1_SDCLK_SHIFT(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING1_SDCLK_SHIFT_SHIFT)) & EPDC_TCE_TIMING1_SDCLK_SHIFT_MASK)
#define EPDC_TCE_TIMING1_SDCLK_INVERT_MASK       (0x8U)
#define EPDC_TCE_TIMING1_SDCLK_INVERT_SHIFT      (3U)
#define EPDC_TCE_TIMING1_SDLE_SHIFT_MASK         (0x30U)
#define EPDC_TCE_TIMING1_SDLE_SHIFT_SHIFT        (4U)
#define EPDC_TCE_TIMING1_SDLE_SHIFT(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING1_SDLE_SHIFT_SHIFT)) & EPDC_TCE_TIMING1_SDLE_SHIFT_MASK)

/*! @name TCE_TIMING1_SET - EPDC Timing Control Engine Timing Register 1 */
#define EPDC_TCE_TIMING1_SET_SDCLK_SHIFT_MASK    (0x3U)
#define EPDC_TCE_TIMING1_SET_SDCLK_SHIFT_SHIFT   (0U)
#define EPDC_TCE_TIMING1_SET_SDCLK_SHIFT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING1_SET_SDCLK_SHIFT_SHIFT)) & EPDC_TCE_TIMING1_SET_SDCLK_SHIFT_MASK)
#define EPDC_TCE_TIMING1_SET_SDCLK_INVERT_MASK   (0x8U)
#define EPDC_TCE_TIMING1_SET_SDCLK_INVERT_SHIFT  (3U)
#define EPDC_TCE_TIMING1_SET_SDLE_SHIFT_MASK     (0x30U)
#define EPDC_TCE_TIMING1_SET_SDLE_SHIFT_SHIFT    (4U)
#define EPDC_TCE_TIMING1_SET_SDLE_SHIFT(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING1_SET_SDLE_SHIFT_SHIFT)) & EPDC_TCE_TIMING1_SET_SDLE_SHIFT_MASK)

/*! @name TCE_TIMING1_CLR - EPDC Timing Control Engine Timing Register 1 */
#define EPDC_TCE_TIMING1_CLR_SDCLK_SHIFT_MASK    (0x3U)
#define EPDC_TCE_TIMING1_CLR_SDCLK_SHIFT_SHIFT   (0U)
#define EPDC_TCE_TIMING1_CLR_SDCLK_SHIFT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING1_CLR_SDCLK_SHIFT_SHIFT)) & EPDC_TCE_TIMING1_CLR_SDCLK_SHIFT_MASK)
#define EPDC_TCE_TIMING1_CLR_SDCLK_INVERT_MASK   (0x8U)
#define EPDC_TCE_TIMING1_CLR_SDCLK_INVERT_SHIFT  (3U)
#define EPDC_TCE_TIMING1_CLR_SDLE_SHIFT_MASK     (0x30U)
#define EPDC_TCE_TIMING1_CLR_SDLE_SHIFT_SHIFT    (4U)
#define EPDC_TCE_TIMING1_CLR_SDLE_SHIFT(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING1_CLR_SDLE_SHIFT_SHIFT)) & EPDC_TCE_TIMING1_CLR_SDLE_SHIFT_MASK)

/*! @name TCE_TIMING1_TOG - EPDC Timing Control Engine Timing Register 1 */
#define EPDC_TCE_TIMING1_TOG_SDCLK_SHIFT_MASK    (0x3U)
#define EPDC_TCE_TIMING1_TOG_SDCLK_SHIFT_SHIFT   (0U)
#define EPDC_TCE_TIMING1_TOG_SDCLK_SHIFT(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING1_TOG_SDCLK_SHIFT_SHIFT)) & EPDC_TCE_TIMING1_TOG_SDCLK_SHIFT_MASK)
#define EPDC_TCE_TIMING1_TOG_SDCLK_INVERT_MASK   (0x8U)
#define EPDC_TCE_TIMING1_TOG_SDCLK_INVERT_SHIFT  (3U)
#define EPDC_TCE_TIMING1_TOG_SDLE_SHIFT_MASK     (0x30U)
#define EPDC_TCE_TIMING1_TOG_SDLE_SHIFT_SHIFT    (4U)
#define EPDC_TCE_TIMING1_TOG_SDLE_SHIFT(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING1_TOG_SDLE_SHIFT_SHIFT)) & EPDC_TCE_TIMING1_TOG_SDLE_SHIFT_MASK)

/*! @name TCE_TIMING2 - EPDC Timing Control Engine Timing Register 2 */
#define EPDC_TCE_TIMING2_GDSP_OFFSET_MASK        (0xFFFFU)
#define EPDC_TCE_TIMING2_GDSP_OFFSET_SHIFT       (0U)
#define EPDC_TCE_TIMING2_GDSP_OFFSET(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING2_GDSP_OFFSET_SHIFT)) & EPDC_TCE_TIMING2_GDSP_OFFSET_MASK)
#define EPDC_TCE_TIMING2_GDCLK_HP_MASK           (0xFFFF0000U)
#define EPDC_TCE_TIMING2_GDCLK_HP_SHIFT          (16U)
#define EPDC_TCE_TIMING2_GDCLK_HP(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING2_GDCLK_HP_SHIFT)) & EPDC_TCE_TIMING2_GDCLK_HP_MASK)

/*! @name TCE_TIMING2_SET - EPDC Timing Control Engine Timing Register 2 */
#define EPDC_TCE_TIMING2_SET_GDSP_OFFSET_MASK    (0xFFFFU)
#define EPDC_TCE_TIMING2_SET_GDSP_OFFSET_SHIFT   (0U)
#define EPDC_TCE_TIMING2_SET_GDSP_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING2_SET_GDSP_OFFSET_SHIFT)) & EPDC_TCE_TIMING2_SET_GDSP_OFFSET_MASK)
#define EPDC_TCE_TIMING2_SET_GDCLK_HP_MASK       (0xFFFF0000U)
#define EPDC_TCE_TIMING2_SET_GDCLK_HP_SHIFT      (16U)
#define EPDC_TCE_TIMING2_SET_GDCLK_HP(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING2_SET_GDCLK_HP_SHIFT)) & EPDC_TCE_TIMING2_SET_GDCLK_HP_MASK)

/*! @name TCE_TIMING2_CLR - EPDC Timing Control Engine Timing Register 2 */
#define EPDC_TCE_TIMING2_CLR_GDSP_OFFSET_MASK    (0xFFFFU)
#define EPDC_TCE_TIMING2_CLR_GDSP_OFFSET_SHIFT   (0U)
#define EPDC_TCE_TIMING2_CLR_GDSP_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING2_CLR_GDSP_OFFSET_SHIFT)) & EPDC_TCE_TIMING2_CLR_GDSP_OFFSET_MASK)
#define EPDC_TCE_TIMING2_CLR_GDCLK_HP_MASK       (0xFFFF0000U)
#define EPDC_TCE_TIMING2_CLR_GDCLK_HP_SHIFT      (16U)
#define EPDC_TCE_TIMING2_CLR_GDCLK_HP(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING2_CLR_GDCLK_HP_SHIFT)) & EPDC_TCE_TIMING2_CLR_GDCLK_HP_MASK)

/*! @name TCE_TIMING2_TOG - EPDC Timing Control Engine Timing Register 2 */
#define EPDC_TCE_TIMING2_TOG_GDSP_OFFSET_MASK    (0xFFFFU)
#define EPDC_TCE_TIMING2_TOG_GDSP_OFFSET_SHIFT   (0U)
#define EPDC_TCE_TIMING2_TOG_GDSP_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING2_TOG_GDSP_OFFSET_SHIFT)) & EPDC_TCE_TIMING2_TOG_GDSP_OFFSET_MASK)
#define EPDC_TCE_TIMING2_TOG_GDCLK_HP_MASK       (0xFFFF0000U)
#define EPDC_TCE_TIMING2_TOG_GDCLK_HP_SHIFT      (16U)
#define EPDC_TCE_TIMING2_TOG_GDCLK_HP(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING2_TOG_GDCLK_HP_SHIFT)) & EPDC_TCE_TIMING2_TOG_GDCLK_HP_MASK)

/*! @name TCE_TIMING3 - EPDC Timing Control Engine Timing Register 3 */
#define EPDC_TCE_TIMING3_GDCLK_OFFSET_MASK       (0xFFFFU)
#define EPDC_TCE_TIMING3_GDCLK_OFFSET_SHIFT      (0U)
#define EPDC_TCE_TIMING3_GDCLK_OFFSET(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING3_GDCLK_OFFSET_SHIFT)) & EPDC_TCE_TIMING3_GDCLK_OFFSET_MASK)
#define EPDC_TCE_TIMING3_GDOE_OFFSET_MASK        (0xFFFF0000U)
#define EPDC_TCE_TIMING3_GDOE_OFFSET_SHIFT       (16U)
#define EPDC_TCE_TIMING3_GDOE_OFFSET(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING3_GDOE_OFFSET_SHIFT)) & EPDC_TCE_TIMING3_GDOE_OFFSET_MASK)

/*! @name TCE_TIMING3_SET - EPDC Timing Control Engine Timing Register 3 */
#define EPDC_TCE_TIMING3_SET_GDCLK_OFFSET_MASK   (0xFFFFU)
#define EPDC_TCE_TIMING3_SET_GDCLK_OFFSET_SHIFT  (0U)
#define EPDC_TCE_TIMING3_SET_GDCLK_OFFSET(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING3_SET_GDCLK_OFFSET_SHIFT)) & EPDC_TCE_TIMING3_SET_GDCLK_OFFSET_MASK)
#define EPDC_TCE_TIMING3_SET_GDOE_OFFSET_MASK    (0xFFFF0000U)
#define EPDC_TCE_TIMING3_SET_GDOE_OFFSET_SHIFT   (16U)
#define EPDC_TCE_TIMING3_SET_GDOE_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING3_SET_GDOE_OFFSET_SHIFT)) & EPDC_TCE_TIMING3_SET_GDOE_OFFSET_MASK)

/*! @name TCE_TIMING3_CLR - EPDC Timing Control Engine Timing Register 3 */
#define EPDC_TCE_TIMING3_CLR_GDCLK_OFFSET_MASK   (0xFFFFU)
#define EPDC_TCE_TIMING3_CLR_GDCLK_OFFSET_SHIFT  (0U)
#define EPDC_TCE_TIMING3_CLR_GDCLK_OFFSET(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING3_CLR_GDCLK_OFFSET_SHIFT)) & EPDC_TCE_TIMING3_CLR_GDCLK_OFFSET_MASK)
#define EPDC_TCE_TIMING3_CLR_GDOE_OFFSET_MASK    (0xFFFF0000U)
#define EPDC_TCE_TIMING3_CLR_GDOE_OFFSET_SHIFT   (16U)
#define EPDC_TCE_TIMING3_CLR_GDOE_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING3_CLR_GDOE_OFFSET_SHIFT)) & EPDC_TCE_TIMING3_CLR_GDOE_OFFSET_MASK)

/*! @name TCE_TIMING3_TOG - EPDC Timing Control Engine Timing Register 3 */
#define EPDC_TCE_TIMING3_TOG_GDCLK_OFFSET_MASK   (0xFFFFU)
#define EPDC_TCE_TIMING3_TOG_GDCLK_OFFSET_SHIFT  (0U)
#define EPDC_TCE_TIMING3_TOG_GDCLK_OFFSET(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING3_TOG_GDCLK_OFFSET_SHIFT)) & EPDC_TCE_TIMING3_TOG_GDCLK_OFFSET_MASK)
#define EPDC_TCE_TIMING3_TOG_GDOE_OFFSET_MASK    (0xFFFF0000U)
#define EPDC_TCE_TIMING3_TOG_GDOE_OFFSET_SHIFT   (16U)
#define EPDC_TCE_TIMING3_TOG_GDOE_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_TCE_TIMING3_TOG_GDOE_OFFSET_SHIFT)) & EPDC_TCE_TIMING3_TOG_GDOE_OFFSET_MASK)

/*! @name PIGEON_CTRL0 - EPDC Pigeon Mode Control Register 0 */
#define EPDC_PIGEON_CTRL0_FD_PERIOD_MASK         (0xFFFU)
#define EPDC_PIGEON_CTRL0_FD_PERIOD_SHIFT        (0U)
#define EPDC_PIGEON_CTRL0_FD_PERIOD(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL0_FD_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL0_FD_PERIOD_MASK)
#define EPDC_PIGEON_CTRL0_LD_PERIOD_MASK         (0xFFF0000U)
#define EPDC_PIGEON_CTRL0_LD_PERIOD_SHIFT        (16U)
#define EPDC_PIGEON_CTRL0_LD_PERIOD(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL0_LD_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL0_LD_PERIOD_MASK)

/*! @name PIGEON_CTRL0_SET - EPDC Pigeon Mode Control Register 0 */
#define EPDC_PIGEON_CTRL0_SET_FD_PERIOD_MASK     (0xFFFU)
#define EPDC_PIGEON_CTRL0_SET_FD_PERIOD_SHIFT    (0U)
#define EPDC_PIGEON_CTRL0_SET_FD_PERIOD(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL0_SET_FD_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL0_SET_FD_PERIOD_MASK)
#define EPDC_PIGEON_CTRL0_SET_LD_PERIOD_MASK     (0xFFF0000U)
#define EPDC_PIGEON_CTRL0_SET_LD_PERIOD_SHIFT    (16U)
#define EPDC_PIGEON_CTRL0_SET_LD_PERIOD(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL0_SET_LD_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL0_SET_LD_PERIOD_MASK)

/*! @name PIGEON_CTRL0_CLR - EPDC Pigeon Mode Control Register 0 */
#define EPDC_PIGEON_CTRL0_CLR_FD_PERIOD_MASK     (0xFFFU)
#define EPDC_PIGEON_CTRL0_CLR_FD_PERIOD_SHIFT    (0U)
#define EPDC_PIGEON_CTRL0_CLR_FD_PERIOD(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL0_CLR_FD_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL0_CLR_FD_PERIOD_MASK)
#define EPDC_PIGEON_CTRL0_CLR_LD_PERIOD_MASK     (0xFFF0000U)
#define EPDC_PIGEON_CTRL0_CLR_LD_PERIOD_SHIFT    (16U)
#define EPDC_PIGEON_CTRL0_CLR_LD_PERIOD(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL0_CLR_LD_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL0_CLR_LD_PERIOD_MASK)

/*! @name PIGEON_CTRL0_TOG - EPDC Pigeon Mode Control Register 0 */
#define EPDC_PIGEON_CTRL0_TOG_FD_PERIOD_MASK     (0xFFFU)
#define EPDC_PIGEON_CTRL0_TOG_FD_PERIOD_SHIFT    (0U)
#define EPDC_PIGEON_CTRL0_TOG_FD_PERIOD(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL0_TOG_FD_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL0_TOG_FD_PERIOD_MASK)
#define EPDC_PIGEON_CTRL0_TOG_LD_PERIOD_MASK     (0xFFF0000U)
#define EPDC_PIGEON_CTRL0_TOG_LD_PERIOD_SHIFT    (16U)
#define EPDC_PIGEON_CTRL0_TOG_LD_PERIOD(x)       (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL0_TOG_LD_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL0_TOG_LD_PERIOD_MASK)

/*! @name PIGEON_CTRL1 - EPDC Pigeon Mode Control Register 1 */
#define EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD_MASK  (0xFFFU)
#define EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD_SHIFT (0U)
#define EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD(x)    (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD_MASK)
#define EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES_MASK  (0xFFF0000U)
#define EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES_SHIFT (16U)
#define EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES(x)    (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES_SHIFT)) & EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES_MASK)

/*! @name PIGEON_CTRL1_SET - EPDC Pigeon Mode Control Register 1 */
#define EPDC_PIGEON_CTRL1_SET_FRAME_CNT_PERIOD_MASK (0xFFFU)
#define EPDC_PIGEON_CTRL1_SET_FRAME_CNT_PERIOD_SHIFT (0U)
#define EPDC_PIGEON_CTRL1_SET_FRAME_CNT_PERIOD(x) (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL1_SET_FRAME_CNT_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL1_SET_FRAME_CNT_PERIOD_MASK)
#define EPDC_PIGEON_CTRL1_SET_FRAME_CNT_CYCLES_MASK (0xFFF0000U)
#define EPDC_PIGEON_CTRL1_SET_FRAME_CNT_CYCLES_SHIFT (16U)
#define EPDC_PIGEON_CTRL1_SET_FRAME_CNT_CYCLES(x) (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL1_SET_FRAME_CNT_CYCLES_SHIFT)) & EPDC_PIGEON_CTRL1_SET_FRAME_CNT_CYCLES_MASK)

/*! @name PIGEON_CTRL1_CLR - EPDC Pigeon Mode Control Register 1 */
#define EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_PERIOD_MASK (0xFFFU)
#define EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_PERIOD_SHIFT (0U)
#define EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_PERIOD(x) (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_PERIOD_MASK)
#define EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_CYCLES_MASK (0xFFF0000U)
#define EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_CYCLES_SHIFT (16U)
#define EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_CYCLES(x) (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_CYCLES_SHIFT)) & EPDC_PIGEON_CTRL1_CLR_FRAME_CNT_CYCLES_MASK)

/*! @name PIGEON_CTRL1_TOG - EPDC Pigeon Mode Control Register 1 */
#define EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_PERIOD_MASK (0xFFFU)
#define EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_PERIOD_SHIFT (0U)
#define EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_PERIOD(x) (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_PERIOD_SHIFT)) & EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_PERIOD_MASK)
#define EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_CYCLES_MASK (0xFFF0000U)
#define EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_CYCLES_SHIFT (16U)
#define EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_CYCLES(x) (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_CYCLES_SHIFT)) & EPDC_PIGEON_CTRL1_TOG_FRAME_CNT_CYCLES_MASK)

/*! @name IRQ_MASK1 - EPDC IRQ Mask Register for LUT 0~31 */
#define EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN_MASK    (0xFFFFFFFFU)
#define EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN_SHIFT   (0U)
#define EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN_SHIFT)) & EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN_MASK)

/*! @name IRQ_MASK1_SET - EPDC IRQ Mask Register for LUT 0~31 */
#define EPDC_IRQ_MASK1_SET_LUTN_CMPLT_IRQ_EN_MASK (0xFFFFFFFFU)
#define EPDC_IRQ_MASK1_SET_LUTN_CMPLT_IRQ_EN_SHIFT (0U)
#define EPDC_IRQ_MASK1_SET_LUTN_CMPLT_IRQ_EN(x)  (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ_MASK1_SET_LUTN_CMPLT_IRQ_EN_SHIFT)) & EPDC_IRQ_MASK1_SET_LUTN_CMPLT_IRQ_EN_MASK)

/*! @name IRQ_MASK1_CLR - EPDC IRQ Mask Register for LUT 0~31 */
#define EPDC_IRQ_MASK1_CLR_LUTN_CMPLT_IRQ_EN_MASK (0xFFFFFFFFU)
#define EPDC_IRQ_MASK1_CLR_LUTN_CMPLT_IRQ_EN_SHIFT (0U)
#define EPDC_IRQ_MASK1_CLR_LUTN_CMPLT_IRQ_EN(x)  (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ_MASK1_CLR_LUTN_CMPLT_IRQ_EN_SHIFT)) & EPDC_IRQ_MASK1_CLR_LUTN_CMPLT_IRQ_EN_MASK)

/*! @name IRQ_MASK1_TOG - EPDC IRQ Mask Register for LUT 0~31 */
#define EPDC_IRQ_MASK1_TOG_LUTN_CMPLT_IRQ_EN_MASK (0xFFFFFFFFU)
#define EPDC_IRQ_MASK1_TOG_LUTN_CMPLT_IRQ_EN_SHIFT (0U)
#define EPDC_IRQ_MASK1_TOG_LUTN_CMPLT_IRQ_EN(x)  (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ_MASK1_TOG_LUTN_CMPLT_IRQ_EN_SHIFT)) & EPDC_IRQ_MASK1_TOG_LUTN_CMPLT_IRQ_EN_MASK)

/*! @name IRQ_MASK2 - EPDC IRQ Mask Register for LUT 32~63 */
#define EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN_MASK    (0xFFFFFFFFU)
#define EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN_SHIFT   (0U)
#define EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN(x)      (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN_SHIFT)) & EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN_MASK)

/*! @name IRQ_MASK2_SET - EPDC IRQ Mask Register for LUT 32~63 */
#define EPDC_IRQ_MASK2_SET_LUTN_CMPLT_IRQ_EN_MASK (0xFFFFFFFFU)
#define EPDC_IRQ_MASK2_SET_LUTN_CMPLT_IRQ_EN_SHIFT (0U)
#define EPDC_IRQ_MASK2_SET_LUTN_CMPLT_IRQ_EN(x)  (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ_MASK2_SET_LUTN_CMPLT_IRQ_EN_SHIFT)) & EPDC_IRQ_MASK2_SET_LUTN_CMPLT_IRQ_EN_MASK)

/*! @name IRQ_MASK2_CLR - EPDC IRQ Mask Register for LUT 32~63 */
#define EPDC_IRQ_MASK2_CLR_LUTN_CMPLT_IRQ_EN_MASK (0xFFFFFFFFU)
#define EPDC_IRQ_MASK2_CLR_LUTN_CMPLT_IRQ_EN_SHIFT (0U)
#define EPDC_IRQ_MASK2_CLR_LUTN_CMPLT_IRQ_EN(x)  (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ_MASK2_CLR_LUTN_CMPLT_IRQ_EN_SHIFT)) & EPDC_IRQ_MASK2_CLR_LUTN_CMPLT_IRQ_EN_MASK)

/*! @name IRQ_MASK2_TOG - EPDC IRQ Mask Register for LUT 32~63 */
#define EPDC_IRQ_MASK2_TOG_LUTN_CMPLT_IRQ_EN_MASK (0xFFFFFFFFU)
#define EPDC_IRQ_MASK2_TOG_LUTN_CMPLT_IRQ_EN_SHIFT (0U)
#define EPDC_IRQ_MASK2_TOG_LUTN_CMPLT_IRQ_EN(x)  (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ_MASK2_TOG_LUTN_CMPLT_IRQ_EN_SHIFT)) & EPDC_IRQ_MASK2_TOG_LUTN_CMPLT_IRQ_EN_MASK)

/*! @name IRQ1 - EPDC Interrupt Register for LUT 0~31 */
#define EPDC_IRQ1_LUTN_CMPLT_IRQ_MASK            (0xFFFFFFFFU)
#define EPDC_IRQ1_LUTN_CMPLT_IRQ_SHIFT           (0U)
#define EPDC_IRQ1_LUTN_CMPLT_IRQ(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ1_LUTN_CMPLT_IRQ_SHIFT)) & EPDC_IRQ1_LUTN_CMPLT_IRQ_MASK)

/*! @name IRQ1_SET - EPDC Interrupt Register for LUT 0~31 */
#define EPDC_IRQ1_SET_LUTN_CMPLT_IRQ_MASK        (0xFFFFFFFFU)
#define EPDC_IRQ1_SET_LUTN_CMPLT_IRQ_SHIFT       (0U)
#define EPDC_IRQ1_SET_LUTN_CMPLT_IRQ(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ1_SET_LUTN_CMPLT_IRQ_SHIFT)) & EPDC_IRQ1_SET_LUTN_CMPLT_IRQ_MASK)

/*! @name IRQ1_CLR - EPDC Interrupt Register for LUT 0~31 */
#define EPDC_IRQ1_CLR_LUTN_CMPLT_IRQ_MASK        (0xFFFFFFFFU)
#define EPDC_IRQ1_CLR_LUTN_CMPLT_IRQ_SHIFT       (0U)
#define EPDC_IRQ1_CLR_LUTN_CMPLT_IRQ(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ1_CLR_LUTN_CMPLT_IRQ_SHIFT)) & EPDC_IRQ1_CLR_LUTN_CMPLT_IRQ_MASK)

/*! @name IRQ1_TOG - EPDC Interrupt Register for LUT 0~31 */
#define EPDC_IRQ1_TOG_LUTN_CMPLT_IRQ_MASK        (0xFFFFFFFFU)
#define EPDC_IRQ1_TOG_LUTN_CMPLT_IRQ_SHIFT       (0U)
#define EPDC_IRQ1_TOG_LUTN_CMPLT_IRQ(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ1_TOG_LUTN_CMPLT_IRQ_SHIFT)) & EPDC_IRQ1_TOG_LUTN_CMPLT_IRQ_MASK)

/*! @name IRQ2 - EPDC Interrupt Registerr for LUT 32~63 */
#define EPDC_IRQ2_LUTN_CMPLT_IRQ_MASK            (0xFFFFFFFFU)
#define EPDC_IRQ2_LUTN_CMPLT_IRQ_SHIFT           (0U)
#define EPDC_IRQ2_LUTN_CMPLT_IRQ(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ2_LUTN_CMPLT_IRQ_SHIFT)) & EPDC_IRQ2_LUTN_CMPLT_IRQ_MASK)

/*! @name IRQ2_SET - EPDC Interrupt Registerr for LUT 32~63 */
#define EPDC_IRQ2_SET_LUTN_CMPLT_IRQ_MASK        (0xFFFFFFFFU)
#define EPDC_IRQ2_SET_LUTN_CMPLT_IRQ_SHIFT       (0U)
#define EPDC_IRQ2_SET_LUTN_CMPLT_IRQ(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ2_SET_LUTN_CMPLT_IRQ_SHIFT)) & EPDC_IRQ2_SET_LUTN_CMPLT_IRQ_MASK)

/*! @name IRQ2_CLR - EPDC Interrupt Registerr for LUT 32~63 */
#define EPDC_IRQ2_CLR_LUTN_CMPLT_IRQ_MASK        (0xFFFFFFFFU)
#define EPDC_IRQ2_CLR_LUTN_CMPLT_IRQ_SHIFT       (0U)
#define EPDC_IRQ2_CLR_LUTN_CMPLT_IRQ(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ2_CLR_LUTN_CMPLT_IRQ_SHIFT)) & EPDC_IRQ2_CLR_LUTN_CMPLT_IRQ_MASK)

/*! @name IRQ2_TOG - EPDC Interrupt Registerr for LUT 32~63 */
#define EPDC_IRQ2_TOG_LUTN_CMPLT_IRQ_MASK        (0xFFFFFFFFU)
#define EPDC_IRQ2_TOG_LUTN_CMPLT_IRQ_SHIFT       (0U)
#define EPDC_IRQ2_TOG_LUTN_CMPLT_IRQ(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_IRQ2_TOG_LUTN_CMPLT_IRQ_SHIFT)) & EPDC_IRQ2_TOG_LUTN_CMPLT_IRQ_MASK)

/*! @name IRQ_MASK - EPDC IRQ Mask Register */
#define EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN_MASK       (0x10000U)
#define EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN_SHIFT      (16U)
#define EPDC_IRQ_MASK_COL_IRQ_EN_MASK            (0x20000U)
#define EPDC_IRQ_MASK_COL_IRQ_EN_SHIFT           (17U)
#define EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN_MASK   (0x40000U)
#define EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN_SHIFT  (18U)
#define EPDC_IRQ_MASK_FRAME_END_IRQ_EN_MASK      (0x80000U)
#define EPDC_IRQ_MASK_FRAME_END_IRQ_EN_SHIFT     (19U)
#define EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN_MASK      (0x100000U)
#define EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN_SHIFT     (20U)
#define EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN_MASK       (0x200000U)
#define EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN_SHIFT      (21U)
#define EPDC_IRQ_MASK_UPD_DONE_IRQ_EN_MASK       (0x400000U)
#define EPDC_IRQ_MASK_UPD_DONE_IRQ_EN_SHIFT      (22U)
#define EPDC_IRQ_MASK_PWR_IRQ_EN_MASK            (0x800000U)
#define EPDC_IRQ_MASK_PWR_IRQ_EN_SHIFT           (23U)

/*! @name IRQ_MASK_SET - EPDC IRQ Mask Register */
#define EPDC_IRQ_MASK_SET_WB_CMPLT_IRQ_EN_MASK   (0x10000U)
#define EPDC_IRQ_MASK_SET_WB_CMPLT_IRQ_EN_SHIFT  (16U)
#define EPDC_IRQ_MASK_SET_COL_IRQ_EN_MASK        (0x20000U)
#define EPDC_IRQ_MASK_SET_COL_IRQ_EN_SHIFT       (17U)
#define EPDC_IRQ_MASK_SET_TCE_UNDERRUN_IRQ_EN_MASK (0x40000U)
#define EPDC_IRQ_MASK_SET_TCE_UNDERRUN_IRQ_EN_SHIFT (18U)
#define EPDC_IRQ_MASK_SET_FRAME_END_IRQ_EN_MASK  (0x80000U)
#define EPDC_IRQ_MASK_SET_FRAME_END_IRQ_EN_SHIFT (19U)
#define EPDC_IRQ_MASK_SET_BUS_ERROR_IRQ_EN_MASK  (0x100000U)
#define EPDC_IRQ_MASK_SET_BUS_ERROR_IRQ_EN_SHIFT (20U)
#define EPDC_IRQ_MASK_SET_TCE_IDLE_IRQ_EN_MASK   (0x200000U)
#define EPDC_IRQ_MASK_SET_TCE_IDLE_IRQ_EN_SHIFT  (21U)
#define EPDC_IRQ_MASK_SET_UPD_DONE_IRQ_EN_MASK   (0x400000U)
#define EPDC_IRQ_MASK_SET_UPD_DONE_IRQ_EN_SHIFT  (22U)
#define EPDC_IRQ_MASK_SET_PWR_IRQ_EN_MASK        (0x800000U)
#define EPDC_IRQ_MASK_SET_PWR_IRQ_EN_SHIFT       (23U)

/*! @name IRQ_MASK_CLR - EPDC IRQ Mask Register */
#define EPDC_IRQ_MASK_CLR_WB_CMPLT_IRQ_EN_MASK   (0x10000U)
#define EPDC_IRQ_MASK_CLR_WB_CMPLT_IRQ_EN_SHIFT  (16U)
#define EPDC_IRQ_MASK_CLR_COL_IRQ_EN_MASK        (0x20000U)
#define EPDC_IRQ_MASK_CLR_COL_IRQ_EN_SHIFT       (17U)
#define EPDC_IRQ_MASK_CLR_TCE_UNDERRUN_IRQ_EN_MASK (0x40000U)
#define EPDC_IRQ_MASK_CLR_TCE_UNDERRUN_IRQ_EN_SHIFT (18U)
#define EPDC_IRQ_MASK_CLR_FRAME_END_IRQ_EN_MASK  (0x80000U)
#define EPDC_IRQ_MASK_CLR_FRAME_END_IRQ_EN_SHIFT (19U)
#define EPDC_IRQ_MASK_CLR_BUS_ERROR_IRQ_EN_MASK  (0x100000U)
#define EPDC_IRQ_MASK_CLR_BUS_ERROR_IRQ_EN_SHIFT (20U)
#define EPDC_IRQ_MASK_CLR_TCE_IDLE_IRQ_EN_MASK   (0x200000U)
#define EPDC_IRQ_MASK_CLR_TCE_IDLE_IRQ_EN_SHIFT  (21U)
#define EPDC_IRQ_MASK_CLR_UPD_DONE_IRQ_EN_MASK   (0x400000U)
#define EPDC_IRQ_MASK_CLR_UPD_DONE_IRQ_EN_SHIFT  (22U)
#define EPDC_IRQ_MASK_CLR_PWR_IRQ_EN_MASK        (0x800000U)
#define EPDC_IRQ_MASK_CLR_PWR_IRQ_EN_SHIFT       (23U)

/*! @name IRQ_MASK_TOG - EPDC IRQ Mask Register */
#define EPDC_IRQ_MASK_TOG_WB_CMPLT_IRQ_EN_MASK   (0x10000U)
#define EPDC_IRQ_MASK_TOG_WB_CMPLT_IRQ_EN_SHIFT  (16U)
#define EPDC_IRQ_MASK_TOG_COL_IRQ_EN_MASK        (0x20000U)
#define EPDC_IRQ_MASK_TOG_COL_IRQ_EN_SHIFT       (17U)
#define EPDC_IRQ_MASK_TOG_TCE_UNDERRUN_IRQ_EN_MASK (0x40000U)
#define EPDC_IRQ_MASK_TOG_TCE_UNDERRUN_IRQ_EN_SHIFT (18U)
#define EPDC_IRQ_MASK_TOG_FRAME_END_IRQ_EN_MASK  (0x80000U)
#define EPDC_IRQ_MASK_TOG_FRAME_END_IRQ_EN_SHIFT (19U)
#define EPDC_IRQ_MASK_TOG_BUS_ERROR_IRQ_EN_MASK  (0x100000U)
#define EPDC_IRQ_MASK_TOG_BUS_ERROR_IRQ_EN_SHIFT (20U)
#define EPDC_IRQ_MASK_TOG_TCE_IDLE_IRQ_EN_MASK   (0x200000U)
#define EPDC_IRQ_MASK_TOG_TCE_IDLE_IRQ_EN_SHIFT  (21U)
#define EPDC_IRQ_MASK_TOG_UPD_DONE_IRQ_EN_MASK   (0x400000U)
#define EPDC_IRQ_MASK_TOG_UPD_DONE_IRQ_EN_SHIFT  (22U)
#define EPDC_IRQ_MASK_TOG_PWR_IRQ_EN_MASK        (0x800000U)
#define EPDC_IRQ_MASK_TOG_PWR_IRQ_EN_SHIFT       (23U)

/*! @name IRQ - EPDC Interrupt Register */
#define EPDC_IRQ_WB_CMPLT_IRQ_MASK               (0x10000U)
#define EPDC_IRQ_WB_CMPLT_IRQ_SHIFT              (16U)
#define EPDC_IRQ_LUT_COL_IRQ_MASK                (0x20000U)
#define EPDC_IRQ_LUT_COL_IRQ_SHIFT               (17U)
#define EPDC_IRQ_TCE_UNDERRUN_IRQ_MASK           (0x40000U)
#define EPDC_IRQ_TCE_UNDERRUN_IRQ_SHIFT          (18U)
#define EPDC_IRQ_FRAME_END_IRQ_MASK              (0x80000U)
#define EPDC_IRQ_FRAME_END_IRQ_SHIFT             (19U)
#define EPDC_IRQ_BUS_ERROR_IRQ_MASK              (0x100000U)
#define EPDC_IRQ_BUS_ERROR_IRQ_SHIFT             (20U)
#define EPDC_IRQ_TCE_IDLE_IRQ_MASK               (0x200000U)
#define EPDC_IRQ_TCE_IDLE_IRQ_SHIFT              (21U)
#define EPDC_IRQ_UPD_DONE_IRQ_MASK               (0x400000U)
#define EPDC_IRQ_UPD_DONE_IRQ_SHIFT              (22U)
#define EPDC_IRQ_PWR_IRQ_MASK                    (0x800000U)
#define EPDC_IRQ_PWR_IRQ_SHIFT                   (23U)

/*! @name IRQ_SET - EPDC Interrupt Register */
#define EPDC_IRQ_SET_WB_CMPLT_IRQ_MASK           (0x10000U)
#define EPDC_IRQ_SET_WB_CMPLT_IRQ_SHIFT          (16U)
#define EPDC_IRQ_SET_LUT_COL_IRQ_MASK            (0x20000U)
#define EPDC_IRQ_SET_LUT_COL_IRQ_SHIFT           (17U)
#define EPDC_IRQ_SET_TCE_UNDERRUN_IRQ_MASK       (0x40000U)
#define EPDC_IRQ_SET_TCE_UNDERRUN_IRQ_SHIFT      (18U)
#define EPDC_IRQ_SET_FRAME_END_IRQ_MASK          (0x80000U)
#define EPDC_IRQ_SET_FRAME_END_IRQ_SHIFT         (19U)
#define EPDC_IRQ_SET_BUS_ERROR_IRQ_MASK          (0x100000U)
#define EPDC_IRQ_SET_BUS_ERROR_IRQ_SHIFT         (20U)
#define EPDC_IRQ_SET_TCE_IDLE_IRQ_MASK           (0x200000U)
#define EPDC_IRQ_SET_TCE_IDLE_IRQ_SHIFT          (21U)
#define EPDC_IRQ_SET_UPD_DONE_IRQ_MASK           (0x400000U)
#define EPDC_IRQ_SET_UPD_DONE_IRQ_SHIFT          (22U)
#define EPDC_IRQ_SET_PWR_IRQ_MASK                (0x800000U)
#define EPDC_IRQ_SET_PWR_IRQ_SHIFT               (23U)

/*! @name IRQ_CLR - EPDC Interrupt Register */
#define EPDC_IRQ_CLR_WB_CMPLT_IRQ_MASK           (0x10000U)
#define EPDC_IRQ_CLR_WB_CMPLT_IRQ_SHIFT          (16U)
#define EPDC_IRQ_CLR_LUT_COL_IRQ_MASK            (0x20000U)
#define EPDC_IRQ_CLR_LUT_COL_IRQ_SHIFT           (17U)
#define EPDC_IRQ_CLR_TCE_UNDERRUN_IRQ_MASK       (0x40000U)
#define EPDC_IRQ_CLR_TCE_UNDERRUN_IRQ_SHIFT      (18U)
#define EPDC_IRQ_CLR_FRAME_END_IRQ_MASK          (0x80000U)
#define EPDC_IRQ_CLR_FRAME_END_IRQ_SHIFT         (19U)
#define EPDC_IRQ_CLR_BUS_ERROR_IRQ_MASK          (0x100000U)
#define EPDC_IRQ_CLR_BUS_ERROR_IRQ_SHIFT         (20U)
#define EPDC_IRQ_CLR_TCE_IDLE_IRQ_MASK           (0x200000U)
#define EPDC_IRQ_CLR_TCE_IDLE_IRQ_SHIFT          (21U)
#define EPDC_IRQ_CLR_UPD_DONE_IRQ_MASK           (0x400000U)
#define EPDC_IRQ_CLR_UPD_DONE_IRQ_SHIFT          (22U)
#define EPDC_IRQ_CLR_PWR_IRQ_MASK                (0x800000U)
#define EPDC_IRQ_CLR_PWR_IRQ_SHIFT               (23U)

/*! @name IRQ_TOG - EPDC Interrupt Register */
#define EPDC_IRQ_TOG_WB_CMPLT_IRQ_MASK           (0x10000U)
#define EPDC_IRQ_TOG_WB_CMPLT_IRQ_SHIFT          (16U)
#define EPDC_IRQ_TOG_LUT_COL_IRQ_MASK            (0x20000U)
#define EPDC_IRQ_TOG_LUT_COL_IRQ_SHIFT           (17U)
#define EPDC_IRQ_TOG_TCE_UNDERRUN_IRQ_MASK       (0x40000U)
#define EPDC_IRQ_TOG_TCE_UNDERRUN_IRQ_SHIFT      (18U)
#define EPDC_IRQ_TOG_FRAME_END_IRQ_MASK          (0x80000U)
#define EPDC_IRQ_TOG_FRAME_END_IRQ_SHIFT         (19U)
#define EPDC_IRQ_TOG_BUS_ERROR_IRQ_MASK          (0x100000U)
#define EPDC_IRQ_TOG_BUS_ERROR_IRQ_SHIFT         (20U)
#define EPDC_IRQ_TOG_TCE_IDLE_IRQ_MASK           (0x200000U)
#define EPDC_IRQ_TOG_TCE_IDLE_IRQ_SHIFT          (21U)
#define EPDC_IRQ_TOG_UPD_DONE_IRQ_MASK           (0x400000U)
#define EPDC_IRQ_TOG_UPD_DONE_IRQ_SHIFT          (22U)
#define EPDC_IRQ_TOG_PWR_IRQ_MASK                (0x800000U)
#define EPDC_IRQ_TOG_PWR_IRQ_SHIFT               (23U)

/*! @name STATUS_LUTS1 - EPDC Status Register - LUTs */
#define EPDC_STATUS_LUTS1_LUTN_STS_MASK          (0xFFFFFFFFU)
#define EPDC_STATUS_LUTS1_LUTN_STS_SHIFT         (0U)
#define EPDC_STATUS_LUTS1_LUTN_STS(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_LUTS1_LUTN_STS_SHIFT)) & EPDC_STATUS_LUTS1_LUTN_STS_MASK)

/*! @name STATUS_LUTS1_SET - EPDC Status Register - LUTs */
#define EPDC_STATUS_LUTS1_SET_LUTN_STS_MASK      (0xFFFFFFFFU)
#define EPDC_STATUS_LUTS1_SET_LUTN_STS_SHIFT     (0U)
#define EPDC_STATUS_LUTS1_SET_LUTN_STS(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_LUTS1_SET_LUTN_STS_SHIFT)) & EPDC_STATUS_LUTS1_SET_LUTN_STS_MASK)

/*! @name STATUS_LUTS1_CLR - EPDC Status Register - LUTs */
#define EPDC_STATUS_LUTS1_CLR_LUTN_STS_MASK      (0xFFFFFFFFU)
#define EPDC_STATUS_LUTS1_CLR_LUTN_STS_SHIFT     (0U)
#define EPDC_STATUS_LUTS1_CLR_LUTN_STS(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_LUTS1_CLR_LUTN_STS_SHIFT)) & EPDC_STATUS_LUTS1_CLR_LUTN_STS_MASK)

/*! @name STATUS_LUTS1_TOG - EPDC Status Register - LUTs */
#define EPDC_STATUS_LUTS1_TOG_LUTN_STS_MASK      (0xFFFFFFFFU)
#define EPDC_STATUS_LUTS1_TOG_LUTN_STS_SHIFT     (0U)
#define EPDC_STATUS_LUTS1_TOG_LUTN_STS(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_LUTS1_TOG_LUTN_STS_SHIFT)) & EPDC_STATUS_LUTS1_TOG_LUTN_STS_MASK)

/*! @name STATUS_LUTS2 - EPDC Status Register - LUTs */
#define EPDC_STATUS_LUTS2_LUTN_STS_MASK          (0xFFFFFFFFU)
#define EPDC_STATUS_LUTS2_LUTN_STS_SHIFT         (0U)
#define EPDC_STATUS_LUTS2_LUTN_STS(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_LUTS2_LUTN_STS_SHIFT)) & EPDC_STATUS_LUTS2_LUTN_STS_MASK)

/*! @name STATUS_LUTS2_SET - EPDC Status Register - LUTs */
#define EPDC_STATUS_LUTS2_SET_LUTN_STS_MASK      (0xFFFFFFFFU)
#define EPDC_STATUS_LUTS2_SET_LUTN_STS_SHIFT     (0U)
#define EPDC_STATUS_LUTS2_SET_LUTN_STS(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_LUTS2_SET_LUTN_STS_SHIFT)) & EPDC_STATUS_LUTS2_SET_LUTN_STS_MASK)

/*! @name STATUS_LUTS2_CLR - EPDC Status Register - LUTs */
#define EPDC_STATUS_LUTS2_CLR_LUTN_STS_MASK      (0xFFFFFFFFU)
#define EPDC_STATUS_LUTS2_CLR_LUTN_STS_SHIFT     (0U)
#define EPDC_STATUS_LUTS2_CLR_LUTN_STS(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_LUTS2_CLR_LUTN_STS_SHIFT)) & EPDC_STATUS_LUTS2_CLR_LUTN_STS_MASK)

/*! @name STATUS_LUTS2_TOG - EPDC Status Register - LUTs */
#define EPDC_STATUS_LUTS2_TOG_LUTN_STS_MASK      (0xFFFFFFFFU)
#define EPDC_STATUS_LUTS2_TOG_LUTN_STS_SHIFT     (0U)
#define EPDC_STATUS_LUTS2_TOG_LUTN_STS(x)        (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_LUTS2_TOG_LUTN_STS_SHIFT)) & EPDC_STATUS_LUTS2_TOG_LUTN_STS_MASK)

/*! @name STATUS_NEXTLUT - EPDC Status Register - Next Available LUT */
#define EPDC_STATUS_NEXTLUT_NEXT_LUT_MASK        (0x3FU)
#define EPDC_STATUS_NEXTLUT_NEXT_LUT_SHIFT       (0U)
#define EPDC_STATUS_NEXTLUT_NEXT_LUT(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_NEXTLUT_NEXT_LUT_SHIFT)) & EPDC_STATUS_NEXTLUT_NEXT_LUT_MASK)
#define EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID_MASK  (0x100U)
#define EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID_SHIFT (8U)

/*! @name STATUS_COL1 - EPDC LUT Collision Status */
#define EPDC_STATUS_COL1_LUTN_COL_STS_MASK       (0xFFFFFFFFU)
#define EPDC_STATUS_COL1_LUTN_COL_STS_SHIFT      (0U)
#define EPDC_STATUS_COL1_LUTN_COL_STS(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_COL1_LUTN_COL_STS_SHIFT)) & EPDC_STATUS_COL1_LUTN_COL_STS_MASK)

/*! @name STATUS_COL1_SET - EPDC LUT Collision Status */
#define EPDC_STATUS_COL1_SET_LUTN_COL_STS_MASK   (0xFFFFFFFFU)
#define EPDC_STATUS_COL1_SET_LUTN_COL_STS_SHIFT  (0U)
#define EPDC_STATUS_COL1_SET_LUTN_COL_STS(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_COL1_SET_LUTN_COL_STS_SHIFT)) & EPDC_STATUS_COL1_SET_LUTN_COL_STS_MASK)

/*! @name STATUS_COL1_CLR - EPDC LUT Collision Status */
#define EPDC_STATUS_COL1_CLR_LUTN_COL_STS_MASK   (0xFFFFFFFFU)
#define EPDC_STATUS_COL1_CLR_LUTN_COL_STS_SHIFT  (0U)
#define EPDC_STATUS_COL1_CLR_LUTN_COL_STS(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_COL1_CLR_LUTN_COL_STS_SHIFT)) & EPDC_STATUS_COL1_CLR_LUTN_COL_STS_MASK)

/*! @name STATUS_COL1_TOG - EPDC LUT Collision Status */
#define EPDC_STATUS_COL1_TOG_LUTN_COL_STS_MASK   (0xFFFFFFFFU)
#define EPDC_STATUS_COL1_TOG_LUTN_COL_STS_SHIFT  (0U)
#define EPDC_STATUS_COL1_TOG_LUTN_COL_STS(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_COL1_TOG_LUTN_COL_STS_SHIFT)) & EPDC_STATUS_COL1_TOG_LUTN_COL_STS_MASK)

/*! @name STATUS_COL2 - EPDC LUT Collision Status */
#define EPDC_STATUS_COL2_LUTN_COL_STS_MASK       (0xFFFFFFFFU)
#define EPDC_STATUS_COL2_LUTN_COL_STS_SHIFT      (0U)
#define EPDC_STATUS_COL2_LUTN_COL_STS(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_COL2_LUTN_COL_STS_SHIFT)) & EPDC_STATUS_COL2_LUTN_COL_STS_MASK)

/*! @name STATUS_COL2_SET - EPDC LUT Collision Status */
#define EPDC_STATUS_COL2_SET_LUTN_COL_STS_MASK   (0xFFFFFFFFU)
#define EPDC_STATUS_COL2_SET_LUTN_COL_STS_SHIFT  (0U)
#define EPDC_STATUS_COL2_SET_LUTN_COL_STS(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_COL2_SET_LUTN_COL_STS_SHIFT)) & EPDC_STATUS_COL2_SET_LUTN_COL_STS_MASK)

/*! @name STATUS_COL2_CLR - EPDC LUT Collision Status */
#define EPDC_STATUS_COL2_CLR_LUTN_COL_STS_MASK   (0xFFFFFFFFU)
#define EPDC_STATUS_COL2_CLR_LUTN_COL_STS_SHIFT  (0U)
#define EPDC_STATUS_COL2_CLR_LUTN_COL_STS(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_COL2_CLR_LUTN_COL_STS_SHIFT)) & EPDC_STATUS_COL2_CLR_LUTN_COL_STS_MASK)

/*! @name STATUS_COL2_TOG - EPDC LUT Collision Status */
#define EPDC_STATUS_COL2_TOG_LUTN_COL_STS_MASK   (0xFFFFFFFFU)
#define EPDC_STATUS_COL2_TOG_LUTN_COL_STS_SHIFT  (0U)
#define EPDC_STATUS_COL2_TOG_LUTN_COL_STS(x)     (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_COL2_TOG_LUTN_COL_STS_SHIFT)) & EPDC_STATUS_COL2_TOG_LUTN_COL_STS_MASK)

/*! @name STATUS - EPDC General Status Register */
#define EPDC_STATUS_WB_BUSY_MASK                 (0x1U)
#define EPDC_STATUS_WB_BUSY_SHIFT                (0U)
#define EPDC_STATUS_LUTS_BUSY_MASK               (0x2U)
#define EPDC_STATUS_LUTS_BUSY_SHIFT              (1U)
#define EPDC_STATUS_LUTS_UNDERRUN_MASK           (0x4U)
#define EPDC_STATUS_LUTS_UNDERRUN_SHIFT          (2U)
#define EPDC_STATUS_UPD_VOID_MASK                (0x8U)
#define EPDC_STATUS_UPD_VOID_SHIFT               (3U)
#define EPDC_STATUS_HISTOGRAM_NP_MASK            (0x1F00U)
#define EPDC_STATUS_HISTOGRAM_NP_SHIFT           (8U)
#define EPDC_STATUS_HISTOGRAM_NP(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_HISTOGRAM_NP_SHIFT)) & EPDC_STATUS_HISTOGRAM_NP_MASK)
#define EPDC_STATUS_HISTOGRAM_CP_MASK            (0x1F0000U)
#define EPDC_STATUS_HISTOGRAM_CP_SHIFT           (16U)
#define EPDC_STATUS_HISTOGRAM_CP(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_HISTOGRAM_CP_SHIFT)) & EPDC_STATUS_HISTOGRAM_CP_MASK)

/*! @name STATUS_SET - EPDC General Status Register */
#define EPDC_STATUS_SET_WB_BUSY_MASK             (0x1U)
#define EPDC_STATUS_SET_WB_BUSY_SHIFT            (0U)
#define EPDC_STATUS_SET_LUTS_BUSY_MASK           (0x2U)
#define EPDC_STATUS_SET_LUTS_BUSY_SHIFT          (1U)
#define EPDC_STATUS_SET_LUTS_UNDERRUN_MASK       (0x4U)
#define EPDC_STATUS_SET_LUTS_UNDERRUN_SHIFT      (2U)
#define EPDC_STATUS_SET_UPD_VOID_MASK            (0x8U)
#define EPDC_STATUS_SET_UPD_VOID_SHIFT           (3U)
#define EPDC_STATUS_SET_HISTOGRAM_NP_MASK        (0x1F00U)
#define EPDC_STATUS_SET_HISTOGRAM_NP_SHIFT       (8U)
#define EPDC_STATUS_SET_HISTOGRAM_NP(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_SET_HISTOGRAM_NP_SHIFT)) & EPDC_STATUS_SET_HISTOGRAM_NP_MASK)
#define EPDC_STATUS_SET_HISTOGRAM_CP_MASK        (0x1F0000U)
#define EPDC_STATUS_SET_HISTOGRAM_CP_SHIFT       (16U)
#define EPDC_STATUS_SET_HISTOGRAM_CP(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_SET_HISTOGRAM_CP_SHIFT)) & EPDC_STATUS_SET_HISTOGRAM_CP_MASK)

/*! @name STATUS_CLR - EPDC General Status Register */
#define EPDC_STATUS_CLR_WB_BUSY_MASK             (0x1U)
#define EPDC_STATUS_CLR_WB_BUSY_SHIFT            (0U)
#define EPDC_STATUS_CLR_LUTS_BUSY_MASK           (0x2U)
#define EPDC_STATUS_CLR_LUTS_BUSY_SHIFT          (1U)
#define EPDC_STATUS_CLR_LUTS_UNDERRUN_MASK       (0x4U)
#define EPDC_STATUS_CLR_LUTS_UNDERRUN_SHIFT      (2U)
#define EPDC_STATUS_CLR_UPD_VOID_MASK            (0x8U)
#define EPDC_STATUS_CLR_UPD_VOID_SHIFT           (3U)
#define EPDC_STATUS_CLR_HISTOGRAM_NP_MASK        (0x1F00U)
#define EPDC_STATUS_CLR_HISTOGRAM_NP_SHIFT       (8U)
#define EPDC_STATUS_CLR_HISTOGRAM_NP(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_CLR_HISTOGRAM_NP_SHIFT)) & EPDC_STATUS_CLR_HISTOGRAM_NP_MASK)
#define EPDC_STATUS_CLR_HISTOGRAM_CP_MASK        (0x1F0000U)
#define EPDC_STATUS_CLR_HISTOGRAM_CP_SHIFT       (16U)
#define EPDC_STATUS_CLR_HISTOGRAM_CP(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_CLR_HISTOGRAM_CP_SHIFT)) & EPDC_STATUS_CLR_HISTOGRAM_CP_MASK)

/*! @name STATUS_TOG - EPDC General Status Register */
#define EPDC_STATUS_TOG_WB_BUSY_MASK             (0x1U)
#define EPDC_STATUS_TOG_WB_BUSY_SHIFT            (0U)
#define EPDC_STATUS_TOG_LUTS_BUSY_MASK           (0x2U)
#define EPDC_STATUS_TOG_LUTS_BUSY_SHIFT          (1U)
#define EPDC_STATUS_TOG_LUTS_UNDERRUN_MASK       (0x4U)
#define EPDC_STATUS_TOG_LUTS_UNDERRUN_SHIFT      (2U)
#define EPDC_STATUS_TOG_UPD_VOID_MASK            (0x8U)
#define EPDC_STATUS_TOG_UPD_VOID_SHIFT           (3U)
#define EPDC_STATUS_TOG_HISTOGRAM_NP_MASK        (0x1F00U)
#define EPDC_STATUS_TOG_HISTOGRAM_NP_SHIFT       (8U)
#define EPDC_STATUS_TOG_HISTOGRAM_NP(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_TOG_HISTOGRAM_NP_SHIFT)) & EPDC_STATUS_TOG_HISTOGRAM_NP_MASK)
#define EPDC_STATUS_TOG_HISTOGRAM_CP_MASK        (0x1F0000U)
#define EPDC_STATUS_TOG_HISTOGRAM_CP_SHIFT       (16U)
#define EPDC_STATUS_TOG_HISTOGRAM_CP(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_STATUS_TOG_HISTOGRAM_CP_SHIFT)) & EPDC_STATUS_TOG_HISTOGRAM_CP_MASK)

/*! @name UPD_COL_CORD - EPDC Collision Region Co-ordinate */
#define EPDC_UPD_COL_CORD_XCORD_MASK             (0x1FFFU)
#define EPDC_UPD_COL_CORD_XCORD_SHIFT            (0U)
#define EPDC_UPD_COL_CORD_XCORD(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_COL_CORD_XCORD_SHIFT)) & EPDC_UPD_COL_CORD_XCORD_MASK)
#define EPDC_UPD_COL_CORD_YCORD_MASK             (0x1FFF0000U)
#define EPDC_UPD_COL_CORD_YCORD_SHIFT            (16U)
#define EPDC_UPD_COL_CORD_YCORD(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_COL_CORD_YCORD_SHIFT)) & EPDC_UPD_COL_CORD_YCORD_MASK)

/*! @name UPD_COL_SIZE - EPDC Collision Region Size */
#define EPDC_UPD_COL_SIZE_WIDTH_MASK             (0x1FFFU)
#define EPDC_UPD_COL_SIZE_WIDTH_SHIFT            (0U)
#define EPDC_UPD_COL_SIZE_WIDTH(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_COL_SIZE_WIDTH_SHIFT)) & EPDC_UPD_COL_SIZE_WIDTH_MASK)
#define EPDC_UPD_COL_SIZE_HEIGHT_MASK            (0x1FFF0000U)
#define EPDC_UPD_COL_SIZE_HEIGHT_SHIFT           (16U)
#define EPDC_UPD_COL_SIZE_HEIGHT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_UPD_COL_SIZE_HEIGHT_SHIFT)) & EPDC_UPD_COL_SIZE_HEIGHT_MASK)

/*! @name HIST1_PARAM - 1-level Histogram Parameter Register. */
#define EPDC_HIST1_PARAM_VALUE0_MASK             (0x1FU)
#define EPDC_HIST1_PARAM_VALUE0_SHIFT            (0U)
#define EPDC_HIST1_PARAM_VALUE0(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_HIST1_PARAM_VALUE0_SHIFT)) & EPDC_HIST1_PARAM_VALUE0_MASK)
#define EPDC_HIST1_PARAM_RSVD_MASK               (0xFFFFFFE0U)
#define EPDC_HIST1_PARAM_RSVD_SHIFT              (5U)
#define EPDC_HIST1_PARAM_RSVD(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_HIST1_PARAM_RSVD_SHIFT)) & EPDC_HIST1_PARAM_RSVD_MASK)

/*! @name HIST2_PARAM - 2-level Histogram Parameter Register. */
#define EPDC_HIST2_PARAM_VALUE0_MASK             (0x1FU)
#define EPDC_HIST2_PARAM_VALUE0_SHIFT            (0U)
#define EPDC_HIST2_PARAM_VALUE0(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_HIST2_PARAM_VALUE0_SHIFT)) & EPDC_HIST2_PARAM_VALUE0_MASK)
#define EPDC_HIST2_PARAM_VALUE1_MASK             (0x1F00U)
#define EPDC_HIST2_PARAM_VALUE1_SHIFT            (8U)
#define EPDC_HIST2_PARAM_VALUE1(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_HIST2_PARAM_VALUE1_SHIFT)) & EPDC_HIST2_PARAM_VALUE1_MASK)
#define EPDC_HIST2_PARAM_RSVD_MASK               (0xFFFF0000U)
#define EPDC_HIST2_PARAM_RSVD_SHIFT              (16U)
#define EPDC_HIST2_PARAM_RSVD(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_HIST2_PARAM_RSVD_SHIFT)) & EPDC_HIST2_PARAM_RSVD_MASK)

/*! @name HIST4_PARAM - 4-level Histogram Parameter Register. */
#define EPDC_HIST4_PARAM_VALUE0_MASK             (0x1FU)
#define EPDC_HIST4_PARAM_VALUE0_SHIFT            (0U)
#define EPDC_HIST4_PARAM_VALUE0(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_HIST4_PARAM_VALUE0_SHIFT)) & EPDC_HIST4_PARAM_VALUE0_MASK)
#define EPDC_HIST4_PARAM_VALUE1_MASK             (0x1F00U)
#define EPDC_HIST4_PARAM_VALUE1_SHIFT            (8U)
#define EPDC_HIST4_PARAM_VALUE1(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_HIST4_PARAM_VALUE1_SHIFT)) & EPDC_HIST4_PARAM_VALUE1_MASK)
#define EPDC_HIST4_PARAM_VALUE2_MASK             (0x1F0000U)
#define EPDC_HIST4_PARAM_VALUE2_SHIFT            (16U)
#define EPDC_HIST4_PARAM_VALUE2(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_HIST4_PARAM_VALUE2_SHIFT)) & EPDC_HIST4_PARAM_VALUE2_MASK)
#define EPDC_HIST4_PARAM_VALUE3_MASK             (0x1F000000U)
#define EPDC_HIST4_PARAM_VALUE3_SHIFT            (24U)
#define EPDC_HIST4_PARAM_VALUE3(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_HIST4_PARAM_VALUE3_SHIFT)) & EPDC_HIST4_PARAM_VALUE3_MASK)

/*! @name HIST8_PARAM0 - 8-level Histogram Parameter 0 Register. */
#define EPDC_HIST8_PARAM0_VALUE0_MASK            (0x1FU)
#define EPDC_HIST8_PARAM0_VALUE0_SHIFT           (0U)
#define EPDC_HIST8_PARAM0_VALUE0(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_HIST8_PARAM0_VALUE0_SHIFT)) & EPDC_HIST8_PARAM0_VALUE0_MASK)
#define EPDC_HIST8_PARAM0_VALUE1_MASK            (0x1F00U)
#define EPDC_HIST8_PARAM0_VALUE1_SHIFT           (8U)
#define EPDC_HIST8_PARAM0_VALUE1(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_HIST8_PARAM0_VALUE1_SHIFT)) & EPDC_HIST8_PARAM0_VALUE1_MASK)
#define EPDC_HIST8_PARAM0_VALUE2_MASK            (0x1F0000U)
#define EPDC_HIST8_PARAM0_VALUE2_SHIFT           (16U)
#define EPDC_HIST8_PARAM0_VALUE2(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_HIST8_PARAM0_VALUE2_SHIFT)) & EPDC_HIST8_PARAM0_VALUE2_MASK)
#define EPDC_HIST8_PARAM0_VALUE3_MASK            (0x1F000000U)
#define EPDC_HIST8_PARAM0_VALUE3_SHIFT           (24U)
#define EPDC_HIST8_PARAM0_VALUE3(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_HIST8_PARAM0_VALUE3_SHIFT)) & EPDC_HIST8_PARAM0_VALUE3_MASK)

/*! @name HIST8_PARAM1 - 8-level Histogram Parameter 1 Register. */
#define EPDC_HIST8_PARAM1_VALUE4_MASK            (0x1FU)
#define EPDC_HIST8_PARAM1_VALUE4_SHIFT           (0U)
#define EPDC_HIST8_PARAM1_VALUE4(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_HIST8_PARAM1_VALUE4_SHIFT)) & EPDC_HIST8_PARAM1_VALUE4_MASK)
#define EPDC_HIST8_PARAM1_VALUE5_MASK            (0x1F00U)
#define EPDC_HIST8_PARAM1_VALUE5_SHIFT           (8U)
#define EPDC_HIST8_PARAM1_VALUE5(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_HIST8_PARAM1_VALUE5_SHIFT)) & EPDC_HIST8_PARAM1_VALUE5_MASK)
#define EPDC_HIST8_PARAM1_VALUE6_MASK            (0x1F0000U)
#define EPDC_HIST8_PARAM1_VALUE6_SHIFT           (16U)
#define EPDC_HIST8_PARAM1_VALUE6(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_HIST8_PARAM1_VALUE6_SHIFT)) & EPDC_HIST8_PARAM1_VALUE6_MASK)
#define EPDC_HIST8_PARAM1_VALUE7_MASK            (0x1F000000U)
#define EPDC_HIST8_PARAM1_VALUE7_SHIFT           (24U)
#define EPDC_HIST8_PARAM1_VALUE7(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_HIST8_PARAM1_VALUE7_SHIFT)) & EPDC_HIST8_PARAM1_VALUE7_MASK)

/*! @name HIST16_PARAM0 - 16-level Histogram Parameter 0 Register. */
#define EPDC_HIST16_PARAM0_VALUE0_MASK           (0x1FU)
#define EPDC_HIST16_PARAM0_VALUE0_SHIFT          (0U)
#define EPDC_HIST16_PARAM0_VALUE0(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM0_VALUE0_SHIFT)) & EPDC_HIST16_PARAM0_VALUE0_MASK)
#define EPDC_HIST16_PARAM0_VALUE1_MASK           (0x1F00U)
#define EPDC_HIST16_PARAM0_VALUE1_SHIFT          (8U)
#define EPDC_HIST16_PARAM0_VALUE1(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM0_VALUE1_SHIFT)) & EPDC_HIST16_PARAM0_VALUE1_MASK)
#define EPDC_HIST16_PARAM0_VALUE2_MASK           (0x1F0000U)
#define EPDC_HIST16_PARAM0_VALUE2_SHIFT          (16U)
#define EPDC_HIST16_PARAM0_VALUE2(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM0_VALUE2_SHIFT)) & EPDC_HIST16_PARAM0_VALUE2_MASK)
#define EPDC_HIST16_PARAM0_VALUE3_MASK           (0x1F000000U)
#define EPDC_HIST16_PARAM0_VALUE3_SHIFT          (24U)
#define EPDC_HIST16_PARAM0_VALUE3(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM0_VALUE3_SHIFT)) & EPDC_HIST16_PARAM0_VALUE3_MASK)

/*! @name HIST16_PARAM1 - 16-level Histogram Parameter Register. */
#define EPDC_HIST16_PARAM1_VALUE4_MASK           (0x1FU)
#define EPDC_HIST16_PARAM1_VALUE4_SHIFT          (0U)
#define EPDC_HIST16_PARAM1_VALUE4(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM1_VALUE4_SHIFT)) & EPDC_HIST16_PARAM1_VALUE4_MASK)
#define EPDC_HIST16_PARAM1_VALUE5_MASK           (0x1F00U)
#define EPDC_HIST16_PARAM1_VALUE5_SHIFT          (8U)
#define EPDC_HIST16_PARAM1_VALUE5(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM1_VALUE5_SHIFT)) & EPDC_HIST16_PARAM1_VALUE5_MASK)
#define EPDC_HIST16_PARAM1_VALUE6_MASK           (0x1F0000U)
#define EPDC_HIST16_PARAM1_VALUE6_SHIFT          (16U)
#define EPDC_HIST16_PARAM1_VALUE6(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM1_VALUE6_SHIFT)) & EPDC_HIST16_PARAM1_VALUE6_MASK)
#define EPDC_HIST16_PARAM1_VALUE7_MASK           (0x1F000000U)
#define EPDC_HIST16_PARAM1_VALUE7_SHIFT          (24U)
#define EPDC_HIST16_PARAM1_VALUE7(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM1_VALUE7_SHIFT)) & EPDC_HIST16_PARAM1_VALUE7_MASK)

/*! @name HIST16_PARAM2 - 16-level Histogram Parameter Register. */
#define EPDC_HIST16_PARAM2_VALUE8_MASK           (0x1FU)
#define EPDC_HIST16_PARAM2_VALUE8_SHIFT          (0U)
#define EPDC_HIST16_PARAM2_VALUE8(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM2_VALUE8_SHIFT)) & EPDC_HIST16_PARAM2_VALUE8_MASK)
#define EPDC_HIST16_PARAM2_VALUE9_MASK           (0x1F00U)
#define EPDC_HIST16_PARAM2_VALUE9_SHIFT          (8U)
#define EPDC_HIST16_PARAM2_VALUE9(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM2_VALUE9_SHIFT)) & EPDC_HIST16_PARAM2_VALUE9_MASK)
#define EPDC_HIST16_PARAM2_VALUE10_MASK          (0x1F0000U)
#define EPDC_HIST16_PARAM2_VALUE10_SHIFT         (16U)
#define EPDC_HIST16_PARAM2_VALUE10(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM2_VALUE10_SHIFT)) & EPDC_HIST16_PARAM2_VALUE10_MASK)
#define EPDC_HIST16_PARAM2_VALUE11_MASK          (0x1F000000U)
#define EPDC_HIST16_PARAM2_VALUE11_SHIFT         (24U)
#define EPDC_HIST16_PARAM2_VALUE11(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM2_VALUE11_SHIFT)) & EPDC_HIST16_PARAM2_VALUE11_MASK)

/*! @name HIST16_PARAM3 - 16-level Histogram Parameter Register. */
#define EPDC_HIST16_PARAM3_VALUE12_MASK          (0x1FU)
#define EPDC_HIST16_PARAM3_VALUE12_SHIFT         (0U)
#define EPDC_HIST16_PARAM3_VALUE12(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM3_VALUE12_SHIFT)) & EPDC_HIST16_PARAM3_VALUE12_MASK)
#define EPDC_HIST16_PARAM3_VALUE13_MASK          (0x1F00U)
#define EPDC_HIST16_PARAM3_VALUE13_SHIFT         (8U)
#define EPDC_HIST16_PARAM3_VALUE13(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM3_VALUE13_SHIFT)) & EPDC_HIST16_PARAM3_VALUE13_MASK)
#define EPDC_HIST16_PARAM3_VALUE14_MASK          (0x1F0000U)
#define EPDC_HIST16_PARAM3_VALUE14_SHIFT         (16U)
#define EPDC_HIST16_PARAM3_VALUE14(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM3_VALUE14_SHIFT)) & EPDC_HIST16_PARAM3_VALUE14_MASK)
#define EPDC_HIST16_PARAM3_VALUE15_MASK          (0x1F000000U)
#define EPDC_HIST16_PARAM3_VALUE15_SHIFT         (24U)
#define EPDC_HIST16_PARAM3_VALUE15(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_HIST16_PARAM3_VALUE15_SHIFT)) & EPDC_HIST16_PARAM3_VALUE15_MASK)

/*! @name GPIO - EPDC General Purpose I/O Debug register */
#define EPDC_GPIO_BDR_MASK                       (0x3U)
#define EPDC_GPIO_BDR_SHIFT                      (0U)
#define EPDC_GPIO_BDR(x)                         (((uint32_t)(((uint32_t)(x)) << EPDC_GPIO_BDR_SHIFT)) & EPDC_GPIO_BDR_MASK)
#define EPDC_GPIO_PWRCTRL_MASK                   (0x3CU)
#define EPDC_GPIO_PWRCTRL_SHIFT                  (2U)
#define EPDC_GPIO_PWRCTRL(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_GPIO_PWRCTRL_SHIFT)) & EPDC_GPIO_PWRCTRL_MASK)
#define EPDC_GPIO_PWRCOM_MASK                    (0x40U)
#define EPDC_GPIO_PWRCOM_SHIFT                   (6U)
#define EPDC_GPIO_PWRWAKE_MASK                   (0x80U)
#define EPDC_GPIO_PWRWAKE_SHIFT                  (7U)
#define EPDC_GPIO_PWRSTAT_MASK                   (0x100U)
#define EPDC_GPIO_PWRSTAT_SHIFT                  (8U)

/*! @name GPIO_SET - EPDC General Purpose I/O Debug register */
#define EPDC_GPIO_SET_BDR_MASK                   (0x3U)
#define EPDC_GPIO_SET_BDR_SHIFT                  (0U)
#define EPDC_GPIO_SET_BDR(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_GPIO_SET_BDR_SHIFT)) & EPDC_GPIO_SET_BDR_MASK)
#define EPDC_GPIO_SET_PWRCTRL_MASK               (0x3CU)
#define EPDC_GPIO_SET_PWRCTRL_SHIFT              (2U)
#define EPDC_GPIO_SET_PWRCTRL(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_GPIO_SET_PWRCTRL_SHIFT)) & EPDC_GPIO_SET_PWRCTRL_MASK)
#define EPDC_GPIO_SET_PWRCOM_MASK                (0x40U)
#define EPDC_GPIO_SET_PWRCOM_SHIFT               (6U)
#define EPDC_GPIO_SET_PWRWAKE_MASK               (0x80U)
#define EPDC_GPIO_SET_PWRWAKE_SHIFT              (7U)
#define EPDC_GPIO_SET_PWRSTAT_MASK               (0x100U)
#define EPDC_GPIO_SET_PWRSTAT_SHIFT              (8U)

/*! @name GPIO_CLR - EPDC General Purpose I/O Debug register */
#define EPDC_GPIO_CLR_BDR_MASK                   (0x3U)
#define EPDC_GPIO_CLR_BDR_SHIFT                  (0U)
#define EPDC_GPIO_CLR_BDR(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_GPIO_CLR_BDR_SHIFT)) & EPDC_GPIO_CLR_BDR_MASK)
#define EPDC_GPIO_CLR_PWRCTRL_MASK               (0x3CU)
#define EPDC_GPIO_CLR_PWRCTRL_SHIFT              (2U)
#define EPDC_GPIO_CLR_PWRCTRL(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_GPIO_CLR_PWRCTRL_SHIFT)) & EPDC_GPIO_CLR_PWRCTRL_MASK)
#define EPDC_GPIO_CLR_PWRCOM_MASK                (0x40U)
#define EPDC_GPIO_CLR_PWRCOM_SHIFT               (6U)
#define EPDC_GPIO_CLR_PWRWAKE_MASK               (0x80U)
#define EPDC_GPIO_CLR_PWRWAKE_SHIFT              (7U)
#define EPDC_GPIO_CLR_PWRSTAT_MASK               (0x100U)
#define EPDC_GPIO_CLR_PWRSTAT_SHIFT              (8U)

/*! @name GPIO_TOG - EPDC General Purpose I/O Debug register */
#define EPDC_GPIO_TOG_BDR_MASK                   (0x3U)
#define EPDC_GPIO_TOG_BDR_SHIFT                  (0U)
#define EPDC_GPIO_TOG_BDR(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_GPIO_TOG_BDR_SHIFT)) & EPDC_GPIO_TOG_BDR_MASK)
#define EPDC_GPIO_TOG_PWRCTRL_MASK               (0x3CU)
#define EPDC_GPIO_TOG_PWRCTRL_SHIFT              (2U)
#define EPDC_GPIO_TOG_PWRCTRL(x)                 (((uint32_t)(((uint32_t)(x)) << EPDC_GPIO_TOG_PWRCTRL_SHIFT)) & EPDC_GPIO_TOG_PWRCTRL_MASK)
#define EPDC_GPIO_TOG_PWRCOM_MASK                (0x40U)
#define EPDC_GPIO_TOG_PWRCOM_SHIFT               (6U)
#define EPDC_GPIO_TOG_PWRWAKE_MASK               (0x80U)
#define EPDC_GPIO_TOG_PWRWAKE_SHIFT              (7U)
#define EPDC_GPIO_TOG_PWRSTAT_MASK               (0x100U)
#define EPDC_GPIO_TOG_PWRSTAT_SHIFT              (8U)

/*! @name VERSION - EPDC Version Register */
#define EPDC_VERSION_STEP_MASK                   (0xFFFFU)
#define EPDC_VERSION_STEP_SHIFT                  (0U)
#define EPDC_VERSION_STEP(x)                     (((uint32_t)(((uint32_t)(x)) << EPDC_VERSION_STEP_SHIFT)) & EPDC_VERSION_STEP_MASK)
#define EPDC_VERSION_MINOR_MASK                  (0xFF0000U)
#define EPDC_VERSION_MINOR_SHIFT                 (16U)
#define EPDC_VERSION_MINOR(x)                    (((uint32_t)(((uint32_t)(x)) << EPDC_VERSION_MINOR_SHIFT)) & EPDC_VERSION_MINOR_MASK)
#define EPDC_VERSION_MAJOR_MASK                  (0xFF000000U)
#define EPDC_VERSION_MAJOR_SHIFT                 (24U)
#define EPDC_VERSION_MAJOR(x)                    (((uint32_t)(((uint32_t)(x)) << EPDC_VERSION_MAJOR_SHIFT)) & EPDC_VERSION_MAJOR_MASK)

/*! @name PIGEON_0_0 - Panel Interface Signal Generator Register 0_0 */
#define EPDC_PIGEON_0_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_0_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_0_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_0_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_0_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_0_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_0_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_0_INC_SEL_SHIFT)) & EPDC_PIGEON_0_0_INC_SEL_MASK)
#define EPDC_PIGEON_0_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_0_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_0_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_0_OFFSET_SHIFT)) & EPDC_PIGEON_0_0_OFFSET_MASK)
#define EPDC_PIGEON_0_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_0_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_0_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_0_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_0_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_0_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_0_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_0_0_MASK_CNT_MASK)
#define EPDC_PIGEON_0_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_0_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_0_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_0_0_STATE_MASK_MASK)

/*! @name PIGEON_0_1 - Panel Interface Signal Generator Register 0_1 */
#define EPDC_PIGEON_0_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_0_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_0_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_1_SET_CNT_SHIFT)) & EPDC_PIGEON_0_1_SET_CNT_MASK)
#define EPDC_PIGEON_0_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_0_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_0_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_0_1_CLR_CNT_MASK)

/*! @name PIGEON_0_2 - Panel Interface Signal Generator Register 0_1 */
#define EPDC_PIGEON_0_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_0_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_0_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_0_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_0_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_0_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_0_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_0_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_0_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_1_0 - Panel Interface Signal Generator Register 1_0 */
#define EPDC_PIGEON_1_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_1_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_1_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_1_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_1_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_1_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_1_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_0_INC_SEL_SHIFT)) & EPDC_PIGEON_1_0_INC_SEL_MASK)
#define EPDC_PIGEON_1_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_1_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_1_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_0_OFFSET_SHIFT)) & EPDC_PIGEON_1_0_OFFSET_MASK)
#define EPDC_PIGEON_1_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_1_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_1_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_1_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_1_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_1_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_1_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_1_0_MASK_CNT_MASK)
#define EPDC_PIGEON_1_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_1_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_1_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_1_0_STATE_MASK_MASK)

/*! @name PIGEON_1_1 - Panel Interface Signal Generator Register 1_1 */
#define EPDC_PIGEON_1_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_1_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_1_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_1_SET_CNT_SHIFT)) & EPDC_PIGEON_1_1_SET_CNT_MASK)
#define EPDC_PIGEON_1_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_1_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_1_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_1_1_CLR_CNT_MASK)

/*! @name PIGEON_1_2 - Panel Interface Signal Generator Register 1_1 */
#define EPDC_PIGEON_1_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_1_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_1_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_1_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_1_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_1_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_1_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_1_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_1_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_2_0 - Panel Interface Signal Generator Register 2_0 */
#define EPDC_PIGEON_2_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_2_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_2_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_2_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_2_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_2_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_2_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_0_INC_SEL_SHIFT)) & EPDC_PIGEON_2_0_INC_SEL_MASK)
#define EPDC_PIGEON_2_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_2_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_2_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_0_OFFSET_SHIFT)) & EPDC_PIGEON_2_0_OFFSET_MASK)
#define EPDC_PIGEON_2_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_2_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_2_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_2_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_2_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_2_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_2_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_2_0_MASK_CNT_MASK)
#define EPDC_PIGEON_2_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_2_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_2_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_2_0_STATE_MASK_MASK)

/*! @name PIGEON_2_1 - Panel Interface Signal Generator Register 2_1 */
#define EPDC_PIGEON_2_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_2_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_2_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_1_SET_CNT_SHIFT)) & EPDC_PIGEON_2_1_SET_CNT_MASK)
#define EPDC_PIGEON_2_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_2_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_2_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_2_1_CLR_CNT_MASK)

/*! @name PIGEON_2_2 - Panel Interface Signal Generator Register 2_1 */
#define EPDC_PIGEON_2_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_2_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_2_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_2_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_2_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_2_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_2_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_2_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_2_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_3_0 - Panel Interface Signal Generator Register 3_0 */
#define EPDC_PIGEON_3_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_3_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_3_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_3_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_3_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_3_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_3_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_0_INC_SEL_SHIFT)) & EPDC_PIGEON_3_0_INC_SEL_MASK)
#define EPDC_PIGEON_3_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_3_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_3_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_0_OFFSET_SHIFT)) & EPDC_PIGEON_3_0_OFFSET_MASK)
#define EPDC_PIGEON_3_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_3_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_3_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_3_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_3_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_3_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_3_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_3_0_MASK_CNT_MASK)
#define EPDC_PIGEON_3_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_3_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_3_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_3_0_STATE_MASK_MASK)

/*! @name PIGEON_3_1 - Panel Interface Signal Generator Register 3_1 */
#define EPDC_PIGEON_3_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_3_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_3_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_1_SET_CNT_SHIFT)) & EPDC_PIGEON_3_1_SET_CNT_MASK)
#define EPDC_PIGEON_3_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_3_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_3_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_3_1_CLR_CNT_MASK)

/*! @name PIGEON_3_2 - Panel Interface Signal Generator Register 3_1 */
#define EPDC_PIGEON_3_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_3_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_3_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_3_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_3_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_3_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_3_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_3_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_3_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_4_0 - Panel Interface Signal Generator Register 4_0 */
#define EPDC_PIGEON_4_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_4_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_4_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_4_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_4_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_4_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_4_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_0_INC_SEL_SHIFT)) & EPDC_PIGEON_4_0_INC_SEL_MASK)
#define EPDC_PIGEON_4_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_4_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_4_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_0_OFFSET_SHIFT)) & EPDC_PIGEON_4_0_OFFSET_MASK)
#define EPDC_PIGEON_4_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_4_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_4_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_4_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_4_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_4_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_4_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_4_0_MASK_CNT_MASK)
#define EPDC_PIGEON_4_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_4_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_4_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_4_0_STATE_MASK_MASK)

/*! @name PIGEON_4_1 - Panel Interface Signal Generator Register 4_1 */
#define EPDC_PIGEON_4_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_4_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_4_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_1_SET_CNT_SHIFT)) & EPDC_PIGEON_4_1_SET_CNT_MASK)
#define EPDC_PIGEON_4_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_4_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_4_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_4_1_CLR_CNT_MASK)

/*! @name PIGEON_4_2 - Panel Interface Signal Generator Register 4_1 */
#define EPDC_PIGEON_4_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_4_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_4_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_4_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_4_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_4_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_4_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_4_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_4_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_5_0 - Panel Interface Signal Generator Register 5_0 */
#define EPDC_PIGEON_5_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_5_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_5_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_5_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_5_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_5_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_5_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_0_INC_SEL_SHIFT)) & EPDC_PIGEON_5_0_INC_SEL_MASK)
#define EPDC_PIGEON_5_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_5_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_5_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_0_OFFSET_SHIFT)) & EPDC_PIGEON_5_0_OFFSET_MASK)
#define EPDC_PIGEON_5_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_5_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_5_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_5_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_5_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_5_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_5_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_5_0_MASK_CNT_MASK)
#define EPDC_PIGEON_5_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_5_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_5_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_5_0_STATE_MASK_MASK)

/*! @name PIGEON_5_1 - Panel Interface Signal Generator Register 5_1 */
#define EPDC_PIGEON_5_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_5_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_5_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_1_SET_CNT_SHIFT)) & EPDC_PIGEON_5_1_SET_CNT_MASK)
#define EPDC_PIGEON_5_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_5_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_5_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_5_1_CLR_CNT_MASK)

/*! @name PIGEON_5_2 - Panel Interface Signal Generator Register 5_1 */
#define EPDC_PIGEON_5_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_5_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_5_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_5_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_5_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_5_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_5_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_5_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_5_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_6_0 - Panel Interface Signal Generator Register 6_0 */
#define EPDC_PIGEON_6_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_6_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_6_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_6_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_6_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_6_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_6_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_0_INC_SEL_SHIFT)) & EPDC_PIGEON_6_0_INC_SEL_MASK)
#define EPDC_PIGEON_6_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_6_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_6_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_0_OFFSET_SHIFT)) & EPDC_PIGEON_6_0_OFFSET_MASK)
#define EPDC_PIGEON_6_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_6_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_6_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_6_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_6_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_6_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_6_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_6_0_MASK_CNT_MASK)
#define EPDC_PIGEON_6_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_6_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_6_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_6_0_STATE_MASK_MASK)

/*! @name PIGEON_6_1 - Panel Interface Signal Generator Register 6_1 */
#define EPDC_PIGEON_6_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_6_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_6_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_1_SET_CNT_SHIFT)) & EPDC_PIGEON_6_1_SET_CNT_MASK)
#define EPDC_PIGEON_6_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_6_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_6_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_6_1_CLR_CNT_MASK)

/*! @name PIGEON_6_2 - Panel Interface Signal Generator Register 6_1 */
#define EPDC_PIGEON_6_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_6_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_6_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_6_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_6_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_6_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_6_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_6_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_6_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_7_0 - Panel Interface Signal Generator Register 7_0 */
#define EPDC_PIGEON_7_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_7_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_7_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_7_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_7_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_7_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_7_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_0_INC_SEL_SHIFT)) & EPDC_PIGEON_7_0_INC_SEL_MASK)
#define EPDC_PIGEON_7_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_7_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_7_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_0_OFFSET_SHIFT)) & EPDC_PIGEON_7_0_OFFSET_MASK)
#define EPDC_PIGEON_7_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_7_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_7_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_7_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_7_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_7_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_7_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_7_0_MASK_CNT_MASK)
#define EPDC_PIGEON_7_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_7_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_7_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_7_0_STATE_MASK_MASK)

/*! @name PIGEON_7_1 - Panel Interface Signal Generator Register 7_1 */
#define EPDC_PIGEON_7_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_7_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_7_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_1_SET_CNT_SHIFT)) & EPDC_PIGEON_7_1_SET_CNT_MASK)
#define EPDC_PIGEON_7_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_7_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_7_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_7_1_CLR_CNT_MASK)

/*! @name PIGEON_7_2 - Panel Interface Signal Generator Register 7_1 */
#define EPDC_PIGEON_7_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_7_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_7_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_7_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_7_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_7_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_7_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_7_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_7_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_8_0 - Panel Interface Signal Generator Register 8_0 */
#define EPDC_PIGEON_8_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_8_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_8_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_8_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_8_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_8_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_8_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_0_INC_SEL_SHIFT)) & EPDC_PIGEON_8_0_INC_SEL_MASK)
#define EPDC_PIGEON_8_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_8_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_8_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_0_OFFSET_SHIFT)) & EPDC_PIGEON_8_0_OFFSET_MASK)
#define EPDC_PIGEON_8_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_8_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_8_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_8_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_8_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_8_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_8_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_8_0_MASK_CNT_MASK)
#define EPDC_PIGEON_8_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_8_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_8_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_8_0_STATE_MASK_MASK)

/*! @name PIGEON_8_1 - Panel Interface Signal Generator Register 8_1 */
#define EPDC_PIGEON_8_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_8_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_8_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_1_SET_CNT_SHIFT)) & EPDC_PIGEON_8_1_SET_CNT_MASK)
#define EPDC_PIGEON_8_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_8_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_8_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_8_1_CLR_CNT_MASK)

/*! @name PIGEON_8_2 - Panel Interface Signal Generator Register 8_1 */
#define EPDC_PIGEON_8_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_8_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_8_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_8_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_8_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_8_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_8_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_8_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_8_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_9_0 - Panel Interface Signal Generator Register 9_0 */
#define EPDC_PIGEON_9_0_EN_MASK                  (0x1U)
#define EPDC_PIGEON_9_0_EN_SHIFT                 (0U)
#define EPDC_PIGEON_9_0_POL_MASK                 (0x2U)
#define EPDC_PIGEON_9_0_POL_SHIFT                (1U)
#define EPDC_PIGEON_9_0_INC_SEL_MASK             (0xCU)
#define EPDC_PIGEON_9_0_INC_SEL_SHIFT            (2U)
#define EPDC_PIGEON_9_0_INC_SEL(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_0_INC_SEL_SHIFT)) & EPDC_PIGEON_9_0_INC_SEL_MASK)
#define EPDC_PIGEON_9_0_OFFSET_MASK              (0xF0U)
#define EPDC_PIGEON_9_0_OFFSET_SHIFT             (4U)
#define EPDC_PIGEON_9_0_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_0_OFFSET_SHIFT)) & EPDC_PIGEON_9_0_OFFSET_MASK)
#define EPDC_PIGEON_9_0_MASK_CNT_SEL_MASK        (0xF00U)
#define EPDC_PIGEON_9_0_MASK_CNT_SEL_SHIFT       (8U)
#define EPDC_PIGEON_9_0_MASK_CNT_SEL(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_9_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_9_0_MASK_CNT_MASK            (0xFFF000U)
#define EPDC_PIGEON_9_0_MASK_CNT_SHIFT           (12U)
#define EPDC_PIGEON_9_0_MASK_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_9_0_MASK_CNT_MASK)
#define EPDC_PIGEON_9_0_STATE_MASK_MASK          (0xFF000000U)
#define EPDC_PIGEON_9_0_STATE_MASK_SHIFT         (24U)
#define EPDC_PIGEON_9_0_STATE_MASK(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_9_0_STATE_MASK_MASK)

/*! @name PIGEON_9_1 - Panel Interface Signal Generator Register 9_1 */
#define EPDC_PIGEON_9_1_SET_CNT_MASK             (0xFFFFU)
#define EPDC_PIGEON_9_1_SET_CNT_SHIFT            (0U)
#define EPDC_PIGEON_9_1_SET_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_1_SET_CNT_SHIFT)) & EPDC_PIGEON_9_1_SET_CNT_MASK)
#define EPDC_PIGEON_9_1_CLR_CNT_MASK             (0xFFFF0000U)
#define EPDC_PIGEON_9_1_CLR_CNT_SHIFT            (16U)
#define EPDC_PIGEON_9_1_CLR_CNT(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_9_1_CLR_CNT_MASK)

/*! @name PIGEON_9_2 - Panel Interface Signal Generator Register 9_1 */
#define EPDC_PIGEON_9_2_SIG_LOGIC_MASK           (0xFU)
#define EPDC_PIGEON_9_2_SIG_LOGIC_SHIFT          (0U)
#define EPDC_PIGEON_9_2_SIG_LOGIC(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_9_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_9_2_SIG_ANOTHER_MASK         (0x1F0U)
#define EPDC_PIGEON_9_2_SIG_ANOTHER_SHIFT        (4U)
#define EPDC_PIGEON_9_2_SIG_ANOTHER(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_9_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_9_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_10_0 - Panel Interface Signal Generator Register 10_0 */
#define EPDC_PIGEON_10_0_EN_MASK                 (0x1U)
#define EPDC_PIGEON_10_0_EN_SHIFT                (0U)
#define EPDC_PIGEON_10_0_POL_MASK                (0x2U)
#define EPDC_PIGEON_10_0_POL_SHIFT               (1U)
#define EPDC_PIGEON_10_0_INC_SEL_MASK            (0xCU)
#define EPDC_PIGEON_10_0_INC_SEL_SHIFT           (2U)
#define EPDC_PIGEON_10_0_INC_SEL(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_0_INC_SEL_SHIFT)) & EPDC_PIGEON_10_0_INC_SEL_MASK)
#define EPDC_PIGEON_10_0_OFFSET_MASK             (0xF0U)
#define EPDC_PIGEON_10_0_OFFSET_SHIFT            (4U)
#define EPDC_PIGEON_10_0_OFFSET(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_0_OFFSET_SHIFT)) & EPDC_PIGEON_10_0_OFFSET_MASK)
#define EPDC_PIGEON_10_0_MASK_CNT_SEL_MASK       (0xF00U)
#define EPDC_PIGEON_10_0_MASK_CNT_SEL_SHIFT      (8U)
#define EPDC_PIGEON_10_0_MASK_CNT_SEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_10_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_10_0_MASK_CNT_MASK           (0xFFF000U)
#define EPDC_PIGEON_10_0_MASK_CNT_SHIFT          (12U)
#define EPDC_PIGEON_10_0_MASK_CNT(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_10_0_MASK_CNT_MASK)
#define EPDC_PIGEON_10_0_STATE_MASK_MASK         (0xFF000000U)
#define EPDC_PIGEON_10_0_STATE_MASK_SHIFT        (24U)
#define EPDC_PIGEON_10_0_STATE_MASK(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_10_0_STATE_MASK_MASK)

/*! @name PIGEON_10_1 - Panel Interface Signal Generator Register 10_1 */
#define EPDC_PIGEON_10_1_SET_CNT_MASK            (0xFFFFU)
#define EPDC_PIGEON_10_1_SET_CNT_SHIFT           (0U)
#define EPDC_PIGEON_10_1_SET_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_1_SET_CNT_SHIFT)) & EPDC_PIGEON_10_1_SET_CNT_MASK)
#define EPDC_PIGEON_10_1_CLR_CNT_MASK            (0xFFFF0000U)
#define EPDC_PIGEON_10_1_CLR_CNT_SHIFT           (16U)
#define EPDC_PIGEON_10_1_CLR_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_10_1_CLR_CNT_MASK)

/*! @name PIGEON_10_2 - Panel Interface Signal Generator Register 10_1 */
#define EPDC_PIGEON_10_2_SIG_LOGIC_MASK          (0xFU)
#define EPDC_PIGEON_10_2_SIG_LOGIC_SHIFT         (0U)
#define EPDC_PIGEON_10_2_SIG_LOGIC(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_10_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_10_2_SIG_ANOTHER_MASK        (0x1F0U)
#define EPDC_PIGEON_10_2_SIG_ANOTHER_SHIFT       (4U)
#define EPDC_PIGEON_10_2_SIG_ANOTHER(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_10_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_10_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_11_0 - Panel Interface Signal Generator Register 11_0 */
#define EPDC_PIGEON_11_0_EN_MASK                 (0x1U)
#define EPDC_PIGEON_11_0_EN_SHIFT                (0U)
#define EPDC_PIGEON_11_0_POL_MASK                (0x2U)
#define EPDC_PIGEON_11_0_POL_SHIFT               (1U)
#define EPDC_PIGEON_11_0_INC_SEL_MASK            (0xCU)
#define EPDC_PIGEON_11_0_INC_SEL_SHIFT           (2U)
#define EPDC_PIGEON_11_0_INC_SEL(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_0_INC_SEL_SHIFT)) & EPDC_PIGEON_11_0_INC_SEL_MASK)
#define EPDC_PIGEON_11_0_OFFSET_MASK             (0xF0U)
#define EPDC_PIGEON_11_0_OFFSET_SHIFT            (4U)
#define EPDC_PIGEON_11_0_OFFSET(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_0_OFFSET_SHIFT)) & EPDC_PIGEON_11_0_OFFSET_MASK)
#define EPDC_PIGEON_11_0_MASK_CNT_SEL_MASK       (0xF00U)
#define EPDC_PIGEON_11_0_MASK_CNT_SEL_SHIFT      (8U)
#define EPDC_PIGEON_11_0_MASK_CNT_SEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_11_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_11_0_MASK_CNT_MASK           (0xFFF000U)
#define EPDC_PIGEON_11_0_MASK_CNT_SHIFT          (12U)
#define EPDC_PIGEON_11_0_MASK_CNT(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_11_0_MASK_CNT_MASK)
#define EPDC_PIGEON_11_0_STATE_MASK_MASK         (0xFF000000U)
#define EPDC_PIGEON_11_0_STATE_MASK_SHIFT        (24U)
#define EPDC_PIGEON_11_0_STATE_MASK(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_11_0_STATE_MASK_MASK)

/*! @name PIGEON_11_1 - Panel Interface Signal Generator Register 11_1 */
#define EPDC_PIGEON_11_1_SET_CNT_MASK            (0xFFFFU)
#define EPDC_PIGEON_11_1_SET_CNT_SHIFT           (0U)
#define EPDC_PIGEON_11_1_SET_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_1_SET_CNT_SHIFT)) & EPDC_PIGEON_11_1_SET_CNT_MASK)
#define EPDC_PIGEON_11_1_CLR_CNT_MASK            (0xFFFF0000U)
#define EPDC_PIGEON_11_1_CLR_CNT_SHIFT           (16U)
#define EPDC_PIGEON_11_1_CLR_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_11_1_CLR_CNT_MASK)

/*! @name PIGEON_11_2 - Panel Interface Signal Generator Register 11_1 */
#define EPDC_PIGEON_11_2_SIG_LOGIC_MASK          (0xFU)
#define EPDC_PIGEON_11_2_SIG_LOGIC_SHIFT         (0U)
#define EPDC_PIGEON_11_2_SIG_LOGIC(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_11_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_11_2_SIG_ANOTHER_MASK        (0x1F0U)
#define EPDC_PIGEON_11_2_SIG_ANOTHER_SHIFT       (4U)
#define EPDC_PIGEON_11_2_SIG_ANOTHER(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_11_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_11_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_12_0 - Panel Interface Signal Generator Register 12_0 */
#define EPDC_PIGEON_12_0_EN_MASK                 (0x1U)
#define EPDC_PIGEON_12_0_EN_SHIFT                (0U)
#define EPDC_PIGEON_12_0_POL_MASK                (0x2U)
#define EPDC_PIGEON_12_0_POL_SHIFT               (1U)
#define EPDC_PIGEON_12_0_INC_SEL_MASK            (0xCU)
#define EPDC_PIGEON_12_0_INC_SEL_SHIFT           (2U)
#define EPDC_PIGEON_12_0_INC_SEL(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_0_INC_SEL_SHIFT)) & EPDC_PIGEON_12_0_INC_SEL_MASK)
#define EPDC_PIGEON_12_0_OFFSET_MASK             (0xF0U)
#define EPDC_PIGEON_12_0_OFFSET_SHIFT            (4U)
#define EPDC_PIGEON_12_0_OFFSET(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_0_OFFSET_SHIFT)) & EPDC_PIGEON_12_0_OFFSET_MASK)
#define EPDC_PIGEON_12_0_MASK_CNT_SEL_MASK       (0xF00U)
#define EPDC_PIGEON_12_0_MASK_CNT_SEL_SHIFT      (8U)
#define EPDC_PIGEON_12_0_MASK_CNT_SEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_12_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_12_0_MASK_CNT_MASK           (0xFFF000U)
#define EPDC_PIGEON_12_0_MASK_CNT_SHIFT          (12U)
#define EPDC_PIGEON_12_0_MASK_CNT(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_12_0_MASK_CNT_MASK)
#define EPDC_PIGEON_12_0_STATE_MASK_MASK         (0xFF000000U)
#define EPDC_PIGEON_12_0_STATE_MASK_SHIFT        (24U)
#define EPDC_PIGEON_12_0_STATE_MASK(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_12_0_STATE_MASK_MASK)

/*! @name PIGEON_12_1 - Panel Interface Signal Generator Register 12_1 */
#define EPDC_PIGEON_12_1_SET_CNT_MASK            (0xFFFFU)
#define EPDC_PIGEON_12_1_SET_CNT_SHIFT           (0U)
#define EPDC_PIGEON_12_1_SET_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_1_SET_CNT_SHIFT)) & EPDC_PIGEON_12_1_SET_CNT_MASK)
#define EPDC_PIGEON_12_1_CLR_CNT_MASK            (0xFFFF0000U)
#define EPDC_PIGEON_12_1_CLR_CNT_SHIFT           (16U)
#define EPDC_PIGEON_12_1_CLR_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_12_1_CLR_CNT_MASK)

/*! @name PIGEON_12_2 - Panel Interface Signal Generator Register 12_1 */
#define EPDC_PIGEON_12_2_SIG_LOGIC_MASK          (0xFU)
#define EPDC_PIGEON_12_2_SIG_LOGIC_SHIFT         (0U)
#define EPDC_PIGEON_12_2_SIG_LOGIC(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_12_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_12_2_SIG_ANOTHER_MASK        (0x1F0U)
#define EPDC_PIGEON_12_2_SIG_ANOTHER_SHIFT       (4U)
#define EPDC_PIGEON_12_2_SIG_ANOTHER(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_12_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_12_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_13_0 - Panel Interface Signal Generator Register 13_0 */
#define EPDC_PIGEON_13_0_EN_MASK                 (0x1U)
#define EPDC_PIGEON_13_0_EN_SHIFT                (0U)
#define EPDC_PIGEON_13_0_POL_MASK                (0x2U)
#define EPDC_PIGEON_13_0_POL_SHIFT               (1U)
#define EPDC_PIGEON_13_0_INC_SEL_MASK            (0xCU)
#define EPDC_PIGEON_13_0_INC_SEL_SHIFT           (2U)
#define EPDC_PIGEON_13_0_INC_SEL(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_0_INC_SEL_SHIFT)) & EPDC_PIGEON_13_0_INC_SEL_MASK)
#define EPDC_PIGEON_13_0_OFFSET_MASK             (0xF0U)
#define EPDC_PIGEON_13_0_OFFSET_SHIFT            (4U)
#define EPDC_PIGEON_13_0_OFFSET(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_0_OFFSET_SHIFT)) & EPDC_PIGEON_13_0_OFFSET_MASK)
#define EPDC_PIGEON_13_0_MASK_CNT_SEL_MASK       (0xF00U)
#define EPDC_PIGEON_13_0_MASK_CNT_SEL_SHIFT      (8U)
#define EPDC_PIGEON_13_0_MASK_CNT_SEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_13_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_13_0_MASK_CNT_MASK           (0xFFF000U)
#define EPDC_PIGEON_13_0_MASK_CNT_SHIFT          (12U)
#define EPDC_PIGEON_13_0_MASK_CNT(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_13_0_MASK_CNT_MASK)
#define EPDC_PIGEON_13_0_STATE_MASK_MASK         (0xFF000000U)
#define EPDC_PIGEON_13_0_STATE_MASK_SHIFT        (24U)
#define EPDC_PIGEON_13_0_STATE_MASK(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_13_0_STATE_MASK_MASK)

/*! @name PIGEON_13_1 - Panel Interface Signal Generator Register 13_1 */
#define EPDC_PIGEON_13_1_SET_CNT_MASK            (0xFFFFU)
#define EPDC_PIGEON_13_1_SET_CNT_SHIFT           (0U)
#define EPDC_PIGEON_13_1_SET_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_1_SET_CNT_SHIFT)) & EPDC_PIGEON_13_1_SET_CNT_MASK)
#define EPDC_PIGEON_13_1_CLR_CNT_MASK            (0xFFFF0000U)
#define EPDC_PIGEON_13_1_CLR_CNT_SHIFT           (16U)
#define EPDC_PIGEON_13_1_CLR_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_13_1_CLR_CNT_MASK)

/*! @name PIGEON_13_2 - Panel Interface Signal Generator Register 13_1 */
#define EPDC_PIGEON_13_2_SIG_LOGIC_MASK          (0xFU)
#define EPDC_PIGEON_13_2_SIG_LOGIC_SHIFT         (0U)
#define EPDC_PIGEON_13_2_SIG_LOGIC(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_13_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_13_2_SIG_ANOTHER_MASK        (0x1F0U)
#define EPDC_PIGEON_13_2_SIG_ANOTHER_SHIFT       (4U)
#define EPDC_PIGEON_13_2_SIG_ANOTHER(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_13_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_13_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_14_0 - Panel Interface Signal Generator Register 14_0 */
#define EPDC_PIGEON_14_0_EN_MASK                 (0x1U)
#define EPDC_PIGEON_14_0_EN_SHIFT                (0U)
#define EPDC_PIGEON_14_0_POL_MASK                (0x2U)
#define EPDC_PIGEON_14_0_POL_SHIFT               (1U)
#define EPDC_PIGEON_14_0_INC_SEL_MASK            (0xCU)
#define EPDC_PIGEON_14_0_INC_SEL_SHIFT           (2U)
#define EPDC_PIGEON_14_0_INC_SEL(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_0_INC_SEL_SHIFT)) & EPDC_PIGEON_14_0_INC_SEL_MASK)
#define EPDC_PIGEON_14_0_OFFSET_MASK             (0xF0U)
#define EPDC_PIGEON_14_0_OFFSET_SHIFT            (4U)
#define EPDC_PIGEON_14_0_OFFSET(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_0_OFFSET_SHIFT)) & EPDC_PIGEON_14_0_OFFSET_MASK)
#define EPDC_PIGEON_14_0_MASK_CNT_SEL_MASK       (0xF00U)
#define EPDC_PIGEON_14_0_MASK_CNT_SEL_SHIFT      (8U)
#define EPDC_PIGEON_14_0_MASK_CNT_SEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_14_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_14_0_MASK_CNT_MASK           (0xFFF000U)
#define EPDC_PIGEON_14_0_MASK_CNT_SHIFT          (12U)
#define EPDC_PIGEON_14_0_MASK_CNT(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_14_0_MASK_CNT_MASK)
#define EPDC_PIGEON_14_0_STATE_MASK_MASK         (0xFF000000U)
#define EPDC_PIGEON_14_0_STATE_MASK_SHIFT        (24U)
#define EPDC_PIGEON_14_0_STATE_MASK(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_14_0_STATE_MASK_MASK)

/*! @name PIGEON_14_1 - Panel Interface Signal Generator Register 14_1 */
#define EPDC_PIGEON_14_1_SET_CNT_MASK            (0xFFFFU)
#define EPDC_PIGEON_14_1_SET_CNT_SHIFT           (0U)
#define EPDC_PIGEON_14_1_SET_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_1_SET_CNT_SHIFT)) & EPDC_PIGEON_14_1_SET_CNT_MASK)
#define EPDC_PIGEON_14_1_CLR_CNT_MASK            (0xFFFF0000U)
#define EPDC_PIGEON_14_1_CLR_CNT_SHIFT           (16U)
#define EPDC_PIGEON_14_1_CLR_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_14_1_CLR_CNT_MASK)

/*! @name PIGEON_14_2 - Panel Interface Signal Generator Register 14_1 */
#define EPDC_PIGEON_14_2_SIG_LOGIC_MASK          (0xFU)
#define EPDC_PIGEON_14_2_SIG_LOGIC_SHIFT         (0U)
#define EPDC_PIGEON_14_2_SIG_LOGIC(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_14_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_14_2_SIG_ANOTHER_MASK        (0x1F0U)
#define EPDC_PIGEON_14_2_SIG_ANOTHER_SHIFT       (4U)
#define EPDC_PIGEON_14_2_SIG_ANOTHER(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_14_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_14_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_15_0 - Panel Interface Signal Generator Register 15_0 */
#define EPDC_PIGEON_15_0_EN_MASK                 (0x1U)
#define EPDC_PIGEON_15_0_EN_SHIFT                (0U)
#define EPDC_PIGEON_15_0_POL_MASK                (0x2U)
#define EPDC_PIGEON_15_0_POL_SHIFT               (1U)
#define EPDC_PIGEON_15_0_INC_SEL_MASK            (0xCU)
#define EPDC_PIGEON_15_0_INC_SEL_SHIFT           (2U)
#define EPDC_PIGEON_15_0_INC_SEL(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_0_INC_SEL_SHIFT)) & EPDC_PIGEON_15_0_INC_SEL_MASK)
#define EPDC_PIGEON_15_0_OFFSET_MASK             (0xF0U)
#define EPDC_PIGEON_15_0_OFFSET_SHIFT            (4U)
#define EPDC_PIGEON_15_0_OFFSET(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_0_OFFSET_SHIFT)) & EPDC_PIGEON_15_0_OFFSET_MASK)
#define EPDC_PIGEON_15_0_MASK_CNT_SEL_MASK       (0xF00U)
#define EPDC_PIGEON_15_0_MASK_CNT_SEL_SHIFT      (8U)
#define EPDC_PIGEON_15_0_MASK_CNT_SEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_15_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_15_0_MASK_CNT_MASK           (0xFFF000U)
#define EPDC_PIGEON_15_0_MASK_CNT_SHIFT          (12U)
#define EPDC_PIGEON_15_0_MASK_CNT(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_15_0_MASK_CNT_MASK)
#define EPDC_PIGEON_15_0_STATE_MASK_MASK         (0xFF000000U)
#define EPDC_PIGEON_15_0_STATE_MASK_SHIFT        (24U)
#define EPDC_PIGEON_15_0_STATE_MASK(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_15_0_STATE_MASK_MASK)

/*! @name PIGEON_15_1 - Panel Interface Signal Generator Register 15_1 */
#define EPDC_PIGEON_15_1_SET_CNT_MASK            (0xFFFFU)
#define EPDC_PIGEON_15_1_SET_CNT_SHIFT           (0U)
#define EPDC_PIGEON_15_1_SET_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_1_SET_CNT_SHIFT)) & EPDC_PIGEON_15_1_SET_CNT_MASK)
#define EPDC_PIGEON_15_1_CLR_CNT_MASK            (0xFFFF0000U)
#define EPDC_PIGEON_15_1_CLR_CNT_SHIFT           (16U)
#define EPDC_PIGEON_15_1_CLR_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_15_1_CLR_CNT_MASK)

/*! @name PIGEON_15_2 - Panel Interface Signal Generator Register 15_1 */
#define EPDC_PIGEON_15_2_SIG_LOGIC_MASK          (0xFU)
#define EPDC_PIGEON_15_2_SIG_LOGIC_SHIFT         (0U)
#define EPDC_PIGEON_15_2_SIG_LOGIC(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_15_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_15_2_SIG_ANOTHER_MASK        (0x1F0U)
#define EPDC_PIGEON_15_2_SIG_ANOTHER_SHIFT       (4U)
#define EPDC_PIGEON_15_2_SIG_ANOTHER(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_15_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_15_2_SIG_ANOTHER_MASK)

/*! @name PIGEON_16_0 - Panel Interface Signal Generator Register 16_0 */
#define EPDC_PIGEON_16_0_EN_MASK                 (0x1U)
#define EPDC_PIGEON_16_0_EN_SHIFT                (0U)
#define EPDC_PIGEON_16_0_POL_MASK                (0x2U)
#define EPDC_PIGEON_16_0_POL_SHIFT               (1U)
#define EPDC_PIGEON_16_0_INC_SEL_MASK            (0xCU)
#define EPDC_PIGEON_16_0_INC_SEL_SHIFT           (2U)
#define EPDC_PIGEON_16_0_INC_SEL(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_0_INC_SEL_SHIFT)) & EPDC_PIGEON_16_0_INC_SEL_MASK)
#define EPDC_PIGEON_16_0_OFFSET_MASK             (0xF0U)
#define EPDC_PIGEON_16_0_OFFSET_SHIFT            (4U)
#define EPDC_PIGEON_16_0_OFFSET(x)               (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_0_OFFSET_SHIFT)) & EPDC_PIGEON_16_0_OFFSET_MASK)
#define EPDC_PIGEON_16_0_MASK_CNT_SEL_MASK       (0xF00U)
#define EPDC_PIGEON_16_0_MASK_CNT_SEL_SHIFT      (8U)
#define EPDC_PIGEON_16_0_MASK_CNT_SEL(x)         (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_0_MASK_CNT_SEL_SHIFT)) & EPDC_PIGEON_16_0_MASK_CNT_SEL_MASK)
#define EPDC_PIGEON_16_0_MASK_CNT_MASK           (0xFFF000U)
#define EPDC_PIGEON_16_0_MASK_CNT_SHIFT          (12U)
#define EPDC_PIGEON_16_0_MASK_CNT(x)             (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_0_MASK_CNT_SHIFT)) & EPDC_PIGEON_16_0_MASK_CNT_MASK)
#define EPDC_PIGEON_16_0_STATE_MASK_MASK         (0xFF000000U)
#define EPDC_PIGEON_16_0_STATE_MASK_SHIFT        (24U)
#define EPDC_PIGEON_16_0_STATE_MASK(x)           (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_0_STATE_MASK_SHIFT)) & EPDC_PIGEON_16_0_STATE_MASK_MASK)

/*! @name PIGEON_16_1 - Panel Interface Signal Generator Register 16_1 */
#define EPDC_PIGEON_16_1_SET_CNT_MASK            (0xFFFFU)
#define EPDC_PIGEON_16_1_SET_CNT_SHIFT           (0U)
#define EPDC_PIGEON_16_1_SET_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_1_SET_CNT_SHIFT)) & EPDC_PIGEON_16_1_SET_CNT_MASK)
#define EPDC_PIGEON_16_1_CLR_CNT_MASK            (0xFFFF0000U)
#define EPDC_PIGEON_16_1_CLR_CNT_SHIFT           (16U)
#define EPDC_PIGEON_16_1_CLR_CNT(x)              (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_1_CLR_CNT_SHIFT)) & EPDC_PIGEON_16_1_CLR_CNT_MASK)

/*! @name PIGEON_16_2 - Panel Interface Signal Generator Register 16_1 */
#define EPDC_PIGEON_16_2_SIG_LOGIC_MASK          (0xFU)
#define EPDC_PIGEON_16_2_SIG_LOGIC_SHIFT         (0U)
#define EPDC_PIGEON_16_2_SIG_LOGIC(x)            (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_2_SIG_LOGIC_SHIFT)) & EPDC_PIGEON_16_2_SIG_LOGIC_MASK)
#define EPDC_PIGEON_16_2_SIG_ANOTHER_MASK        (0x1F0U)
#define EPDC_PIGEON_16_2_SIG_ANOTHER_SHIFT       (4U)
#define EPDC_PIGEON_16_2_SIG_ANOTHER(x)          (((uint32_t)(((uint32_t)(x)) << EPDC_PIGEON_16_2_SIG_ANOTHER_SHIFT)) & EPDC_PIGEON_16_2_SIG_ANOTHER_MASK)


/*!
 * @}
 */ /* end of group EPDC_Register_Masks */


/* EPDC - Peripheral instance base addresses */
/** Peripheral EPDC base pointer */
#define EPDC_BASE_PTR                            ((EPDC_MemMapPtr)0x306F0000u)
/** Array initializer of EPDC peripheral base pointers */
#define EPDC_BASE_PTRS                           { EPDC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- EPDC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup EPDC_Register_Accessor_Macros EPDC - Register accessor macros
 * @{
 */


/* EPDC - Register instance definitions */
/* EPDC */
#define EPDC_CTRL                                EPDC_CTRL_REG(EPDC_BASE_PTR)
#define EPDC_CTRL_SET                            EPDC_CTRL_SET_REG(EPDC_BASE_PTR)
#define EPDC_CTRL_CLR                            EPDC_CTRL_CLR_REG(EPDC_BASE_PTR)
#define EPDC_CTRL_TOG                            EPDC_CTRL_TOG_REG(EPDC_BASE_PTR)
#define EPDC_WB_ADDR_TCE                         EPDC_WB_ADDR_TCE_REG(EPDC_BASE_PTR)
#define EPDC_WVADDR                              EPDC_WVADDR_REG(EPDC_BASE_PTR)
#define EPDC_WB_ADDR                             EPDC_WB_ADDR_REG(EPDC_BASE_PTR)
#define EPDC_RES                                 EPDC_RES_REG(EPDC_BASE_PTR)
#define EPDC_FORMAT                              EPDC_FORMAT_REG(EPDC_BASE_PTR)
#define EPDC_FORMAT_SET                          EPDC_FORMAT_SET_REG(EPDC_BASE_PTR)
#define EPDC_FORMAT_CLR                          EPDC_FORMAT_CLR_REG(EPDC_BASE_PTR)
#define EPDC_FORMAT_TOG                          EPDC_FORMAT_TOG_REG(EPDC_BASE_PTR)
#define EPDC_WB_FIELD0                           EPDC_WB_FIELD0_REG(EPDC_BASE_PTR)
#define EPDC_WB_FIELD1                           EPDC_WB_FIELD1_REG(EPDC_BASE_PTR)
#define EPDC_WB_FIELD2                           EPDC_WB_FIELD2_REG(EPDC_BASE_PTR)
#define EPDC_WB_FIELD3                           EPDC_WB_FIELD3_REG(EPDC_BASE_PTR)
#define EPDC_FIFOCTRL                            EPDC_FIFOCTRL_REG(EPDC_BASE_PTR)
#define EPDC_FIFOCTRL_SET                        EPDC_FIFOCTRL_SET_REG(EPDC_BASE_PTR)
#define EPDC_FIFOCTRL_CLR                        EPDC_FIFOCTRL_CLR_REG(EPDC_BASE_PTR)
#define EPDC_FIFOCTRL_TOG                        EPDC_FIFOCTRL_TOG_REG(EPDC_BASE_PTR)
#define EPDC_UPD_ADDR                            EPDC_UPD_ADDR_REG(EPDC_BASE_PTR)
#define EPDC_UPD_STRIDE                          EPDC_UPD_STRIDE_REG(EPDC_BASE_PTR)
#define EPDC_UPD_CORD                            EPDC_UPD_CORD_REG(EPDC_BASE_PTR)
#define EPDC_UPD_SIZE                            EPDC_UPD_SIZE_REG(EPDC_BASE_PTR)
#define EPDC_UPD_CTRL                            EPDC_UPD_CTRL_REG(EPDC_BASE_PTR)
#define EPDC_UPD_CTRL_SET                        EPDC_UPD_CTRL_SET_REG(EPDC_BASE_PTR)
#define EPDC_UPD_CTRL_CLR                        EPDC_UPD_CTRL_CLR_REG(EPDC_BASE_PTR)
#define EPDC_UPD_CTRL_TOG                        EPDC_UPD_CTRL_TOG_REG(EPDC_BASE_PTR)
#define EPDC_UPD_FIXED                           EPDC_UPD_FIXED_REG(EPDC_BASE_PTR)
#define EPDC_UPD_FIXED_SET                       EPDC_UPD_FIXED_SET_REG(EPDC_BASE_PTR)
#define EPDC_UPD_FIXED_CLR                       EPDC_UPD_FIXED_CLR_REG(EPDC_BASE_PTR)
#define EPDC_UPD_FIXED_TOG                       EPDC_UPD_FIXED_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TEMP                                EPDC_TEMP_REG(EPDC_BASE_PTR)
#define EPDC_AUTOWV_LUT                          EPDC_AUTOWV_LUT_REG(EPDC_BASE_PTR)
#define EPDC_LUT_STANDBY1                        EPDC_LUT_STANDBY1_REG(EPDC_BASE_PTR)
#define EPDC_LUT_STANDBY1_SET                    EPDC_LUT_STANDBY1_SET_REG(EPDC_BASE_PTR)
#define EPDC_LUT_STANDBY1_CLR                    EPDC_LUT_STANDBY1_CLR_REG(EPDC_BASE_PTR)
#define EPDC_LUT_STANDBY1_TOG                    EPDC_LUT_STANDBY1_TOG_REG(EPDC_BASE_PTR)
#define EPDC_LUT_STANDBY2                        EPDC_LUT_STANDBY2_REG(EPDC_BASE_PTR)
#define EPDC_LUT_STANDBY2_SET                    EPDC_LUT_STANDBY2_SET_REG(EPDC_BASE_PTR)
#define EPDC_LUT_STANDBY2_CLR                    EPDC_LUT_STANDBY2_CLR_REG(EPDC_BASE_PTR)
#define EPDC_LUT_STANDBY2_TOG                    EPDC_LUT_STANDBY2_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_CTRL                            EPDC_TCE_CTRL_REG(EPDC_BASE_PTR)
#define EPDC_TCE_CTRL_SET                        EPDC_TCE_CTRL_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_CTRL_CLR                        EPDC_TCE_CTRL_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_CTRL_TOG                        EPDC_TCE_CTRL_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_SDCFG                           EPDC_TCE_SDCFG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_SDCFG_SET                       EPDC_TCE_SDCFG_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_SDCFG_CLR                       EPDC_TCE_SDCFG_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_SDCFG_TOG                       EPDC_TCE_SDCFG_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_GDCFG                           EPDC_TCE_GDCFG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_GDCFG_SET                       EPDC_TCE_GDCFG_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_GDCFG_CLR                       EPDC_TCE_GDCFG_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_GDCFG_TOG                       EPDC_TCE_GDCFG_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_HSCAN1                          EPDC_TCE_HSCAN1_REG(EPDC_BASE_PTR)
#define EPDC_TCE_HSCAN1_SET                      EPDC_TCE_HSCAN1_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_HSCAN1_CLR                      EPDC_TCE_HSCAN1_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_HSCAN1_TOG                      EPDC_TCE_HSCAN1_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_HSCAN2                          EPDC_TCE_HSCAN2_REG(EPDC_BASE_PTR)
#define EPDC_TCE_HSCAN2_SET                      EPDC_TCE_HSCAN2_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_HSCAN2_CLR                      EPDC_TCE_HSCAN2_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_HSCAN2_TOG                      EPDC_TCE_HSCAN2_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_VSCAN                           EPDC_TCE_VSCAN_REG(EPDC_BASE_PTR)
#define EPDC_TCE_VSCAN_SET                       EPDC_TCE_VSCAN_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_VSCAN_CLR                       EPDC_TCE_VSCAN_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_VSCAN_TOG                       EPDC_TCE_VSCAN_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_OE                              EPDC_TCE_OE_REG(EPDC_BASE_PTR)
#define EPDC_TCE_OE_SET                          EPDC_TCE_OE_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_OE_CLR                          EPDC_TCE_OE_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_OE_TOG                          EPDC_TCE_OE_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_POLARITY                        EPDC_TCE_POLARITY_REG(EPDC_BASE_PTR)
#define EPDC_TCE_POLARITY_SET                    EPDC_TCE_POLARITY_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_POLARITY_CLR                    EPDC_TCE_POLARITY_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_POLARITY_TOG                    EPDC_TCE_POLARITY_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING1                         EPDC_TCE_TIMING1_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING1_SET                     EPDC_TCE_TIMING1_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING1_CLR                     EPDC_TCE_TIMING1_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING1_TOG                     EPDC_TCE_TIMING1_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING2                         EPDC_TCE_TIMING2_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING2_SET                     EPDC_TCE_TIMING2_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING2_CLR                     EPDC_TCE_TIMING2_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING2_TOG                     EPDC_TCE_TIMING2_TOG_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING3                         EPDC_TCE_TIMING3_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING3_SET                     EPDC_TCE_TIMING3_SET_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING3_CLR                     EPDC_TCE_TIMING3_CLR_REG(EPDC_BASE_PTR)
#define EPDC_TCE_TIMING3_TOG                     EPDC_TCE_TIMING3_TOG_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_CTRL0                        EPDC_PIGEON_CTRL0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_CTRL0_SET                    EPDC_PIGEON_CTRL0_SET_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_CTRL0_CLR                    EPDC_PIGEON_CTRL0_CLR_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_CTRL0_TOG                    EPDC_PIGEON_CTRL0_TOG_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_CTRL1                        EPDC_PIGEON_CTRL1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_CTRL1_SET                    EPDC_PIGEON_CTRL1_SET_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_CTRL1_CLR                    EPDC_PIGEON_CTRL1_CLR_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_CTRL1_TOG                    EPDC_PIGEON_CTRL1_TOG_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK1                           EPDC_IRQ_MASK1_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK1_SET                       EPDC_IRQ_MASK1_SET_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK1_CLR                       EPDC_IRQ_MASK1_CLR_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK1_TOG                       EPDC_IRQ_MASK1_TOG_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK2                           EPDC_IRQ_MASK2_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK2_SET                       EPDC_IRQ_MASK2_SET_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK2_CLR                       EPDC_IRQ_MASK2_CLR_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK2_TOG                       EPDC_IRQ_MASK2_TOG_REG(EPDC_BASE_PTR)
#define EPDC_IRQ1                                EPDC_IRQ1_REG(EPDC_BASE_PTR)
#define EPDC_IRQ1_SET                            EPDC_IRQ1_SET_REG(EPDC_BASE_PTR)
#define EPDC_IRQ1_CLR                            EPDC_IRQ1_CLR_REG(EPDC_BASE_PTR)
#define EPDC_IRQ1_TOG                            EPDC_IRQ1_TOG_REG(EPDC_BASE_PTR)
#define EPDC_IRQ2                                EPDC_IRQ2_REG(EPDC_BASE_PTR)
#define EPDC_IRQ2_SET                            EPDC_IRQ2_SET_REG(EPDC_BASE_PTR)
#define EPDC_IRQ2_CLR                            EPDC_IRQ2_CLR_REG(EPDC_BASE_PTR)
#define EPDC_IRQ2_TOG                            EPDC_IRQ2_TOG_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK                            EPDC_IRQ_MASK_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK_SET                        EPDC_IRQ_MASK_SET_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK_CLR                        EPDC_IRQ_MASK_CLR_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_MASK_TOG                        EPDC_IRQ_MASK_TOG_REG(EPDC_BASE_PTR)
#define EPDC_IRQ                                 EPDC_IRQ_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_SET                             EPDC_IRQ_SET_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_CLR                             EPDC_IRQ_CLR_REG(EPDC_BASE_PTR)
#define EPDC_IRQ_TOG                             EPDC_IRQ_TOG_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_LUTS1                        EPDC_STATUS_LUTS1_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_LUTS1_SET                    EPDC_STATUS_LUTS1_SET_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_LUTS1_CLR                    EPDC_STATUS_LUTS1_CLR_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_LUTS1_TOG                    EPDC_STATUS_LUTS1_TOG_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_LUTS2                        EPDC_STATUS_LUTS2_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_LUTS2_SET                    EPDC_STATUS_LUTS2_SET_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_LUTS2_CLR                    EPDC_STATUS_LUTS2_CLR_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_LUTS2_TOG                    EPDC_STATUS_LUTS2_TOG_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_NEXTLUT                      EPDC_STATUS_NEXTLUT_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_COL1                         EPDC_STATUS_COL1_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_COL1_SET                     EPDC_STATUS_COL1_SET_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_COL1_CLR                     EPDC_STATUS_COL1_CLR_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_COL1_TOG                     EPDC_STATUS_COL1_TOG_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_COL2                         EPDC_STATUS_COL2_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_COL2_SET                     EPDC_STATUS_COL2_SET_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_COL2_CLR                     EPDC_STATUS_COL2_CLR_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_COL2_TOG                     EPDC_STATUS_COL2_TOG_REG(EPDC_BASE_PTR)
#define EPDC_STATUS                              EPDC_STATUS_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_SET                          EPDC_STATUS_SET_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_CLR                          EPDC_STATUS_CLR_REG(EPDC_BASE_PTR)
#define EPDC_STATUS_TOG                          EPDC_STATUS_TOG_REG(EPDC_BASE_PTR)
#define EPDC_UPD_COL_CORD                        EPDC_UPD_COL_CORD_REG(EPDC_BASE_PTR)
#define EPDC_UPD_COL_SIZE                        EPDC_UPD_COL_SIZE_REG(EPDC_BASE_PTR)
#define EPDC_HIST1_PARAM                         EPDC_HIST1_PARAM_REG(EPDC_BASE_PTR)
#define EPDC_HIST2_PARAM                         EPDC_HIST2_PARAM_REG(EPDC_BASE_PTR)
#define EPDC_HIST4_PARAM                         EPDC_HIST4_PARAM_REG(EPDC_BASE_PTR)
#define EPDC_HIST8_PARAM0                        EPDC_HIST8_PARAM0_REG(EPDC_BASE_PTR)
#define EPDC_HIST8_PARAM1                        EPDC_HIST8_PARAM1_REG(EPDC_BASE_PTR)
#define EPDC_HIST16_PARAM0                       EPDC_HIST16_PARAM0_REG(EPDC_BASE_PTR)
#define EPDC_HIST16_PARAM1                       EPDC_HIST16_PARAM1_REG(EPDC_BASE_PTR)
#define EPDC_HIST16_PARAM2                       EPDC_HIST16_PARAM2_REG(EPDC_BASE_PTR)
#define EPDC_HIST16_PARAM3                       EPDC_HIST16_PARAM3_REG(EPDC_BASE_PTR)
#define EPDC_GPIO                                EPDC_GPIO_REG(EPDC_BASE_PTR)
#define EPDC_GPIO_SET                            EPDC_GPIO_SET_REG(EPDC_BASE_PTR)
#define EPDC_GPIO_CLR                            EPDC_GPIO_CLR_REG(EPDC_BASE_PTR)
#define EPDC_GPIO_TOG                            EPDC_GPIO_TOG_REG(EPDC_BASE_PTR)
#define EPDC_VERSION                             EPDC_VERSION_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_0_0                          EPDC_PIGEON_0_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_0_1                          EPDC_PIGEON_0_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_0_2                          EPDC_PIGEON_0_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_1_0                          EPDC_PIGEON_1_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_1_1                          EPDC_PIGEON_1_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_1_2                          EPDC_PIGEON_1_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_2_0                          EPDC_PIGEON_2_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_2_1                          EPDC_PIGEON_2_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_2_2                          EPDC_PIGEON_2_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_3_0                          EPDC_PIGEON_3_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_3_1                          EPDC_PIGEON_3_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_3_2                          EPDC_PIGEON_3_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_4_0                          EPDC_PIGEON_4_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_4_1                          EPDC_PIGEON_4_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_4_2                          EPDC_PIGEON_4_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_5_0                          EPDC_PIGEON_5_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_5_1                          EPDC_PIGEON_5_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_5_2                          EPDC_PIGEON_5_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_6_0                          EPDC_PIGEON_6_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_6_1                          EPDC_PIGEON_6_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_6_2                          EPDC_PIGEON_6_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_7_0                          EPDC_PIGEON_7_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_7_1                          EPDC_PIGEON_7_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_7_2                          EPDC_PIGEON_7_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_8_0                          EPDC_PIGEON_8_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_8_1                          EPDC_PIGEON_8_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_8_2                          EPDC_PIGEON_8_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_9_0                          EPDC_PIGEON_9_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_9_1                          EPDC_PIGEON_9_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_9_2                          EPDC_PIGEON_9_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_10_0                         EPDC_PIGEON_10_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_10_1                         EPDC_PIGEON_10_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_10_2                         EPDC_PIGEON_10_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_11_0                         EPDC_PIGEON_11_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_11_1                         EPDC_PIGEON_11_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_11_2                         EPDC_PIGEON_11_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_12_0                         EPDC_PIGEON_12_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_12_1                         EPDC_PIGEON_12_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_12_2                         EPDC_PIGEON_12_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_13_0                         EPDC_PIGEON_13_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_13_1                         EPDC_PIGEON_13_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_13_2                         EPDC_PIGEON_13_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_14_0                         EPDC_PIGEON_14_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_14_1                         EPDC_PIGEON_14_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_14_2                         EPDC_PIGEON_14_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_15_0                         EPDC_PIGEON_15_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_15_1                         EPDC_PIGEON_15_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_15_2                         EPDC_PIGEON_15_2_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_16_0                         EPDC_PIGEON_16_0_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_16_1                         EPDC_PIGEON_16_1_REG(EPDC_BASE_PTR)
#define EPDC_PIGEON_16_2                         EPDC_PIGEON_16_2_REG(EPDC_BASE_PTR)

/*!
 * @}
 */ /* end of group EPDC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group EPDC_Peripheral */


/* ----------------------------------------------------------------------------
   -- FTM
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FTM_Peripheral FTM
 * @{
 */

/** FTM - Peripheral register structure */
typedef struct FTM_MemMap {
  uint32_t SC;                                     /**< Status And Control, offset: 0x0 */
  uint32_t CNT;                                    /**< Counter, offset: 0x4 */
  uint32_t MOD;                                    /**< Modulo, offset: 0x8 */
  struct {                                         /* offset: 0xC, array step: 0x8 */
    uint32_t CnSC;                                   /**< Channel (n) Status And Control, array offset: 0xC, array step: 0x8 */
    uint32_t CnV;                                    /**< Channel (n) Value, array offset: 0x10, array step: 0x8 */
  } CONTROLS[8];
  uint32_t CNTIN;                                  /**< Counter Initial Value, offset: 0x4C */
  uint32_t STATUS;                                 /**< Capture And Compare Status, offset: 0x50 */
  uint32_t MODE;                                   /**< Features Mode Selection, offset: 0x54 */
  uint32_t SYNC;                                   /**< Synchronization, offset: 0x58 */
  uint32_t OUTINIT;                                /**< Initial State For Channels Output, offset: 0x5C */
  uint32_t OUTMASK;                                /**< Output Mask, offset: 0x60 */
  uint32_t COMBINE;                                /**< Function For Linked Channels, offset: 0x64 */
  uint32_t DEADTIME;                               /**< Deadtime Insertion Control, offset: 0x68 */
  uint32_t EXTTRIG;                                /**< FTM External Trigger, offset: 0x6C */
  uint32_t POL;                                    /**< Channels Polarity, offset: 0x70 */
  uint32_t FMS;                                    /**< Fault Mode Status, offset: 0x74 */
  uint32_t FILTER;                                 /**< Input Capture Filter Control, offset: 0x78 */
  uint8_t RESERVED_0[4];
  uint32_t QDCTRL;                                 /**< Quadrature Decoder Control And Status, offset: 0x80 */
  uint32_t CONF;                                   /**< Configuration, offset: 0x84 */
  uint8_t RESERVED_1[4];
  uint32_t SYNCONF;                                /**< Synchronization Configuration, offset: 0x8C */
  uint32_t INVCTRL;                                /**< FTM Inverting Control, offset: 0x90 */
  uint32_t SWOCTRL;                                /**< FTM Software Output Control, offset: 0x94 */
  uint32_t PWMLOAD;                                /**< FTM PWM Load, offset: 0x98 */
} volatile *FTM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- FTM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FTM_Register_Accessor_Macros FTM - Register accessor macros
 * @{
 */


/* FTM - Register accessors */
#define FTM_SC_REG(base)                         ((base)->SC)
#define FTM_CNT_REG(base)                        ((base)->CNT)
#define FTM_MOD_REG(base)                        ((base)->MOD)
#define FTM_CnSC_REG(base,index)                 ((base)->CONTROLS[index].CnSC)
#define FTM_CnV_REG(base,index)                  ((base)->CONTROLS[index].CnV)
#define FTM_CNTIN_REG(base)                      ((base)->CNTIN)
#define FTM_STATUS_REG(base)                     ((base)->STATUS)
#define FTM_MODE_REG(base)                       ((base)->MODE)
#define FTM_SYNC_REG(base)                       ((base)->SYNC)
#define FTM_OUTINIT_REG(base)                    ((base)->OUTINIT)
#define FTM_OUTMASK_REG(base)                    ((base)->OUTMASK)
#define FTM_COMBINE_REG(base)                    ((base)->COMBINE)
#define FTM_DEADTIME_REG(base)                   ((base)->DEADTIME)
#define FTM_EXTTRIG_REG(base)                    ((base)->EXTTRIG)
#define FTM_POL_REG(base)                        ((base)->POL)
#define FTM_FMS_REG(base)                        ((base)->FMS)
#define FTM_FILTER_REG(base)                     ((base)->FILTER)
#define FTM_QDCTRL_REG(base)                     ((base)->QDCTRL)
#define FTM_CONF_REG(base)                       ((base)->CONF)
#define FTM_SYNCONF_REG(base)                    ((base)->SYNCONF)
#define FTM_INVCTRL_REG(base)                    ((base)->INVCTRL)
#define FTM_SWOCTRL_REG(base)                    ((base)->SWOCTRL)
#define FTM_PWMLOAD_REG(base)                    ((base)->PWMLOAD)

/*!
 * @}
 */ /* end of group FTM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- FTM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FTM_Register_Masks FTM Register Masks
 * @{
 */

/*! @name SC - Status And Control */
#define FTM_SC_PS_MASK                           (0x7U)
#define FTM_SC_PS_SHIFT                          (0U)
#define FTM_SC_PS(x)                             (((uint32_t)(((uint32_t)(x)) << FTM_SC_PS_SHIFT)) & FTM_SC_PS_MASK)
#define FTM_SC_CLKS_MASK                         (0x18U)
#define FTM_SC_CLKS_SHIFT                        (3U)
#define FTM_SC_CLKS(x)                           (((uint32_t)(((uint32_t)(x)) << FTM_SC_CLKS_SHIFT)) & FTM_SC_CLKS_MASK)
#define FTM_SC_CPWMS_MASK                        (0x20U)
#define FTM_SC_CPWMS_SHIFT                       (5U)
#define FTM_SC_TOIE_MASK                         (0x40U)
#define FTM_SC_TOIE_SHIFT                        (6U)
#define FTM_SC_TOF_MASK                          (0x80U)
#define FTM_SC_TOF_SHIFT                         (7U)

/*! @name CNT - Counter */
#define FTM_CNT_COUNT_MASK                       (0xFFFFU)
#define FTM_CNT_COUNT_SHIFT                      (0U)
#define FTM_CNT_COUNT(x)                         (((uint32_t)(((uint32_t)(x)) << FTM_CNT_COUNT_SHIFT)) & FTM_CNT_COUNT_MASK)

/*! @name MOD - Modulo */
#define FTM_MOD_MOD_MASK                         (0xFFFFU)
#define FTM_MOD_MOD_SHIFT                        (0U)
#define FTM_MOD_MOD(x)                           (((uint32_t)(((uint32_t)(x)) << FTM_MOD_MOD_SHIFT)) & FTM_MOD_MOD_MASK)

/*! @name CnSC - Channel (n) Status And Control */
#define FTM_CnSC_DMA_MASK                        (0x1U)
#define FTM_CnSC_DMA_SHIFT                       (0U)
#define FTM_CnSC_ICRST_MASK                      (0x2U)
#define FTM_CnSC_ICRST_SHIFT                     (1U)
#define FTM_CnSC_ELSA_MASK                       (0x4U)
#define FTM_CnSC_ELSA_SHIFT                      (2U)
#define FTM_CnSC_ELSB_MASK                       (0x8U)
#define FTM_CnSC_ELSB_SHIFT                      (3U)
#define FTM_CnSC_MSA_MASK                        (0x10U)
#define FTM_CnSC_MSA_SHIFT                       (4U)
#define FTM_CnSC_MSB_MASK                        (0x20U)
#define FTM_CnSC_MSB_SHIFT                       (5U)
#define FTM_CnSC_CHIE_MASK                       (0x40U)
#define FTM_CnSC_CHIE_SHIFT                      (6U)
#define FTM_CnSC_CHF_MASK                        (0x80U)
#define FTM_CnSC_CHF_SHIFT                       (7U)

/* The count of FTM_CnSC */
#define FTM_CnSC_COUNT                           (8U)

/*! @name CnV - Channel (n) Value */
#define FTM_CnV_VAL_MASK                         (0xFFFFU)
#define FTM_CnV_VAL_SHIFT                        (0U)
#define FTM_CnV_VAL(x)                           (((uint32_t)(((uint32_t)(x)) << FTM_CnV_VAL_SHIFT)) & FTM_CnV_VAL_MASK)

/* The count of FTM_CnV */
#define FTM_CnV_COUNT                            (8U)

/*! @name CNTIN - Counter Initial Value */
#define FTM_CNTIN_INIT_MASK                      (0xFFFFU)
#define FTM_CNTIN_INIT_SHIFT                     (0U)
#define FTM_CNTIN_INIT(x)                        (((uint32_t)(((uint32_t)(x)) << FTM_CNTIN_INIT_SHIFT)) & FTM_CNTIN_INIT_MASK)

/*! @name STATUS - Capture And Compare Status */
#define FTM_STATUS_CH0F_MASK                     (0x1U)
#define FTM_STATUS_CH0F_SHIFT                    (0U)
#define FTM_STATUS_CH1F_MASK                     (0x2U)
#define FTM_STATUS_CH1F_SHIFT                    (1U)
#define FTM_STATUS_CH2F_MASK                     (0x4U)
#define FTM_STATUS_CH2F_SHIFT                    (2U)
#define FTM_STATUS_CH3F_MASK                     (0x8U)
#define FTM_STATUS_CH3F_SHIFT                    (3U)
#define FTM_STATUS_CH4F_MASK                     (0x10U)
#define FTM_STATUS_CH4F_SHIFT                    (4U)
#define FTM_STATUS_CH5F_MASK                     (0x20U)
#define FTM_STATUS_CH5F_SHIFT                    (5U)
#define FTM_STATUS_CH6F_MASK                     (0x40U)
#define FTM_STATUS_CH6F_SHIFT                    (6U)
#define FTM_STATUS_CH7F_MASK                     (0x80U)
#define FTM_STATUS_CH7F_SHIFT                    (7U)

/*! @name MODE - Features Mode Selection */
#define FTM_MODE_FTMEN_MASK                      (0x1U)
#define FTM_MODE_FTMEN_SHIFT                     (0U)
#define FTM_MODE_INIT_MASK                       (0x2U)
#define FTM_MODE_INIT_SHIFT                      (1U)
#define FTM_MODE_WPDIS_MASK                      (0x4U)
#define FTM_MODE_WPDIS_SHIFT                     (2U)
#define FTM_MODE_PWMSYNC_MASK                    (0x8U)
#define FTM_MODE_PWMSYNC_SHIFT                   (3U)
#define FTM_MODE_CAPTEST_MASK                    (0x10U)
#define FTM_MODE_CAPTEST_SHIFT                   (4U)

/*! @name SYNC - Synchronization */
#define FTM_SYNC_CNTMIN_MASK                     (0x1U)
#define FTM_SYNC_CNTMIN_SHIFT                    (0U)
#define FTM_SYNC_CNTMAX_MASK                     (0x2U)
#define FTM_SYNC_CNTMAX_SHIFT                    (1U)
#define FTM_SYNC_REINIT_MASK                     (0x4U)
#define FTM_SYNC_REINIT_SHIFT                    (2U)
#define FTM_SYNC_SYNCHOM_MASK                    (0x8U)
#define FTM_SYNC_SYNCHOM_SHIFT                   (3U)
#define FTM_SYNC_TRIG0_MASK                      (0x10U)
#define FTM_SYNC_TRIG0_SHIFT                     (4U)
#define FTM_SYNC_TRIG1_MASK                      (0x20U)
#define FTM_SYNC_TRIG1_SHIFT                     (5U)
#define FTM_SYNC_TRIG2_MASK                      (0x40U)
#define FTM_SYNC_TRIG2_SHIFT                     (6U)
#define FTM_SYNC_SWSYNC_MASK                     (0x80U)
#define FTM_SYNC_SWSYNC_SHIFT                    (7U)

/*! @name OUTINIT - Initial State For Channels Output */
#define FTM_OUTINIT_CH0OI_MASK                   (0x1U)
#define FTM_OUTINIT_CH0OI_SHIFT                  (0U)
#define FTM_OUTINIT_CH1OI_MASK                   (0x2U)
#define FTM_OUTINIT_CH1OI_SHIFT                  (1U)
#define FTM_OUTINIT_CH2OI_MASK                   (0x4U)
#define FTM_OUTINIT_CH2OI_SHIFT                  (2U)
#define FTM_OUTINIT_CH3OI_MASK                   (0x8U)
#define FTM_OUTINIT_CH3OI_SHIFT                  (3U)
#define FTM_OUTINIT_CH4OI_MASK                   (0x10U)
#define FTM_OUTINIT_CH4OI_SHIFT                  (4U)
#define FTM_OUTINIT_CH5OI_MASK                   (0x20U)
#define FTM_OUTINIT_CH5OI_SHIFT                  (5U)
#define FTM_OUTINIT_CH6OI_MASK                   (0x40U)
#define FTM_OUTINIT_CH6OI_SHIFT                  (6U)
#define FTM_OUTINIT_CH7OI_MASK                   (0x80U)
#define FTM_OUTINIT_CH7OI_SHIFT                  (7U)

/*! @name OUTMASK - Output Mask */
#define FTM_OUTMASK_CH0OM_MASK                   (0x1U)
#define FTM_OUTMASK_CH0OM_SHIFT                  (0U)
#define FTM_OUTMASK_CH1OM_MASK                   (0x2U)
#define FTM_OUTMASK_CH1OM_SHIFT                  (1U)
#define FTM_OUTMASK_CH2OM_MASK                   (0x4U)
#define FTM_OUTMASK_CH2OM_SHIFT                  (2U)
#define FTM_OUTMASK_CH3OM_MASK                   (0x8U)
#define FTM_OUTMASK_CH3OM_SHIFT                  (3U)
#define FTM_OUTMASK_CH4OM_MASK                   (0x10U)
#define FTM_OUTMASK_CH4OM_SHIFT                  (4U)
#define FTM_OUTMASK_CH5OM_MASK                   (0x20U)
#define FTM_OUTMASK_CH5OM_SHIFT                  (5U)
#define FTM_OUTMASK_CH6OM_MASK                   (0x40U)
#define FTM_OUTMASK_CH6OM_SHIFT                  (6U)
#define FTM_OUTMASK_CH7OM_MASK                   (0x80U)
#define FTM_OUTMASK_CH7OM_SHIFT                  (7U)

/*! @name COMBINE - Function For Linked Channels */
#define FTM_COMBINE_COMBINE0_MASK                (0x1U)
#define FTM_COMBINE_COMBINE0_SHIFT               (0U)
#define FTM_COMBINE_COMP0_MASK                   (0x2U)
#define FTM_COMBINE_COMP0_SHIFT                  (1U)
#define FTM_COMBINE_DECAPEN0_MASK                (0x4U)
#define FTM_COMBINE_DECAPEN0_SHIFT               (2U)
#define FTM_COMBINE_DECAP0_MASK                  (0x8U)
#define FTM_COMBINE_DECAP0_SHIFT                 (3U)
#define FTM_COMBINE_DTEN0_MASK                   (0x10U)
#define FTM_COMBINE_DTEN0_SHIFT                  (4U)
#define FTM_COMBINE_SYNCEN0_MASK                 (0x20U)
#define FTM_COMBINE_SYNCEN0_SHIFT                (5U)
#define FTM_COMBINE_COMBINE1_MASK                (0x100U)
#define FTM_COMBINE_COMBINE1_SHIFT               (8U)
#define FTM_COMBINE_COMP1_MASK                   (0x200U)
#define FTM_COMBINE_COMP1_SHIFT                  (9U)
#define FTM_COMBINE_DECAPEN1_MASK                (0x400U)
#define FTM_COMBINE_DECAPEN1_SHIFT               (10U)
#define FTM_COMBINE_DECAP1_MASK                  (0x800U)
#define FTM_COMBINE_DECAP1_SHIFT                 (11U)
#define FTM_COMBINE_DTEN1_MASK                   (0x1000U)
#define FTM_COMBINE_DTEN1_SHIFT                  (12U)
#define FTM_COMBINE_SYNCEN1_MASK                 (0x2000U)
#define FTM_COMBINE_SYNCEN1_SHIFT                (13U)
#define FTM_COMBINE_COMBINE2_MASK                (0x10000U)
#define FTM_COMBINE_COMBINE2_SHIFT               (16U)
#define FTM_COMBINE_COMP2_MASK                   (0x20000U)
#define FTM_COMBINE_COMP2_SHIFT                  (17U)
#define FTM_COMBINE_DECAPEN2_MASK                (0x40000U)
#define FTM_COMBINE_DECAPEN2_SHIFT               (18U)
#define FTM_COMBINE_DECAP2_MASK                  (0x80000U)
#define FTM_COMBINE_DECAP2_SHIFT                 (19U)
#define FTM_COMBINE_DTEN2_MASK                   (0x100000U)
#define FTM_COMBINE_DTEN2_SHIFT                  (20U)
#define FTM_COMBINE_SYNCEN2_MASK                 (0x200000U)
#define FTM_COMBINE_SYNCEN2_SHIFT                (21U)
#define FTM_COMBINE_COMBINE3_MASK                (0x1000000U)
#define FTM_COMBINE_COMBINE3_SHIFT               (24U)
#define FTM_COMBINE_COMP3_MASK                   (0x2000000U)
#define FTM_COMBINE_COMP3_SHIFT                  (25U)
#define FTM_COMBINE_DECAPEN3_MASK                (0x4000000U)
#define FTM_COMBINE_DECAPEN3_SHIFT               (26U)
#define FTM_COMBINE_DECAP3_MASK                  (0x8000000U)
#define FTM_COMBINE_DECAP3_SHIFT                 (27U)
#define FTM_COMBINE_DTEN3_MASK                   (0x10000000U)
#define FTM_COMBINE_DTEN3_SHIFT                  (28U)
#define FTM_COMBINE_SYNCEN3_MASK                 (0x20000000U)
#define FTM_COMBINE_SYNCEN3_SHIFT                (29U)

/*! @name DEADTIME - Deadtime Insertion Control */
#define FTM_DEADTIME_DTVAL_MASK                  (0x3FU)
#define FTM_DEADTIME_DTVAL_SHIFT                 (0U)
#define FTM_DEADTIME_DTVAL(x)                    (((uint32_t)(((uint32_t)(x)) << FTM_DEADTIME_DTVAL_SHIFT)) & FTM_DEADTIME_DTVAL_MASK)
#define FTM_DEADTIME_DTPS_MASK                   (0xC0U)
#define FTM_DEADTIME_DTPS_SHIFT                  (6U)
#define FTM_DEADTIME_DTPS(x)                     (((uint32_t)(((uint32_t)(x)) << FTM_DEADTIME_DTPS_SHIFT)) & FTM_DEADTIME_DTPS_MASK)

/*! @name EXTTRIG - FTM External Trigger */
#define FTM_EXTTRIG_CH2TRIG_MASK                 (0x1U)
#define FTM_EXTTRIG_CH2TRIG_SHIFT                (0U)
#define FTM_EXTTRIG_CH3TRIG_MASK                 (0x2U)
#define FTM_EXTTRIG_CH3TRIG_SHIFT                (1U)
#define FTM_EXTTRIG_CH4TRIG_MASK                 (0x4U)
#define FTM_EXTTRIG_CH4TRIG_SHIFT                (2U)
#define FTM_EXTTRIG_CH5TRIG_MASK                 (0x8U)
#define FTM_EXTTRIG_CH5TRIG_SHIFT                (3U)
#define FTM_EXTTRIG_CH0TRIG_MASK                 (0x10U)
#define FTM_EXTTRIG_CH0TRIG_SHIFT                (4U)
#define FTM_EXTTRIG_CH1TRIG_MASK                 (0x20U)
#define FTM_EXTTRIG_CH1TRIG_SHIFT                (5U)
#define FTM_EXTTRIG_INITTRIGEN_MASK              (0x40U)
#define FTM_EXTTRIG_INITTRIGEN_SHIFT             (6U)
#define FTM_EXTTRIG_TRIGF_MASK                   (0x80U)
#define FTM_EXTTRIG_TRIGF_SHIFT                  (7U)

/*! @name POL - Channels Polarity */
#define FTM_POL_POL0_MASK                        (0x1U)
#define FTM_POL_POL0_SHIFT                       (0U)
#define FTM_POL_POL1_MASK                        (0x2U)
#define FTM_POL_POL1_SHIFT                       (1U)
#define FTM_POL_POL2_MASK                        (0x4U)
#define FTM_POL_POL2_SHIFT                       (2U)
#define FTM_POL_POL3_MASK                        (0x8U)
#define FTM_POL_POL3_SHIFT                       (3U)
#define FTM_POL_POL4_MASK                        (0x10U)
#define FTM_POL_POL4_SHIFT                       (4U)
#define FTM_POL_POL5_MASK                        (0x20U)
#define FTM_POL_POL5_SHIFT                       (5U)
#define FTM_POL_POL6_MASK                        (0x40U)
#define FTM_POL_POL6_SHIFT                       (6U)
#define FTM_POL_POL7_MASK                        (0x80U)
#define FTM_POL_POL7_SHIFT                       (7U)

/*! @name FMS - Fault Mode Status */
#define FTM_FMS_WPEN_MASK                        (0x40U)
#define FTM_FMS_WPEN_SHIFT                       (6U)

/*! @name FILTER - Input Capture Filter Control */
#define FTM_FILTER_CH0FVAL_MASK                  (0xFU)
#define FTM_FILTER_CH0FVAL_SHIFT                 (0U)
#define FTM_FILTER_CH0FVAL(x)                    (((uint32_t)(((uint32_t)(x)) << FTM_FILTER_CH0FVAL_SHIFT)) & FTM_FILTER_CH0FVAL_MASK)
#define FTM_FILTER_CH1FVAL_MASK                  (0xF0U)
#define FTM_FILTER_CH1FVAL_SHIFT                 (4U)
#define FTM_FILTER_CH1FVAL(x)                    (((uint32_t)(((uint32_t)(x)) << FTM_FILTER_CH1FVAL_SHIFT)) & FTM_FILTER_CH1FVAL_MASK)
#define FTM_FILTER_CH2FVAL_MASK                  (0xF00U)
#define FTM_FILTER_CH2FVAL_SHIFT                 (8U)
#define FTM_FILTER_CH2FVAL(x)                    (((uint32_t)(((uint32_t)(x)) << FTM_FILTER_CH2FVAL_SHIFT)) & FTM_FILTER_CH2FVAL_MASK)
#define FTM_FILTER_CH3FVAL_MASK                  (0xF000U)
#define FTM_FILTER_CH3FVAL_SHIFT                 (12U)
#define FTM_FILTER_CH3FVAL(x)                    (((uint32_t)(((uint32_t)(x)) << FTM_FILTER_CH3FVAL_SHIFT)) & FTM_FILTER_CH3FVAL_MASK)

/*! @name QDCTRL - Quadrature Decoder Control And Status */
#define FTM_QDCTRL_QUADEN_MASK                   (0x1U)
#define FTM_QDCTRL_QUADEN_SHIFT                  (0U)
#define FTM_QDCTRL_TOFDIR_MASK                   (0x2U)
#define FTM_QDCTRL_TOFDIR_SHIFT                  (1U)
#define FTM_QDCTRL_QUADIR_MASK                   (0x4U)
#define FTM_QDCTRL_QUADIR_SHIFT                  (2U)
#define FTM_QDCTRL_QUADMODE_MASK                 (0x8U)
#define FTM_QDCTRL_QUADMODE_SHIFT                (3U)
#define FTM_QDCTRL_PHBPOL_MASK                   (0x10U)
#define FTM_QDCTRL_PHBPOL_SHIFT                  (4U)
#define FTM_QDCTRL_PHAPOL_MASK                   (0x20U)
#define FTM_QDCTRL_PHAPOL_SHIFT                  (5U)
#define FTM_QDCTRL_PHBFLTREN_MASK                (0x40U)
#define FTM_QDCTRL_PHBFLTREN_SHIFT               (6U)
#define FTM_QDCTRL_PHAFLTREN_MASK                (0x80U)
#define FTM_QDCTRL_PHAFLTREN_SHIFT               (7U)

/*! @name CONF - Configuration */
#define FTM_CONF_NUMTOF_MASK                     (0x1FU)
#define FTM_CONF_NUMTOF_SHIFT                    (0U)
#define FTM_CONF_NUMTOF(x)                       (((uint32_t)(((uint32_t)(x)) << FTM_CONF_NUMTOF_SHIFT)) & FTM_CONF_NUMTOF_MASK)
#define FTM_CONF_BDMMODE_MASK                    (0xC0U)
#define FTM_CONF_BDMMODE_SHIFT                   (6U)
#define FTM_CONF_BDMMODE(x)                      (((uint32_t)(((uint32_t)(x)) << FTM_CONF_BDMMODE_SHIFT)) & FTM_CONF_BDMMODE_MASK)
#define FTM_CONF_GTBEEN_MASK                     (0x200U)
#define FTM_CONF_GTBEEN_SHIFT                    (9U)
#define FTM_CONF_GTBEOUT_MASK                    (0x400U)
#define FTM_CONF_GTBEOUT_SHIFT                   (10U)

/*! @name SYNCONF - Synchronization Configuration */
#define FTM_SYNCONF_HWTRIGMODE_MASK              (0x1U)
#define FTM_SYNCONF_HWTRIGMODE_SHIFT             (0U)
#define FTM_SYNCONF_CNTINC_MASK                  (0x4U)
#define FTM_SYNCONF_CNTINC_SHIFT                 (2U)
#define FTM_SYNCONF_INVC_MASK                    (0x10U)
#define FTM_SYNCONF_INVC_SHIFT                   (4U)
#define FTM_SYNCONF_SWOC_MASK                    (0x20U)
#define FTM_SYNCONF_SWOC_SHIFT                   (5U)
#define FTM_SYNCONF_SYNCMODE_MASK                (0x80U)
#define FTM_SYNCONF_SYNCMODE_SHIFT               (7U)
#define FTM_SYNCONF_SWRSTCNT_MASK                (0x100U)
#define FTM_SYNCONF_SWRSTCNT_SHIFT               (8U)
#define FTM_SYNCONF_SWWRBUF_MASK                 (0x200U)
#define FTM_SYNCONF_SWWRBUF_SHIFT                (9U)
#define FTM_SYNCONF_SWOM_MASK                    (0x400U)
#define FTM_SYNCONF_SWOM_SHIFT                   (10U)
#define FTM_SYNCONF_SWINVC_MASK                  (0x800U)
#define FTM_SYNCONF_SWINVC_SHIFT                 (11U)
#define FTM_SYNCONF_SWSOC_MASK                   (0x1000U)
#define FTM_SYNCONF_SWSOC_SHIFT                  (12U)
#define FTM_SYNCONF_HWRSTCNT_MASK                (0x10000U)
#define FTM_SYNCONF_HWRSTCNT_SHIFT               (16U)
#define FTM_SYNCONF_HWWRBUF_MASK                 (0x20000U)
#define FTM_SYNCONF_HWWRBUF_SHIFT                (17U)
#define FTM_SYNCONF_HWOM_MASK                    (0x40000U)
#define FTM_SYNCONF_HWOM_SHIFT                   (18U)
#define FTM_SYNCONF_HWINVC_MASK                  (0x80000U)
#define FTM_SYNCONF_HWINVC_SHIFT                 (19U)
#define FTM_SYNCONF_HWSOC_MASK                   (0x100000U)
#define FTM_SYNCONF_HWSOC_SHIFT                  (20U)

/*! @name INVCTRL - FTM Inverting Control */
#define FTM_INVCTRL_INV0EN_MASK                  (0x1U)
#define FTM_INVCTRL_INV0EN_SHIFT                 (0U)
#define FTM_INVCTRL_INV1EN_MASK                  (0x2U)
#define FTM_INVCTRL_INV1EN_SHIFT                 (1U)
#define FTM_INVCTRL_INV2EN_MASK                  (0x4U)
#define FTM_INVCTRL_INV2EN_SHIFT                 (2U)
#define FTM_INVCTRL_INV3EN_MASK                  (0x8U)
#define FTM_INVCTRL_INV3EN_SHIFT                 (3U)

/*! @name SWOCTRL - FTM Software Output Control */
#define FTM_SWOCTRL_CH0OC_MASK                   (0x1U)
#define FTM_SWOCTRL_CH0OC_SHIFT                  (0U)
#define FTM_SWOCTRL_CH1OC_MASK                   (0x2U)
#define FTM_SWOCTRL_CH1OC_SHIFT                  (1U)
#define FTM_SWOCTRL_CH2OC_MASK                   (0x4U)
#define FTM_SWOCTRL_CH2OC_SHIFT                  (2U)
#define FTM_SWOCTRL_CH3OC_MASK                   (0x8U)
#define FTM_SWOCTRL_CH3OC_SHIFT                  (3U)
#define FTM_SWOCTRL_CH4OC_MASK                   (0x10U)
#define FTM_SWOCTRL_CH4OC_SHIFT                  (4U)
#define FTM_SWOCTRL_CH5OC_MASK                   (0x20U)
#define FTM_SWOCTRL_CH5OC_SHIFT                  (5U)
#define FTM_SWOCTRL_CH6OC_MASK                   (0x40U)
#define FTM_SWOCTRL_CH6OC_SHIFT                  (6U)
#define FTM_SWOCTRL_CH7OC_MASK                   (0x80U)
#define FTM_SWOCTRL_CH7OC_SHIFT                  (7U)
#define FTM_SWOCTRL_CH0OCV_MASK                  (0x100U)
#define FTM_SWOCTRL_CH0OCV_SHIFT                 (8U)
#define FTM_SWOCTRL_CH1OCV_MASK                  (0x200U)
#define FTM_SWOCTRL_CH1OCV_SHIFT                 (9U)
#define FTM_SWOCTRL_CH2OCV_MASK                  (0x400U)
#define FTM_SWOCTRL_CH2OCV_SHIFT                 (10U)
#define FTM_SWOCTRL_CH3OCV_MASK                  (0x800U)
#define FTM_SWOCTRL_CH3OCV_SHIFT                 (11U)
#define FTM_SWOCTRL_CH4OCV_MASK                  (0x1000U)
#define FTM_SWOCTRL_CH4OCV_SHIFT                 (12U)
#define FTM_SWOCTRL_CH5OCV_MASK                  (0x2000U)
#define FTM_SWOCTRL_CH5OCV_SHIFT                 (13U)
#define FTM_SWOCTRL_CH6OCV_MASK                  (0x4000U)
#define FTM_SWOCTRL_CH6OCV_SHIFT                 (14U)
#define FTM_SWOCTRL_CH7OCV_MASK                  (0x8000U)
#define FTM_SWOCTRL_CH7OCV_SHIFT                 (15U)

/*! @name PWMLOAD - FTM PWM Load */
#define FTM_PWMLOAD_CH0SEL_MASK                  (0x1U)
#define FTM_PWMLOAD_CH0SEL_SHIFT                 (0U)
#define FTM_PWMLOAD_CH1SEL_MASK                  (0x2U)
#define FTM_PWMLOAD_CH1SEL_SHIFT                 (1U)
#define FTM_PWMLOAD_CH2SEL_MASK                  (0x4U)
#define FTM_PWMLOAD_CH2SEL_SHIFT                 (2U)
#define FTM_PWMLOAD_CH3SEL_MASK                  (0x8U)
#define FTM_PWMLOAD_CH3SEL_SHIFT                 (3U)
#define FTM_PWMLOAD_CH4SEL_MASK                  (0x10U)
#define FTM_PWMLOAD_CH4SEL_SHIFT                 (4U)
#define FTM_PWMLOAD_CH5SEL_MASK                  (0x20U)
#define FTM_PWMLOAD_CH5SEL_SHIFT                 (5U)
#define FTM_PWMLOAD_CH6SEL_MASK                  (0x40U)
#define FTM_PWMLOAD_CH6SEL_SHIFT                 (6U)
#define FTM_PWMLOAD_CH7SEL_MASK                  (0x80U)
#define FTM_PWMLOAD_CH7SEL_SHIFT                 (7U)
#define FTM_PWMLOAD_LDOK_MASK                    (0x200U)
#define FTM_PWMLOAD_LDOK_SHIFT                   (9U)


/*!
 * @}
 */ /* end of group FTM_Register_Masks */


/* FTM - Peripheral instance base addresses */
/** Peripheral FTM1 base pointer */
#define FTM1_BASE_PTR                            ((FTM_MemMapPtr)0x30640000u)
/** Peripheral FTM2 base pointer */
#define FTM2_BASE_PTR                            ((FTM_MemMapPtr)0x30650000u)
/** Array initializer of FTM peripheral base pointers */
#define FTM_BASE_PTRS                            { FTM1_BASE_PTR, FTM2_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- FTM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FTM_Register_Accessor_Macros FTM - Register accessor macros
 * @{
 */


/* FTM - Register instance definitions */
/* FTM1 */
#define FTM1_SC                                  FTM_SC_REG(FTM1_BASE_PTR)
#define FTM1_CNT                                 FTM_CNT_REG(FTM1_BASE_PTR)
#define FTM1_MOD                                 FTM_MOD_REG(FTM1_BASE_PTR)
#define FTM1_C0SC                                FTM_CnSC_REG(FTM1_BASE_PTR,0)
#define FTM1_C0V                                 FTM_CnV_REG(FTM1_BASE_PTR,0)
#define FTM1_C1SC                                FTM_CnSC_REG(FTM1_BASE_PTR,1)
#define FTM1_C1V                                 FTM_CnV_REG(FTM1_BASE_PTR,1)
#define FTM1_C2SC                                FTM_CnSC_REG(FTM1_BASE_PTR,2)
#define FTM1_C2V                                 FTM_CnV_REG(FTM1_BASE_PTR,2)
#define FTM1_C3SC                                FTM_CnSC_REG(FTM1_BASE_PTR,3)
#define FTM1_C3V                                 FTM_CnV_REG(FTM1_BASE_PTR,3)
#define FTM1_C4SC                                FTM_CnSC_REG(FTM1_BASE_PTR,4)
#define FTM1_C4V                                 FTM_CnV_REG(FTM1_BASE_PTR,4)
#define FTM1_C5SC                                FTM_CnSC_REG(FTM1_BASE_PTR,5)
#define FTM1_C5V                                 FTM_CnV_REG(FTM1_BASE_PTR,5)
#define FTM1_C6SC                                FTM_CnSC_REG(FTM1_BASE_PTR,6)
#define FTM1_C6V                                 FTM_CnV_REG(FTM1_BASE_PTR,6)
#define FTM1_C7SC                                FTM_CnSC_REG(FTM1_BASE_PTR,7)
#define FTM1_C7V                                 FTM_CnV_REG(FTM1_BASE_PTR,7)
#define FTM1_CNTIN                               FTM_CNTIN_REG(FTM1_BASE_PTR)
#define FTM1_STATUS                              FTM_STATUS_REG(FTM1_BASE_PTR)
#define FTM1_MODE                                FTM_MODE_REG(FTM1_BASE_PTR)
#define FTM1_SYNC                                FTM_SYNC_REG(FTM1_BASE_PTR)
#define FTM1_OUTINIT                             FTM_OUTINIT_REG(FTM1_BASE_PTR)
#define FTM1_OUTMASK                             FTM_OUTMASK_REG(FTM1_BASE_PTR)
#define FTM1_COMBINE                             FTM_COMBINE_REG(FTM1_BASE_PTR)
#define FTM1_DEADTIME                            FTM_DEADTIME_REG(FTM1_BASE_PTR)
#define FTM1_EXTTRIG                             FTM_EXTTRIG_REG(FTM1_BASE_PTR)
#define FTM1_POL                                 FTM_POL_REG(FTM1_BASE_PTR)
#define FTM1_FMS                                 FTM_FMS_REG(FTM1_BASE_PTR)
#define FTM1_FILTER                              FTM_FILTER_REG(FTM1_BASE_PTR)
#define FTM1_QDCTRL                              FTM_QDCTRL_REG(FTM1_BASE_PTR)
#define FTM1_CONF                                FTM_CONF_REG(FTM1_BASE_PTR)
#define FTM1_SYNCONF                             FTM_SYNCONF_REG(FTM1_BASE_PTR)
#define FTM1_INVCTRL                             FTM_INVCTRL_REG(FTM1_BASE_PTR)
#define FTM1_SWOCTRL                             FTM_SWOCTRL_REG(FTM1_BASE_PTR)
#define FTM1_PWMLOAD                             FTM_PWMLOAD_REG(FTM1_BASE_PTR)
/* FTM2 */
#define FTM2_SC                                  FTM_SC_REG(FTM2_BASE_PTR)
#define FTM2_CNT                                 FTM_CNT_REG(FTM2_BASE_PTR)
#define FTM2_MOD                                 FTM_MOD_REG(FTM2_BASE_PTR)
#define FTM2_C0SC                                FTM_CnSC_REG(FTM2_BASE_PTR,0)
#define FTM2_C0V                                 FTM_CnV_REG(FTM2_BASE_PTR,0)
#define FTM2_C1SC                                FTM_CnSC_REG(FTM2_BASE_PTR,1)
#define FTM2_C1V                                 FTM_CnV_REG(FTM2_BASE_PTR,1)
#define FTM2_C2SC                                FTM_CnSC_REG(FTM2_BASE_PTR,2)
#define FTM2_C2V                                 FTM_CnV_REG(FTM2_BASE_PTR,2)
#define FTM2_C3SC                                FTM_CnSC_REG(FTM2_BASE_PTR,3)
#define FTM2_C3V                                 FTM_CnV_REG(FTM2_BASE_PTR,3)
#define FTM2_C4SC                                FTM_CnSC_REG(FTM2_BASE_PTR,4)
#define FTM2_C4V                                 FTM_CnV_REG(FTM2_BASE_PTR,4)
#define FTM2_C5SC                                FTM_CnSC_REG(FTM2_BASE_PTR,5)
#define FTM2_C5V                                 FTM_CnV_REG(FTM2_BASE_PTR,5)
#define FTM2_C6SC                                FTM_CnSC_REG(FTM2_BASE_PTR,6)
#define FTM2_C6V                                 FTM_CnV_REG(FTM2_BASE_PTR,6)
#define FTM2_C7SC                                FTM_CnSC_REG(FTM2_BASE_PTR,7)
#define FTM2_C7V                                 FTM_CnV_REG(FTM2_BASE_PTR,7)
#define FTM2_CNTIN                               FTM_CNTIN_REG(FTM2_BASE_PTR)
#define FTM2_STATUS                              FTM_STATUS_REG(FTM2_BASE_PTR)
#define FTM2_MODE                                FTM_MODE_REG(FTM2_BASE_PTR)
#define FTM2_SYNC                                FTM_SYNC_REG(FTM2_BASE_PTR)
#define FTM2_OUTINIT                             FTM_OUTINIT_REG(FTM2_BASE_PTR)
#define FTM2_OUTMASK                             FTM_OUTMASK_REG(FTM2_BASE_PTR)
#define FTM2_COMBINE                             FTM_COMBINE_REG(FTM2_BASE_PTR)
#define FTM2_DEADTIME                            FTM_DEADTIME_REG(FTM2_BASE_PTR)
#define FTM2_EXTTRIG                             FTM_EXTTRIG_REG(FTM2_BASE_PTR)
#define FTM2_POL                                 FTM_POL_REG(FTM2_BASE_PTR)
#define FTM2_FMS                                 FTM_FMS_REG(FTM2_BASE_PTR)
#define FTM2_FILTER                              FTM_FILTER_REG(FTM2_BASE_PTR)
#define FTM2_QDCTRL                              FTM_QDCTRL_REG(FTM2_BASE_PTR)
#define FTM2_CONF                                FTM_CONF_REG(FTM2_BASE_PTR)
#define FTM2_SYNCONF                             FTM_SYNCONF_REG(FTM2_BASE_PTR)
#define FTM2_INVCTRL                             FTM_INVCTRL_REG(FTM2_BASE_PTR)
#define FTM2_SWOCTRL                             FTM_SWOCTRL_REG(FTM2_BASE_PTR)
#define FTM2_PWMLOAD                             FTM_PWMLOAD_REG(FTM2_BASE_PTR)

/* FTM - Register array accessors */
#define FTM1_CnSC(index)                         FTM_CnSC_REG(FTM1_BASE_PTR,index)
#define FTM2_CnSC(index)                         FTM_CnSC_REG(FTM2_BASE_PTR,index)
#define FTM1_CnV(index)                          FTM_CnV_REG(FTM1_BASE_PTR,index)
#define FTM2_CnV(index)                          FTM_CnV_REG(FTM2_BASE_PTR,index)

/*!
 * @}
 */ /* end of group FTM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group FTM_Peripheral */


/* ----------------------------------------------------------------------------
   -- GPC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPC_Peripheral GPC
 * @{
 */

/** GPC - Peripheral register structure */
typedef struct GPC_MemMap {
  uint32_t LPCR_A7_BSC;                            /**< Basic Low power control register of A7 platform, offset: 0x0 */
  uint32_t LPCR_A7_AD;                             /**< Advanced Low power control register of A7 platform, offset: 0x4 */
  uint32_t LPCR_M4;                                /**< Low power control register of CPU1, offset: 0x8 */
  uint8_t RESERVED_0[8];
  uint32_t SLPCR;                                  /**< System low power control register, offset: 0x14 */
  uint8_t RESERVED_1[8];
  uint32_t MLPCR;                                  /**< Memory low power control register, offset: 0x20 */
  uint32_t PGC_ACK_SEL_A7;                         /**< PGC acknowledge signal selection of A7 platform, offset: 0x24 */
  uint32_t PGC_ACK_SEL_M4;                         /**< PGC acknowledge signal selection of M4 platform, offset: 0x28 */
  uint32_t MISC;                                   /**< GPC Miscellaneous register, offset: 0x2C */
  uint32_t IMR1_CORE0_A7;                          /**< IRQ masking register 1 of A7 core0, offset: 0x30 */
  uint32_t IMR2_CORE0_A7;                          /**< IRQ masking register 2 of A7 core0, offset: 0x34 */
  uint32_t IMR3_CORE0_A7;                          /**< IRQ masking register 3 of A7 core0, offset: 0x38 */
  uint32_t IMR4_CORE0_A7;                          /**< IRQ masking register 4 of A7 core0, offset: 0x3C */
  uint32_t IMR1_CORE1_A7;                          /**< IRQ masking register 1 of A7 core1, offset: 0x40 */
  uint32_t IMR2_CORE1_A7;                          /**< IRQ masking register 2 of A7 core1, offset: 0x44 */
  uint32_t IMR3_CORE1_A7;                          /**< IRQ masking register 3 of A7 core1, offset: 0x48 */
  uint32_t IMR4_CORE1_A7;                          /**< IRQ masking register 4 of A7 core1, offset: 0x4C */
  uint32_t IMR1_M4;                                /**< IRQ masking register 1 of M4, offset: 0x50 */
  uint32_t IMR2_M4;                                /**< IRQ masking register 2 of M4, offset: 0x54 */
  uint32_t IMR3_M4;                                /**< IRQ masking register 3 of M4, offset: 0x58 */
  uint32_t IMR4_M4;                                /**< IRQ masking register 4 of M4, offset: 0x5C */
  uint8_t RESERVED_2[16];
  uint32_t ISR1_A7;                                /**< IRQ status register 1 of A7, offset: 0x70 */
  uint32_t ISR2_A7;                                /**< IRQ status register 2 of A7, offset: 0x74 */
  uint32_t ISR3_A7;                                /**< IRQ status register 3 of A7, offset: 0x78 */
  uint32_t ISR4_A7;                                /**< IRQ status register 4 of A7, offset: 0x7C */
  uint32_t ISR1_M4;                                /**< IRQ status register 1 of M4, offset: 0x80 */
  uint32_t ISR2_M4;                                /**< IRQ status register 2 of M4, offset: 0x84 */
  uint32_t ISR3_M4;                                /**< IRQ status register 3 of M4, offset: 0x88 */
  uint32_t ISR4_M4;                                /**< IRQ status register 4 of M4, offset: 0x8C */
  uint8_t RESERVED_3[32];
  uint32_t SLT0_CFG;                               /**< Slot configure register, offset: 0xB0 */
  uint32_t SLT1_CFG;                               /**< Slot configure register, offset: 0xB4 */
  uint32_t SLT2_CFG;                               /**< Slot configure register, offset: 0xB8 */
  uint32_t SLT3_CFG;                               /**< Slot configure register, offset: 0xBC */
  uint32_t SLT4_CFG;                               /**< Slot configure register, offset: 0xC0 */
  uint32_t SLT5_CFG;                               /**< Slot configure register, offset: 0xC4 */
  uint32_t SLT6_CFG;                               /**< Slot configure register, offset: 0xC8 */
  uint32_t SLT7_CFG;                               /**< Slot configure register, offset: 0xCC */
  uint32_t SLT8_CFG;                               /**< Slot configure register, offset: 0xD0 */
  uint32_t SLT9_CFG;                               /**< Slot configure register, offset: 0xD4 */
  uint8_t RESERVED_4[20];
  uint32_t PGC_CPU_MAPPING;                        /**< PGC CPU mapping, offset: 0xEC */
  uint32_t CPU_PGC_SW_PUP_REQ;                     /**< CPU PGC software up trigger, offset: 0xF0 */
  uint8_t RESERVED_5[4];
  uint32_t PU_PGC_SW_PUP_REQ;                      /**< PU PGC software up trigger, offset: 0xF8 */
  uint32_t CPU_PGC_SW_PDN_REQ;                     /**< CPU PGC software down trigger, offset: 0xFC */
  uint8_t RESERVED_6[4];
  uint32_t PU_PGC_SW_PDN_REQ;                      /**< PU PGC software down trigger, offset: 0x104 */
  uint8_t RESERVED_7[40];
  uint32_t CPU_PGC_PUP_STATUS1;                    /**< CPU PGC software up trigger status1, offset: 0x130 */
  uint32_t A7_MIX_PGC_PUP_STATUS0;                 /**< A7 MIX software up trigger status register, offset: 0x134 */
  uint32_t A7_MIX_PGC_PUP_STATUS1;                 /**< A7 MIX software up trigger status register, offset: 0x138 */
  uint32_t A7_MIX_PGC_PUP_STATUS2;                 /**< A7 MIX software up trigger status register, offset: 0x13C */
  uint32_t M4_MIX_PGC_PUP_STATUS0;                 /**< M4 MIX PGC software up trigger status register, offset: 0x140 */
  uint32_t M4_MIX_PGC_PUP_STATUS1;                 /**< M4 MIX PGC software up trigger status register, offset: 0x144 */
  uint32_t M4_MIX_PGC_PUP_STATUS2;                 /**< M4 MIX PGC software up trigger status register, offset: 0x148 */
  uint32_t A7_PU_PGC_PUP_STATUS0;                  /**< A7 PU software up trigger status register, offset: 0x14C */
  uint32_t A7_PU_PGC_PUP_STATUS1;                  /**< A7 PU software up trigger status register, offset: 0x150 */
  uint32_t A7_PU_PGC_PUP_STATUS2;                  /**< A7 PU software up trigger status register, offset: 0x154 */
  uint32_t M4_PU_PGC_PUP_STATUS0;                  /**< M4 PU PGC software up trigger status register, offset: 0x158 */
  uint32_t M4_PU_PGC_PUP_STATUS1;                  /**< M4 PU PGC software up trigger status register, offset: 0x15C */
  uint32_t M4_PU_PGC_PUP_STATUS2;                  /**< M4 PU PGC software up trigger status register, offset: 0x160 */
  uint8_t RESERVED_8[12];
  uint32_t CPU_PGC_PDN_STATUS1;                    /**< CPU PGC software dn trigger status1, offset: 0x170 */
  uint8_t RESERVED_9[24];
  uint32_t A7_PU_PGC_PDN_STATUS0;                  /**< A7 PU PGC software down trigger status, offset: 0x18C */
  uint32_t A7_PU_PGC_PDN_STATUS1;                  /**< A7 PU PGC software down trigger status, offset: 0x190 */
  uint32_t A7_PU_PGC_PDN_STATUS2;                  /**< A7 PU PGC software down trigger status, offset: 0x194 */
  uint32_t M4_PU_PGC_PDN_STATUS0;                  /**< M4 PU PGC software down trigger status, offset: 0x198 */
  uint32_t M4_PU_PGC_PDN_STATUS1;                  /**< M4 PU PGC software down trigger status, offset: 0x19C */
  uint32_t M4_PU_PGC_PDN_STATUS2;                  /**< M4 PU PGC software down trigger status, offset: 0x1A0 */
  uint8_t RESERVED_10[12];
  uint32_t A7_MIX_PDN_FLG;                         /**< A7 MIX PDN FLG, offset: 0x1B0 */
  uint32_t A7_PU_PDN_FLG;                          /**< A7 PU PDN FLG, offset: 0x1B4 */
  uint32_t M4_MIX_PDN_FLG;                         /**< M4 MIX PDN FLG, offset: 0x1B8 */
  uint32_t M4_PU_PDN_FLG;                          /**< M4 PU PDN FLG, offset: 0x1BC */
} volatile *GPC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- GPC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPC_Register_Accessor_Macros GPC - Register accessor macros
 * @{
 */


/* GPC - Register accessors */
#define GPC_LPCR_A7_BSC_REG(base)                ((base)->LPCR_A7_BSC)
#define GPC_LPCR_A7_AD_REG(base)                 ((base)->LPCR_A7_AD)
#define GPC_LPCR_M4_REG(base)                    ((base)->LPCR_M4)
#define GPC_SLPCR_REG(base)                      ((base)->SLPCR)
#define GPC_MLPCR_REG(base)                      ((base)->MLPCR)
#define GPC_PGC_ACK_SEL_A7_REG(base)             ((base)->PGC_ACK_SEL_A7)
#define GPC_PGC_ACK_SEL_M4_REG(base)             ((base)->PGC_ACK_SEL_M4)
#define GPC_MISC_REG(base)                       ((base)->MISC)
#define GPC_IMR1_CORE0_A7_REG(base)              ((base)->IMR1_CORE0_A7)
#define GPC_IMR2_CORE0_A7_REG(base)              ((base)->IMR2_CORE0_A7)
#define GPC_IMR3_CORE0_A7_REG(base)              ((base)->IMR3_CORE0_A7)
#define GPC_IMR4_CORE0_A7_REG(base)              ((base)->IMR4_CORE0_A7)
#define GPC_IMR1_CORE1_A7_REG(base)              ((base)->IMR1_CORE1_A7)
#define GPC_IMR2_CORE1_A7_REG(base)              ((base)->IMR2_CORE1_A7)
#define GPC_IMR3_CORE1_A7_REG(base)              ((base)->IMR3_CORE1_A7)
#define GPC_IMR4_CORE1_A7_REG(base)              ((base)->IMR4_CORE1_A7)
#define GPC_IMR1_M4_REG(base)                    ((base)->IMR1_M4)
#define GPC_IMR2_M4_REG(base)                    ((base)->IMR2_M4)
#define GPC_IMR3_M4_REG(base)                    ((base)->IMR3_M4)
#define GPC_IMR4_M4_REG(base)                    ((base)->IMR4_M4)
#define GPC_ISR1_A7_REG(base)                    ((base)->ISR1_A7)
#define GPC_ISR2_A7_REG(base)                    ((base)->ISR2_A7)
#define GPC_ISR3_A7_REG(base)                    ((base)->ISR3_A7)
#define GPC_ISR4_A7_REG(base)                    ((base)->ISR4_A7)
#define GPC_ISR1_M4_REG(base)                    ((base)->ISR1_M4)
#define GPC_ISR2_M4_REG(base)                    ((base)->ISR2_M4)
#define GPC_ISR3_M4_REG(base)                    ((base)->ISR3_M4)
#define GPC_ISR4_M4_REG(base)                    ((base)->ISR4_M4)
#define GPC_SLT0_CFG_REG(base)                   ((base)->SLT0_CFG)
#define GPC_SLT1_CFG_REG(base)                   ((base)->SLT1_CFG)
#define GPC_SLT2_CFG_REG(base)                   ((base)->SLT2_CFG)
#define GPC_SLT3_CFG_REG(base)                   ((base)->SLT3_CFG)
#define GPC_SLT4_CFG_REG(base)                   ((base)->SLT4_CFG)
#define GPC_SLT5_CFG_REG(base)                   ((base)->SLT5_CFG)
#define GPC_SLT6_CFG_REG(base)                   ((base)->SLT6_CFG)
#define GPC_SLT7_CFG_REG(base)                   ((base)->SLT7_CFG)
#define GPC_SLT8_CFG_REG(base)                   ((base)->SLT8_CFG)
#define GPC_SLT9_CFG_REG(base)                   ((base)->SLT9_CFG)
#define GPC_PGC_CPU_MAPPING_REG(base)            ((base)->PGC_CPU_MAPPING)
#define GPC_CPU_PGC_SW_PUP_REQ_REG(base)         ((base)->CPU_PGC_SW_PUP_REQ)
#define GPC_PU_PGC_SW_PUP_REQ_REG(base)          ((base)->PU_PGC_SW_PUP_REQ)
#define GPC_CPU_PGC_SW_PDN_REQ_REG(base)         ((base)->CPU_PGC_SW_PDN_REQ)
#define GPC_PU_PGC_SW_PDN_REQ_REG(base)          ((base)->PU_PGC_SW_PDN_REQ)
#define GPC_CPU_PGC_PUP_STATUS1_REG(base)        ((base)->CPU_PGC_PUP_STATUS1)
#define GPC_A7_MIX_PGC_PUP_STATUS0_REG(base)     ((base)->A7_MIX_PGC_PUP_STATUS0)
#define GPC_A7_MIX_PGC_PUP_STATUS1_REG(base)     ((base)->A7_MIX_PGC_PUP_STATUS1)
#define GPC_A7_MIX_PGC_PUP_STATUS2_REG(base)     ((base)->A7_MIX_PGC_PUP_STATUS2)
#define GPC_M4_MIX_PGC_PUP_STATUS0_REG(base)     ((base)->M4_MIX_PGC_PUP_STATUS0)
#define GPC_M4_MIX_PGC_PUP_STATUS1_REG(base)     ((base)->M4_MIX_PGC_PUP_STATUS1)
#define GPC_M4_MIX_PGC_PUP_STATUS2_REG(base)     ((base)->M4_MIX_PGC_PUP_STATUS2)
#define GPC_A7_PU_PGC_PUP_STATUS0_REG(base)      ((base)->A7_PU_PGC_PUP_STATUS0)
#define GPC_A7_PU_PGC_PUP_STATUS1_REG(base)      ((base)->A7_PU_PGC_PUP_STATUS1)
#define GPC_A7_PU_PGC_PUP_STATUS2_REG(base)      ((base)->A7_PU_PGC_PUP_STATUS2)
#define GPC_M4_PU_PGC_PUP_STATUS0_REG(base)      ((base)->M4_PU_PGC_PUP_STATUS0)
#define GPC_M4_PU_PGC_PUP_STATUS1_REG(base)      ((base)->M4_PU_PGC_PUP_STATUS1)
#define GPC_M4_PU_PGC_PUP_STATUS2_REG(base)      ((base)->M4_PU_PGC_PUP_STATUS2)
#define GPC_CPU_PGC_PDN_STATUS1_REG(base)        ((base)->CPU_PGC_PDN_STATUS1)
#define GPC_A7_PU_PGC_PDN_STATUS0_REG(base)      ((base)->A7_PU_PGC_PDN_STATUS0)
#define GPC_A7_PU_PGC_PDN_STATUS1_REG(base)      ((base)->A7_PU_PGC_PDN_STATUS1)
#define GPC_A7_PU_PGC_PDN_STATUS2_REG(base)      ((base)->A7_PU_PGC_PDN_STATUS2)
#define GPC_M4_PU_PGC_PDN_STATUS0_REG(base)      ((base)->M4_PU_PGC_PDN_STATUS0)
#define GPC_M4_PU_PGC_PDN_STATUS1_REG(base)      ((base)->M4_PU_PGC_PDN_STATUS1)
#define GPC_M4_PU_PGC_PDN_STATUS2_REG(base)      ((base)->M4_PU_PGC_PDN_STATUS2)
#define GPC_A7_MIX_PDN_FLG_REG(base)             ((base)->A7_MIX_PDN_FLG)
#define GPC_A7_PU_PDN_FLG_REG(base)              ((base)->A7_PU_PDN_FLG)
#define GPC_M4_MIX_PDN_FLG_REG(base)             ((base)->M4_MIX_PDN_FLG)
#define GPC_M4_PU_PDN_FLG_REG(base)              ((base)->M4_PU_PDN_FLG)

/*!
 * @}
 */ /* end of group GPC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- GPC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPC_Register_Masks GPC Register Masks
 * @{
 */

/*! @name LPCR_A7_BSC - Basic Low power control register of A7 platform */
#define GPC_LPCR_A7_BSC_LPM0_MASK                (0x3U)
#define GPC_LPCR_A7_BSC_LPM0_SHIFT               (0U)
#define GPC_LPCR_A7_BSC_LPM0(x)                  (((uint32_t)(((uint32_t)(x)) << GPC_LPCR_A7_BSC_LPM0_SHIFT)) & GPC_LPCR_A7_BSC_LPM0_MASK)
#define GPC_LPCR_A7_BSC_LPM1_MASK                (0xCU)
#define GPC_LPCR_A7_BSC_LPM1_SHIFT               (2U)
#define GPC_LPCR_A7_BSC_LPM1(x)                  (((uint32_t)(((uint32_t)(x)) << GPC_LPCR_A7_BSC_LPM1_SHIFT)) & GPC_LPCR_A7_BSC_LPM1_MASK)
#define GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM_MASK      (0x4000U)
#define GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM_SHIFT     (14U)
#define GPC_LPCR_A7_BSC_MASK_CORE0_WFI_MASK      (0x10000U)
#define GPC_LPCR_A7_BSC_MASK_CORE0_WFI_SHIFT     (16U)
#define GPC_LPCR_A7_BSC_MASK_CORE1_WFI_MASK      (0x20000U)
#define GPC_LPCR_A7_BSC_MASK_CORE1_WFI_SHIFT     (17U)
#define GPC_LPCR_A7_BSC_MASK_L2CC_WFI_MASK       (0x4000000U)
#define GPC_LPCR_A7_BSC_MASK_L2CC_WFI_SHIFT      (26U)
#define GPC_LPCR_A7_BSC_IRQ_SRC_C0_MASK          (0x10000000U)
#define GPC_LPCR_A7_BSC_IRQ_SRC_C0_SHIFT         (28U)
#define GPC_LPCR_A7_BSC_IRQ_SRC_C1_MASK          (0x20000000U)
#define GPC_LPCR_A7_BSC_IRQ_SRC_C1_SHIFT         (29U)
#define GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP_MASK      (0x40000000U)
#define GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP_SHIFT     (30U)
#define GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER_MASK    (0x80000000U)
#define GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER_SHIFT   (31U)

/*! @name LPCR_A7_AD - Advanced Low power control register of A7 platform */
#define GPC_LPCR_A7_AD_EN_C0_WFI_PDN_MASK        (0x1U)
#define GPC_LPCR_A7_AD_EN_C0_WFI_PDN_SHIFT       (0U)
#define GPC_LPCR_A7_AD_EN_C0_PDN_MASK            (0x2U)
#define GPC_LPCR_A7_AD_EN_C0_PDN_SHIFT           (1U)
#define GPC_LPCR_A7_AD_EN_C1_WFI_PDN_MASK        (0x4U)
#define GPC_LPCR_A7_AD_EN_C1_WFI_PDN_SHIFT       (2U)
#define GPC_LPCR_A7_AD_EN_C1_PDN_MASK            (0x8U)
#define GPC_LPCR_A7_AD_EN_C1_PDN_SHIFT           (3U)
#define GPC_LPCR_A7_AD_EN_PLAT_PDN_MASK          (0x10U)
#define GPC_LPCR_A7_AD_EN_PLAT_PDN_SHIFT         (4U)
#define GPC_LPCR_A7_AD_EN_C0_IRQ_PUP_MASK        (0x100U)
#define GPC_LPCR_A7_AD_EN_C0_IRQ_PUP_SHIFT       (8U)
#define GPC_LPCR_A7_AD_EN_C0_PUP_MASK            (0x200U)
#define GPC_LPCR_A7_AD_EN_C0_PUP_SHIFT           (9U)
#define GPC_LPCR_A7_AD_EN_C1_IRQ_PUP_MASK        (0x400U)
#define GPC_LPCR_A7_AD_EN_C1_IRQ_PUP_SHIFT       (10U)
#define GPC_LPCR_A7_AD_EN_C1_PUP_MASK            (0x800U)
#define GPC_LPCR_A7_AD_EN_C1_PUP_SHIFT           (11U)
#define GPC_LPCR_A7_AD_L2_PGE_MASK               (0x10000U)
#define GPC_LPCR_A7_AD_L2_PGE_SHIFT              (16U)

/*! @name LPCR_M4 - Low power control register of CPU1 */
#define GPC_LPCR_M4_LPM0_MASK                    (0x3U)
#define GPC_LPCR_M4_LPM0_SHIFT                   (0U)
#define GPC_LPCR_M4_LPM0(x)                      (((uint32_t)(((uint32_t)(x)) << GPC_LPCR_M4_LPM0_SHIFT)) & GPC_LPCR_M4_LPM0_MASK)
#define GPC_LPCR_M4_EN_M4_PDN_MASK               (0x4U)
#define GPC_LPCR_M4_EN_M4_PDN_SHIFT              (2U)
#define GPC_LPCR_M4_EN_M4_PUP_MASK               (0x8U)
#define GPC_LPCR_M4_EN_M4_PUP_SHIFT              (3U)
#define GPC_LPCR_M4_CPU_CLK_ON_LPM_MASK          (0x4000U)
#define GPC_LPCR_M4_CPU_CLK_ON_LPM_SHIFT         (14U)
#define GPC_LPCR_M4_MASK_M4_WFI_MASK             (0x10000U)
#define GPC_LPCR_M4_MASK_M4_WFI_SHIFT            (16U)
#define GPC_LPCR_M4_MASK_DSM_TRIGGER_MASK        (0x80000000U)
#define GPC_LPCR_M4_MASK_DSM_TRIGGER_SHIFT       (31U)

/*! @name SLPCR - System low power control register */
#define GPC_SLPCR_BYPASS_PMIC_READY_MASK         (0x1U)
#define GPC_SLPCR_BYPASS_PMIC_READY_SHIFT        (0U)
#define GPC_SLPCR_SBYOS_MASK                     (0x2U)
#define GPC_SLPCR_SBYOS_SHIFT                    (1U)
#define GPC_SLPCR_VSTBY_MASK                     (0x4U)
#define GPC_SLPCR_VSTBY_SHIFT                    (2U)
#define GPC_SLPCR_STBY_COUNT_MASK                (0x38U)
#define GPC_SLPCR_STBY_COUNT_SHIFT               (3U)
#define GPC_SLPCR_STBY_COUNT(x)                  (((uint32_t)(((uint32_t)(x)) << GPC_SLPCR_STBY_COUNT_SHIFT)) & GPC_SLPCR_STBY_COUNT_MASK)
#define GPC_SLPCR_COSC_PWRDOWN_MASK              (0x40U)
#define GPC_SLPCR_COSC_PWRDOWN_SHIFT             (6U)
#define GPC_SLPCR_COSC_EN_MASK                   (0x80U)
#define GPC_SLPCR_COSC_EN_SHIFT                  (7U)
#define GPC_SLPCR_OSCCNT_MASK                    (0xFF00U)
#define GPC_SLPCR_OSCCNT_SHIFT                   (8U)
#define GPC_SLPCR_OSCCNT(x)                      (((uint32_t)(((uint32_t)(x)) << GPC_SLPCR_OSCCNT_SHIFT)) & GPC_SLPCR_OSCCNT_MASK)
#define GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE_MASK   (0x10000U)
#define GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE_SHIFT  (16U)
#define GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE_MASK   (0x20000U)
#define GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE_SHIFT  (17U)
#define GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE_MASK   (0x40000U)
#define GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE_SHIFT  (18U)
#define GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE_MASK   (0x80000U)
#define GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE_SHIFT  (19U)
#define GPC_SLPCR_DISABLE_A7_IS_DSM_MASK         (0x800000U)
#define GPC_SLPCR_DISABLE_A7_IS_DSM_SHIFT        (23U)
#define GPC_SLPCR_REG_BYPASS_COUNT_MASK          (0x3F000000U)
#define GPC_SLPCR_REG_BYPASS_COUNT_SHIFT         (24U)
#define GPC_SLPCR_REG_BYPASS_COUNT(x)            (((uint32_t)(((uint32_t)(x)) << GPC_SLPCR_REG_BYPASS_COUNT_SHIFT)) & GPC_SLPCR_REG_BYPASS_COUNT_MASK)
#define GPC_SLPCR_RBC_EN_MASK                    (0x40000000U)
#define GPC_SLPCR_RBC_EN_SHIFT                   (30U)
#define GPC_SLPCR_EN_DSM_MASK                    (0x80000000U)
#define GPC_SLPCR_EN_DSM_SHIFT                   (31U)

/*! @name MLPCR - Memory low power control register */
#define GPC_MLPCR_MEMLP_CTL_DIS_MASK             (0x1U)
#define GPC_MLPCR_MEMLP_CTL_DIS_SHIFT            (0U)
#define GPC_MLPCR_MEMLP_RET_SEL_MASK             (0x2U)
#define GPC_MLPCR_MEMLP_RET_SEL_SHIFT            (1U)
#define GPC_MLPCR_ROMLP_PDN_DIS_MASK             (0x4U)
#define GPC_MLPCR_ROMLP_PDN_DIS_SHIFT            (2U)
#define GPC_MLPCR_MEMLP_ENT_CNT_MASK             (0xFF00U)
#define GPC_MLPCR_MEMLP_ENT_CNT_SHIFT            (8U)
#define GPC_MLPCR_MEMLP_ENT_CNT(x)               (((uint32_t)(((uint32_t)(x)) << GPC_MLPCR_MEMLP_ENT_CNT_SHIFT)) & GPC_MLPCR_MEMLP_ENT_CNT_MASK)
#define GPC_MLPCR_MEM_EXT_CNT_MASK               (0xFF0000U)
#define GPC_MLPCR_MEM_EXT_CNT_SHIFT              (16U)
#define GPC_MLPCR_MEM_EXT_CNT(x)                 (((uint32_t)(((uint32_t)(x)) << GPC_MLPCR_MEM_EXT_CNT_SHIFT)) & GPC_MLPCR_MEM_EXT_CNT_MASK)
#define GPC_MLPCR_MEMLP_RET_PGEN_MASK            (0xFF000000U)
#define GPC_MLPCR_MEMLP_RET_PGEN_SHIFT           (24U)
#define GPC_MLPCR_MEMLP_RET_PGEN(x)              (((uint32_t)(((uint32_t)(x)) << GPC_MLPCR_MEMLP_RET_PGEN_SHIFT)) & GPC_MLPCR_MEMLP_RET_PGEN_MASK)

/*! @name PGC_ACK_SEL_A7 - PGC acknowledge signal selection of A7 platform */
#define GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK_MASK (0x1U)
#define GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK_SHIFT (0U)
#define GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK_MASK (0x2U)
#define GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK_SHIFT (1U)
#define GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK_MASK (0x4U)
#define GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK_SHIFT (2U)
#define GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK_MASK   (0x8U)
#define GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK_SHIFT  (3U)
#define GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK_MASK (0x10U)
#define GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK_SHIFT (4U)
#define GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK_MASK (0x20U)
#define GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK_SHIFT (5U)
#define GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK_MASK (0x40U)
#define GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK_SHIFT (6U)
#define GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK_MASK (0x80U)
#define GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK_SHIFT (7U)
#define GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK_MASK (0x100U)
#define GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK_SHIFT (8U)
#define GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK_MASK   (0x8000U)
#define GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK_SHIFT  (15U)
#define GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK_MASK (0x10000U)
#define GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK_SHIFT (16U)
#define GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK_MASK (0x20000U)
#define GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK_SHIFT (17U)
#define GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK_MASK (0x40000U)
#define GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK_SHIFT (18U)
#define GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK_MASK   (0x80000U)
#define GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK_SHIFT  (19U)
#define GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK_MASK (0x100000U)
#define GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK_SHIFT (20U)
#define GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK_MASK (0x200000U)
#define GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK_SHIFT (21U)
#define GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK_MASK (0x400000U)
#define GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK_SHIFT (22U)
#define GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK_MASK (0x800000U)
#define GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK_SHIFT (23U)
#define GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK_MASK (0x1000000U)
#define GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK_SHIFT (24U)
#define GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK_MASK   (0x80000000U)
#define GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK_SHIFT  (31U)

/*! @name PGC_ACK_SEL_M4 - PGC acknowledge signal selection of M4 platform */
#define GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK_MASK (0x1U)
#define GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK_SHIFT (0U)
#define GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK_MASK   (0x8U)
#define GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK_SHIFT  (3U)
#define GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK_MASK (0x10U)
#define GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK_SHIFT (4U)
#define GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK_MASK (0x20U)
#define GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK_SHIFT (5U)
#define GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK_MASK (0x40U)
#define GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK_SHIFT (6U)
#define GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK_MASK (0x80U)
#define GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK_SHIFT (7U)
#define GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK_MASK (0x100U)
#define GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK_SHIFT (8U)
#define GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK_MASK (0x8000U)
#define GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK_SHIFT (15U)
#define GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK_MASK (0x10000U)
#define GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK_SHIFT (16U)
#define GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK_MASK   (0x80000U)
#define GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK_SHIFT  (19U)
#define GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK_MASK (0x100000U)
#define GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK_SHIFT (20U)
#define GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK_MASK (0x200000U)
#define GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK_SHIFT (21U)
#define GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK_MASK (0x400000U)
#define GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK_SHIFT (22U)
#define GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK_MASK (0x800000U)
#define GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK_SHIFT (23U)
#define GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK_MASK (0x1000000U)
#define GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK_SHIFT (24U)
#define GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK_MASK (0x80000000U)
#define GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK_SHIFT (31U)

/*! @name MISC - GPC Miscellaneous register */
#define GPC_MISC_M4_SLEEP_HOLD_REQ_B_MASK        (0x1U)
#define GPC_MISC_M4_SLEEP_HOLD_REQ_B_SHIFT       (0U)
#define GPC_MISC_GPC_IRQ_MASK_MASK               (0x20U)
#define GPC_MISC_GPC_IRQ_MASK_SHIFT              (5U)
#define GPC_MISC_M4_PDN_REQ_MASK_MASK            (0x100U)
#define GPC_MISC_M4_PDN_REQ_MASK_SHIFT           (8U)

/*! @name IMR1_CORE0_A7 - IRQ masking register 1 of A7 core0 */
#define GPC_IMR1_CORE0_A7_IMR1_CORE0_A7_MASK     (0xFFFFFFFFU)
#define GPC_IMR1_CORE0_A7_IMR1_CORE0_A7_SHIFT    (0U)
#define GPC_IMR1_CORE0_A7_IMR1_CORE0_A7(x)       (((uint32_t)(((uint32_t)(x)) << GPC_IMR1_CORE0_A7_IMR1_CORE0_A7_SHIFT)) & GPC_IMR1_CORE0_A7_IMR1_CORE0_A7_MASK)

/*! @name IMR2_CORE0_A7 - IRQ masking register 2 of A7 core0 */
#define GPC_IMR2_CORE0_A7_IMR2_CORE0_A7_MASK     (0xFFFFFFFFU)
#define GPC_IMR2_CORE0_A7_IMR2_CORE0_A7_SHIFT    (0U)
#define GPC_IMR2_CORE0_A7_IMR2_CORE0_A7(x)       (((uint32_t)(((uint32_t)(x)) << GPC_IMR2_CORE0_A7_IMR2_CORE0_A7_SHIFT)) & GPC_IMR2_CORE0_A7_IMR2_CORE0_A7_MASK)

/*! @name IMR3_CORE0_A7 - IRQ masking register 3 of A7 core0 */
#define GPC_IMR3_CORE0_A7_IMR3_CORE0_A7_MASK     (0xFFFFFFFFU)
#define GPC_IMR3_CORE0_A7_IMR3_CORE0_A7_SHIFT    (0U)
#define GPC_IMR3_CORE0_A7_IMR3_CORE0_A7(x)       (((uint32_t)(((uint32_t)(x)) << GPC_IMR3_CORE0_A7_IMR3_CORE0_A7_SHIFT)) & GPC_IMR3_CORE0_A7_IMR3_CORE0_A7_MASK)

/*! @name IMR4_CORE0_A7 - IRQ masking register 4 of A7 core0 */
#define GPC_IMR4_CORE0_A7_IMR4_CORE0_A7_MASK     (0xFFFFFFFFU)
#define GPC_IMR4_CORE0_A7_IMR4_CORE0_A7_SHIFT    (0U)
#define GPC_IMR4_CORE0_A7_IMR4_CORE0_A7(x)       (((uint32_t)(((uint32_t)(x)) << GPC_IMR4_CORE0_A7_IMR4_CORE0_A7_SHIFT)) & GPC_IMR4_CORE0_A7_IMR4_CORE0_A7_MASK)

/*! @name IMR1_CORE1_A7 - IRQ masking register 1 of A7 core1 */
#define GPC_IMR1_CORE1_A7_IMR1_CORE1_A7_MASK     (0xFFFFFFFFU)
#define GPC_IMR1_CORE1_A7_IMR1_CORE1_A7_SHIFT    (0U)
#define GPC_IMR1_CORE1_A7_IMR1_CORE1_A7(x)       (((uint32_t)(((uint32_t)(x)) << GPC_IMR1_CORE1_A7_IMR1_CORE1_A7_SHIFT)) & GPC_IMR1_CORE1_A7_IMR1_CORE1_A7_MASK)

/*! @name IMR2_CORE1_A7 - IRQ masking register 2 of A7 core1 */
#define GPC_IMR2_CORE1_A7_IMR2_CORE1_A7_MASK     (0xFFFFFFFFU)
#define GPC_IMR2_CORE1_A7_IMR2_CORE1_A7_SHIFT    (0U)
#define GPC_IMR2_CORE1_A7_IMR2_CORE1_A7(x)       (((uint32_t)(((uint32_t)(x)) << GPC_IMR2_CORE1_A7_IMR2_CORE1_A7_SHIFT)) & GPC_IMR2_CORE1_A7_IMR2_CORE1_A7_MASK)

/*! @name IMR3_CORE1_A7 - IRQ masking register 3 of A7 core1 */
#define GPC_IMR3_CORE1_A7_IMR3_CORE1_A7_MASK     (0xFFFFFFFFU)
#define GPC_IMR3_CORE1_A7_IMR3_CORE1_A7_SHIFT    (0U)
#define GPC_IMR3_CORE1_A7_IMR3_CORE1_A7(x)       (((uint32_t)(((uint32_t)(x)) << GPC_IMR3_CORE1_A7_IMR3_CORE1_A7_SHIFT)) & GPC_IMR3_CORE1_A7_IMR3_CORE1_A7_MASK)

/*! @name IMR4_CORE1_A7 - IRQ masking register 4 of A7 core1 */
#define GPC_IMR4_CORE1_A7_IMR4_CORE1_A7_MASK     (0xFFFFFFFFU)
#define GPC_IMR4_CORE1_A7_IMR4_CORE1_A7_SHIFT    (0U)
#define GPC_IMR4_CORE1_A7_IMR4_CORE1_A7(x)       (((uint32_t)(((uint32_t)(x)) << GPC_IMR4_CORE1_A7_IMR4_CORE1_A7_SHIFT)) & GPC_IMR4_CORE1_A7_IMR4_CORE1_A7_MASK)

/*! @name IMR1_M4 - IRQ masking register 1 of M4 */
#define GPC_IMR1_M4_IMR1_M4_MASK                 (0xFFFFFFFFU)
#define GPC_IMR1_M4_IMR1_M4_SHIFT                (0U)
#define GPC_IMR1_M4_IMR1_M4(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_IMR1_M4_IMR1_M4_SHIFT)) & GPC_IMR1_M4_IMR1_M4_MASK)

/*! @name IMR2_M4 - IRQ masking register 2 of M4 */
#define GPC_IMR2_M4_IMR2_M4_MASK                 (0xFFFFFFFFU)
#define GPC_IMR2_M4_IMR2_M4_SHIFT                (0U)
#define GPC_IMR2_M4_IMR2_M4(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_IMR2_M4_IMR2_M4_SHIFT)) & GPC_IMR2_M4_IMR2_M4_MASK)

/*! @name IMR3_M4 - IRQ masking register 3 of M4 */
#define GPC_IMR3_M4_IMR3_M4_MASK                 (0xFFFFFFFFU)
#define GPC_IMR3_M4_IMR3_M4_SHIFT                (0U)
#define GPC_IMR3_M4_IMR3_M4(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_IMR3_M4_IMR3_M4_SHIFT)) & GPC_IMR3_M4_IMR3_M4_MASK)

/*! @name IMR4_M4 - IRQ masking register 4 of M4 */
#define GPC_IMR4_M4_IMR4_M4_MASK                 (0xFFFFFFFFU)
#define GPC_IMR4_M4_IMR4_M4_SHIFT                (0U)
#define GPC_IMR4_M4_IMR4_M4(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_IMR4_M4_IMR4_M4_SHIFT)) & GPC_IMR4_M4_IMR4_M4_MASK)

/*! @name ISR1_A7 - IRQ status register 1 of A7 */
#define GPC_ISR1_A7_ISR1_A7_MASK                 (0xFFFFFFFFU)
#define GPC_ISR1_A7_ISR1_A7_SHIFT                (0U)
#define GPC_ISR1_A7_ISR1_A7(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_ISR1_A7_ISR1_A7_SHIFT)) & GPC_ISR1_A7_ISR1_A7_MASK)

/*! @name ISR2_A7 - IRQ status register 2 of A7 */
#define GPC_ISR2_A7_ISR2_A7_MASK                 (0xFFFFFFFFU)
#define GPC_ISR2_A7_ISR2_A7_SHIFT                (0U)
#define GPC_ISR2_A7_ISR2_A7(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_ISR2_A7_ISR2_A7_SHIFT)) & GPC_ISR2_A7_ISR2_A7_MASK)

/*! @name ISR3_A7 - IRQ status register 3 of A7 */
#define GPC_ISR3_A7_ISR3_A7_MASK                 (0xFFFFFFFFU)
#define GPC_ISR3_A7_ISR3_A7_SHIFT                (0U)
#define GPC_ISR3_A7_ISR3_A7(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_ISR3_A7_ISR3_A7_SHIFT)) & GPC_ISR3_A7_ISR3_A7_MASK)

/*! @name ISR4_A7 - IRQ status register 4 of A7 */
#define GPC_ISR4_A7_ISR4_A7_MASK                 (0xFFFFFFFFU)
#define GPC_ISR4_A7_ISR4_A7_SHIFT                (0U)
#define GPC_ISR4_A7_ISR4_A7(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_ISR4_A7_ISR4_A7_SHIFT)) & GPC_ISR4_A7_ISR4_A7_MASK)

/*! @name ISR1_M4 - IRQ status register 1 of M4 */
#define GPC_ISR1_M4_ISR1_M4_MASK                 (0xFFFFFFFFU)
#define GPC_ISR1_M4_ISR1_M4_SHIFT                (0U)
#define GPC_ISR1_M4_ISR1_M4(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_ISR1_M4_ISR1_M4_SHIFT)) & GPC_ISR1_M4_ISR1_M4_MASK)

/*! @name ISR2_M4 - IRQ status register 2 of M4 */
#define GPC_ISR2_M4_ISR2_M4_MASK                 (0xFFFFFFFFU)
#define GPC_ISR2_M4_ISR2_M4_SHIFT                (0U)
#define GPC_ISR2_M4_ISR2_M4(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_ISR2_M4_ISR2_M4_SHIFT)) & GPC_ISR2_M4_ISR2_M4_MASK)

/*! @name ISR3_M4 - IRQ status register 3 of M4 */
#define GPC_ISR3_M4_ISR3_M4_MASK                 (0xFFFFFFFFU)
#define GPC_ISR3_M4_ISR3_M4_SHIFT                (0U)
#define GPC_ISR3_M4_ISR3_M4(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_ISR3_M4_ISR3_M4_SHIFT)) & GPC_ISR3_M4_ISR3_M4_MASK)

/*! @name ISR4_M4 - IRQ status register 4 of M4 */
#define GPC_ISR4_M4_ISR4_M4_MASK                 (0xFFFFFFFFU)
#define GPC_ISR4_M4_ISR4_M4_SHIFT                (0U)
#define GPC_ISR4_M4_ISR4_M4(x)                   (((uint32_t)(((uint32_t)(x)) << GPC_ISR4_M4_ISR4_M4_SHIFT)) & GPC_ISR4_M4_ISR4_M4_MASK)

/*! @name SLT0_CFG - Slot configure register */
#define GPC_SLT0_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT0_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT0_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT0_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT0_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT0_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT0_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT0_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT0_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT0_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT0_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT0_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT0_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT0_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT0_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT0_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT0_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT0_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT0_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT0_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT0_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT0_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT0_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT0_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT0_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT0_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT0_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT0_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT0_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT0_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT0_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT0_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT0_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT0_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT0_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT0_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT0_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT0_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT0_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT0_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT1_CFG - Slot configure register */
#define GPC_SLT1_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT1_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT1_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT1_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT1_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT1_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT1_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT1_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT1_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT1_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT1_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT1_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT1_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT1_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT1_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT1_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT1_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT1_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT1_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT1_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT1_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT1_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT1_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT1_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT1_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT1_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT1_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT1_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT1_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT1_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT1_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT1_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT1_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT1_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT1_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT1_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT1_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT1_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT1_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT1_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT2_CFG - Slot configure register */
#define GPC_SLT2_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT2_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT2_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT2_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT2_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT2_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT2_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT2_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT2_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT2_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT2_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT2_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT2_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT2_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT2_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT2_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT2_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT2_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT2_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT2_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT2_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT2_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT2_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT2_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT2_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT2_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT2_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT2_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT2_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT2_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT2_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT2_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT2_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT2_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT2_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT2_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT2_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT2_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT2_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT2_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT3_CFG - Slot configure register */
#define GPC_SLT3_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT3_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT3_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT3_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT3_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT3_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT3_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT3_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT3_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT3_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT3_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT3_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT3_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT3_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT3_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT3_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT3_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT3_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT3_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT3_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT3_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT3_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT3_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT3_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT3_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT3_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT3_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT3_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT3_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT3_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT3_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT3_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT3_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT3_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT3_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT3_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT3_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT3_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT3_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT3_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT4_CFG - Slot configure register */
#define GPC_SLT4_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT4_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT4_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT4_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT4_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT4_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT4_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT4_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT4_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT4_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT4_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT4_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT4_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT4_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT4_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT4_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT4_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT4_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT4_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT4_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT4_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT4_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT4_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT4_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT4_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT4_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT4_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT4_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT4_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT4_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT4_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT4_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT4_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT4_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT4_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT4_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT4_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT4_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT4_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT4_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT5_CFG - Slot configure register */
#define GPC_SLT5_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT5_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT5_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT5_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT5_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT5_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT5_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT5_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT5_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT5_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT5_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT5_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT5_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT5_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT5_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT5_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT5_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT5_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT5_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT5_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT5_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT5_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT5_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT5_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT5_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT5_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT5_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT5_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT5_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT5_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT5_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT5_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT5_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT5_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT5_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT5_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT5_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT5_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT5_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT5_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT6_CFG - Slot configure register */
#define GPC_SLT6_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT6_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT6_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT6_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT6_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT6_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT6_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT6_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT6_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT6_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT6_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT6_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT6_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT6_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT6_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT6_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT6_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT6_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT6_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT6_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT6_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT6_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT6_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT6_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT6_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT6_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT6_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT6_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT6_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT6_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT6_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT6_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT6_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT6_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT6_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT6_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT6_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT6_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT6_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT6_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT7_CFG - Slot configure register */
#define GPC_SLT7_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT7_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT7_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT7_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT7_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT7_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT7_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT7_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT7_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT7_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT7_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT7_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT7_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT7_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT7_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT7_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT7_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT7_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT7_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT7_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT7_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT7_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT7_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT7_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT7_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT7_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT7_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT7_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT7_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT7_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT7_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT7_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT7_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT7_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT7_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT7_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT7_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT7_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT7_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT7_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT8_CFG - Slot configure register */
#define GPC_SLT8_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT8_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT8_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT8_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT8_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT8_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT8_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT8_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT8_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT8_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT8_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT8_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT8_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT8_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT8_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT8_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT8_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT8_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT8_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT8_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT8_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT8_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT8_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT8_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT8_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT8_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT8_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT8_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT8_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT8_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT8_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT8_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT8_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT8_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT8_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT8_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT8_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT8_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT8_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT8_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name SLT9_CFG - Slot configure register */
#define GPC_SLT9_CFG_CORE0_A7_PDN_SLOT_CONTROL_MASK (0x1U)
#define GPC_SLT9_CFG_CORE0_A7_PDN_SLOT_CONTROL_SHIFT (0U)
#define GPC_SLT9_CFG_CORE0_A7_PUP_SLOT_CONTROL_MASK (0x2U)
#define GPC_SLT9_CFG_CORE0_A7_PUP_SLOT_CONTROL_SHIFT (1U)
#define GPC_SLT9_CFG_CORE1_A7_PDN_SLOT_CONTROL_MASK (0x4U)
#define GPC_SLT9_CFG_CORE1_A7_PDN_SLOT_CONTROL_SHIFT (2U)
#define GPC_SLT9_CFG_CORE1_A7_PUP_SLOT_CONTROL_MASK (0x8U)
#define GPC_SLT9_CFG_CORE1_A7_PUP_SLOT_CONTROL_SHIFT (3U)
#define GPC_SLT9_CFG_SCU_PDN_SLOT_CONTROL_MASK   (0x10U)
#define GPC_SLT9_CFG_SCU_PDN_SLOT_CONTROL_SHIFT  (4U)
#define GPC_SLT9_CFG_SCU_PUP_SLOT_CONTROL_MASK   (0x20U)
#define GPC_SLT9_CFG_SCU_PUP_SLOT_CONTROL_SHIFT  (5U)
#define GPC_SLT9_CFG_FASTMEGA_PDN_SLOT_CONTROL_MASK (0x40U)
#define GPC_SLT9_CFG_FASTMEGA_PDN_SLOT_CONTROL_SHIFT (6U)
#define GPC_SLT9_CFG_FASTMEGA_PUP_SLOT_CONTROL_MASK (0x80U)
#define GPC_SLT9_CFG_FASTMEGA_PUP_SLOT_CONTROL_SHIFT (7U)
#define GPC_SLT9_CFG_MIPI_PHY_PDN_SLOT_CONTROL_MASK (0x100U)
#define GPC_SLT9_CFG_MIPI_PHY_PDN_SLOT_CONTROL_SHIFT (8U)
#define GPC_SLT9_CFG_MIPI_PHY_PUP_SLOT_CONTROL_MASK (0x200U)
#define GPC_SLT9_CFG_MIPI_PHY_PUP_SLOT_CONTROL_SHIFT (9U)
#define GPC_SLT9_CFG_PCIE_PHY_PDN_SLOT_CONTROL_MASK (0x400U)
#define GPC_SLT9_CFG_PCIE_PHY_PDN_SLOT_CONTROL_SHIFT (10U)
#define GPC_SLT9_CFG_PCIE_PHY_PUP_SLOT_CONTROL_MASK (0x800U)
#define GPC_SLT9_CFG_PCIE_PHY_PUP_SLOT_CONTROL_SHIFT (11U)
#define GPC_SLT9_CFG_USB_OTG1_PDN_SLOT_CONTROL_MASK (0x1000U)
#define GPC_SLT9_CFG_USB_OTG1_PDN_SLOT_CONTROL_SHIFT (12U)
#define GPC_SLT9_CFG_USB_OTG1_PUP_SLOT_CONTROL_MASK (0x2000U)
#define GPC_SLT9_CFG_USB_OTG1_PUP_SLOT_CONTROL_SHIFT (13U)
#define GPC_SLT9_CFG_USB_OTG2_PDN_SLOT_CONTROL_MASK (0x4000U)
#define GPC_SLT9_CFG_USB_OTG2_PDN_SLOT_CONTROL_SHIFT (14U)
#define GPC_SLT9_CFG_USB_OTG2_PUP_SLOT_CONTROL_MASK (0x8000U)
#define GPC_SLT9_CFG_USB_OTG2_PUP_SLOT_CONTROL_SHIFT (15U)
#define GPC_SLT9_CFG_USB_HSIC_PDN_SLOT_CONTROL_MASK (0x10000U)
#define GPC_SLT9_CFG_USB_HSIC_PDN_SLOT_CONTROL_SHIFT (16U)
#define GPC_SLT9_CFG_USB_HSIC_PUP_SLOT_CONTROL_MASK (0x20000U)
#define GPC_SLT9_CFG_USB_HSIC_PUP_SLOT_CONTROL_SHIFT (17U)
#define GPC_SLT9_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_MASK (0x40000U)
#define GPC_SLT9_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL_SHIFT (18U)
#define GPC_SLT9_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_MASK (0x80000U)
#define GPC_SLT9_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL_SHIFT (19U)

/*! @name PGC_CPU_MAPPING - PGC CPU mapping */
#define GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN_MASK (0x1U)
#define GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN_SHIFT (0U)
#define GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN_MASK (0x4U)
#define GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN_SHIFT (2U)
#define GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN_MASK (0x8U)
#define GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN_SHIFT (3U)
#define GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN_MASK (0x10U)
#define GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN_SHIFT (4U)
#define GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN_MASK (0x20U)
#define GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN_SHIFT (5U)
#define GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN_MASK (0x40U)
#define GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN_SHIFT (6U)
#define GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN_MASK (0x100U)
#define GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN_SHIFT (8U)
#define GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN_MASK (0x400U)
#define GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN_SHIFT (10U)
#define GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN_MASK (0x800U)
#define GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN_SHIFT (11U)
#define GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN_MASK (0x1000U)
#define GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN_SHIFT (12U)
#define GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN_MASK (0x2000U)
#define GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN_SHIFT (13U)
#define GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN_MASK (0x4000U)
#define GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN_SHIFT (14U)

/*! @name CPU_PGC_SW_PUP_REQ - CPU PGC software up trigger */
#define GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ_MASK (0x1U)
#define GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ_SHIFT (0U)
#define GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ_MASK (0x2U)
#define GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ_SHIFT (1U)
#define GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ_MASK (0x4U)
#define GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ_SHIFT (2U)

/*! @name PU_PGC_SW_PUP_REQ - PU PGC software up trigger */
#define GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ_MASK (0x1U)
#define GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ_SHIFT (0U)
#define GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ_MASK (0x2U)
#define GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ_SHIFT (1U)
#define GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ_MASK (0x4U)
#define GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ_SHIFT (2U)
#define GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ_MASK (0x8U)
#define GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ_SHIFT (3U)
#define GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ_MASK (0x10U)
#define GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ_SHIFT (4U)

/*! @name CPU_PGC_SW_PDN_REQ - CPU PGC software down trigger */
#define GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ_MASK (0x1U)
#define GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ_SHIFT (0U)
#define GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ_MASK (0x2U)
#define GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ_SHIFT (1U)
#define GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ_MASK (0x4U)
#define GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ_SHIFT (2U)

/*! @name PU_PGC_SW_PDN_REQ - PU PGC software down trigger */
#define GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ_MASK (0x1U)
#define GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ_SHIFT (0U)
#define GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ_MASK (0x2U)
#define GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ_SHIFT (1U)
#define GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ_MASK (0x4U)
#define GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ_SHIFT (2U)
#define GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ_MASK (0x8U)
#define GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ_SHIFT (3U)
#define GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ_MASK (0x10U)
#define GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ_SHIFT (4U)

/*! @name CPU_PGC_PUP_STATUS1 - CPU PGC software up trigger status1 */
#define GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS_MASK (0x1U)
#define GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS_SHIFT (0U)
#define GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS_MASK (0x2U)
#define GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS_SHIFT (1U)
#define GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS_MASK (0x4U)
#define GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS_SHIFT (2U)

/*! @name A7_MIX_PGC_PUP_STATUS0 - A7 MIX software up trigger status register */
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_A7_MIX_PGC_PUP_STATUS0_A7_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name A7_MIX_PGC_PUP_STATUS1 - A7 MIX software up trigger status register */
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_A7_MIX_PGC_PUP_STATUS1_A7_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name A7_MIX_PGC_PUP_STATUS2 - A7 MIX software up trigger status register */
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_A7_MIX_PGC_PUP_STATUS2_A7_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name M4_MIX_PGC_PUP_STATUS0 - M4 MIX PGC software up trigger status register */
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_M4_MIX_PGC_PUP_STATUS0_M4_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name M4_MIX_PGC_PUP_STATUS1 - M4 MIX PGC software up trigger status register */
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_M4_MIX_PGC_PUP_STATUS1_M4_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name M4_MIX_PGC_PUP_STATUS2 - M4 MIX PGC software up trigger status register */
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_M4_MIX_PGC_PUP_STATUS2_M4_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name A7_PU_PGC_PUP_STATUS0 - A7 PU software up trigger status register */
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_A7_PU_PGC_PUP_STATUS0_A7_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name A7_PU_PGC_PUP_STATUS1 - A7 PU software up trigger status register */
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_A7_PU_PGC_PUP_STATUS1_A7_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name A7_PU_PGC_PUP_STATUS2 - A7 PU software up trigger status register */
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_A7_PU_PGC_PUP_STATUS2_A7_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name M4_PU_PGC_PUP_STATUS0 - M4 PU PGC software up trigger status register */
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_M4_PU_PGC_PUP_STATUS0_M4_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name M4_PU_PGC_PUP_STATUS1 - M4 PU PGC software up trigger status register */
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_M4_PU_PGC_PUP_STATUS1_M4_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name M4_PU_PGC_PUP_STATUS2 - M4 PU PGC software up trigger status register */
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_MIPI_PHY_PGC_PUP_STATUS_MASK (0x1U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_MIPI_PHY_PGC_PUP_STATUS_SHIFT (0U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_PCIE_PHY_PGC_PUP_STATUS_MASK (0x2U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_PCIE_PHY_PGC_PUP_STATUS_SHIFT (1U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_USB_OTG1_PHY_PGC_PUP_STATUS_MASK (0x4U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_USB_OTG1_PHY_PGC_PUP_STATUS_SHIFT (2U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_USB_OTG2_PHY_PGC_PUP_STATUS_MASK (0x8U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_USB_OTG2_PHY_PGC_PUP_STATUS_SHIFT (3U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_USB_HSIC_PHY_PGC_PUP_STATUS_MASK (0x10U)
#define GPC_M4_PU_PGC_PUP_STATUS2_M4_USB_HSIC_PHY_PGC_PUP_STATUS_SHIFT (4U)

/*! @name CPU_PGC_PDN_STATUS1 - CPU PGC software dn trigger status1 */
#define GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS_MASK (0x1U)
#define GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS_SHIFT (0U)
#define GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS_MASK (0x2U)
#define GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS_SHIFT (1U)
#define GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS_MASK (0x4U)
#define GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS_SHIFT (2U)

/*! @name A7_PU_PGC_PDN_STATUS0 - A7 PU PGC software down trigger status */
#define GPC_A7_PU_PGC_PDN_STATUS0_CORE0_A7_PDN_STATUS_MASK (0x1U)
#define GPC_A7_PU_PGC_PDN_STATUS0_CORE0_A7_PDN_STATUS_SHIFT (0U)
#define GPC_A7_PU_PGC_PDN_STATUS0_CORE1_A7_PDN_STATUS_MASK (0x2U)
#define GPC_A7_PU_PGC_PDN_STATUS0_CORE1_A7_PDN_STATUS_SHIFT (1U)
#define GPC_A7_PU_PGC_PDN_STATUS0_SCU_A7_PDN_STATUS_MASK (0x4U)
#define GPC_A7_PU_PGC_PDN_STATUS0_SCU_A7_PDN_STATUS_SHIFT (2U)

/*! @name A7_PU_PGC_PDN_STATUS1 - A7 PU PGC software down trigger status */
#define GPC_A7_PU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS_MASK (0x1U)
#define GPC_A7_PU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS_SHIFT (0U)
#define GPC_A7_PU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS_MASK (0x2U)
#define GPC_A7_PU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS_SHIFT (1U)
#define GPC_A7_PU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS_MASK (0x4U)
#define GPC_A7_PU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS_SHIFT (2U)

/*! @name A7_PU_PGC_PDN_STATUS2 - A7 PU PGC software down trigger status */
#define GPC_A7_PU_PGC_PDN_STATUS2_CORE0_A7_PDN_STATUS_MASK (0x1U)
#define GPC_A7_PU_PGC_PDN_STATUS2_CORE0_A7_PDN_STATUS_SHIFT (0U)
#define GPC_A7_PU_PGC_PDN_STATUS2_CORE1_A7_PDN_STATUS_MASK (0x2U)
#define GPC_A7_PU_PGC_PDN_STATUS2_CORE1_A7_PDN_STATUS_SHIFT (1U)
#define GPC_A7_PU_PGC_PDN_STATUS2_SCU_A7_PDN_STATUS_MASK (0x4U)
#define GPC_A7_PU_PGC_PDN_STATUS2_SCU_A7_PDN_STATUS_SHIFT (2U)

/*! @name M4_PU_PGC_PDN_STATUS0 - M4 PU PGC software down trigger status */
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_MIPI_PHY_PGC_PDN_STATUS_MASK (0x1U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_MIPI_PHY_PGC_PDN_STATUS_SHIFT (0U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_PCIE_PHY_PGC_PDN_STATUS_MASK (0x2U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_PCIE_PHY_PGC_PDN_STATUS_SHIFT (1U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_USB_OTG1_PHY_PGC_PDN_STATUS_MASK (0x4U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_USB_OTG1_PHY_PGC_PDN_STATUS_SHIFT (2U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_USB_OTG2_PHY_PGC_PDN_STATUS_MASK (0x8U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_USB_OTG2_PHY_PGC_PDN_STATUS_SHIFT (3U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_USB_HSIC_PHY_PGC_PDN_STATUS_MASK (0x10U)
#define GPC_M4_PU_PGC_PDN_STATUS0_A7_USB_HSIC_PHY_PGC_PDN_STATUS_SHIFT (4U)

/*! @name M4_PU_PGC_PDN_STATUS1 - M4 PU PGC software down trigger status */
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_MIPI_PHY_PGC_PDN_STATUS_MASK (0x1U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_MIPI_PHY_PGC_PDN_STATUS_SHIFT (0U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_PCIE_PHY_PGC_PDN_STATUS_MASK (0x2U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_PCIE_PHY_PGC_PDN_STATUS_SHIFT (1U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_USB_OTG1_PHY_PGC_PDN_STATUS_MASK (0x4U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_USB_OTG1_PHY_PGC_PDN_STATUS_SHIFT (2U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_USB_OTG2_PHY_PGC_PDN_STATUS_MASK (0x8U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_USB_OTG2_PHY_PGC_PDN_STATUS_SHIFT (3U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_USB_HSIC_PHY_PGC_PDN_STATUS_MASK (0x10U)
#define GPC_M4_PU_PGC_PDN_STATUS1_A7_USB_HSIC_PHY_PGC_PDN_STATUS_SHIFT (4U)

/*! @name M4_PU_PGC_PDN_STATUS2 - M4 PU PGC software down trigger status */
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_MIPI_PHY_PGC_PDN_STATUS_MASK (0x1U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_MIPI_PHY_PGC_PDN_STATUS_SHIFT (0U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_PCIE_PHY_PGC_PDN_STATUS_MASK (0x2U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_PCIE_PHY_PGC_PDN_STATUS_SHIFT (1U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_USB_OTG1_PHY_PGC_PDN_STATUS_MASK (0x4U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_USB_OTG1_PHY_PGC_PDN_STATUS_SHIFT (2U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_USB_OTG2_PHY_PGC_PDN_STATUS_MASK (0x8U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_USB_OTG2_PHY_PGC_PDN_STATUS_SHIFT (3U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_USB_HSIC_PHY_PGC_PDN_STATUS_MASK (0x10U)
#define GPC_M4_PU_PGC_PDN_STATUS2_A7_USB_HSIC_PHY_PGC_PDN_STATUS_SHIFT (4U)

/*! @name A7_MIX_PDN_FLG - A7 MIX PDN FLG */
#define GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG_MASK  (0x1U)
#define GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG_SHIFT (0U)

/*! @name A7_PU_PDN_FLG - A7 PU PDN FLG */
#define GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG_MASK (0x1U)
#define GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG_SHIFT (0U)
#define GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG_MASK (0x2U)
#define GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG_SHIFT (1U)
#define GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG_MASK (0x4U)
#define GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG_SHIFT (2U)
#define GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG_MASK (0x8U)
#define GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG_SHIFT (3U)
#define GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG_MASK (0x10U)
#define GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG_SHIFT (4U)

/*! @name M4_MIX_PDN_FLG - M4 MIX PDN FLG */
#define GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG_MASK  (0x1U)
#define GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG_SHIFT (0U)

/*! @name M4_PU_PDN_FLG - M4 PU PDN FLG */
#define GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG_MASK (0x1U)
#define GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG_SHIFT (0U)
#define GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG_MASK (0x2U)
#define GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG_SHIFT (1U)
#define GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG_MASK (0x4U)
#define GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG_SHIFT (2U)
#define GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG_MASK (0x8U)
#define GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG_SHIFT (3U)
#define GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG_MASK (0x10U)
#define GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG_SHIFT (4U)


/*!
 * @}
 */ /* end of group GPC_Register_Masks */


/* GPC - Peripheral instance base addresses */
/** Peripheral GPC base pointer */
#define GPC_BASE_PTR                             ((GPC_MemMapPtr)0x303A0000u)
/** Array initializer of GPC peripheral base pointers */
#define GPC_BASE_PTRS                            { GPC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- GPC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPC_Register_Accessor_Macros GPC - Register accessor macros
 * @{
 */


/* GPC - Register instance definitions */
/* GPC */
#define GPC_LPCR_A7_BSC                          GPC_LPCR_A7_BSC_REG(GPC_BASE_PTR)
#define GPC_LPCR_A7_AD                           GPC_LPCR_A7_AD_REG(GPC_BASE_PTR)
#define GPC_LPCR_M4                              GPC_LPCR_M4_REG(GPC_BASE_PTR)
#define GPC_SLPCR                                GPC_SLPCR_REG(GPC_BASE_PTR)
#define GPC_MLPCR                                GPC_MLPCR_REG(GPC_BASE_PTR)
#define GPC_PGC_ACK_SEL_A7                       GPC_PGC_ACK_SEL_A7_REG(GPC_BASE_PTR)
#define GPC_PGC_ACK_SEL_M4                       GPC_PGC_ACK_SEL_M4_REG(GPC_BASE_PTR)
#define GPC_MISC                                 GPC_MISC_REG(GPC_BASE_PTR)
#define GPC_IMR1_CORE0_A7                        GPC_IMR1_CORE0_A7_REG(GPC_BASE_PTR)
#define GPC_IMR2_CORE0_A7                        GPC_IMR2_CORE0_A7_REG(GPC_BASE_PTR)
#define GPC_IMR3_CORE0_A7                        GPC_IMR3_CORE0_A7_REG(GPC_BASE_PTR)
#define GPC_IMR4_CORE0_A7                        GPC_IMR4_CORE0_A7_REG(GPC_BASE_PTR)
#define GPC_IMR1_CORE1_A7                        GPC_IMR1_CORE1_A7_REG(GPC_BASE_PTR)
#define GPC_IMR2_CORE1_A7                        GPC_IMR2_CORE1_A7_REG(GPC_BASE_PTR)
#define GPC_IMR3_CORE1_A7                        GPC_IMR3_CORE1_A7_REG(GPC_BASE_PTR)
#define GPC_IMR4_CORE1_A7                        GPC_IMR4_CORE1_A7_REG(GPC_BASE_PTR)
#define GPC_IMR1_M4                              GPC_IMR1_M4_REG(GPC_BASE_PTR)
#define GPC_IMR2_M4                              GPC_IMR2_M4_REG(GPC_BASE_PTR)
#define GPC_IMR3_M4                              GPC_IMR3_M4_REG(GPC_BASE_PTR)
#define GPC_IMR4_M4                              GPC_IMR4_M4_REG(GPC_BASE_PTR)
#define GPC_ISR1_A7                              GPC_ISR1_A7_REG(GPC_BASE_PTR)
#define GPC_ISR2_A7                              GPC_ISR2_A7_REG(GPC_BASE_PTR)
#define GPC_ISR3_A7                              GPC_ISR3_A7_REG(GPC_BASE_PTR)
#define GPC_ISR4_A7                              GPC_ISR4_A7_REG(GPC_BASE_PTR)
#define GPC_ISR1_M4                              GPC_ISR1_M4_REG(GPC_BASE_PTR)
#define GPC_ISR2_M4                              GPC_ISR2_M4_REG(GPC_BASE_PTR)
#define GPC_ISR3_M4                              GPC_ISR3_M4_REG(GPC_BASE_PTR)
#define GPC_ISR4_M4                              GPC_ISR4_M4_REG(GPC_BASE_PTR)
#define GPC_SLT0_CFG                             GPC_SLT0_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT1_CFG                             GPC_SLT1_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT2_CFG                             GPC_SLT2_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT3_CFG                             GPC_SLT3_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT4_CFG                             GPC_SLT4_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT5_CFG                             GPC_SLT5_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT6_CFG                             GPC_SLT6_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT7_CFG                             GPC_SLT7_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT8_CFG                             GPC_SLT8_CFG_REG(GPC_BASE_PTR)
#define GPC_SLT9_CFG                             GPC_SLT9_CFG_REG(GPC_BASE_PTR)
#define GPC_PGC_CPU_MAPPING                      GPC_PGC_CPU_MAPPING_REG(GPC_BASE_PTR)
#define GPC_CPU_PGC_SW_PUP_REQ                   GPC_CPU_PGC_SW_PUP_REQ_REG(GPC_BASE_PTR)
#define GPC_PU_PGC_SW_PUP_REQ                    GPC_PU_PGC_SW_PUP_REQ_REG(GPC_BASE_PTR)
#define GPC_CPU_PGC_SW_PDN_REQ                   GPC_CPU_PGC_SW_PDN_REQ_REG(GPC_BASE_PTR)
#define GPC_PU_PGC_SW_PDN_REQ                    GPC_PU_PGC_SW_PDN_REQ_REG(GPC_BASE_PTR)
#define GPC_CPU_PGC_PUP_STATUS1                  GPC_CPU_PGC_PUP_STATUS1_REG(GPC_BASE_PTR)
#define GPC_A7_MIX_PGC_PUP_STATUS0               GPC_A7_MIX_PGC_PUP_STATUS0_REG(GPC_BASE_PTR)
#define GPC_A7_MIX_PGC_PUP_STATUS1               GPC_A7_MIX_PGC_PUP_STATUS1_REG(GPC_BASE_PTR)
#define GPC_A7_MIX_PGC_PUP_STATUS2               GPC_A7_MIX_PGC_PUP_STATUS2_REG(GPC_BASE_PTR)
#define GPC_M4_MIX_PGC_PUP_STATUS0               GPC_M4_MIX_PGC_PUP_STATUS0_REG(GPC_BASE_PTR)
#define GPC_M4_MIX_PGC_PUP_STATUS1               GPC_M4_MIX_PGC_PUP_STATUS1_REG(GPC_BASE_PTR)
#define GPC_M4_MIX_PGC_PUP_STATUS2               GPC_M4_MIX_PGC_PUP_STATUS2_REG(GPC_BASE_PTR)
#define GPC_A7_PU_PGC_PUP_STATUS0                GPC_A7_PU_PGC_PUP_STATUS0_REG(GPC_BASE_PTR)
#define GPC_A7_PU_PGC_PUP_STATUS1                GPC_A7_PU_PGC_PUP_STATUS1_REG(GPC_BASE_PTR)
#define GPC_A7_PU_PGC_PUP_STATUS2                GPC_A7_PU_PGC_PUP_STATUS2_REG(GPC_BASE_PTR)
#define GPC_M4_PU_PGC_PUP_STATUS0                GPC_M4_PU_PGC_PUP_STATUS0_REG(GPC_BASE_PTR)
#define GPC_M4_PU_PGC_PUP_STATUS1                GPC_M4_PU_PGC_PUP_STATUS1_REG(GPC_BASE_PTR)
#define GPC_M4_PU_PGC_PUP_STATUS2                GPC_M4_PU_PGC_PUP_STATUS2_REG(GPC_BASE_PTR)
#define GPC_CPU_PGC_PDN_STATUS1                  GPC_CPU_PGC_PDN_STATUS1_REG(GPC_BASE_PTR)
#define GPC_A7_PU_PGC_PDN_STATUS0                GPC_A7_PU_PGC_PDN_STATUS0_REG(GPC_BASE_PTR)
#define GPC_A7_PU_PGC_PDN_STATUS1                GPC_A7_PU_PGC_PDN_STATUS1_REG(GPC_BASE_PTR)
#define GPC_A7_PU_PGC_PDN_STATUS2                GPC_A7_PU_PGC_PDN_STATUS2_REG(GPC_BASE_PTR)
#define GPC_M4_PU_PGC_PDN_STATUS0                GPC_M4_PU_PGC_PDN_STATUS0_REG(GPC_BASE_PTR)
#define GPC_M4_PU_PGC_PDN_STATUS1                GPC_M4_PU_PGC_PDN_STATUS1_REG(GPC_BASE_PTR)
#define GPC_M4_PU_PGC_PDN_STATUS2                GPC_M4_PU_PGC_PDN_STATUS2_REG(GPC_BASE_PTR)
#define GPC_A7_MIX_PDN_FLG                       GPC_A7_MIX_PDN_FLG_REG(GPC_BASE_PTR)
#define GPC_A7_PU_PDN_FLG                        GPC_A7_PU_PDN_FLG_REG(GPC_BASE_PTR)
#define GPC_M4_MIX_PDN_FLG                       GPC_M4_MIX_PDN_FLG_REG(GPC_BASE_PTR)
#define GPC_M4_PU_PDN_FLG                        GPC_M4_PU_PDN_FLG_REG(GPC_BASE_PTR)

/*!
 * @}
 */ /* end of group GPC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group GPC_Peripheral */


/* ----------------------------------------------------------------------------
   -- GPC_PGC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPC_PGC_Peripheral GPC_PGC
 * @{
 */

/** GPC_PGC - Peripheral register structure */
typedef struct GPC_PGC_MemMap {
  uint32_t A7CORE0_CTRL;                           /**< GPC PGC Control Register, offset: 0x0 */
  uint32_t A7CORE0_PUPSCR;                         /**< GPC PGC Up Sequence Control Register, offset: 0x4 */
  uint32_t A7CORE0_PDNSCR;                         /**< GPC PGC Down Sequence Control Register, offset: 0x8 */
  uint32_t A7CORE0_SR;                             /**< GPC PGC Status Register, offset: 0xC */
  uint8_t RESERVED_0[48];
  uint32_t A7CORE1_CTRL;                           /**< GPC PGC Control Register, offset: 0x40 */
  uint32_t A7CORE1_PUPSCR;                         /**< GPC PGC Up Sequence Control Register, offset: 0x44 */
  uint32_t A7CORE1_PDNSCR;                         /**< GPC PGC Down Sequence Control Register, offset: 0x48 */
  uint32_t A7CORE1_SR;                             /**< GPC PGC Status Register, offset: 0x4C */
  uint8_t RESERVED_1[48];
  uint32_t A7SCU_CTRL;                             /**< GPC PGC Control Register, offset: 0x80 */
  uint32_t A7SCU_PUPSCR;                           /**< GPC PGC Up Sequence Control Register, offset: 0x84 */
  uint32_t A7SCU_PDNSCR;                           /**< GPC PGC Down Sequence Control Register, offset: 0x88 */
  uint32_t A7SCU_SR;                               /**< GPC PGC Status Register, offset: 0x8C */
  uint32_t SCU_AUXSW;                              /**< GPC PGC Auxiliary Power Switch SCU Control Register, offset: 0x90 */
  uint8_t RESERVED_2[44];
  uint32_t MIX_CTRL;                               /**< GPC PGC Control Register, offset: 0xC0 */
  uint32_t MIX_PUPSCR;                             /**< GPC PGC Up Sequence Control Register, offset: 0xC4 */
  uint32_t MIX_PDNSCR;                             /**< GPC PGC Down Sequence Control Register, offset: 0xC8 */
  uint32_t MIX_SR;                                 /**< GPC PGC Status Register, offset: 0xCC */
  uint8_t RESERVED_3[48];
  uint32_t MIPI_CTRL;                              /**< GPC PGC Control Register, offset: 0x100 */
  uint32_t MIPI_PUPSCR;                            /**< GPC PGC Up Sequence Control Register, offset: 0x104 */
  uint32_t MIPI_PDNSCR;                            /**< GPC PGC Down Sequence Control Register, offset: 0x108 */
  uint32_t MIPI_SR;                                /**< GPC PGC Status Register, offset: 0x10C */
  uint8_t RESERVED_4[48];
  uint32_t PCIE_CTRL;                              /**< GPC PGC Control Register, offset: 0x140 */
  uint32_t PCIE_PUPSCR;                            /**< GPC PGC Up Sequence Control Register, offset: 0x144 */
  uint32_t PCIE_PDNSCR;                            /**< GPC PGC Down Sequence Control Register, offset: 0x148 */
  uint32_t PCIE_SR;                                /**< GPC PGC Status Register, offset: 0x14C */
  uint8_t RESERVED_5[704];
  uint32_t MIPI_AUXSW;                             /**< GPC PGC Auxiliary Power Switch Control Register, offset: 0x410 */
  uint8_t RESERVED_6[60];
  uint32_t PCIE_AUXSW;                             /**< GPC PGC Auxiliary Power Switch Control Register, offset: 0x450 */
  uint8_t RESERVED_7[172];
  uint32_t HSIC_CTRL;                              /**< GPC PGC Control Register, offset: 0x500 */
  uint32_t HSIC_PUPSCR;                            /**< GPC PGC Up Sequence Control Register, offset: 0x504 */
  uint32_t HSIC_PDNSCR;                            /**< GPC PGC Down Sequence Control Register, offset: 0x508 */
  uint32_t HSIC_SR;                                /**< GPC PGC Status Register, offset: 0x50C */
} volatile *GPC_PGC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- GPC_PGC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPC_PGC_Register_Accessor_Macros GPC_PGC - Register accessor macros
 * @{
 */


/* GPC_PGC - Register accessors */
#define GPC_PGC_A7CORE0_CTRL_REG(base)           ((base)->A7CORE0_CTRL)
#define GPC_PGC_A7CORE0_PUPSCR_REG(base)         ((base)->A7CORE0_PUPSCR)
#define GPC_PGC_A7CORE0_PDNSCR_REG(base)         ((base)->A7CORE0_PDNSCR)
#define GPC_PGC_A7CORE0_SR_REG(base)             ((base)->A7CORE0_SR)
#define GPC_PGC_A7CORE1_CTRL_REG(base)           ((base)->A7CORE1_CTRL)
#define GPC_PGC_A7CORE1_PUPSCR_REG(base)         ((base)->A7CORE1_PUPSCR)
#define GPC_PGC_A7CORE1_PDNSCR_REG(base)         ((base)->A7CORE1_PDNSCR)
#define GPC_PGC_A7CORE1_SR_REG(base)             ((base)->A7CORE1_SR)
#define GPC_PGC_A7SCU_CTRL_REG(base)             ((base)->A7SCU_CTRL)
#define GPC_PGC_A7SCU_PUPSCR_REG(base)           ((base)->A7SCU_PUPSCR)
#define GPC_PGC_A7SCU_PDNSCR_REG(base)           ((base)->A7SCU_PDNSCR)
#define GPC_PGC_A7SCU_SR_REG(base)               ((base)->A7SCU_SR)
#define GPC_PGC_SCU_AUXSW_REG(base)              ((base)->SCU_AUXSW)
#define GPC_PGC_MIX_CTRL_REG(base)               ((base)->MIX_CTRL)
#define GPC_PGC_MIX_PUPSCR_REG(base)             ((base)->MIX_PUPSCR)
#define GPC_PGC_MIX_PDNSCR_REG(base)             ((base)->MIX_PDNSCR)
#define GPC_PGC_MIX_SR_REG(base)                 ((base)->MIX_SR)
#define GPC_PGC_MIPI_CTRL_REG(base)              ((base)->MIPI_CTRL)
#define GPC_PGC_MIPI_PUPSCR_REG(base)            ((base)->MIPI_PUPSCR)
#define GPC_PGC_MIPI_PDNSCR_REG(base)            ((base)->MIPI_PDNSCR)
#define GPC_PGC_MIPI_SR_REG(base)                ((base)->MIPI_SR)
#define GPC_PGC_PCIE_CTRL_REG(base)              ((base)->PCIE_CTRL)
#define GPC_PGC_PCIE_PUPSCR_REG(base)            ((base)->PCIE_PUPSCR)
#define GPC_PGC_PCIE_PDNSCR_REG(base)            ((base)->PCIE_PDNSCR)
#define GPC_PGC_PCIE_SR_REG(base)                ((base)->PCIE_SR)
#define GPC_PGC_MIPI_AUXSW_REG(base)             ((base)->MIPI_AUXSW)
#define GPC_PGC_PCIE_AUXSW_REG(base)             ((base)->PCIE_AUXSW)
#define GPC_PGC_HSIC_CTRL_REG(base)              ((base)->HSIC_CTRL)
#define GPC_PGC_HSIC_PUPSCR_REG(base)            ((base)->HSIC_PUPSCR)
#define GPC_PGC_HSIC_PDNSCR_REG(base)            ((base)->HSIC_PDNSCR)
#define GPC_PGC_HSIC_SR_REG(base)                ((base)->HSIC_SR)

/*!
 * @}
 */ /* end of group GPC_PGC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- GPC_PGC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPC_PGC_Register_Masks GPC_PGC Register Masks
 * @{
 */

/*! @name A7CORE0_CTRL - GPC PGC Control Register */
#define GPC_PGC_A7CORE0_CTRL_PCR_MASK            (0x1U)
#define GPC_PGC_A7CORE0_CTRL_PCR_SHIFT           (0U)
#define GPC_PGC_A7CORE0_CTRL_L2RSTDIS_MASK       (0x7EU)
#define GPC_PGC_A7CORE0_CTRL_L2RSTDIS_SHIFT      (1U)
#define GPC_PGC_A7CORE0_CTRL_L2RSTDIS(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_CTRL_L2RSTDIS_SHIFT)) & GPC_PGC_A7CORE0_CTRL_L2RSTDIS_MASK)
#define GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1_MASK    (0x3F00U)
#define GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1_SHIFT   (8U)
#define GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1(x)      (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1_SHIFT)) & GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1_MASK)
#define GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR_MASK (0x3F0000U)
#define GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR_SHIFT (16U)
#define GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR(x)  (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR_SHIFT)) & GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR_MASK)
#define GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM_MASK (0x3F000000U)
#define GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT (24U)
#define GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT)) & GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM_MASK)

/*! @name A7CORE0_PUPSCR - GPC PGC Up Sequence Control Register */
#define GPC_PGC_A7CORE0_PUPSCR_SW_MASK           (0x3FU)
#define GPC_PGC_A7CORE0_PUPSCR_SW_SHIFT          (0U)
#define GPC_PGC_A7CORE0_PUPSCR_SW(x)             (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_PUPSCR_SW_SHIFT)) & GPC_PGC_A7CORE0_PUPSCR_SW_MASK)
#define GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT_MASK (0x40U)
#define GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT_SHIFT (6U)
#define GPC_PGC_A7CORE0_PUPSCR_SW2ISO_MASK       (0x7FFF80U)
#define GPC_PGC_A7CORE0_PUPSCR_SW2ISO_SHIFT      (7U)
#define GPC_PGC_A7CORE0_PUPSCR_SW2ISO(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_PUPSCR_SW2ISO_SHIFT)) & GPC_PGC_A7CORE0_PUPSCR_SW2ISO_MASK)
#define GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK (0xFF800000U)
#define GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT (23U)
#define GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK)

/*! @name A7CORE0_PDNSCR - GPC PGC Down Sequence Control Register */
#define GPC_PGC_A7CORE0_PDNSCR_ISO_MASK          (0x3FU)
#define GPC_PGC_A7CORE0_PDNSCR_ISO_SHIFT         (0U)
#define GPC_PGC_A7CORE0_PDNSCR_ISO(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_PDNSCR_ISO_SHIFT)) & GPC_PGC_A7CORE0_PDNSCR_ISO_MASK)
#define GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT_MASK (0x80U)
#define GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT_SHIFT (7U)
#define GPC_PGC_A7CORE0_PDNSCR_ISO2SW_MASK       (0x3F00U)
#define GPC_PGC_A7CORE0_PDNSCR_ISO2SW_SHIFT      (8U)
#define GPC_PGC_A7CORE0_PDNSCR_ISO2SW(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_PDNSCR_ISO2SW_SHIFT)) & GPC_PGC_A7CORE0_PDNSCR_ISO2SW_MASK)
#define GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK (0xFF0000U)
#define GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT (16U)
#define GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK)
#define GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK (0xFF000000U)
#define GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT (24U)
#define GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT)) & GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK)

/*! @name A7CORE0_SR - GPC PGC Status Register */
#define GPC_PGC_A7CORE0_SR_PSR_MASK              (0x1U)
#define GPC_PGC_A7CORE0_SR_PSR_SHIFT             (0U)
#define GPC_PGC_A7CORE0_SR_L2RETN_FLAG_MASK      (0x2U)
#define GPC_PGC_A7CORE0_SR_L2RETN_FLAG_SHIFT     (1U)
#define GPC_PGC_A7CORE0_SR_ALLOFF_FLAG_MASK      (0x4U)
#define GPC_PGC_A7CORE0_SR_ALLOFF_FLAG_SHIFT     (2U)
#define GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL_MASK  (0x78U)
#define GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL_SHIFT (3U)
#define GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL(x)    (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL_SHIFT)) & GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL_MASK)
#define GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT_MASK (0x3FF00U)
#define GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT_SHIFT (8U)
#define GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT_SHIFT)) & GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT_MASK)

/*! @name A7CORE1_CTRL - GPC PGC Control Register */
#define GPC_PGC_A7CORE1_CTRL_PCR_MASK            (0x1U)
#define GPC_PGC_A7CORE1_CTRL_PCR_SHIFT           (0U)
#define GPC_PGC_A7CORE1_CTRL_L2RSTDIS_MASK       (0x7EU)
#define GPC_PGC_A7CORE1_CTRL_L2RSTDIS_SHIFT      (1U)
#define GPC_PGC_A7CORE1_CTRL_L2RSTDIS(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_CTRL_L2RSTDIS_SHIFT)) & GPC_PGC_A7CORE1_CTRL_L2RSTDIS_MASK)
#define GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1_MASK    (0x3F00U)
#define GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1_SHIFT   (8U)
#define GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1(x)      (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1_SHIFT)) & GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1_MASK)
#define GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR_MASK (0x3F0000U)
#define GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR_SHIFT (16U)
#define GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR(x)  (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR_SHIFT)) & GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR_MASK)
#define GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM_MASK (0x3F000000U)
#define GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT (24U)
#define GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT)) & GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM_MASK)

/*! @name A7CORE1_PUPSCR - GPC PGC Up Sequence Control Register */
#define GPC_PGC_A7CORE1_PUPSCR_SW_MASK           (0x3FU)
#define GPC_PGC_A7CORE1_PUPSCR_SW_SHIFT          (0U)
#define GPC_PGC_A7CORE1_PUPSCR_SW(x)             (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_PUPSCR_SW_SHIFT)) & GPC_PGC_A7CORE1_PUPSCR_SW_MASK)
#define GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT_MASK (0x40U)
#define GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT_SHIFT (6U)
#define GPC_PGC_A7CORE1_PUPSCR_SW2ISO_MASK       (0x7FFF80U)
#define GPC_PGC_A7CORE1_PUPSCR_SW2ISO_SHIFT      (7U)
#define GPC_PGC_A7CORE1_PUPSCR_SW2ISO(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_PUPSCR_SW2ISO_SHIFT)) & GPC_PGC_A7CORE1_PUPSCR_SW2ISO_MASK)
#define GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK (0xFF800000U)
#define GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT (23U)
#define GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK)

/*! @name A7CORE1_PDNSCR - GPC PGC Down Sequence Control Register */
#define GPC_PGC_A7CORE1_PDNSCR_ISO_MASK          (0x3FU)
#define GPC_PGC_A7CORE1_PDNSCR_ISO_SHIFT         (0U)
#define GPC_PGC_A7CORE1_PDNSCR_ISO(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_PDNSCR_ISO_SHIFT)) & GPC_PGC_A7CORE1_PDNSCR_ISO_MASK)
#define GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT_MASK (0x80U)
#define GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT_SHIFT (7U)
#define GPC_PGC_A7CORE1_PDNSCR_ISO2SW_MASK       (0x3F00U)
#define GPC_PGC_A7CORE1_PDNSCR_ISO2SW_SHIFT      (8U)
#define GPC_PGC_A7CORE1_PDNSCR_ISO2SW(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_PDNSCR_ISO2SW_SHIFT)) & GPC_PGC_A7CORE1_PDNSCR_ISO2SW_MASK)
#define GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK (0xFF0000U)
#define GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT (16U)
#define GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK)
#define GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK (0xFF000000U)
#define GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT (24U)
#define GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT)) & GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK)

/*! @name A7CORE1_SR - GPC PGC Status Register */
#define GPC_PGC_A7CORE1_SR_PSR_MASK              (0x1U)
#define GPC_PGC_A7CORE1_SR_PSR_SHIFT             (0U)
#define GPC_PGC_A7CORE1_SR_L2RETN_FLAG_MASK      (0x2U)
#define GPC_PGC_A7CORE1_SR_L2RETN_FLAG_SHIFT     (1U)
#define GPC_PGC_A7CORE1_SR_ALLOFF_FLAG_MASK      (0x4U)
#define GPC_PGC_A7CORE1_SR_ALLOFF_FLAG_SHIFT     (2U)
#define GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL_MASK  (0x78U)
#define GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL_SHIFT (3U)
#define GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL(x)    (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL_SHIFT)) & GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL_MASK)
#define GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT_MASK (0x3FF00U)
#define GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT_SHIFT (8U)
#define GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT_SHIFT)) & GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT_MASK)

/*! @name A7SCU_CTRL - GPC PGC Control Register */
#define GPC_PGC_A7SCU_CTRL_PCR_MASK              (0x1U)
#define GPC_PGC_A7SCU_CTRL_PCR_SHIFT             (0U)
#define GPC_PGC_A7SCU_CTRL_L2RSTDIS_MASK         (0x7EU)
#define GPC_PGC_A7SCU_CTRL_L2RSTDIS_SHIFT        (1U)
#define GPC_PGC_A7SCU_CTRL_L2RSTDIS(x)           (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_CTRL_L2RSTDIS_SHIFT)) & GPC_PGC_A7SCU_CTRL_L2RSTDIS_MASK)
#define GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1_MASK      (0x3F00U)
#define GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1_SHIFT     (8U)
#define GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1(x)        (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1_SHIFT)) & GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1_MASK)
#define GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR_MASK  (0x3F0000U)
#define GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR_SHIFT (16U)
#define GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR(x)    (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR_SHIFT)) & GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR_MASK)
#define GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM_MASK (0x3F000000U)
#define GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT (24U)
#define GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT)) & GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM_MASK)

/*! @name A7SCU_PUPSCR - GPC PGC Up Sequence Control Register */
#define GPC_PGC_A7SCU_PUPSCR_SW_MASK             (0x3FU)
#define GPC_PGC_A7SCU_PUPSCR_SW_SHIFT            (0U)
#define GPC_PGC_A7SCU_PUPSCR_SW(x)               (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_PUPSCR_SW_SHIFT)) & GPC_PGC_A7SCU_PUPSCR_SW_MASK)
#define GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT_MASK (0x40U)
#define GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT_SHIFT (6U)
#define GPC_PGC_A7SCU_PUPSCR_SW2ISO_MASK         (0x7FFF80U)
#define GPC_PGC_A7SCU_PUPSCR_SW2ISO_SHIFT        (7U)
#define GPC_PGC_A7SCU_PUPSCR_SW2ISO(x)           (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_PUPSCR_SW2ISO_SHIFT)) & GPC_PGC_A7SCU_PUPSCR_SW2ISO_MASK)
#define GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK (0xFF800000U)
#define GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT (23U)
#define GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK)

/*! @name A7SCU_PDNSCR - GPC PGC Down Sequence Control Register */
#define GPC_PGC_A7SCU_PDNSCR_ISO_MASK            (0x3FU)
#define GPC_PGC_A7SCU_PDNSCR_ISO_SHIFT           (0U)
#define GPC_PGC_A7SCU_PDNSCR_ISO(x)              (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_PDNSCR_ISO_SHIFT)) & GPC_PGC_A7SCU_PDNSCR_ISO_MASK)
#define GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT_MASK (0x80U)
#define GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT_SHIFT (7U)
#define GPC_PGC_A7SCU_PDNSCR_ISO2SW_MASK         (0x3F00U)
#define GPC_PGC_A7SCU_PDNSCR_ISO2SW_SHIFT        (8U)
#define GPC_PGC_A7SCU_PDNSCR_ISO2SW(x)           (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_PDNSCR_ISO2SW_SHIFT)) & GPC_PGC_A7SCU_PDNSCR_ISO2SW_MASK)
#define GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK (0xFF0000U)
#define GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT (16U)
#define GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK)
#define GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK (0xFF000000U)
#define GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT (24U)
#define GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT)) & GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK)

/*! @name A7SCU_SR - GPC PGC Status Register */
#define GPC_PGC_A7SCU_SR_PSR_MASK                (0x1U)
#define GPC_PGC_A7SCU_SR_PSR_SHIFT               (0U)
#define GPC_PGC_A7SCU_SR_L2RETN_FLAG_MASK        (0x2U)
#define GPC_PGC_A7SCU_SR_L2RETN_FLAG_SHIFT       (1U)
#define GPC_PGC_A7SCU_SR_ALLOFF_FLAG_MASK        (0x4U)
#define GPC_PGC_A7SCU_SR_ALLOFF_FLAG_SHIFT       (2U)
#define GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL_MASK    (0x78U)
#define GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL_SHIFT   (3U)
#define GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL(x)      (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL_SHIFT)) & GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL_MASK)
#define GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT_MASK (0x3FF00U)
#define GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT_SHIFT (8U)
#define GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT_SHIFT)) & GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT_MASK)

/*! @name SCU_AUXSW - GPC PGC Auxiliary Power Switch SCU Control Register */
#define GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2_MASK (0x3FFU)
#define GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2_SHIFT (0U)
#define GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2_SHIFT)) & GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2_MASK)
#define GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR_MASK (0xFFC00U)
#define GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR_SHIFT (10U)
#define GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR_SHIFT)) & GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR_MASK)
#define GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC_MASK   (0x3FF00000U)
#define GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC_SHIFT  (20U)
#define GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC(x)     (((uint32_t)(((uint32_t)(x)) << GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC_SHIFT)) & GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC_MASK)

/*! @name MIX_CTRL - GPC PGC Control Register */
#define GPC_PGC_MIX_CTRL_PCR_MASK                (0x1U)
#define GPC_PGC_MIX_CTRL_PCR_SHIFT               (0U)
#define GPC_PGC_MIX_CTRL_L2RSTDIS_MASK           (0x7EU)
#define GPC_PGC_MIX_CTRL_L2RSTDIS_SHIFT          (1U)
#define GPC_PGC_MIX_CTRL_L2RSTDIS(x)             (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_CTRL_L2RSTDIS_SHIFT)) & GPC_PGC_MIX_CTRL_L2RSTDIS_MASK)
#define GPC_PGC_MIX_CTRL_DFTRAM_TCD1_MASK        (0x3F00U)
#define GPC_PGC_MIX_CTRL_DFTRAM_TCD1_SHIFT       (8U)
#define GPC_PGC_MIX_CTRL_DFTRAM_TCD1(x)          (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_CTRL_DFTRAM_TCD1_SHIFT)) & GPC_PGC_MIX_CTRL_DFTRAM_TCD1_MASK)
#define GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR_MASK    (0x3F0000U)
#define GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR_SHIFT   (16U)
#define GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR(x)      (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR_SHIFT)) & GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR_MASK)
#define GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM_MASK (0x3F000000U)
#define GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT (24U)
#define GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM(x)  (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT)) & GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM_MASK)

/*! @name MIX_PUPSCR - GPC PGC Up Sequence Control Register */
#define GPC_PGC_MIX_PUPSCR_SW_MASK               (0x3FU)
#define GPC_PGC_MIX_PUPSCR_SW_SHIFT              (0U)
#define GPC_PGC_MIX_PUPSCR_SW(x)                 (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_PUPSCR_SW_SHIFT)) & GPC_PGC_MIX_PUPSCR_SW_MASK)
#define GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT_MASK (0x40U)
#define GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT_SHIFT (6U)
#define GPC_PGC_MIX_PUPSCR_SW2ISO_MASK           (0x7FFF80U)
#define GPC_PGC_MIX_PUPSCR_SW2ISO_SHIFT          (7U)
#define GPC_PGC_MIX_PUPSCR_SW2ISO(x)             (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_PUPSCR_SW2ISO_SHIFT)) & GPC_PGC_MIX_PUPSCR_SW2ISO_MASK)
#define GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK (0xFF800000U)
#define GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT (23U)
#define GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK)

/*! @name MIX_PDNSCR - GPC PGC Down Sequence Control Register */
#define GPC_PGC_MIX_PDNSCR_ISO_MASK              (0x3FU)
#define GPC_PGC_MIX_PDNSCR_ISO_SHIFT             (0U)
#define GPC_PGC_MIX_PDNSCR_ISO(x)                (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_PDNSCR_ISO_SHIFT)) & GPC_PGC_MIX_PDNSCR_ISO_MASK)
#define GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT_MASK (0x80U)
#define GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT_SHIFT (7U)
#define GPC_PGC_MIX_PDNSCR_ISO2SW_MASK           (0x3F00U)
#define GPC_PGC_MIX_PDNSCR_ISO2SW_SHIFT          (8U)
#define GPC_PGC_MIX_PDNSCR_ISO2SW(x)             (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_PDNSCR_ISO2SW_SHIFT)) & GPC_PGC_MIX_PDNSCR_ISO2SW_MASK)
#define GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK (0xFF0000U)
#define GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT (16U)
#define GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK)
#define GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK (0xFF000000U)
#define GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT (24U)
#define GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT)) & GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK)

/*! @name MIX_SR - GPC PGC Status Register */
#define GPC_PGC_MIX_SR_PSR_MASK                  (0x1U)
#define GPC_PGC_MIX_SR_PSR_SHIFT                 (0U)
#define GPC_PGC_MIX_SR_L2RETN_FLAG_MASK          (0x2U)
#define GPC_PGC_MIX_SR_L2RETN_FLAG_SHIFT         (1U)
#define GPC_PGC_MIX_SR_ALLOFF_FLAG_MASK          (0x4U)
#define GPC_PGC_MIX_SR_ALLOFF_FLAG_SHIFT         (2U)
#define GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL_MASK      (0x78U)
#define GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL_SHIFT     (3U)
#define GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL(x)        (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL_SHIFT)) & GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL_MASK)
#define GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT_MASK (0x3FF00U)
#define GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT_SHIFT (8U)
#define GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT(x)  (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT_SHIFT)) & GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT_MASK)

/*! @name MIPI_CTRL - GPC PGC Control Register */
#define GPC_PGC_MIPI_CTRL_PCR_MASK               (0x1U)
#define GPC_PGC_MIPI_CTRL_PCR_SHIFT              (0U)
#define GPC_PGC_MIPI_CTRL_L2RSTDIS_MASK          (0x7EU)
#define GPC_PGC_MIPI_CTRL_L2RSTDIS_SHIFT         (1U)
#define GPC_PGC_MIPI_CTRL_L2RSTDIS(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_CTRL_L2RSTDIS_SHIFT)) & GPC_PGC_MIPI_CTRL_L2RSTDIS_MASK)
#define GPC_PGC_MIPI_CTRL_DFTRAM_TCD1_MASK       (0x3F00U)
#define GPC_PGC_MIPI_CTRL_DFTRAM_TCD1_SHIFT      (8U)
#define GPC_PGC_MIPI_CTRL_DFTRAM_TCD1(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_CTRL_DFTRAM_TCD1_SHIFT)) & GPC_PGC_MIPI_CTRL_DFTRAM_TCD1_MASK)
#define GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR_MASK   (0x3F0000U)
#define GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR_SHIFT  (16U)
#define GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR(x)     (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR_SHIFT)) & GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR_MASK)
#define GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM_MASK (0x3F000000U)
#define GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT (24U)
#define GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT)) & GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM_MASK)

/*! @name MIPI_PUPSCR - GPC PGC Up Sequence Control Register */
#define GPC_PGC_MIPI_PUPSCR_SW_MASK              (0x3FU)
#define GPC_PGC_MIPI_PUPSCR_SW_SHIFT             (0U)
#define GPC_PGC_MIPI_PUPSCR_SW(x)                (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_PUPSCR_SW_SHIFT)) & GPC_PGC_MIPI_PUPSCR_SW_MASK)
#define GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT_MASK (0x40U)
#define GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT_SHIFT (6U)
#define GPC_PGC_MIPI_PUPSCR_SW2ISO_MASK          (0x7FFF80U)
#define GPC_PGC_MIPI_PUPSCR_SW2ISO_SHIFT         (7U)
#define GPC_PGC_MIPI_PUPSCR_SW2ISO(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_PUPSCR_SW2ISO_SHIFT)) & GPC_PGC_MIPI_PUPSCR_SW2ISO_MASK)
#define GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK (0xFF800000U)
#define GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT (23U)
#define GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK)

/*! @name MIPI_PDNSCR - GPC PGC Down Sequence Control Register */
#define GPC_PGC_MIPI_PDNSCR_ISO_MASK             (0x3FU)
#define GPC_PGC_MIPI_PDNSCR_ISO_SHIFT            (0U)
#define GPC_PGC_MIPI_PDNSCR_ISO(x)               (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_PDNSCR_ISO_SHIFT)) & GPC_PGC_MIPI_PDNSCR_ISO_MASK)
#define GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT_MASK (0x80U)
#define GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT_SHIFT (7U)
#define GPC_PGC_MIPI_PDNSCR_ISO2SW_MASK          (0x3F00U)
#define GPC_PGC_MIPI_PDNSCR_ISO2SW_SHIFT         (8U)
#define GPC_PGC_MIPI_PDNSCR_ISO2SW(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_PDNSCR_ISO2SW_SHIFT)) & GPC_PGC_MIPI_PDNSCR_ISO2SW_MASK)
#define GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK (0xFF0000U)
#define GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT (16U)
#define GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK)
#define GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK (0xFF000000U)
#define GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT (24U)
#define GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT)) & GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK)

/*! @name MIPI_SR - GPC PGC Status Register */
#define GPC_PGC_MIPI_SR_PSR_MASK                 (0x1U)
#define GPC_PGC_MIPI_SR_PSR_SHIFT                (0U)
#define GPC_PGC_MIPI_SR_L2RETN_FLAG_MASK         (0x2U)
#define GPC_PGC_MIPI_SR_L2RETN_FLAG_SHIFT        (1U)
#define GPC_PGC_MIPI_SR_ALLOFF_FLAG_MASK         (0x4U)
#define GPC_PGC_MIPI_SR_ALLOFF_FLAG_SHIFT        (2U)
#define GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL_MASK     (0x78U)
#define GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL_SHIFT    (3U)
#define GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL(x)       (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL_SHIFT)) & GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL_MASK)
#define GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT_MASK (0x3FF00U)
#define GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT_SHIFT (8U)
#define GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT_SHIFT)) & GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT_MASK)

/*! @name PCIE_CTRL - GPC PGC Control Register */
#define GPC_PGC_PCIE_CTRL_PCR_MASK               (0x1U)
#define GPC_PGC_PCIE_CTRL_PCR_SHIFT              (0U)
#define GPC_PGC_PCIE_CTRL_L2RSTDIS_MASK          (0x7EU)
#define GPC_PGC_PCIE_CTRL_L2RSTDIS_SHIFT         (1U)
#define GPC_PGC_PCIE_CTRL_L2RSTDIS(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_CTRL_L2RSTDIS_SHIFT)) & GPC_PGC_PCIE_CTRL_L2RSTDIS_MASK)
#define GPC_PGC_PCIE_CTRL_DFTRAM_TCD1_MASK       (0x3F00U)
#define GPC_PGC_PCIE_CTRL_DFTRAM_TCD1_SHIFT      (8U)
#define GPC_PGC_PCIE_CTRL_DFTRAM_TCD1(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_CTRL_DFTRAM_TCD1_SHIFT)) & GPC_PGC_PCIE_CTRL_DFTRAM_TCD1_MASK)
#define GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR_MASK   (0x3F0000U)
#define GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR_SHIFT  (16U)
#define GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR(x)     (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR_SHIFT)) & GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR_MASK)
#define GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM_MASK (0x3F000000U)
#define GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT (24U)
#define GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT)) & GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM_MASK)

/*! @name PCIE_PUPSCR - GPC PGC Up Sequence Control Register */
#define GPC_PGC_PCIE_PUPSCR_SW_MASK              (0x3FU)
#define GPC_PGC_PCIE_PUPSCR_SW_SHIFT             (0U)
#define GPC_PGC_PCIE_PUPSCR_SW(x)                (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_PUPSCR_SW_SHIFT)) & GPC_PGC_PCIE_PUPSCR_SW_MASK)
#define GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT_MASK (0x40U)
#define GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT_SHIFT (6U)
#define GPC_PGC_PCIE_PUPSCR_SW2ISO_MASK          (0x7FFF80U)
#define GPC_PGC_PCIE_PUPSCR_SW2ISO_SHIFT         (7U)
#define GPC_PGC_PCIE_PUPSCR_SW2ISO(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_PUPSCR_SW2ISO_SHIFT)) & GPC_PGC_PCIE_PUPSCR_SW2ISO_MASK)
#define GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK (0xFF800000U)
#define GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT (23U)
#define GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT_MASK)

/*! @name PCIE_PDNSCR - GPC PGC Down Sequence Control Register */
#define GPC_PGC_PCIE_PDNSCR_ISO_MASK             (0x3FU)
#define GPC_PGC_PCIE_PDNSCR_ISO_SHIFT            (0U)
#define GPC_PGC_PCIE_PDNSCR_ISO(x)               (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_PDNSCR_ISO_SHIFT)) & GPC_PGC_PCIE_PDNSCR_ISO_MASK)
#define GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT_MASK (0x80U)
#define GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT_SHIFT (7U)
#define GPC_PGC_PCIE_PDNSCR_ISO2SW_MASK          (0x3F00U)
#define GPC_PGC_PCIE_PDNSCR_ISO2SW_SHIFT         (8U)
#define GPC_PGC_PCIE_PDNSCR_ISO2SW(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_PDNSCR_ISO2SW_SHIFT)) & GPC_PGC_PCIE_PDNSCR_ISO2SW_MASK)
#define GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK (0xFF0000U)
#define GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT (16U)
#define GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT_SHIFT)) & GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT_MASK)
#define GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK (0xFF000000U)
#define GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT (24U)
#define GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT)) & GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK)

/*! @name PCIE_SR - GPC PGC Status Register */
#define GPC_PGC_PCIE_SR_PSR_MASK                 (0x1U)
#define GPC_PGC_PCIE_SR_PSR_SHIFT                (0U)
#define GPC_PGC_PCIE_SR_L2RETN_FLAG_MASK         (0x2U)
#define GPC_PGC_PCIE_SR_L2RETN_FLAG_SHIFT        (1U)
#define GPC_PGC_PCIE_SR_ALLOFF_FLAG_MASK         (0x4U)
#define GPC_PGC_PCIE_SR_ALLOFF_FLAG_SHIFT        (2U)
#define GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL_MASK     (0x78U)
#define GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL_SHIFT    (3U)
#define GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL(x)       (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL_SHIFT)) & GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL_MASK)
#define GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT_MASK (0x3FF00U)
#define GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT_SHIFT (8U)
#define GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT_SHIFT)) & GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT_MASK)

/*! @name MIPI_AUXSW - GPC PGC Auxiliary Power Switch Control Register */
#define GPC_PGC_MIPI_AUXSW_SW2_MASK              (0x3FU)
#define GPC_PGC_MIPI_AUXSW_SW2_SHIFT             (0U)
#define GPC_PGC_MIPI_AUXSW_SW2(x)                (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_AUXSW_SW2_SHIFT)) & GPC_PGC_MIPI_AUXSW_SW2_MASK)
#define GPC_PGC_MIPI_AUXSW_ISO2SW2_MASK          (0x3F00U)
#define GPC_PGC_MIPI_AUXSW_ISO2SW2_SHIFT         (8U)
#define GPC_PGC_MIPI_AUXSW_ISO2SW2(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_AUXSW_ISO2SW2_SHIFT)) & GPC_PGC_MIPI_AUXSW_ISO2SW2_MASK)
#define GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL_MASK  (0xF0000U)
#define GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL_SHIFT (16U)
#define GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL(x)    (((uint32_t)(((uint32_t)(x)) << GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL_SHIFT)) & GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL_MASK)

/*! @name PCIE_AUXSW - GPC PGC Auxiliary Power Switch Control Register */
#define GPC_PGC_PCIE_AUXSW_SW2_MASK              (0x3FU)
#define GPC_PGC_PCIE_AUXSW_SW2_SHIFT             (0U)
#define GPC_PGC_PCIE_AUXSW_SW2(x)                (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_AUXSW_SW2_SHIFT)) & GPC_PGC_PCIE_AUXSW_SW2_MASK)
#define GPC_PGC_PCIE_AUXSW_ISO2SW2_MASK          (0x3F00U)
#define GPC_PGC_PCIE_AUXSW_ISO2SW2_SHIFT         (8U)
#define GPC_PGC_PCIE_AUXSW_ISO2SW2(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_AUXSW_ISO2SW2_SHIFT)) & GPC_PGC_PCIE_AUXSW_ISO2SW2_MASK)
#define GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL_MASK  (0xF0000U)
#define GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL_SHIFT (16U)
#define GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL(x)    (((uint32_t)(((uint32_t)(x)) << GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL_SHIFT)) & GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL_MASK)

/*! @name HSIC_CTRL - GPC PGC Control Register */
#define GPC_PGC_HSIC_CTRL_PCR_MASK               (0x1U)
#define GPC_PGC_HSIC_CTRL_PCR_SHIFT              (0U)
#define GPC_PGC_HSIC_CTRL_L2RSTDIS_MASK          (0x7EU)
#define GPC_PGC_HSIC_CTRL_L2RSTDIS_SHIFT         (1U)
#define GPC_PGC_HSIC_CTRL_L2RSTDIS(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_CTRL_L2RSTDIS_SHIFT)) & GPC_PGC_HSIC_CTRL_L2RSTDIS_MASK)
#define GPC_PGC_HSIC_CTRL_DFTRAM_TCD1_MASK       (0x3F00U)
#define GPC_PGC_HSIC_CTRL_DFTRAM_TCD1_SHIFT      (8U)
#define GPC_PGC_HSIC_CTRL_DFTRAM_TCD1(x)         (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_CTRL_DFTRAM_TCD1_SHIFT)) & GPC_PGC_HSIC_CTRL_DFTRAM_TCD1_MASK)
#define GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR_MASK   (0x3F0000U)
#define GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR_SHIFT  (16U)
#define GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR(x)     (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR_SHIFT)) & GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR_MASK)
#define GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM_MASK (0x3F000000U)
#define GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT (24U)
#define GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM_SHIFT)) & GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM_MASK)

/*! @name HSIC_PUPSCR - GPC PGC Up Sequence Control Register */
#define GPC_PGC_HSIC_PUPSCR_SW_MASK              (0x3FU)
#define GPC_PGC_HSIC_PUPSCR_SW_SHIFT             (0U)
#define GPC_PGC_HSIC_PUPSCR_SW(x)                (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_PUPSCR_SW_SHIFT)) & GPC_PGC_HSIC_PUPSCR_SW_MASK)
#define GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT_MASK (0x40U)
#define GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT_SHIFT (6U)
#define GPC_PGC_HSIC_PUPSCR_SW2ISO_MASK          (0x7FFF80U)
#define GPC_PGC_HSIC_PUPSCR_SW2ISO_SHIFT         (7U)
#define GPC_PGC_HSIC_PUPSCR_SW2ISO(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_PUPSCR_SW2ISO_SHIFT)) & GPC_PGC_HSIC_PUPSCR_SW2ISO_MASK)
#define GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT_MASK (0xFF800000U)
#define GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT_SHIFT (23U)
#define GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT(x)  (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT_SHIFT)) & GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT_MASK)

/*! @name HSIC_PDNSCR - GPC PGC Down Sequence Control Register */
#define GPC_PGC_HSIC_PDNSCR_ISO_MASK             (0x3FU)
#define GPC_PGC_HSIC_PDNSCR_ISO_SHIFT            (0U)
#define GPC_PGC_HSIC_PDNSCR_ISO(x)               (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_PDNSCR_ISO_SHIFT)) & GPC_PGC_HSIC_PDNSCR_ISO_MASK)
#define GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT_MASK (0x80U)
#define GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT_SHIFT (7U)
#define GPC_PGC_HSIC_PDNSCR_ISO2SW_MASK          (0x3F00U)
#define GPC_PGC_HSIC_PDNSCR_ISO2SW_SHIFT         (8U)
#define GPC_PGC_HSIC_PDNSCR_ISO2SW(x)            (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_PDNSCR_ISO2SW_SHIFT)) & GPC_PGC_HSIC_PDNSCR_ISO2SW_MASK)
#define GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT_MASK (0xFF0000U)
#define GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT_SHIFT (16U)
#define GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT(x)  (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT_SHIFT)) & GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT_MASK)
#define GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK (0xFF000000U)
#define GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT (24U)
#define GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT_SHIFT)) & GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT_MASK)

/*! @name HSIC_SR - GPC PGC Status Register */
#define GPC_PGC_HSIC_SR_PSR_MASK                 (0x1U)
#define GPC_PGC_HSIC_SR_PSR_SHIFT                (0U)
#define GPC_PGC_HSIC_SR_L2RETN_FLAG_MASK         (0x2U)
#define GPC_PGC_HSIC_SR_L2RETN_FLAG_SHIFT        (1U)
#define GPC_PGC_HSIC_SR_ALLOFF_FLAG_MASK         (0x4U)
#define GPC_PGC_HSIC_SR_ALLOFF_FLAG_SHIFT        (2U)
#define GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL_MASK     (0x78U)
#define GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL_SHIFT    (3U)
#define GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL(x)       (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL_SHIFT)) & GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL_MASK)
#define GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT_MASK (0x3FF00U)
#define GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT_SHIFT (8U)
#define GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT(x) (((uint32_t)(((uint32_t)(x)) << GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT_SHIFT)) & GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT_MASK)


/*!
 * @}
 */ /* end of group GPC_PGC_Register_Masks */


/* GPC_PGC - Peripheral instance base addresses */
/** Peripheral GPC_PGC base pointer */
#define GPC_PGC_BASE_PTR                         ((GPC_PGC_MemMapPtr)0x303A0800u)
/** Array initializer of GPC_PGC peripheral base pointers */
#define GPC_PGC_BASE_PTRS                        { GPC_PGC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- GPC_PGC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPC_PGC_Register_Accessor_Macros GPC_PGC - Register accessor macros
 * @{
 */


/* GPC_PGC - Register instance definitions */
/* GPC_PGC */
#define GPC_PGC_A7CORE0_CTRL                     GPC_PGC_A7CORE0_CTRL_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7CORE0_PUPSCR                   GPC_PGC_A7CORE0_PUPSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7CORE0_PDNSCR                   GPC_PGC_A7CORE0_PDNSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7CORE0_SR                       GPC_PGC_A7CORE0_SR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7CORE1_CTRL                     GPC_PGC_A7CORE1_CTRL_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7CORE1_PUPSCR                   GPC_PGC_A7CORE1_PUPSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7CORE1_PDNSCR                   GPC_PGC_A7CORE1_PDNSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7CORE1_SR                       GPC_PGC_A7CORE1_SR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7SCU_CTRL                       GPC_PGC_A7SCU_CTRL_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7SCU_PUPSCR                     GPC_PGC_A7SCU_PUPSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7SCU_PDNSCR                     GPC_PGC_A7SCU_PDNSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_A7SCU_SR                         GPC_PGC_A7SCU_SR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_SCU_AUXSW                        GPC_PGC_SCU_AUXSW_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIX_CTRL                         GPC_PGC_MIX_CTRL_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIX_PUPSCR                       GPC_PGC_MIX_PUPSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIX_PDNSCR                       GPC_PGC_MIX_PDNSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIX_SR                           GPC_PGC_MIX_SR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIPI_CTRL                        GPC_PGC_MIPI_CTRL_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIPI_PUPSCR                      GPC_PGC_MIPI_PUPSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIPI_PDNSCR                      GPC_PGC_MIPI_PDNSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIPI_SR                          GPC_PGC_MIPI_SR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_PCIE_CTRL                        GPC_PGC_PCIE_CTRL_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_PCIE_PUPSCR                      GPC_PGC_PCIE_PUPSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_PCIE_PDNSCR                      GPC_PGC_PCIE_PDNSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_PCIE_SR                          GPC_PGC_PCIE_SR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_MIPI_AUXSW                       GPC_PGC_MIPI_AUXSW_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_PCIE_AUXSW                       GPC_PGC_PCIE_AUXSW_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_HSIC_CTRL                        GPC_PGC_HSIC_CTRL_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_HSIC_PUPSCR                      GPC_PGC_HSIC_PUPSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_HSIC_PDNSCR                      GPC_PGC_HSIC_PDNSCR_REG(GPC_PGC_BASE_PTR)
#define GPC_PGC_HSIC_SR                          GPC_PGC_HSIC_SR_REG(GPC_PGC_BASE_PTR)

/*!
 * @}
 */ /* end of group GPC_PGC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group GPC_PGC_Peripheral */


/* ----------------------------------------------------------------------------
   -- GPIO
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Peripheral GPIO
 * @{
 */

/** GPIO - Peripheral register structure */
typedef struct GPIO_MemMap {
  uint32_t DR;                                     /**< GPIO data register, offset: 0x0 */
  uint32_t GDIR;                                   /**< GPIO direction register, offset: 0x4 */
  uint32_t PSR;                                    /**< GPIO pad status register, offset: 0x8 */
  uint32_t ICR1;                                   /**< GPIO interrupt configuration register1, offset: 0xC */
  uint32_t ICR2;                                   /**< GPIO interrupt configuration register2, offset: 0x10 */
  uint32_t IMR;                                    /**< GPIO interrupt mask register, offset: 0x14 */
  uint32_t ISR;                                    /**< GPIO interrupt status register, offset: 0x18 */
  uint32_t EDGE_SEL;                               /**< GPIO edge select register, offset: 0x1C */
} volatile *GPIO_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- GPIO - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Register_Accessor_Macros GPIO - Register accessor macros
 * @{
 */


/* GPIO - Register accessors */
#define GPIO_DR_REG(base)                        ((base)->DR)
#define GPIO_GDIR_REG(base)                      ((base)->GDIR)
#define GPIO_PSR_REG(base)                       ((base)->PSR)
#define GPIO_ICR1_REG(base)                      ((base)->ICR1)
#define GPIO_ICR2_REG(base)                      ((base)->ICR2)
#define GPIO_IMR_REG(base)                       ((base)->IMR)
#define GPIO_ISR_REG(base)                       ((base)->ISR)
#define GPIO_EDGE_SEL_REG(base)                  ((base)->EDGE_SEL)

/*!
 * @}
 */ /* end of group GPIO_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- GPIO Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Register_Masks GPIO Register Masks
 * @{
 */

/*! @name DR - GPIO data register */
#define GPIO_DR_DR_MASK                          (0xFFFFFFFFU)
#define GPIO_DR_DR_SHIFT                         (0U)
#define GPIO_DR_DR(x)                            (((uint32_t)(((uint32_t)(x)) << GPIO_DR_DR_SHIFT)) & GPIO_DR_DR_MASK)

/*! @name GDIR - GPIO direction register */
#define GPIO_GDIR_GDIR_MASK                      (0xFFFFFFFFU)
#define GPIO_GDIR_GDIR_SHIFT                     (0U)
#define GPIO_GDIR_GDIR(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_GDIR_GDIR_SHIFT)) & GPIO_GDIR_GDIR_MASK)

/*! @name PSR - GPIO pad status register */
#define GPIO_PSR_PSR_MASK                        (0xFFFFFFFFU)
#define GPIO_PSR_PSR_SHIFT                       (0U)
#define GPIO_PSR_PSR(x)                          (((uint32_t)(((uint32_t)(x)) << GPIO_PSR_PSR_SHIFT)) & GPIO_PSR_PSR_MASK)

/*! @name ICR1 - GPIO interrupt configuration register1 */
#define GPIO_ICR1_ICR0_MASK                      (0x3U)
#define GPIO_ICR1_ICR0_SHIFT                     (0U)
#define GPIO_ICR1_ICR0(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR0_SHIFT)) & GPIO_ICR1_ICR0_MASK)
#define GPIO_ICR1_ICR1_MASK                      (0xCU)
#define GPIO_ICR1_ICR1_SHIFT                     (2U)
#define GPIO_ICR1_ICR1(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR1_SHIFT)) & GPIO_ICR1_ICR1_MASK)
#define GPIO_ICR1_ICR2_MASK                      (0x30U)
#define GPIO_ICR1_ICR2_SHIFT                     (4U)
#define GPIO_ICR1_ICR2(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR2_SHIFT)) & GPIO_ICR1_ICR2_MASK)
#define GPIO_ICR1_ICR3_MASK                      (0xC0U)
#define GPIO_ICR1_ICR3_SHIFT                     (6U)
#define GPIO_ICR1_ICR3(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR3_SHIFT)) & GPIO_ICR1_ICR3_MASK)
#define GPIO_ICR1_ICR4_MASK                      (0x300U)
#define GPIO_ICR1_ICR4_SHIFT                     (8U)
#define GPIO_ICR1_ICR4(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR4_SHIFT)) & GPIO_ICR1_ICR4_MASK)
#define GPIO_ICR1_ICR5_MASK                      (0xC00U)
#define GPIO_ICR1_ICR5_SHIFT                     (10U)
#define GPIO_ICR1_ICR5(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR5_SHIFT)) & GPIO_ICR1_ICR5_MASK)
#define GPIO_ICR1_ICR6_MASK                      (0x3000U)
#define GPIO_ICR1_ICR6_SHIFT                     (12U)
#define GPIO_ICR1_ICR6(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR6_SHIFT)) & GPIO_ICR1_ICR6_MASK)
#define GPIO_ICR1_ICR7_MASK                      (0xC000U)
#define GPIO_ICR1_ICR7_SHIFT                     (14U)
#define GPIO_ICR1_ICR7(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR7_SHIFT)) & GPIO_ICR1_ICR7_MASK)
#define GPIO_ICR1_ICR8_MASK                      (0x30000U)
#define GPIO_ICR1_ICR8_SHIFT                     (16U)
#define GPIO_ICR1_ICR8(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR8_SHIFT)) & GPIO_ICR1_ICR8_MASK)
#define GPIO_ICR1_ICR9_MASK                      (0xC0000U)
#define GPIO_ICR1_ICR9_SHIFT                     (18U)
#define GPIO_ICR1_ICR9(x)                        (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR9_SHIFT)) & GPIO_ICR1_ICR9_MASK)
#define GPIO_ICR1_ICR10_MASK                     (0x300000U)
#define GPIO_ICR1_ICR10_SHIFT                    (20U)
#define GPIO_ICR1_ICR10(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR10_SHIFT)) & GPIO_ICR1_ICR10_MASK)
#define GPIO_ICR1_ICR11_MASK                     (0xC00000U)
#define GPIO_ICR1_ICR11_SHIFT                    (22U)
#define GPIO_ICR1_ICR11(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR11_SHIFT)) & GPIO_ICR1_ICR11_MASK)
#define GPIO_ICR1_ICR12_MASK                     (0x3000000U)
#define GPIO_ICR1_ICR12_SHIFT                    (24U)
#define GPIO_ICR1_ICR12(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR12_SHIFT)) & GPIO_ICR1_ICR12_MASK)
#define GPIO_ICR1_ICR13_MASK                     (0xC000000U)
#define GPIO_ICR1_ICR13_SHIFT                    (26U)
#define GPIO_ICR1_ICR13(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR13_SHIFT)) & GPIO_ICR1_ICR13_MASK)
#define GPIO_ICR1_ICR14_MASK                     (0x30000000U)
#define GPIO_ICR1_ICR14_SHIFT                    (28U)
#define GPIO_ICR1_ICR14(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR14_SHIFT)) & GPIO_ICR1_ICR14_MASK)
#define GPIO_ICR1_ICR15_MASK                     (0xC0000000U)
#define GPIO_ICR1_ICR15_SHIFT                    (30U)
#define GPIO_ICR1_ICR15(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR1_ICR15_SHIFT)) & GPIO_ICR1_ICR15_MASK)

/*! @name ICR2 - GPIO interrupt configuration register2 */
#define GPIO_ICR2_ICR16_MASK                     (0x3U)
#define GPIO_ICR2_ICR16_SHIFT                    (0U)
#define GPIO_ICR2_ICR16(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR16_SHIFT)) & GPIO_ICR2_ICR16_MASK)
#define GPIO_ICR2_ICR17_MASK                     (0xCU)
#define GPIO_ICR2_ICR17_SHIFT                    (2U)
#define GPIO_ICR2_ICR17(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR17_SHIFT)) & GPIO_ICR2_ICR17_MASK)
#define GPIO_ICR2_ICR18_MASK                     (0x30U)
#define GPIO_ICR2_ICR18_SHIFT                    (4U)
#define GPIO_ICR2_ICR18(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR18_SHIFT)) & GPIO_ICR2_ICR18_MASK)
#define GPIO_ICR2_ICR19_MASK                     (0xC0U)
#define GPIO_ICR2_ICR19_SHIFT                    (6U)
#define GPIO_ICR2_ICR19(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR19_SHIFT)) & GPIO_ICR2_ICR19_MASK)
#define GPIO_ICR2_ICR20_MASK                     (0x300U)
#define GPIO_ICR2_ICR20_SHIFT                    (8U)
#define GPIO_ICR2_ICR20(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR20_SHIFT)) & GPIO_ICR2_ICR20_MASK)
#define GPIO_ICR2_ICR21_MASK                     (0xC00U)
#define GPIO_ICR2_ICR21_SHIFT                    (10U)
#define GPIO_ICR2_ICR21(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR21_SHIFT)) & GPIO_ICR2_ICR21_MASK)
#define GPIO_ICR2_ICR22_MASK                     (0x3000U)
#define GPIO_ICR2_ICR22_SHIFT                    (12U)
#define GPIO_ICR2_ICR22(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR22_SHIFT)) & GPIO_ICR2_ICR22_MASK)
#define GPIO_ICR2_ICR23_MASK                     (0xC000U)
#define GPIO_ICR2_ICR23_SHIFT                    (14U)
#define GPIO_ICR2_ICR23(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR23_SHIFT)) & GPIO_ICR2_ICR23_MASK)
#define GPIO_ICR2_ICR24_MASK                     (0x30000U)
#define GPIO_ICR2_ICR24_SHIFT                    (16U)
#define GPIO_ICR2_ICR24(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR24_SHIFT)) & GPIO_ICR2_ICR24_MASK)
#define GPIO_ICR2_ICR25_MASK                     (0xC0000U)
#define GPIO_ICR2_ICR25_SHIFT                    (18U)
#define GPIO_ICR2_ICR25(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR25_SHIFT)) & GPIO_ICR2_ICR25_MASK)
#define GPIO_ICR2_ICR26_MASK                     (0x300000U)
#define GPIO_ICR2_ICR26_SHIFT                    (20U)
#define GPIO_ICR2_ICR26(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR26_SHIFT)) & GPIO_ICR2_ICR26_MASK)
#define GPIO_ICR2_ICR27_MASK                     (0xC00000U)
#define GPIO_ICR2_ICR27_SHIFT                    (22U)
#define GPIO_ICR2_ICR27(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR27_SHIFT)) & GPIO_ICR2_ICR27_MASK)
#define GPIO_ICR2_ICR28_MASK                     (0x3000000U)
#define GPIO_ICR2_ICR28_SHIFT                    (24U)
#define GPIO_ICR2_ICR28(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR28_SHIFT)) & GPIO_ICR2_ICR28_MASK)
#define GPIO_ICR2_ICR29_MASK                     (0xC000000U)
#define GPIO_ICR2_ICR29_SHIFT                    (26U)
#define GPIO_ICR2_ICR29(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR29_SHIFT)) & GPIO_ICR2_ICR29_MASK)
#define GPIO_ICR2_ICR30_MASK                     (0x30000000U)
#define GPIO_ICR2_ICR30_SHIFT                    (28U)
#define GPIO_ICR2_ICR30(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR30_SHIFT)) & GPIO_ICR2_ICR30_MASK)
#define GPIO_ICR2_ICR31_MASK                     (0xC0000000U)
#define GPIO_ICR2_ICR31_SHIFT                    (30U)
#define GPIO_ICR2_ICR31(x)                       (((uint32_t)(((uint32_t)(x)) << GPIO_ICR2_ICR31_SHIFT)) & GPIO_ICR2_ICR31_MASK)

/*! @name IMR - GPIO interrupt mask register */
#define GPIO_IMR_IMR_MASK                        (0xFFFFFFFFU)
#define GPIO_IMR_IMR_SHIFT                       (0U)
#define GPIO_IMR_IMR(x)                          (((uint32_t)(((uint32_t)(x)) << GPIO_IMR_IMR_SHIFT)) & GPIO_IMR_IMR_MASK)

/*! @name ISR - GPIO interrupt status register */
#define GPIO_ISR_ISR_MASK                        (0xFFFFFFFFU)
#define GPIO_ISR_ISR_SHIFT                       (0U)
#define GPIO_ISR_ISR(x)                          (((uint32_t)(((uint32_t)(x)) << GPIO_ISR_ISR_SHIFT)) & GPIO_ISR_ISR_MASK)

/*! @name EDGE_SEL - GPIO edge select register */
#define GPIO_EDGE_SEL_GPIO_EDGE_SEL_MASK         (0xFFFFFFFFU)
#define GPIO_EDGE_SEL_GPIO_EDGE_SEL_SHIFT        (0U)
#define GPIO_EDGE_SEL_GPIO_EDGE_SEL(x)           (((uint32_t)(((uint32_t)(x)) << GPIO_EDGE_SEL_GPIO_EDGE_SEL_SHIFT)) & GPIO_EDGE_SEL_GPIO_EDGE_SEL_MASK)


/*!
 * @}
 */ /* end of group GPIO_Register_Masks */


/* GPIO - Peripheral instance base addresses */
/** Peripheral GPIO1 base pointer */
#define GPIO1_BASE_PTR                           ((GPIO_MemMapPtr)0x30200000u)
/** Peripheral GPIO2 base pointer */
#define GPIO2_BASE_PTR                           ((GPIO_MemMapPtr)0x30210000u)
/** Peripheral GPIO3 base pointer */
#define GPIO3_BASE_PTR                           ((GPIO_MemMapPtr)0x30220000u)
/** Peripheral GPIO4 base pointer */
#define GPIO4_BASE_PTR                           ((GPIO_MemMapPtr)0x30230000u)
/** Peripheral GPIO5 base pointer */
#define GPIO5_BASE_PTR                           ((GPIO_MemMapPtr)0x30240000u)
/** Peripheral GPIO6 base pointer */
#define GPIO6_BASE_PTR                           ((GPIO_MemMapPtr)0x30250000u)
/** Peripheral GPIO7 base pointer */
#define GPIO7_BASE_PTR                           ((GPIO_MemMapPtr)0x30260000u)
/** Array initializer of GPIO peripheral base pointers */
#define GPIO_BASE_PTRS                           { GPIO1_BASE_PTR, GPIO2_BASE_PTR, GPIO3_BASE_PTR, GPIO4_BASE_PTR, GPIO5_BASE_PTR, GPIO6_BASE_PTR, GPIO7_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- GPIO - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Register_Accessor_Macros GPIO - Register accessor macros
 * @{
 */


/* GPIO - Register instance definitions */
/* GPIO1 */
#define GPIO1_DR                                 GPIO_DR_REG(GPIO1_BASE_PTR)
#define GPIO1_GDIR                               GPIO_GDIR_REG(GPIO1_BASE_PTR)
#define GPIO1_PSR                                GPIO_PSR_REG(GPIO1_BASE_PTR)
#define GPIO1_ICR1                               GPIO_ICR1_REG(GPIO1_BASE_PTR)
#define GPIO1_ICR2                               GPIO_ICR2_REG(GPIO1_BASE_PTR)
#define GPIO1_IMR                                GPIO_IMR_REG(GPIO1_BASE_PTR)
#define GPIO1_ISR                                GPIO_ISR_REG(GPIO1_BASE_PTR)
#define GPIO1_EDGE_SEL                           GPIO_EDGE_SEL_REG(GPIO1_BASE_PTR)
/* GPIO2 */
#define GPIO2_DR                                 GPIO_DR_REG(GPIO2_BASE_PTR)
#define GPIO2_GDIR                               GPIO_GDIR_REG(GPIO2_BASE_PTR)
#define GPIO2_PSR                                GPIO_PSR_REG(GPIO2_BASE_PTR)
#define GPIO2_ICR1                               GPIO_ICR1_REG(GPIO2_BASE_PTR)
#define GPIO2_ICR2                               GPIO_ICR2_REG(GPIO2_BASE_PTR)
#define GPIO2_IMR                                GPIO_IMR_REG(GPIO2_BASE_PTR)
#define GPIO2_ISR                                GPIO_ISR_REG(GPIO2_BASE_PTR)
#define GPIO2_EDGE_SEL                           GPIO_EDGE_SEL_REG(GPIO2_BASE_PTR)
/* GPIO3 */
#define GPIO3_DR                                 GPIO_DR_REG(GPIO3_BASE_PTR)
#define GPIO3_GDIR                               GPIO_GDIR_REG(GPIO3_BASE_PTR)
#define GPIO3_PSR                                GPIO_PSR_REG(GPIO3_BASE_PTR)
#define GPIO3_ICR1                               GPIO_ICR1_REG(GPIO3_BASE_PTR)
#define GPIO3_ICR2                               GPIO_ICR2_REG(GPIO3_BASE_PTR)
#define GPIO3_IMR                                GPIO_IMR_REG(GPIO3_BASE_PTR)
#define GPIO3_ISR                                GPIO_ISR_REG(GPIO3_BASE_PTR)
#define GPIO3_EDGE_SEL                           GPIO_EDGE_SEL_REG(GPIO3_BASE_PTR)
/* GPIO4 */
#define GPIO4_DR                                 GPIO_DR_REG(GPIO4_BASE_PTR)
#define GPIO4_GDIR                               GPIO_GDIR_REG(GPIO4_BASE_PTR)
#define GPIO4_PSR                                GPIO_PSR_REG(GPIO4_BASE_PTR)
#define GPIO4_ICR1                               GPIO_ICR1_REG(GPIO4_BASE_PTR)
#define GPIO4_ICR2                               GPIO_ICR2_REG(GPIO4_BASE_PTR)
#define GPIO4_IMR                                GPIO_IMR_REG(GPIO4_BASE_PTR)
#define GPIO4_ISR                                GPIO_ISR_REG(GPIO4_BASE_PTR)
#define GPIO4_EDGE_SEL                           GPIO_EDGE_SEL_REG(GPIO4_BASE_PTR)
/* GPIO5 */
#define GPIO5_DR                                 GPIO_DR_REG(GPIO5_BASE_PTR)
#define GPIO5_GDIR                               GPIO_GDIR_REG(GPIO5_BASE_PTR)
#define GPIO5_PSR                                GPIO_PSR_REG(GPIO5_BASE_PTR)
#define GPIO5_ICR1                               GPIO_ICR1_REG(GPIO5_BASE_PTR)
#define GPIO5_ICR2                               GPIO_ICR2_REG(GPIO5_BASE_PTR)
#define GPIO5_IMR                                GPIO_IMR_REG(GPIO5_BASE_PTR)
#define GPIO5_ISR                                GPIO_ISR_REG(GPIO5_BASE_PTR)
#define GPIO5_EDGE_SEL                           GPIO_EDGE_SEL_REG(GPIO5_BASE_PTR)
/* GPIO6 */
#define GPIO6_DR                                 GPIO_DR_REG(GPIO6_BASE_PTR)
#define GPIO6_GDIR                               GPIO_GDIR_REG(GPIO6_BASE_PTR)
#define GPIO6_PSR                                GPIO_PSR_REG(GPIO6_BASE_PTR)
#define GPIO6_ICR1                               GPIO_ICR1_REG(GPIO6_BASE_PTR)
#define GPIO6_ICR2                               GPIO_ICR2_REG(GPIO6_BASE_PTR)
#define GPIO6_IMR                                GPIO_IMR_REG(GPIO6_BASE_PTR)
#define GPIO6_ISR                                GPIO_ISR_REG(GPIO6_BASE_PTR)
#define GPIO6_EDGE_SEL                           GPIO_EDGE_SEL_REG(GPIO6_BASE_PTR)
/* GPIO7 */
#define GPIO7_DR                                 GPIO_DR_REG(GPIO7_BASE_PTR)
#define GPIO7_GDIR                               GPIO_GDIR_REG(GPIO7_BASE_PTR)
#define GPIO7_PSR                                GPIO_PSR_REG(GPIO7_BASE_PTR)
#define GPIO7_ICR1                               GPIO_ICR1_REG(GPIO7_BASE_PTR)
#define GPIO7_ICR2                               GPIO_ICR2_REG(GPIO7_BASE_PTR)
#define GPIO7_IMR                                GPIO_IMR_REG(GPIO7_BASE_PTR)
#define GPIO7_ISR                                GPIO_ISR_REG(GPIO7_BASE_PTR)
#define GPIO7_EDGE_SEL                           GPIO_EDGE_SEL_REG(GPIO7_BASE_PTR)

/*!
 * @}
 */ /* end of group GPIO_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group GPIO_Peripheral */


/* ----------------------------------------------------------------------------
   -- GPMI
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPMI_Peripheral GPMI
 * @{
 */

/** GPMI - Peripheral register structure */
typedef struct GPMI_MemMap {
  uint32_t CTRL0;                                  /**< GPMI Control Register 0 Description, offset: 0x0 */
  uint32_t CTRL0_SET;                              /**< GPMI Control Register 0 Description, offset: 0x4 */
  uint32_t CTRL0_CLR;                              /**< GPMI Control Register 0 Description, offset: 0x8 */
  uint32_t CTRL0_TOG;                              /**< GPMI Control Register 0 Description, offset: 0xC */
  uint32_t COMPARE;                                /**< GPMI Compare Register Description, offset: 0x10 */
  uint8_t RESERVED_0[12];
  uint32_t ECCCTRL;                                /**< GPMI Integrated ECC Control Register Description, offset: 0x20 */
  uint32_t ECCCTRL_SET;                            /**< GPMI Integrated ECC Control Register Description, offset: 0x24 */
  uint32_t ECCCTRL_CLR;                            /**< GPMI Integrated ECC Control Register Description, offset: 0x28 */
  uint32_t ECCCTRL_TOG;                            /**< GPMI Integrated ECC Control Register Description, offset: 0x2C */
  uint32_t ECCCOUNT;                               /**< GPMI Integrated ECC Transfer Count Register Description, offset: 0x30 */
  uint8_t RESERVED_1[12];
  uint32_t PAYLOAD;                                /**< GPMI Payload Address Register Description, offset: 0x40 */
  uint8_t RESERVED_2[12];
  uint32_t AUXILIARY;                              /**< GPMI Auxiliary Address Register Description, offset: 0x50 */
  uint8_t RESERVED_3[12];
  uint32_t CTRL1;                                  /**< GPMI Control Register 1 Description, offset: 0x60 */
  uint32_t CTRL1_SET;                              /**< GPMI Control Register 1 Description, offset: 0x64 */
  uint32_t CTRL1_CLR;                              /**< GPMI Control Register 1 Description, offset: 0x68 */
  uint32_t CTRL1_TOG;                              /**< GPMI Control Register 1 Description, offset: 0x6C */
  uint32_t TIMING0;                                /**< GPMI Timing Register 0 Description, offset: 0x70 */
  uint8_t RESERVED_4[12];
  uint32_t TIMING1;                                /**< GPMI Timing Register 1 Description, offset: 0x80 */
  uint8_t RESERVED_5[12];
  uint32_t TIMING2;                                /**< GPMI Timing Register 2 Description, offset: 0x90 */
  uint8_t RESERVED_6[12];
  uint32_t DATA;                                   /**< GPMI DMA Data Transfer Register Description, offset: 0xA0 */
  uint8_t RESERVED_7[12];
  uint32_t STAT;                                   /**< GPMI Status Register Description, offset: 0xB0 */
  uint8_t RESERVED_8[12];
  uint32_t DEBUG;                                  /**< GPMI Debug Information Register Description, offset: 0xC0 */
  uint8_t RESERVED_9[12];
  uint32_t VERSION;                                /**< GPMI Version Register Description, offset: 0xD0 */
  uint8_t RESERVED_10[12];
  uint32_t DEBUG2;                                 /**< GPMI Debug2 Information Register Description, offset: 0xE0 */
  uint8_t RESERVED_11[12];
  uint32_t DEBUG3;                                 /**< GPMI Debug3 Information Register Description, offset: 0xF0 */
  uint8_t RESERVED_12[12];
  uint32_t READ_DDR_DLL_CTRL;                      /**< GPMI Double Rate Read DLL Control Register Description, offset: 0x100 */
  uint8_t RESERVED_13[12];
  uint32_t WRITE_DDR_DLL_CTRL;                     /**< GPMI Double Rate Write DLL Control Register Description, offset: 0x110 */
  uint8_t RESERVED_14[12];
  uint32_t READ_DDR_DLL_STS;                       /**< GPMI Double Rate Read DLL Status Register Description, offset: 0x120 */
  uint8_t RESERVED_15[12];
  uint32_t WRITE_DDR_DLL_STS;                      /**< GPMI Double Rate Write DLL Status Register Description, offset: 0x130 */
} volatile *GPMI_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- GPMI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPMI_Register_Accessor_Macros GPMI - Register accessor macros
 * @{
 */


/* GPMI - Register accessors */
#define GPMI_CTRL0_REG(base)                     ((base)->CTRL0)
#define GPMI_CTRL0_SET_REG(base)                 ((base)->CTRL0_SET)
#define GPMI_CTRL0_CLR_REG(base)                 ((base)->CTRL0_CLR)
#define GPMI_CTRL0_TOG_REG(base)                 ((base)->CTRL0_TOG)
#define GPMI_COMPARE_REG(base)                   ((base)->COMPARE)
#define GPMI_ECCCTRL_REG(base)                   ((base)->ECCCTRL)
#define GPMI_ECCCTRL_SET_REG(base)               ((base)->ECCCTRL_SET)
#define GPMI_ECCCTRL_CLR_REG(base)               ((base)->ECCCTRL_CLR)
#define GPMI_ECCCTRL_TOG_REG(base)               ((base)->ECCCTRL_TOG)
#define GPMI_ECCCOUNT_REG(base)                  ((base)->ECCCOUNT)
#define GPMI_PAYLOAD_REG(base)                   ((base)->PAYLOAD)
#define GPMI_AUXILIARY_REG(base)                 ((base)->AUXILIARY)
#define GPMI_CTRL1_REG(base)                     ((base)->CTRL1)
#define GPMI_CTRL1_SET_REG(base)                 ((base)->CTRL1_SET)
#define GPMI_CTRL1_CLR_REG(base)                 ((base)->CTRL1_CLR)
#define GPMI_CTRL1_TOG_REG(base)                 ((base)->CTRL1_TOG)
#define GPMI_TIMING0_REG(base)                   ((base)->TIMING0)
#define GPMI_TIMING1_REG(base)                   ((base)->TIMING1)
#define GPMI_TIMING2_REG(base)                   ((base)->TIMING2)
#define GPMI_DATA_REG(base)                      ((base)->DATA)
#define GPMI_STAT_REG(base)                      ((base)->STAT)
#define GPMI_DEBUG_REG(base)                     ((base)->DEBUG)
#define GPMI_VERSION_REG(base)                   ((base)->VERSION)
#define GPMI_DEBUG2_REG(base)                    ((base)->DEBUG2)
#define GPMI_DEBUG3_REG(base)                    ((base)->DEBUG3)
#define GPMI_READ_DDR_DLL_CTRL_REG(base)         ((base)->READ_DDR_DLL_CTRL)
#define GPMI_WRITE_DDR_DLL_CTRL_REG(base)        ((base)->WRITE_DDR_DLL_CTRL)
#define GPMI_READ_DDR_DLL_STS_REG(base)          ((base)->READ_DDR_DLL_STS)
#define GPMI_WRITE_DDR_DLL_STS_REG(base)         ((base)->WRITE_DDR_DLL_STS)

/*!
 * @}
 */ /* end of group GPMI_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- GPMI Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPMI_Register_Masks GPMI Register Masks
 * @{
 */

/*! @name CTRL0 - GPMI Control Register 0 Description */
#define GPMI_CTRL0_XFER_COUNT_MASK               (0xFFFFU)
#define GPMI_CTRL0_XFER_COUNT_SHIFT              (0U)
#define GPMI_CTRL0_XFER_COUNT(x)                 (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_XFER_COUNT_SHIFT)) & GPMI_CTRL0_XFER_COUNT_MASK)
#define GPMI_CTRL0_ADDRESS_INCREMENT_MASK        (0x10000U)
#define GPMI_CTRL0_ADDRESS_INCREMENT_SHIFT       (16U)
#define GPMI_CTRL0_ADDRESS_MASK                  (0xE0000U)
#define GPMI_CTRL0_ADDRESS_SHIFT                 (17U)
#define GPMI_CTRL0_ADDRESS(x)                    (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_ADDRESS_SHIFT)) & GPMI_CTRL0_ADDRESS_MASK)
#define GPMI_CTRL0_CS_MASK                       (0x700000U)
#define GPMI_CTRL0_CS_SHIFT                      (20U)
#define GPMI_CTRL0_CS(x)                         (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_CS_SHIFT)) & GPMI_CTRL0_CS_MASK)
#define GPMI_CTRL0_WORD_LENGTH_MASK              (0x800000U)
#define GPMI_CTRL0_WORD_LENGTH_SHIFT             (23U)
#define GPMI_CTRL0_COMMAND_MODE_MASK             (0x3000000U)
#define GPMI_CTRL0_COMMAND_MODE_SHIFT            (24U)
#define GPMI_CTRL0_COMMAND_MODE(x)               (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_COMMAND_MODE_SHIFT)) & GPMI_CTRL0_COMMAND_MODE_MASK)
#define GPMI_CTRL0_UDMA_MASK                     (0x4000000U)
#define GPMI_CTRL0_UDMA_SHIFT                    (26U)
#define GPMI_CTRL0_LOCK_CS_MASK                  (0x8000000U)
#define GPMI_CTRL0_LOCK_CS_SHIFT                 (27U)
#define GPMI_CTRL0_DEV_IRQ_EN_MASK               (0x10000000U)
#define GPMI_CTRL0_DEV_IRQ_EN_SHIFT              (28U)
#define GPMI_CTRL0_RUN_MASK                      (0x20000000U)
#define GPMI_CTRL0_RUN_SHIFT                     (29U)
#define GPMI_CTRL0_CLKGATE_MASK                  (0x40000000U)
#define GPMI_CTRL0_CLKGATE_SHIFT                 (30U)
#define GPMI_CTRL0_SFTRST_MASK                   (0x80000000U)
#define GPMI_CTRL0_SFTRST_SHIFT                  (31U)

/*! @name CTRL0_SET - GPMI Control Register 0 Description */
#define GPMI_CTRL0_SET_XFER_COUNT_MASK           (0xFFFFU)
#define GPMI_CTRL0_SET_XFER_COUNT_SHIFT          (0U)
#define GPMI_CTRL0_SET_XFER_COUNT(x)             (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_SET_XFER_COUNT_SHIFT)) & GPMI_CTRL0_SET_XFER_COUNT_MASK)
#define GPMI_CTRL0_SET_ADDRESS_INCREMENT_MASK    (0x10000U)
#define GPMI_CTRL0_SET_ADDRESS_INCREMENT_SHIFT   (16U)
#define GPMI_CTRL0_SET_ADDRESS_MASK              (0xE0000U)
#define GPMI_CTRL0_SET_ADDRESS_SHIFT             (17U)
#define GPMI_CTRL0_SET_ADDRESS(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_SET_ADDRESS_SHIFT)) & GPMI_CTRL0_SET_ADDRESS_MASK)
#define GPMI_CTRL0_SET_CS_MASK                   (0x700000U)
#define GPMI_CTRL0_SET_CS_SHIFT                  (20U)
#define GPMI_CTRL0_SET_CS(x)                     (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_SET_CS_SHIFT)) & GPMI_CTRL0_SET_CS_MASK)
#define GPMI_CTRL0_SET_WORD_LENGTH_MASK          (0x800000U)
#define GPMI_CTRL0_SET_WORD_LENGTH_SHIFT         (23U)
#define GPMI_CTRL0_SET_COMMAND_MODE_MASK         (0x3000000U)
#define GPMI_CTRL0_SET_COMMAND_MODE_SHIFT        (24U)
#define GPMI_CTRL0_SET_COMMAND_MODE(x)           (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_SET_COMMAND_MODE_SHIFT)) & GPMI_CTRL0_SET_COMMAND_MODE_MASK)
#define GPMI_CTRL0_SET_UDMA_MASK                 (0x4000000U)
#define GPMI_CTRL0_SET_UDMA_SHIFT                (26U)
#define GPMI_CTRL0_SET_LOCK_CS_MASK              (0x8000000U)
#define GPMI_CTRL0_SET_LOCK_CS_SHIFT             (27U)
#define GPMI_CTRL0_SET_DEV_IRQ_EN_MASK           (0x10000000U)
#define GPMI_CTRL0_SET_DEV_IRQ_EN_SHIFT          (28U)
#define GPMI_CTRL0_SET_RUN_MASK                  (0x20000000U)
#define GPMI_CTRL0_SET_RUN_SHIFT                 (29U)
#define GPMI_CTRL0_SET_CLKGATE_MASK              (0x40000000U)
#define GPMI_CTRL0_SET_CLKGATE_SHIFT             (30U)
#define GPMI_CTRL0_SET_SFTRST_MASK               (0x80000000U)
#define GPMI_CTRL0_SET_SFTRST_SHIFT              (31U)

/*! @name CTRL0_CLR - GPMI Control Register 0 Description */
#define GPMI_CTRL0_CLR_XFER_COUNT_MASK           (0xFFFFU)
#define GPMI_CTRL0_CLR_XFER_COUNT_SHIFT          (0U)
#define GPMI_CTRL0_CLR_XFER_COUNT(x)             (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_CLR_XFER_COUNT_SHIFT)) & GPMI_CTRL0_CLR_XFER_COUNT_MASK)
#define GPMI_CTRL0_CLR_ADDRESS_INCREMENT_MASK    (0x10000U)
#define GPMI_CTRL0_CLR_ADDRESS_INCREMENT_SHIFT   (16U)
#define GPMI_CTRL0_CLR_ADDRESS_MASK              (0xE0000U)
#define GPMI_CTRL0_CLR_ADDRESS_SHIFT             (17U)
#define GPMI_CTRL0_CLR_ADDRESS(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_CLR_ADDRESS_SHIFT)) & GPMI_CTRL0_CLR_ADDRESS_MASK)
#define GPMI_CTRL0_CLR_CS_MASK                   (0x700000U)
#define GPMI_CTRL0_CLR_CS_SHIFT                  (20U)
#define GPMI_CTRL0_CLR_CS(x)                     (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_CLR_CS_SHIFT)) & GPMI_CTRL0_CLR_CS_MASK)
#define GPMI_CTRL0_CLR_WORD_LENGTH_MASK          (0x800000U)
#define GPMI_CTRL0_CLR_WORD_LENGTH_SHIFT         (23U)
#define GPMI_CTRL0_CLR_COMMAND_MODE_MASK         (0x3000000U)
#define GPMI_CTRL0_CLR_COMMAND_MODE_SHIFT        (24U)
#define GPMI_CTRL0_CLR_COMMAND_MODE(x)           (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_CLR_COMMAND_MODE_SHIFT)) & GPMI_CTRL0_CLR_COMMAND_MODE_MASK)
#define GPMI_CTRL0_CLR_UDMA_MASK                 (0x4000000U)
#define GPMI_CTRL0_CLR_UDMA_SHIFT                (26U)
#define GPMI_CTRL0_CLR_LOCK_CS_MASK              (0x8000000U)
#define GPMI_CTRL0_CLR_LOCK_CS_SHIFT             (27U)
#define GPMI_CTRL0_CLR_DEV_IRQ_EN_MASK           (0x10000000U)
#define GPMI_CTRL0_CLR_DEV_IRQ_EN_SHIFT          (28U)
#define GPMI_CTRL0_CLR_RUN_MASK                  (0x20000000U)
#define GPMI_CTRL0_CLR_RUN_SHIFT                 (29U)
#define GPMI_CTRL0_CLR_CLKGATE_MASK              (0x40000000U)
#define GPMI_CTRL0_CLR_CLKGATE_SHIFT             (30U)
#define GPMI_CTRL0_CLR_SFTRST_MASK               (0x80000000U)
#define GPMI_CTRL0_CLR_SFTRST_SHIFT              (31U)

/*! @name CTRL0_TOG - GPMI Control Register 0 Description */
#define GPMI_CTRL0_TOG_XFER_COUNT_MASK           (0xFFFFU)
#define GPMI_CTRL0_TOG_XFER_COUNT_SHIFT          (0U)
#define GPMI_CTRL0_TOG_XFER_COUNT(x)             (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_TOG_XFER_COUNT_SHIFT)) & GPMI_CTRL0_TOG_XFER_COUNT_MASK)
#define GPMI_CTRL0_TOG_ADDRESS_INCREMENT_MASK    (0x10000U)
#define GPMI_CTRL0_TOG_ADDRESS_INCREMENT_SHIFT   (16U)
#define GPMI_CTRL0_TOG_ADDRESS_MASK              (0xE0000U)
#define GPMI_CTRL0_TOG_ADDRESS_SHIFT             (17U)
#define GPMI_CTRL0_TOG_ADDRESS(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_TOG_ADDRESS_SHIFT)) & GPMI_CTRL0_TOG_ADDRESS_MASK)
#define GPMI_CTRL0_TOG_CS_MASK                   (0x700000U)
#define GPMI_CTRL0_TOG_CS_SHIFT                  (20U)
#define GPMI_CTRL0_TOG_CS(x)                     (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_TOG_CS_SHIFT)) & GPMI_CTRL0_TOG_CS_MASK)
#define GPMI_CTRL0_TOG_WORD_LENGTH_MASK          (0x800000U)
#define GPMI_CTRL0_TOG_WORD_LENGTH_SHIFT         (23U)
#define GPMI_CTRL0_TOG_COMMAND_MODE_MASK         (0x3000000U)
#define GPMI_CTRL0_TOG_COMMAND_MODE_SHIFT        (24U)
#define GPMI_CTRL0_TOG_COMMAND_MODE(x)           (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL0_TOG_COMMAND_MODE_SHIFT)) & GPMI_CTRL0_TOG_COMMAND_MODE_MASK)
#define GPMI_CTRL0_TOG_UDMA_MASK                 (0x4000000U)
#define GPMI_CTRL0_TOG_UDMA_SHIFT                (26U)
#define GPMI_CTRL0_TOG_LOCK_CS_MASK              (0x8000000U)
#define GPMI_CTRL0_TOG_LOCK_CS_SHIFT             (27U)
#define GPMI_CTRL0_TOG_DEV_IRQ_EN_MASK           (0x10000000U)
#define GPMI_CTRL0_TOG_DEV_IRQ_EN_SHIFT          (28U)
#define GPMI_CTRL0_TOG_RUN_MASK                  (0x20000000U)
#define GPMI_CTRL0_TOG_RUN_SHIFT                 (29U)
#define GPMI_CTRL0_TOG_CLKGATE_MASK              (0x40000000U)
#define GPMI_CTRL0_TOG_CLKGATE_SHIFT             (30U)
#define GPMI_CTRL0_TOG_SFTRST_MASK               (0x80000000U)
#define GPMI_CTRL0_TOG_SFTRST_SHIFT              (31U)

/*! @name COMPARE - GPMI Compare Register Description */
#define GPMI_COMPARE_REFERENCE_MASK              (0xFFFFU)
#define GPMI_COMPARE_REFERENCE_SHIFT             (0U)
#define GPMI_COMPARE_REFERENCE(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_COMPARE_REFERENCE_SHIFT)) & GPMI_COMPARE_REFERENCE_MASK)
#define GPMI_COMPARE_MASK_MASK                   (0xFFFF0000U)
#define GPMI_COMPARE_MASK_SHIFT                  (16U)
#define GPMI_COMPARE_MASK(x)                     (((uint32_t)(((uint32_t)(x)) << GPMI_COMPARE_MASK_SHIFT)) & GPMI_COMPARE_MASK_MASK)

/*! @name ECCCTRL - GPMI Integrated ECC Control Register Description */
#define GPMI_ECCCTRL_BUFFER_MASK_MASK            (0x1FFU)
#define GPMI_ECCCTRL_BUFFER_MASK_SHIFT           (0U)
#define GPMI_ECCCTRL_BUFFER_MASK(x)              (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_BUFFER_MASK_SHIFT)) & GPMI_ECCCTRL_BUFFER_MASK_MASK)
#define GPMI_ECCCTRL_RANDOMIZER_TYPE_MASK        (0x600U)
#define GPMI_ECCCTRL_RANDOMIZER_TYPE_SHIFT       (9U)
#define GPMI_ECCCTRL_RANDOMIZER_TYPE(x)          (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_RANDOMIZER_TYPE_SHIFT)) & GPMI_ECCCTRL_RANDOMIZER_TYPE_MASK)
#define GPMI_ECCCTRL_RANDOMIZER_ENABLE_MASK      (0x800U)
#define GPMI_ECCCTRL_RANDOMIZER_ENABLE_SHIFT     (11U)
#define GPMI_ECCCTRL_ENABLE_ECC_MASK             (0x1000U)
#define GPMI_ECCCTRL_ENABLE_ECC_SHIFT            (12U)
#define GPMI_ECCCTRL_ECC_CMD_MASK                (0x6000U)
#define GPMI_ECCCTRL_ECC_CMD_SHIFT               (13U)
#define GPMI_ECCCTRL_ECC_CMD(x)                  (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_ECC_CMD_SHIFT)) & GPMI_ECCCTRL_ECC_CMD_MASK)
#define GPMI_ECCCTRL_RSVD2_MASK                  (0x8000U)
#define GPMI_ECCCTRL_RSVD2_SHIFT                 (15U)
#define GPMI_ECCCTRL_HANDLE_MASK                 (0xFFFF0000U)
#define GPMI_ECCCTRL_HANDLE_SHIFT                (16U)
#define GPMI_ECCCTRL_HANDLE(x)                   (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_HANDLE_SHIFT)) & GPMI_ECCCTRL_HANDLE_MASK)

/*! @name ECCCTRL_SET - GPMI Integrated ECC Control Register Description */
#define GPMI_ECCCTRL_SET_BUFFER_MASK_MASK        (0x1FFU)
#define GPMI_ECCCTRL_SET_BUFFER_MASK_SHIFT       (0U)
#define GPMI_ECCCTRL_SET_BUFFER_MASK(x)          (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_SET_BUFFER_MASK_SHIFT)) & GPMI_ECCCTRL_SET_BUFFER_MASK_MASK)
#define GPMI_ECCCTRL_SET_RANDOMIZER_TYPE_MASK    (0x600U)
#define GPMI_ECCCTRL_SET_RANDOMIZER_TYPE_SHIFT   (9U)
#define GPMI_ECCCTRL_SET_RANDOMIZER_TYPE(x)      (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_SET_RANDOMIZER_TYPE_SHIFT)) & GPMI_ECCCTRL_SET_RANDOMIZER_TYPE_MASK)
#define GPMI_ECCCTRL_SET_RANDOMIZER_ENABLE_MASK  (0x800U)
#define GPMI_ECCCTRL_SET_RANDOMIZER_ENABLE_SHIFT (11U)
#define GPMI_ECCCTRL_SET_ENABLE_ECC_MASK         (0x1000U)
#define GPMI_ECCCTRL_SET_ENABLE_ECC_SHIFT        (12U)
#define GPMI_ECCCTRL_SET_ECC_CMD_MASK            (0x6000U)
#define GPMI_ECCCTRL_SET_ECC_CMD_SHIFT           (13U)
#define GPMI_ECCCTRL_SET_ECC_CMD(x)              (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_SET_ECC_CMD_SHIFT)) & GPMI_ECCCTRL_SET_ECC_CMD_MASK)
#define GPMI_ECCCTRL_SET_RSVD2_MASK              (0x8000U)
#define GPMI_ECCCTRL_SET_RSVD2_SHIFT             (15U)
#define GPMI_ECCCTRL_SET_HANDLE_MASK             (0xFFFF0000U)
#define GPMI_ECCCTRL_SET_HANDLE_SHIFT            (16U)
#define GPMI_ECCCTRL_SET_HANDLE(x)               (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_SET_HANDLE_SHIFT)) & GPMI_ECCCTRL_SET_HANDLE_MASK)

/*! @name ECCCTRL_CLR - GPMI Integrated ECC Control Register Description */
#define GPMI_ECCCTRL_CLR_BUFFER_MASK_MASK        (0x1FFU)
#define GPMI_ECCCTRL_CLR_BUFFER_MASK_SHIFT       (0U)
#define GPMI_ECCCTRL_CLR_BUFFER_MASK(x)          (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_CLR_BUFFER_MASK_SHIFT)) & GPMI_ECCCTRL_CLR_BUFFER_MASK_MASK)
#define GPMI_ECCCTRL_CLR_RANDOMIZER_TYPE_MASK    (0x600U)
#define GPMI_ECCCTRL_CLR_RANDOMIZER_TYPE_SHIFT   (9U)
#define GPMI_ECCCTRL_CLR_RANDOMIZER_TYPE(x)      (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_CLR_RANDOMIZER_TYPE_SHIFT)) & GPMI_ECCCTRL_CLR_RANDOMIZER_TYPE_MASK)
#define GPMI_ECCCTRL_CLR_RANDOMIZER_ENABLE_MASK  (0x800U)
#define GPMI_ECCCTRL_CLR_RANDOMIZER_ENABLE_SHIFT (11U)
#define GPMI_ECCCTRL_CLR_ENABLE_ECC_MASK         (0x1000U)
#define GPMI_ECCCTRL_CLR_ENABLE_ECC_SHIFT        (12U)
#define GPMI_ECCCTRL_CLR_ECC_CMD_MASK            (0x6000U)
#define GPMI_ECCCTRL_CLR_ECC_CMD_SHIFT           (13U)
#define GPMI_ECCCTRL_CLR_ECC_CMD(x)              (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_CLR_ECC_CMD_SHIFT)) & GPMI_ECCCTRL_CLR_ECC_CMD_MASK)
#define GPMI_ECCCTRL_CLR_RSVD2_MASK              (0x8000U)
#define GPMI_ECCCTRL_CLR_RSVD2_SHIFT             (15U)
#define GPMI_ECCCTRL_CLR_HANDLE_MASK             (0xFFFF0000U)
#define GPMI_ECCCTRL_CLR_HANDLE_SHIFT            (16U)
#define GPMI_ECCCTRL_CLR_HANDLE(x)               (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_CLR_HANDLE_SHIFT)) & GPMI_ECCCTRL_CLR_HANDLE_MASK)

/*! @name ECCCTRL_TOG - GPMI Integrated ECC Control Register Description */
#define GPMI_ECCCTRL_TOG_BUFFER_MASK_MASK        (0x1FFU)
#define GPMI_ECCCTRL_TOG_BUFFER_MASK_SHIFT       (0U)
#define GPMI_ECCCTRL_TOG_BUFFER_MASK(x)          (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_TOG_BUFFER_MASK_SHIFT)) & GPMI_ECCCTRL_TOG_BUFFER_MASK_MASK)
#define GPMI_ECCCTRL_TOG_RANDOMIZER_TYPE_MASK    (0x600U)
#define GPMI_ECCCTRL_TOG_RANDOMIZER_TYPE_SHIFT   (9U)
#define GPMI_ECCCTRL_TOG_RANDOMIZER_TYPE(x)      (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_TOG_RANDOMIZER_TYPE_SHIFT)) & GPMI_ECCCTRL_TOG_RANDOMIZER_TYPE_MASK)
#define GPMI_ECCCTRL_TOG_RANDOMIZER_ENABLE_MASK  (0x800U)
#define GPMI_ECCCTRL_TOG_RANDOMIZER_ENABLE_SHIFT (11U)
#define GPMI_ECCCTRL_TOG_ENABLE_ECC_MASK         (0x1000U)
#define GPMI_ECCCTRL_TOG_ENABLE_ECC_SHIFT        (12U)
#define GPMI_ECCCTRL_TOG_ECC_CMD_MASK            (0x6000U)
#define GPMI_ECCCTRL_TOG_ECC_CMD_SHIFT           (13U)
#define GPMI_ECCCTRL_TOG_ECC_CMD(x)              (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_TOG_ECC_CMD_SHIFT)) & GPMI_ECCCTRL_TOG_ECC_CMD_MASK)
#define GPMI_ECCCTRL_TOG_RSVD2_MASK              (0x8000U)
#define GPMI_ECCCTRL_TOG_RSVD2_SHIFT             (15U)
#define GPMI_ECCCTRL_TOG_HANDLE_MASK             (0xFFFF0000U)
#define GPMI_ECCCTRL_TOG_HANDLE_SHIFT            (16U)
#define GPMI_ECCCTRL_TOG_HANDLE(x)               (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCTRL_TOG_HANDLE_SHIFT)) & GPMI_ECCCTRL_TOG_HANDLE_MASK)

/*! @name ECCCOUNT - GPMI Integrated ECC Transfer Count Register Description */
#define GPMI_ECCCOUNT_COUNT_MASK                 (0xFFFFU)
#define GPMI_ECCCOUNT_COUNT_SHIFT                (0U)
#define GPMI_ECCCOUNT_COUNT(x)                   (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCOUNT_COUNT_SHIFT)) & GPMI_ECCCOUNT_COUNT_MASK)
#define GPMI_ECCCOUNT_RANDOMIZER_PAGE_MASK       (0xFF0000U)
#define GPMI_ECCCOUNT_RANDOMIZER_PAGE_SHIFT      (16U)
#define GPMI_ECCCOUNT_RANDOMIZER_PAGE(x)         (((uint32_t)(((uint32_t)(x)) << GPMI_ECCCOUNT_RANDOMIZER_PAGE_SHIFT)) & GPMI_ECCCOUNT_RANDOMIZER_PAGE_MASK)

/*! @name PAYLOAD - GPMI Payload Address Register Description */
#define GPMI_PAYLOAD_RSVD0_MASK                  (0x3U)
#define GPMI_PAYLOAD_RSVD0_SHIFT                 (0U)
#define GPMI_PAYLOAD_RSVD0(x)                    (((uint32_t)(((uint32_t)(x)) << GPMI_PAYLOAD_RSVD0_SHIFT)) & GPMI_PAYLOAD_RSVD0_MASK)
#define GPMI_PAYLOAD_ADDRESS_MASK                (0xFFFFFFFCU)
#define GPMI_PAYLOAD_ADDRESS_SHIFT               (2U)
#define GPMI_PAYLOAD_ADDRESS(x)                  (((uint32_t)(((uint32_t)(x)) << GPMI_PAYLOAD_ADDRESS_SHIFT)) & GPMI_PAYLOAD_ADDRESS_MASK)

/*! @name AUXILIARY - GPMI Auxiliary Address Register Description */
#define GPMI_AUXILIARY_RSVD0_MASK                (0x3U)
#define GPMI_AUXILIARY_RSVD0_SHIFT               (0U)
#define GPMI_AUXILIARY_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << GPMI_AUXILIARY_RSVD0_SHIFT)) & GPMI_AUXILIARY_RSVD0_MASK)
#define GPMI_AUXILIARY_ADDRESS_MASK              (0xFFFFFFFCU)
#define GPMI_AUXILIARY_ADDRESS_SHIFT             (2U)
#define GPMI_AUXILIARY_ADDRESS(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_AUXILIARY_ADDRESS_SHIFT)) & GPMI_AUXILIARY_ADDRESS_MASK)

/*! @name CTRL1 - GPMI Control Register 1 Description */
#define GPMI_CTRL1_GPMI_MODE_MASK                (0x1U)
#define GPMI_CTRL1_GPMI_MODE_SHIFT               (0U)
#define GPMI_CTRL1_CAMERA_MODE_MASK              (0x2U)
#define GPMI_CTRL1_CAMERA_MODE_SHIFT             (1U)
#define GPMI_CTRL1_ATA_IRQRDY_POLARITY_MASK      (0x4U)
#define GPMI_CTRL1_ATA_IRQRDY_POLARITY_SHIFT     (2U)
#define GPMI_CTRL1_DEV_RESET_MASK                (0x8U)
#define GPMI_CTRL1_DEV_RESET_SHIFT               (3U)
#define GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL_MASK (0x70U)
#define GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL_SHIFT (4U)
#define GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(x) (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL_SHIFT)) & GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL_MASK)
#define GPMI_CTRL1_ABORT_WAIT_REQUEST_MASK       (0x80U)
#define GPMI_CTRL1_ABORT_WAIT_REQUEST_SHIFT      (7U)
#define GPMI_CTRL1_BURST_EN_MASK                 (0x100U)
#define GPMI_CTRL1_BURST_EN_SHIFT                (8U)
#define GPMI_CTRL1_TIMEOUT_IRQ_MASK              (0x200U)
#define GPMI_CTRL1_TIMEOUT_IRQ_SHIFT             (9U)
#define GPMI_CTRL1_DEV_IRQ_MASK                  (0x400U)
#define GPMI_CTRL1_DEV_IRQ_SHIFT                 (10U)
#define GPMI_CTRL1_DMA2ECC_MODE_MASK             (0x800U)
#define GPMI_CTRL1_DMA2ECC_MODE_SHIFT            (11U)
#define GPMI_CTRL1_RDN_DELAY_MASK                (0xF000U)
#define GPMI_CTRL1_RDN_DELAY_SHIFT               (12U)
#define GPMI_CTRL1_RDN_DELAY(x)                  (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_RDN_DELAY_SHIFT)) & GPMI_CTRL1_RDN_DELAY_MASK)
#define GPMI_CTRL1_HALF_PERIOD_MASK              (0x10000U)
#define GPMI_CTRL1_HALF_PERIOD_SHIFT             (16U)
#define GPMI_CTRL1_DLL_ENABLE_MASK               (0x20000U)
#define GPMI_CTRL1_DLL_ENABLE_SHIFT              (17U)
#define GPMI_CTRL1_BCH_MODE_MASK                 (0x40000U)
#define GPMI_CTRL1_BCH_MODE_SHIFT                (18U)
#define GPMI_CTRL1_GANGED_RDYBUSY_MASK           (0x80000U)
#define GPMI_CTRL1_GANGED_RDYBUSY_SHIFT          (19U)
#define GPMI_CTRL1_TIMEOUT_IRQ_EN_MASK           (0x100000U)
#define GPMI_CTRL1_TIMEOUT_IRQ_EN_SHIFT          (20U)
#define GPMI_CTRL1_TEST_TRIGGER_MASK             (0x200000U)
#define GPMI_CTRL1_TEST_TRIGGER_SHIFT            (21U)
#define GPMI_CTRL1_WRN_DLY_SEL_MASK              (0xC00000U)
#define GPMI_CTRL1_WRN_DLY_SEL_SHIFT             (22U)
#define GPMI_CTRL1_WRN_DLY_SEL(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_WRN_DLY_SEL_SHIFT)) & GPMI_CTRL1_WRN_DLY_SEL_MASK)
#define GPMI_CTRL1_DECOUPLE_CS_MASK              (0x1000000U)
#define GPMI_CTRL1_DECOUPLE_CS_SHIFT             (24U)
#define GPMI_CTRL1_SSYNCMODE_MASK                (0x2000000U)
#define GPMI_CTRL1_SSYNCMODE_SHIFT               (25U)
#define GPMI_CTRL1_UPDATE_CS_MASK                (0x4000000U)
#define GPMI_CTRL1_UPDATE_CS_SHIFT               (26U)
#define GPMI_CTRL1_GPMI_CLK_DIV2_EN_MASK         (0x8000000U)
#define GPMI_CTRL1_GPMI_CLK_DIV2_EN_SHIFT        (27U)
#define GPMI_CTRL1_TOGGLE_MODE_MASK              (0x10000000U)
#define GPMI_CTRL1_TOGGLE_MODE_SHIFT             (28U)
#define GPMI_CTRL1_WRITE_CLK_STOP_MASK           (0x20000000U)
#define GPMI_CTRL1_WRITE_CLK_STOP_SHIFT          (29U)
#define GPMI_CTRL1_SSYNC_CLK_STOP_MASK           (0x40000000U)
#define GPMI_CTRL1_SSYNC_CLK_STOP_SHIFT          (30U)
#define GPMI_CTRL1_DEV_CLK_STOP_MASK             (0x80000000U)
#define GPMI_CTRL1_DEV_CLK_STOP_SHIFT            (31U)

/*! @name CTRL1_SET - GPMI Control Register 1 Description */
#define GPMI_CTRL1_SET_GPMI_MODE_MASK            (0x1U)
#define GPMI_CTRL1_SET_GPMI_MODE_SHIFT           (0U)
#define GPMI_CTRL1_SET_CAMERA_MODE_MASK          (0x2U)
#define GPMI_CTRL1_SET_CAMERA_MODE_SHIFT         (1U)
#define GPMI_CTRL1_SET_ATA_IRQRDY_POLARITY_MASK  (0x4U)
#define GPMI_CTRL1_SET_ATA_IRQRDY_POLARITY_SHIFT (2U)
#define GPMI_CTRL1_SET_DEV_RESET_MASK            (0x8U)
#define GPMI_CTRL1_SET_DEV_RESET_SHIFT           (3U)
#define GPMI_CTRL1_SET_ABORT_WAIT_FOR_READY_CHANNEL_MASK (0x70U)
#define GPMI_CTRL1_SET_ABORT_WAIT_FOR_READY_CHANNEL_SHIFT (4U)
#define GPMI_CTRL1_SET_ABORT_WAIT_FOR_READY_CHANNEL(x) (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_SET_ABORT_WAIT_FOR_READY_CHANNEL_SHIFT)) & GPMI_CTRL1_SET_ABORT_WAIT_FOR_READY_CHANNEL_MASK)
#define GPMI_CTRL1_SET_ABORT_WAIT_REQUEST_MASK   (0x80U)
#define GPMI_CTRL1_SET_ABORT_WAIT_REQUEST_SHIFT  (7U)
#define GPMI_CTRL1_SET_BURST_EN_MASK             (0x100U)
#define GPMI_CTRL1_SET_BURST_EN_SHIFT            (8U)
#define GPMI_CTRL1_SET_TIMEOUT_IRQ_MASK          (0x200U)
#define GPMI_CTRL1_SET_TIMEOUT_IRQ_SHIFT         (9U)
#define GPMI_CTRL1_SET_DEV_IRQ_MASK              (0x400U)
#define GPMI_CTRL1_SET_DEV_IRQ_SHIFT             (10U)
#define GPMI_CTRL1_SET_DMA2ECC_MODE_MASK         (0x800U)
#define GPMI_CTRL1_SET_DMA2ECC_MODE_SHIFT        (11U)
#define GPMI_CTRL1_SET_RDN_DELAY_MASK            (0xF000U)
#define GPMI_CTRL1_SET_RDN_DELAY_SHIFT           (12U)
#define GPMI_CTRL1_SET_RDN_DELAY(x)              (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_SET_RDN_DELAY_SHIFT)) & GPMI_CTRL1_SET_RDN_DELAY_MASK)
#define GPMI_CTRL1_SET_HALF_PERIOD_MASK          (0x10000U)
#define GPMI_CTRL1_SET_HALF_PERIOD_SHIFT         (16U)
#define GPMI_CTRL1_SET_DLL_ENABLE_MASK           (0x20000U)
#define GPMI_CTRL1_SET_DLL_ENABLE_SHIFT          (17U)
#define GPMI_CTRL1_SET_BCH_MODE_MASK             (0x40000U)
#define GPMI_CTRL1_SET_BCH_MODE_SHIFT            (18U)
#define GPMI_CTRL1_SET_GANGED_RDYBUSY_MASK       (0x80000U)
#define GPMI_CTRL1_SET_GANGED_RDYBUSY_SHIFT      (19U)
#define GPMI_CTRL1_SET_TIMEOUT_IRQ_EN_MASK       (0x100000U)
#define GPMI_CTRL1_SET_TIMEOUT_IRQ_EN_SHIFT      (20U)
#define GPMI_CTRL1_SET_TEST_TRIGGER_MASK         (0x200000U)
#define GPMI_CTRL1_SET_TEST_TRIGGER_SHIFT        (21U)
#define GPMI_CTRL1_SET_WRN_DLY_SEL_MASK          (0xC00000U)
#define GPMI_CTRL1_SET_WRN_DLY_SEL_SHIFT         (22U)
#define GPMI_CTRL1_SET_WRN_DLY_SEL(x)            (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_SET_WRN_DLY_SEL_SHIFT)) & GPMI_CTRL1_SET_WRN_DLY_SEL_MASK)
#define GPMI_CTRL1_SET_DECOUPLE_CS_MASK          (0x1000000U)
#define GPMI_CTRL1_SET_DECOUPLE_CS_SHIFT         (24U)
#define GPMI_CTRL1_SET_SSYNCMODE_MASK            (0x2000000U)
#define GPMI_CTRL1_SET_SSYNCMODE_SHIFT           (25U)
#define GPMI_CTRL1_SET_UPDATE_CS_MASK            (0x4000000U)
#define GPMI_CTRL1_SET_UPDATE_CS_SHIFT           (26U)
#define GPMI_CTRL1_SET_GPMI_CLK_DIV2_EN_MASK     (0x8000000U)
#define GPMI_CTRL1_SET_GPMI_CLK_DIV2_EN_SHIFT    (27U)
#define GPMI_CTRL1_SET_TOGGLE_MODE_MASK          (0x10000000U)
#define GPMI_CTRL1_SET_TOGGLE_MODE_SHIFT         (28U)
#define GPMI_CTRL1_SET_WRITE_CLK_STOP_MASK       (0x20000000U)
#define GPMI_CTRL1_SET_WRITE_CLK_STOP_SHIFT      (29U)
#define GPMI_CTRL1_SET_SSYNC_CLK_STOP_MASK       (0x40000000U)
#define GPMI_CTRL1_SET_SSYNC_CLK_STOP_SHIFT      (30U)
#define GPMI_CTRL1_SET_DEV_CLK_STOP_MASK         (0x80000000U)
#define GPMI_CTRL1_SET_DEV_CLK_STOP_SHIFT        (31U)

/*! @name CTRL1_CLR - GPMI Control Register 1 Description */
#define GPMI_CTRL1_CLR_GPMI_MODE_MASK            (0x1U)
#define GPMI_CTRL1_CLR_GPMI_MODE_SHIFT           (0U)
#define GPMI_CTRL1_CLR_CAMERA_MODE_MASK          (0x2U)
#define GPMI_CTRL1_CLR_CAMERA_MODE_SHIFT         (1U)
#define GPMI_CTRL1_CLR_ATA_IRQRDY_POLARITY_MASK  (0x4U)
#define GPMI_CTRL1_CLR_ATA_IRQRDY_POLARITY_SHIFT (2U)
#define GPMI_CTRL1_CLR_DEV_RESET_MASK            (0x8U)
#define GPMI_CTRL1_CLR_DEV_RESET_SHIFT           (3U)
#define GPMI_CTRL1_CLR_ABORT_WAIT_FOR_READY_CHANNEL_MASK (0x70U)
#define GPMI_CTRL1_CLR_ABORT_WAIT_FOR_READY_CHANNEL_SHIFT (4U)
#define GPMI_CTRL1_CLR_ABORT_WAIT_FOR_READY_CHANNEL(x) (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_CLR_ABORT_WAIT_FOR_READY_CHANNEL_SHIFT)) & GPMI_CTRL1_CLR_ABORT_WAIT_FOR_READY_CHANNEL_MASK)
#define GPMI_CTRL1_CLR_ABORT_WAIT_REQUEST_MASK   (0x80U)
#define GPMI_CTRL1_CLR_ABORT_WAIT_REQUEST_SHIFT  (7U)
#define GPMI_CTRL1_CLR_BURST_EN_MASK             (0x100U)
#define GPMI_CTRL1_CLR_BURST_EN_SHIFT            (8U)
#define GPMI_CTRL1_CLR_TIMEOUT_IRQ_MASK          (0x200U)
#define GPMI_CTRL1_CLR_TIMEOUT_IRQ_SHIFT         (9U)
#define GPMI_CTRL1_CLR_DEV_IRQ_MASK              (0x400U)
#define GPMI_CTRL1_CLR_DEV_IRQ_SHIFT             (10U)
#define GPMI_CTRL1_CLR_DMA2ECC_MODE_MASK         (0x800U)
#define GPMI_CTRL1_CLR_DMA2ECC_MODE_SHIFT        (11U)
#define GPMI_CTRL1_CLR_RDN_DELAY_MASK            (0xF000U)
#define GPMI_CTRL1_CLR_RDN_DELAY_SHIFT           (12U)
#define GPMI_CTRL1_CLR_RDN_DELAY(x)              (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_CLR_RDN_DELAY_SHIFT)) & GPMI_CTRL1_CLR_RDN_DELAY_MASK)
#define GPMI_CTRL1_CLR_HALF_PERIOD_MASK          (0x10000U)
#define GPMI_CTRL1_CLR_HALF_PERIOD_SHIFT         (16U)
#define GPMI_CTRL1_CLR_DLL_ENABLE_MASK           (0x20000U)
#define GPMI_CTRL1_CLR_DLL_ENABLE_SHIFT          (17U)
#define GPMI_CTRL1_CLR_BCH_MODE_MASK             (0x40000U)
#define GPMI_CTRL1_CLR_BCH_MODE_SHIFT            (18U)
#define GPMI_CTRL1_CLR_GANGED_RDYBUSY_MASK       (0x80000U)
#define GPMI_CTRL1_CLR_GANGED_RDYBUSY_SHIFT      (19U)
#define GPMI_CTRL1_CLR_TIMEOUT_IRQ_EN_MASK       (0x100000U)
#define GPMI_CTRL1_CLR_TIMEOUT_IRQ_EN_SHIFT      (20U)
#define GPMI_CTRL1_CLR_TEST_TRIGGER_MASK         (0x200000U)
#define GPMI_CTRL1_CLR_TEST_TRIGGER_SHIFT        (21U)
#define GPMI_CTRL1_CLR_WRN_DLY_SEL_MASK          (0xC00000U)
#define GPMI_CTRL1_CLR_WRN_DLY_SEL_SHIFT         (22U)
#define GPMI_CTRL1_CLR_WRN_DLY_SEL(x)            (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_CLR_WRN_DLY_SEL_SHIFT)) & GPMI_CTRL1_CLR_WRN_DLY_SEL_MASK)
#define GPMI_CTRL1_CLR_DECOUPLE_CS_MASK          (0x1000000U)
#define GPMI_CTRL1_CLR_DECOUPLE_CS_SHIFT         (24U)
#define GPMI_CTRL1_CLR_SSYNCMODE_MASK            (0x2000000U)
#define GPMI_CTRL1_CLR_SSYNCMODE_SHIFT           (25U)
#define GPMI_CTRL1_CLR_UPDATE_CS_MASK            (0x4000000U)
#define GPMI_CTRL1_CLR_UPDATE_CS_SHIFT           (26U)
#define GPMI_CTRL1_CLR_GPMI_CLK_DIV2_EN_MASK     (0x8000000U)
#define GPMI_CTRL1_CLR_GPMI_CLK_DIV2_EN_SHIFT    (27U)
#define GPMI_CTRL1_CLR_TOGGLE_MODE_MASK          (0x10000000U)
#define GPMI_CTRL1_CLR_TOGGLE_MODE_SHIFT         (28U)
#define GPMI_CTRL1_CLR_WRITE_CLK_STOP_MASK       (0x20000000U)
#define GPMI_CTRL1_CLR_WRITE_CLK_STOP_SHIFT      (29U)
#define GPMI_CTRL1_CLR_SSYNC_CLK_STOP_MASK       (0x40000000U)
#define GPMI_CTRL1_CLR_SSYNC_CLK_STOP_SHIFT      (30U)
#define GPMI_CTRL1_CLR_DEV_CLK_STOP_MASK         (0x80000000U)
#define GPMI_CTRL1_CLR_DEV_CLK_STOP_SHIFT        (31U)

/*! @name CTRL1_TOG - GPMI Control Register 1 Description */
#define GPMI_CTRL1_TOG_GPMI_MODE_MASK            (0x1U)
#define GPMI_CTRL1_TOG_GPMI_MODE_SHIFT           (0U)
#define GPMI_CTRL1_TOG_CAMERA_MODE_MASK          (0x2U)
#define GPMI_CTRL1_TOG_CAMERA_MODE_SHIFT         (1U)
#define GPMI_CTRL1_TOG_ATA_IRQRDY_POLARITY_MASK  (0x4U)
#define GPMI_CTRL1_TOG_ATA_IRQRDY_POLARITY_SHIFT (2U)
#define GPMI_CTRL1_TOG_DEV_RESET_MASK            (0x8U)
#define GPMI_CTRL1_TOG_DEV_RESET_SHIFT           (3U)
#define GPMI_CTRL1_TOG_ABORT_WAIT_FOR_READY_CHANNEL_MASK (0x70U)
#define GPMI_CTRL1_TOG_ABORT_WAIT_FOR_READY_CHANNEL_SHIFT (4U)
#define GPMI_CTRL1_TOG_ABORT_WAIT_FOR_READY_CHANNEL(x) (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_TOG_ABORT_WAIT_FOR_READY_CHANNEL_SHIFT)) & GPMI_CTRL1_TOG_ABORT_WAIT_FOR_READY_CHANNEL_MASK)
#define GPMI_CTRL1_TOG_ABORT_WAIT_REQUEST_MASK   (0x80U)
#define GPMI_CTRL1_TOG_ABORT_WAIT_REQUEST_SHIFT  (7U)
#define GPMI_CTRL1_TOG_BURST_EN_MASK             (0x100U)
#define GPMI_CTRL1_TOG_BURST_EN_SHIFT            (8U)
#define GPMI_CTRL1_TOG_TIMEOUT_IRQ_MASK          (0x200U)
#define GPMI_CTRL1_TOG_TIMEOUT_IRQ_SHIFT         (9U)
#define GPMI_CTRL1_TOG_DEV_IRQ_MASK              (0x400U)
#define GPMI_CTRL1_TOG_DEV_IRQ_SHIFT             (10U)
#define GPMI_CTRL1_TOG_DMA2ECC_MODE_MASK         (0x800U)
#define GPMI_CTRL1_TOG_DMA2ECC_MODE_SHIFT        (11U)
#define GPMI_CTRL1_TOG_RDN_DELAY_MASK            (0xF000U)
#define GPMI_CTRL1_TOG_RDN_DELAY_SHIFT           (12U)
#define GPMI_CTRL1_TOG_RDN_DELAY(x)              (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_TOG_RDN_DELAY_SHIFT)) & GPMI_CTRL1_TOG_RDN_DELAY_MASK)
#define GPMI_CTRL1_TOG_HALF_PERIOD_MASK          (0x10000U)
#define GPMI_CTRL1_TOG_HALF_PERIOD_SHIFT         (16U)
#define GPMI_CTRL1_TOG_DLL_ENABLE_MASK           (0x20000U)
#define GPMI_CTRL1_TOG_DLL_ENABLE_SHIFT          (17U)
#define GPMI_CTRL1_TOG_BCH_MODE_MASK             (0x40000U)
#define GPMI_CTRL1_TOG_BCH_MODE_SHIFT            (18U)
#define GPMI_CTRL1_TOG_GANGED_RDYBUSY_MASK       (0x80000U)
#define GPMI_CTRL1_TOG_GANGED_RDYBUSY_SHIFT      (19U)
#define GPMI_CTRL1_TOG_TIMEOUT_IRQ_EN_MASK       (0x100000U)
#define GPMI_CTRL1_TOG_TIMEOUT_IRQ_EN_SHIFT      (20U)
#define GPMI_CTRL1_TOG_TEST_TRIGGER_MASK         (0x200000U)
#define GPMI_CTRL1_TOG_TEST_TRIGGER_SHIFT        (21U)
#define GPMI_CTRL1_TOG_WRN_DLY_SEL_MASK          (0xC00000U)
#define GPMI_CTRL1_TOG_WRN_DLY_SEL_SHIFT         (22U)
#define GPMI_CTRL1_TOG_WRN_DLY_SEL(x)            (((uint32_t)(((uint32_t)(x)) << GPMI_CTRL1_TOG_WRN_DLY_SEL_SHIFT)) & GPMI_CTRL1_TOG_WRN_DLY_SEL_MASK)
#define GPMI_CTRL1_TOG_DECOUPLE_CS_MASK          (0x1000000U)
#define GPMI_CTRL1_TOG_DECOUPLE_CS_SHIFT         (24U)
#define GPMI_CTRL1_TOG_SSYNCMODE_MASK            (0x2000000U)
#define GPMI_CTRL1_TOG_SSYNCMODE_SHIFT           (25U)
#define GPMI_CTRL1_TOG_UPDATE_CS_MASK            (0x4000000U)
#define GPMI_CTRL1_TOG_UPDATE_CS_SHIFT           (26U)
#define GPMI_CTRL1_TOG_GPMI_CLK_DIV2_EN_MASK     (0x8000000U)
#define GPMI_CTRL1_TOG_GPMI_CLK_DIV2_EN_SHIFT    (27U)
#define GPMI_CTRL1_TOG_TOGGLE_MODE_MASK          (0x10000000U)
#define GPMI_CTRL1_TOG_TOGGLE_MODE_SHIFT         (28U)
#define GPMI_CTRL1_TOG_WRITE_CLK_STOP_MASK       (0x20000000U)
#define GPMI_CTRL1_TOG_WRITE_CLK_STOP_SHIFT      (29U)
#define GPMI_CTRL1_TOG_SSYNC_CLK_STOP_MASK       (0x40000000U)
#define GPMI_CTRL1_TOG_SSYNC_CLK_STOP_SHIFT      (30U)
#define GPMI_CTRL1_TOG_DEV_CLK_STOP_MASK         (0x80000000U)
#define GPMI_CTRL1_TOG_DEV_CLK_STOP_SHIFT        (31U)

/*! @name TIMING0 - GPMI Timing Register 0 Description */
#define GPMI_TIMING0_DATA_SETUP_MASK             (0xFFU)
#define GPMI_TIMING0_DATA_SETUP_SHIFT            (0U)
#define GPMI_TIMING0_DATA_SETUP(x)               (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING0_DATA_SETUP_SHIFT)) & GPMI_TIMING0_DATA_SETUP_MASK)
#define GPMI_TIMING0_DATA_HOLD_MASK              (0xFF00U)
#define GPMI_TIMING0_DATA_HOLD_SHIFT             (8U)
#define GPMI_TIMING0_DATA_HOLD(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING0_DATA_HOLD_SHIFT)) & GPMI_TIMING0_DATA_HOLD_MASK)
#define GPMI_TIMING0_ADDRESS_SETUP_MASK          (0xFF0000U)
#define GPMI_TIMING0_ADDRESS_SETUP_SHIFT         (16U)
#define GPMI_TIMING0_ADDRESS_SETUP(x)            (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING0_ADDRESS_SETUP_SHIFT)) & GPMI_TIMING0_ADDRESS_SETUP_MASK)
#define GPMI_TIMING0_RSVD1_MASK                  (0xFF000000U)
#define GPMI_TIMING0_RSVD1_SHIFT                 (24U)
#define GPMI_TIMING0_RSVD1(x)                    (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING0_RSVD1_SHIFT)) & GPMI_TIMING0_RSVD1_MASK)

/*! @name TIMING1 - GPMI Timing Register 1 Description */
#define GPMI_TIMING1_RSVD1_MASK                  (0xFFFFU)
#define GPMI_TIMING1_RSVD1_SHIFT                 (0U)
#define GPMI_TIMING1_RSVD1(x)                    (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING1_RSVD1_SHIFT)) & GPMI_TIMING1_RSVD1_MASK)
#define GPMI_TIMING1_DEVICE_BUSY_TIMEOUT_MASK    (0xFFFF0000U)
#define GPMI_TIMING1_DEVICE_BUSY_TIMEOUT_SHIFT   (16U)
#define GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(x)      (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING1_DEVICE_BUSY_TIMEOUT_SHIFT)) & GPMI_TIMING1_DEVICE_BUSY_TIMEOUT_MASK)

/*! @name TIMING2 - GPMI Timing Register 2 Description */
#define GPMI_TIMING2_DATA_PAUSE_MASK             (0xFU)
#define GPMI_TIMING2_DATA_PAUSE_SHIFT            (0U)
#define GPMI_TIMING2_DATA_PAUSE(x)               (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_DATA_PAUSE_SHIFT)) & GPMI_TIMING2_DATA_PAUSE_MASK)
#define GPMI_TIMING2_CMDADD_PAUSE_MASK           (0xF0U)
#define GPMI_TIMING2_CMDADD_PAUSE_SHIFT          (4U)
#define GPMI_TIMING2_CMDADD_PAUSE(x)             (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_CMDADD_PAUSE_SHIFT)) & GPMI_TIMING2_CMDADD_PAUSE_MASK)
#define GPMI_TIMING2_POSTAMBLE_DELAY_MASK        (0xF00U)
#define GPMI_TIMING2_POSTAMBLE_DELAY_SHIFT       (8U)
#define GPMI_TIMING2_POSTAMBLE_DELAY(x)          (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_POSTAMBLE_DELAY_SHIFT)) & GPMI_TIMING2_POSTAMBLE_DELAY_MASK)
#define GPMI_TIMING2_PREAMBLE_DELAY_MASK         (0xF000U)
#define GPMI_TIMING2_PREAMBLE_DELAY_SHIFT        (12U)
#define GPMI_TIMING2_PREAMBLE_DELAY(x)           (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_PREAMBLE_DELAY_SHIFT)) & GPMI_TIMING2_PREAMBLE_DELAY_MASK)
#define GPMI_TIMING2_CE_DELAY_MASK               (0x1F0000U)
#define GPMI_TIMING2_CE_DELAY_SHIFT              (16U)
#define GPMI_TIMING2_CE_DELAY(x)                 (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_CE_DELAY_SHIFT)) & GPMI_TIMING2_CE_DELAY_MASK)
#define GPMI_TIMING2_RSVD0_MASK                  (0xE00000U)
#define GPMI_TIMING2_RSVD0_SHIFT                 (21U)
#define GPMI_TIMING2_RSVD0(x)                    (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_RSVD0_SHIFT)) & GPMI_TIMING2_RSVD0_MASK)
#define GPMI_TIMING2_READ_LATENCY_MASK           (0x7000000U)
#define GPMI_TIMING2_READ_LATENCY_SHIFT          (24U)
#define GPMI_TIMING2_READ_LATENCY(x)             (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_READ_LATENCY_SHIFT)) & GPMI_TIMING2_READ_LATENCY_MASK)
#define GPMI_TIMING2_TCR_MASK                    (0x18000000U)
#define GPMI_TIMING2_TCR_SHIFT                   (27U)
#define GPMI_TIMING2_TCR(x)                      (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_TCR_SHIFT)) & GPMI_TIMING2_TCR_MASK)
#define GPMI_TIMING2_TRPSTH_MASK                 (0xE0000000U)
#define GPMI_TIMING2_TRPSTH_SHIFT                (29U)
#define GPMI_TIMING2_TRPSTH(x)                   (((uint32_t)(((uint32_t)(x)) << GPMI_TIMING2_TRPSTH_SHIFT)) & GPMI_TIMING2_TRPSTH_MASK)

/*! @name DATA - GPMI DMA Data Transfer Register Description */
#define GPMI_DATA_DATA_MASK                      (0xFFFFFFFFU)
#define GPMI_DATA_DATA_SHIFT                     (0U)
#define GPMI_DATA_DATA(x)                        (((uint32_t)(((uint32_t)(x)) << GPMI_DATA_DATA_SHIFT)) & GPMI_DATA_DATA_MASK)

/*! @name STAT - GPMI Status Register Description */
#define GPMI_STAT_PRESENT_MASK                   (0x1U)
#define GPMI_STAT_PRESENT_SHIFT                  (0U)
#define GPMI_STAT_FIFO_FULL_MASK                 (0x2U)
#define GPMI_STAT_FIFO_FULL_SHIFT                (1U)
#define GPMI_STAT_FIFO_EMPTY_MASK                (0x4U)
#define GPMI_STAT_FIFO_EMPTY_SHIFT               (2U)
#define GPMI_STAT_INVALID_BUFFER_MASK_MASK       (0x8U)
#define GPMI_STAT_INVALID_BUFFER_MASK_SHIFT      (3U)
#define GPMI_STAT_ATA_IRQ_MASK                   (0x10U)
#define GPMI_STAT_ATA_IRQ_SHIFT                  (4U)
#define GPMI_STAT_RSVD1_MASK                     (0xE0U)
#define GPMI_STAT_RSVD1_SHIFT                    (5U)
#define GPMI_STAT_RSVD1(x)                       (((uint32_t)(((uint32_t)(x)) << GPMI_STAT_RSVD1_SHIFT)) & GPMI_STAT_RSVD1_MASK)
#define GPMI_STAT_DEV0_ERROR_MASK                (0x100U)
#define GPMI_STAT_DEV0_ERROR_SHIFT               (8U)
#define GPMI_STAT_DEV1_ERROR_MASK                (0x200U)
#define GPMI_STAT_DEV1_ERROR_SHIFT               (9U)
#define GPMI_STAT_DEV2_ERROR_MASK                (0x400U)
#define GPMI_STAT_DEV2_ERROR_SHIFT               (10U)
#define GPMI_STAT_DEV3_ERROR_MASK                (0x800U)
#define GPMI_STAT_DEV3_ERROR_SHIFT               (11U)
#define GPMI_STAT_DEV4_ERROR_MASK                (0x1000U)
#define GPMI_STAT_DEV4_ERROR_SHIFT               (12U)
#define GPMI_STAT_DEV5_ERROR_MASK                (0x2000U)
#define GPMI_STAT_DEV5_ERROR_SHIFT               (13U)
#define GPMI_STAT_DEV6_ERROR_MASK                (0x4000U)
#define GPMI_STAT_DEV6_ERROR_SHIFT               (14U)
#define GPMI_STAT_DEV7_ERROR_MASK                (0x8000U)
#define GPMI_STAT_DEV7_ERROR_SHIFT               (15U)
#define GPMI_STAT_RDY_TIMEOUT_MASK               (0xFF0000U)
#define GPMI_STAT_RDY_TIMEOUT_SHIFT              (16U)
#define GPMI_STAT_RDY_TIMEOUT(x)                 (((uint32_t)(((uint32_t)(x)) << GPMI_STAT_RDY_TIMEOUT_SHIFT)) & GPMI_STAT_RDY_TIMEOUT_MASK)
#define GPMI_STAT_READY_BUSY_MASK                (0xFF000000U)
#define GPMI_STAT_READY_BUSY_SHIFT               (24U)
#define GPMI_STAT_READY_BUSY(x)                  (((uint32_t)(((uint32_t)(x)) << GPMI_STAT_READY_BUSY_SHIFT)) & GPMI_STAT_READY_BUSY_MASK)

/*! @name DEBUG - GPMI Debug Information Register Description */
#define GPMI_DEBUG_CMD_END_MASK                  (0xFFU)
#define GPMI_DEBUG_CMD_END_SHIFT                 (0U)
#define GPMI_DEBUG_CMD_END(x)                    (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG_CMD_END_SHIFT)) & GPMI_DEBUG_CMD_END_MASK)
#define GPMI_DEBUG_DMAREQ_MASK                   (0xFF00U)
#define GPMI_DEBUG_DMAREQ_SHIFT                  (8U)
#define GPMI_DEBUG_DMAREQ(x)                     (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG_DMAREQ_SHIFT)) & GPMI_DEBUG_DMAREQ_MASK)
#define GPMI_DEBUG_DMA_SENSE_MASK                (0xFF0000U)
#define GPMI_DEBUG_DMA_SENSE_SHIFT               (16U)
#define GPMI_DEBUG_DMA_SENSE(x)                  (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG_DMA_SENSE_SHIFT)) & GPMI_DEBUG_DMA_SENSE_MASK)
#define GPMI_DEBUG_WAIT_FOR_READY_END_MASK       (0xFF000000U)
#define GPMI_DEBUG_WAIT_FOR_READY_END_SHIFT      (24U)
#define GPMI_DEBUG_WAIT_FOR_READY_END(x)         (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG_WAIT_FOR_READY_END_SHIFT)) & GPMI_DEBUG_WAIT_FOR_READY_END_MASK)

/*! @name VERSION - GPMI Version Register Description */
#define GPMI_VERSION_STEP_MASK                   (0xFFFFU)
#define GPMI_VERSION_STEP_SHIFT                  (0U)
#define GPMI_VERSION_STEP(x)                     (((uint32_t)(((uint32_t)(x)) << GPMI_VERSION_STEP_SHIFT)) & GPMI_VERSION_STEP_MASK)
#define GPMI_VERSION_MINOR_MASK                  (0xFF0000U)
#define GPMI_VERSION_MINOR_SHIFT                 (16U)
#define GPMI_VERSION_MINOR(x)                    (((uint32_t)(((uint32_t)(x)) << GPMI_VERSION_MINOR_SHIFT)) & GPMI_VERSION_MINOR_MASK)
#define GPMI_VERSION_MAJOR_MASK                  (0xFF000000U)
#define GPMI_VERSION_MAJOR_SHIFT                 (24U)
#define GPMI_VERSION_MAJOR(x)                    (((uint32_t)(((uint32_t)(x)) << GPMI_VERSION_MAJOR_SHIFT)) & GPMI_VERSION_MAJOR_MASK)

/*! @name DEBUG2 - GPMI Debug2 Information Register Description */
#define GPMI_DEBUG2_RDN_TAP_MASK                 (0x3FU)
#define GPMI_DEBUG2_RDN_TAP_SHIFT                (0U)
#define GPMI_DEBUG2_RDN_TAP(x)                   (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG2_RDN_TAP_SHIFT)) & GPMI_DEBUG2_RDN_TAP_MASK)
#define GPMI_DEBUG2_UPDATE_WINDOW_MASK           (0x40U)
#define GPMI_DEBUG2_UPDATE_WINDOW_SHIFT          (6U)
#define GPMI_DEBUG2_VIEW_DELAYED_RDN_MASK        (0x80U)
#define GPMI_DEBUG2_VIEW_DELAYED_RDN_SHIFT       (7U)
#define GPMI_DEBUG2_SYND2GPMI_READY_MASK         (0x100U)
#define GPMI_DEBUG2_SYND2GPMI_READY_SHIFT        (8U)
#define GPMI_DEBUG2_SYND2GPMI_VALID_MASK         (0x200U)
#define GPMI_DEBUG2_SYND2GPMI_VALID_SHIFT        (9U)
#define GPMI_DEBUG2_GPMI2SYND_READY_MASK         (0x400U)
#define GPMI_DEBUG2_GPMI2SYND_READY_SHIFT        (10U)
#define GPMI_DEBUG2_GPMI2SYND_VALID_MASK         (0x800U)
#define GPMI_DEBUG2_GPMI2SYND_VALID_SHIFT        (11U)
#define GPMI_DEBUG2_SYND2GPMI_BE_MASK            (0xF000U)
#define GPMI_DEBUG2_SYND2GPMI_BE_SHIFT           (12U)
#define GPMI_DEBUG2_SYND2GPMI_BE(x)              (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG2_SYND2GPMI_BE_SHIFT)) & GPMI_DEBUG2_SYND2GPMI_BE_MASK)
#define GPMI_DEBUG2_MAIN_STATE_MASK              (0xF0000U)
#define GPMI_DEBUG2_MAIN_STATE_SHIFT             (16U)
#define GPMI_DEBUG2_MAIN_STATE(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG2_MAIN_STATE_SHIFT)) & GPMI_DEBUG2_MAIN_STATE_MASK)
#define GPMI_DEBUG2_PIN_STATE_MASK               (0x700000U)
#define GPMI_DEBUG2_PIN_STATE_SHIFT              (20U)
#define GPMI_DEBUG2_PIN_STATE(x)                 (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG2_PIN_STATE_SHIFT)) & GPMI_DEBUG2_PIN_STATE_MASK)
#define GPMI_DEBUG2_BUSY_MASK                    (0x800000U)
#define GPMI_DEBUG2_BUSY_SHIFT                   (23U)
#define GPMI_DEBUG2_UDMA_STATE_MASK              (0xF000000U)
#define GPMI_DEBUG2_UDMA_STATE_SHIFT             (24U)
#define GPMI_DEBUG2_UDMA_STATE(x)                (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG2_UDMA_STATE_SHIFT)) & GPMI_DEBUG2_UDMA_STATE_MASK)
#define GPMI_DEBUG2_RSVD1_MASK                   (0xF0000000U)
#define GPMI_DEBUG2_RSVD1_SHIFT                  (28U)
#define GPMI_DEBUG2_RSVD1(x)                     (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG2_RSVD1_SHIFT)) & GPMI_DEBUG2_RSVD1_MASK)

/*! @name DEBUG3 - GPMI Debug3 Information Register Description */
#define GPMI_DEBUG3_DEV_WORD_CNTR_MASK           (0xFFFFU)
#define GPMI_DEBUG3_DEV_WORD_CNTR_SHIFT          (0U)
#define GPMI_DEBUG3_DEV_WORD_CNTR(x)             (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG3_DEV_WORD_CNTR_SHIFT)) & GPMI_DEBUG3_DEV_WORD_CNTR_MASK)
#define GPMI_DEBUG3_APB_WORD_CNTR_MASK           (0xFFFF0000U)
#define GPMI_DEBUG3_APB_WORD_CNTR_SHIFT          (16U)
#define GPMI_DEBUG3_APB_WORD_CNTR(x)             (((uint32_t)(((uint32_t)(x)) << GPMI_DEBUG3_APB_WORD_CNTR_SHIFT)) & GPMI_DEBUG3_APB_WORD_CNTR_MASK)

/*! @name READ_DDR_DLL_CTRL - GPMI Double Rate Read DLL Control Register Description */
#define GPMI_READ_DDR_DLL_CTRL_ENABLE_MASK       (0x1U)
#define GPMI_READ_DDR_DLL_CTRL_ENABLE_SHIFT      (0U)
#define GPMI_READ_DDR_DLL_CTRL_RESET_MASK        (0x2U)
#define GPMI_READ_DDR_DLL_CTRL_RESET_SHIFT       (1U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD_MASK (0x4U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD_SHIFT (2U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET_MASK (0x78U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET_SHIFT (3U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(x) (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET_SHIFT)) & GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET_MASK)
#define GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE_MASK  (0x80U)
#define GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE_SHIFT (7U)
#define GPMI_READ_DDR_DLL_CTRL_REFCLK_ON_MASK    (0x100U)
#define GPMI_READ_DDR_DLL_CTRL_REFCLK_ON_SHIFT   (8U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_MASK (0x200U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_SHIFT (9U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL_MASK (0x3FC00U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT (10U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x) (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT)) & GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL_MASK)
#define GPMI_READ_DDR_DLL_CTRL_RSVD1_MASK        (0xC0000U)
#define GPMI_READ_DDR_DLL_CTRL_RSVD1_SHIFT       (18U)
#define GPMI_READ_DDR_DLL_CTRL_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_CTRL_RSVD1_SHIFT)) & GPMI_READ_DDR_DLL_CTRL_RSVD1_MASK)
#define GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT_MASK (0xFF00000U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT_SHIFT (20U)
#define GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(x) (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT_SHIFT)) & GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT_MASK)
#define GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT_MASK (0xF0000000U)
#define GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT_SHIFT (28U)
#define GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(x) (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT_SHIFT)) & GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT_MASK)

/*! @name WRITE_DDR_DLL_CTRL - GPMI Double Rate Write DLL Control Register Description */
#define GPMI_WRITE_DDR_DLL_CTRL_ENABLE_MASK      (0x1U)
#define GPMI_WRITE_DDR_DLL_CTRL_ENABLE_SHIFT     (0U)
#define GPMI_WRITE_DDR_DLL_CTRL_RESET_MASK       (0x2U)
#define GPMI_WRITE_DDR_DLL_CTRL_RESET_SHIFT      (1U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD_MASK (0x4U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD_SHIFT (2U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET_MASK (0x78U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET_SHIFT (3U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(x) (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET_SHIFT)) & GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET_MASK)
#define GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE_MASK (0x80U)
#define GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE_SHIFT (7U)
#define GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON_MASK   (0x100U)
#define GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON_SHIFT  (8U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_MASK (0x200U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_SHIFT (9U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL_MASK (0x3FC00U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT (10U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x) (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT)) & GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL_MASK)
#define GPMI_WRITE_DDR_DLL_CTRL_RSVD1_MASK       (0xC0000U)
#define GPMI_WRITE_DDR_DLL_CTRL_RSVD1_SHIFT      (18U)
#define GPMI_WRITE_DDR_DLL_CTRL_RSVD1(x)         (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_CTRL_RSVD1_SHIFT)) & GPMI_WRITE_DDR_DLL_CTRL_RSVD1_MASK)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT_MASK (0xFF00000U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT_SHIFT (20U)
#define GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(x) (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT_SHIFT)) & GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT_MASK)
#define GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT_MASK (0xF0000000U)
#define GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT_SHIFT (28U)
#define GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(x) (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT_SHIFT)) & GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT_MASK)

/*! @name READ_DDR_DLL_STS - GPMI Double Rate Read DLL Status Register Description */
#define GPMI_READ_DDR_DLL_STS_SLV_LOCK_MASK      (0x1U)
#define GPMI_READ_DDR_DLL_STS_SLV_LOCK_SHIFT     (0U)
#define GPMI_READ_DDR_DLL_STS_SLV_SEL_MASK       (0x1FEU)
#define GPMI_READ_DDR_DLL_STS_SLV_SEL_SHIFT      (1U)
#define GPMI_READ_DDR_DLL_STS_SLV_SEL(x)         (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_STS_SLV_SEL_SHIFT)) & GPMI_READ_DDR_DLL_STS_SLV_SEL_MASK)
#define GPMI_READ_DDR_DLL_STS_RSVD0_MASK         (0xFE00U)
#define GPMI_READ_DDR_DLL_STS_RSVD0_SHIFT        (9U)
#define GPMI_READ_DDR_DLL_STS_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_STS_RSVD0_SHIFT)) & GPMI_READ_DDR_DLL_STS_RSVD0_MASK)
#define GPMI_READ_DDR_DLL_STS_REF_LOCK_MASK      (0x10000U)
#define GPMI_READ_DDR_DLL_STS_REF_LOCK_SHIFT     (16U)
#define GPMI_READ_DDR_DLL_STS_REF_SEL_MASK       (0x1FE0000U)
#define GPMI_READ_DDR_DLL_STS_REF_SEL_SHIFT      (17U)
#define GPMI_READ_DDR_DLL_STS_REF_SEL(x)         (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_STS_REF_SEL_SHIFT)) & GPMI_READ_DDR_DLL_STS_REF_SEL_MASK)
#define GPMI_READ_DDR_DLL_STS_RSVD1_MASK         (0xFE000000U)
#define GPMI_READ_DDR_DLL_STS_RSVD1_SHIFT        (25U)
#define GPMI_READ_DDR_DLL_STS_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << GPMI_READ_DDR_DLL_STS_RSVD1_SHIFT)) & GPMI_READ_DDR_DLL_STS_RSVD1_MASK)

/*! @name WRITE_DDR_DLL_STS - GPMI Double Rate Write DLL Status Register Description */
#define GPMI_WRITE_DDR_DLL_STS_SLV_LOCK_MASK     (0x1U)
#define GPMI_WRITE_DDR_DLL_STS_SLV_LOCK_SHIFT    (0U)
#define GPMI_WRITE_DDR_DLL_STS_SLV_SEL_MASK      (0x1FEU)
#define GPMI_WRITE_DDR_DLL_STS_SLV_SEL_SHIFT     (1U)
#define GPMI_WRITE_DDR_DLL_STS_SLV_SEL(x)        (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_STS_SLV_SEL_SHIFT)) & GPMI_WRITE_DDR_DLL_STS_SLV_SEL_MASK)
#define GPMI_WRITE_DDR_DLL_STS_RSVD0_MASK        (0xFE00U)
#define GPMI_WRITE_DDR_DLL_STS_RSVD0_SHIFT       (9U)
#define GPMI_WRITE_DDR_DLL_STS_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_STS_RSVD0_SHIFT)) & GPMI_WRITE_DDR_DLL_STS_RSVD0_MASK)
#define GPMI_WRITE_DDR_DLL_STS_REF_LOCK_MASK     (0x10000U)
#define GPMI_WRITE_DDR_DLL_STS_REF_LOCK_SHIFT    (16U)
#define GPMI_WRITE_DDR_DLL_STS_REF_SEL_MASK      (0x1FE0000U)
#define GPMI_WRITE_DDR_DLL_STS_REF_SEL_SHIFT     (17U)
#define GPMI_WRITE_DDR_DLL_STS_REF_SEL(x)        (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_STS_REF_SEL_SHIFT)) & GPMI_WRITE_DDR_DLL_STS_REF_SEL_MASK)
#define GPMI_WRITE_DDR_DLL_STS_RSVD1_MASK        (0xFE000000U)
#define GPMI_WRITE_DDR_DLL_STS_RSVD1_SHIFT       (25U)
#define GPMI_WRITE_DDR_DLL_STS_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << GPMI_WRITE_DDR_DLL_STS_RSVD1_SHIFT)) & GPMI_WRITE_DDR_DLL_STS_RSVD1_MASK)


/*!
 * @}
 */ /* end of group GPMI_Register_Masks */


/* GPMI - Peripheral instance base addresses */
/** Peripheral GPMI base pointer */
#define GPMI_BASE_PTR                            ((GPMI_MemMapPtr)0x33002000u)
/** Array initializer of GPMI peripheral base pointers */
#define GPMI_BASE_PTRS                           { GPMI_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- GPMI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPMI_Register_Accessor_Macros GPMI - Register accessor macros
 * @{
 */


/* GPMI - Register instance definitions */
/* GPMI */
#define GPMI_CTRL0                               GPMI_CTRL0_REG(GPMI_BASE_PTR)
#define GPMI_CTRL0_SET                           GPMI_CTRL0_SET_REG(GPMI_BASE_PTR)
#define GPMI_CTRL0_CLR                           GPMI_CTRL0_CLR_REG(GPMI_BASE_PTR)
#define GPMI_CTRL0_TOG                           GPMI_CTRL0_TOG_REG(GPMI_BASE_PTR)
#define GPMI_COMPARE                             GPMI_COMPARE_REG(GPMI_BASE_PTR)
#define GPMI_ECCCTRL                             GPMI_ECCCTRL_REG(GPMI_BASE_PTR)
#define GPMI_ECCCTRL_SET                         GPMI_ECCCTRL_SET_REG(GPMI_BASE_PTR)
#define GPMI_ECCCTRL_CLR                         GPMI_ECCCTRL_CLR_REG(GPMI_BASE_PTR)
#define GPMI_ECCCTRL_TOG                         GPMI_ECCCTRL_TOG_REG(GPMI_BASE_PTR)
#define GPMI_ECCCOUNT                            GPMI_ECCCOUNT_REG(GPMI_BASE_PTR)
#define GPMI_PAYLOAD                             GPMI_PAYLOAD_REG(GPMI_BASE_PTR)
#define GPMI_AUXILIARY                           GPMI_AUXILIARY_REG(GPMI_BASE_PTR)
#define GPMI_CTRL1                               GPMI_CTRL1_REG(GPMI_BASE_PTR)
#define GPMI_CTRL1_SET                           GPMI_CTRL1_SET_REG(GPMI_BASE_PTR)
#define GPMI_CTRL1_CLR                           GPMI_CTRL1_CLR_REG(GPMI_BASE_PTR)
#define GPMI_CTRL1_TOG                           GPMI_CTRL1_TOG_REG(GPMI_BASE_PTR)
#define GPMI_TIMING0                             GPMI_TIMING0_REG(GPMI_BASE_PTR)
#define GPMI_TIMING1                             GPMI_TIMING1_REG(GPMI_BASE_PTR)
#define GPMI_TIMING2                             GPMI_TIMING2_REG(GPMI_BASE_PTR)
#define GPMI_DATA                                GPMI_DATA_REG(GPMI_BASE_PTR)
#define GPMI_STAT                                GPMI_STAT_REG(GPMI_BASE_PTR)
#define GPMI_DEBUG                               GPMI_DEBUG_REG(GPMI_BASE_PTR)
#define GPMI_VERSION                             GPMI_VERSION_REG(GPMI_BASE_PTR)
#define GPMI_DEBUG2                              GPMI_DEBUG2_REG(GPMI_BASE_PTR)
#define GPMI_DEBUG3                              GPMI_DEBUG3_REG(GPMI_BASE_PTR)
#define GPMI_READ_DDR_DLL_CTRL                   GPMI_READ_DDR_DLL_CTRL_REG(GPMI_BASE_PTR)
#define GPMI_WRITE_DDR_DLL_CTRL                  GPMI_WRITE_DDR_DLL_CTRL_REG(GPMI_BASE_PTR)
#define GPMI_READ_DDR_DLL_STS                    GPMI_READ_DDR_DLL_STS_REG(GPMI_BASE_PTR)
#define GPMI_WRITE_DDR_DLL_STS                   GPMI_WRITE_DDR_DLL_STS_REG(GPMI_BASE_PTR)

/*!
 * @}
 */ /* end of group GPMI_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group GPMI_Peripheral */


/* ----------------------------------------------------------------------------
   -- GPT
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPT_Peripheral GPT
 * @{
 */

/** GPT - Peripheral register structure */
typedef struct GPT_MemMap {
  uint32_t CR;                                     /**< GPT Control Register, offset: 0x0 */
  uint32_t PR;                                     /**< GPT Prescaler Register, offset: 0x4 */
  uint32_t SR;                                     /**< GPT Status Register, offset: 0x8 */
  uint32_t IR;                                     /**< GPT Interrupt Register, offset: 0xC */
  uint32_t OCR1;                                   /**< GPT Output Compare Register 1, offset: 0x10 */
  uint32_t OCR2;                                   /**< GPT Output Compare Register 2, offset: 0x14 */
  uint32_t OCR3;                                   /**< GPT Output Compare Register 3, offset: 0x18 */
  uint32_t ICR1;                                   /**< GPT Input Capture Register 1, offset: 0x1C */
  uint32_t ICR2;                                   /**< GPT Input Capture Register 2, offset: 0x20 */
  uint32_t CNT;                                    /**< GPT Counter Register, offset: 0x24 */
} volatile *GPT_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- GPT - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPT_Register_Accessor_Macros GPT - Register accessor macros
 * @{
 */


/* GPT - Register accessors */
#define GPT_CR_REG(base)                         ((base)->CR)
#define GPT_PR_REG(base)                         ((base)->PR)
#define GPT_SR_REG(base)                         ((base)->SR)
#define GPT_IR_REG(base)                         ((base)->IR)
#define GPT_OCR1_REG(base)                       ((base)->OCR1)
#define GPT_OCR2_REG(base)                       ((base)->OCR2)
#define GPT_OCR3_REG(base)                       ((base)->OCR3)
#define GPT_ICR1_REG(base)                       ((base)->ICR1)
#define GPT_ICR2_REG(base)                       ((base)->ICR2)
#define GPT_CNT_REG(base)                        ((base)->CNT)

/*!
 * @}
 */ /* end of group GPT_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- GPT Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPT_Register_Masks GPT Register Masks
 * @{
 */

/*! @name CR - GPT Control Register */
#define GPT_CR_EN_MASK                           (0x1U)
#define GPT_CR_EN_SHIFT                          (0U)
#define GPT_CR_ENMOD_MASK                        (0x2U)
#define GPT_CR_ENMOD_SHIFT                       (1U)
#define GPT_CR_DBGEN_MASK                        (0x4U)
#define GPT_CR_DBGEN_SHIFT                       (2U)
#define GPT_CR_WAITEN_MASK                       (0x8U)
#define GPT_CR_WAITEN_SHIFT                      (3U)
#define GPT_CR_DOZEEN_MASK                       (0x10U)
#define GPT_CR_DOZEEN_SHIFT                      (4U)
#define GPT_CR_STOPEN_MASK                       (0x20U)
#define GPT_CR_STOPEN_SHIFT                      (5U)
#define GPT_CR_CLKSRC_MASK                       (0x1C0U)
#define GPT_CR_CLKSRC_SHIFT                      (6U)
#define GPT_CR_CLKSRC(x)                         (((uint32_t)(((uint32_t)(x)) << GPT_CR_CLKSRC_SHIFT)) & GPT_CR_CLKSRC_MASK)
#define GPT_CR_FRR_MASK                          (0x200U)
#define GPT_CR_FRR_SHIFT                         (9U)
#define GPT_CR_EN_24M_MASK                       (0x400U)
#define GPT_CR_EN_24M_SHIFT                      (10U)
#define GPT_CR_SWR_MASK                          (0x8000U)
#define GPT_CR_SWR_SHIFT                         (15U)
#define GPT_CR_IM1_MASK                          (0x30000U)
#define GPT_CR_IM1_SHIFT                         (16U)
#define GPT_CR_IM1(x)                            (((uint32_t)(((uint32_t)(x)) << GPT_CR_IM1_SHIFT)) & GPT_CR_IM1_MASK)
#define GPT_CR_IM2_MASK                          (0xC0000U)
#define GPT_CR_IM2_SHIFT                         (18U)
#define GPT_CR_IM2(x)                            (((uint32_t)(((uint32_t)(x)) << GPT_CR_IM2_SHIFT)) & GPT_CR_IM2_MASK)
#define GPT_CR_OM1_MASK                          (0x700000U)
#define GPT_CR_OM1_SHIFT                         (20U)
#define GPT_CR_OM1(x)                            (((uint32_t)(((uint32_t)(x)) << GPT_CR_OM1_SHIFT)) & GPT_CR_OM1_MASK)
#define GPT_CR_OM2_MASK                          (0x3800000U)
#define GPT_CR_OM2_SHIFT                         (23U)
#define GPT_CR_OM2(x)                            (((uint32_t)(((uint32_t)(x)) << GPT_CR_OM2_SHIFT)) & GPT_CR_OM2_MASK)
#define GPT_CR_OM3_MASK                          (0x1C000000U)
#define GPT_CR_OM3_SHIFT                         (26U)
#define GPT_CR_OM3(x)                            (((uint32_t)(((uint32_t)(x)) << GPT_CR_OM3_SHIFT)) & GPT_CR_OM3_MASK)
#define GPT_CR_FO1_MASK                          (0x20000000U)
#define GPT_CR_FO1_SHIFT                         (29U)
#define GPT_CR_FO2_MASK                          (0x40000000U)
#define GPT_CR_FO2_SHIFT                         (30U)
#define GPT_CR_FO3_MASK                          (0x80000000U)
#define GPT_CR_FO3_SHIFT                         (31U)

/*! @name PR - GPT Prescaler Register */
#define GPT_PR_PRESCALER_MASK                    (0xFFFU)
#define GPT_PR_PRESCALER_SHIFT                   (0U)
#define GPT_PR_PRESCALER(x)                      (((uint32_t)(((uint32_t)(x)) << GPT_PR_PRESCALER_SHIFT)) & GPT_PR_PRESCALER_MASK)
#define GPT_PR_PRESCALER24M_MASK                 (0xF000U)
#define GPT_PR_PRESCALER24M_SHIFT                (12U)
#define GPT_PR_PRESCALER24M(x)                   (((uint32_t)(((uint32_t)(x)) << GPT_PR_PRESCALER24M_SHIFT)) & GPT_PR_PRESCALER24M_MASK)

/*! @name SR - GPT Status Register */
#define GPT_SR_OF1_MASK                          (0x1U)
#define GPT_SR_OF1_SHIFT                         (0U)
#define GPT_SR_OF2_MASK                          (0x2U)
#define GPT_SR_OF2_SHIFT                         (1U)
#define GPT_SR_OF3_MASK                          (0x4U)
#define GPT_SR_OF3_SHIFT                         (2U)
#define GPT_SR_IF1_MASK                          (0x8U)
#define GPT_SR_IF1_SHIFT                         (3U)
#define GPT_SR_IF2_MASK                          (0x10U)
#define GPT_SR_IF2_SHIFT                         (4U)
#define GPT_SR_ROV_MASK                          (0x20U)
#define GPT_SR_ROV_SHIFT                         (5U)

/*! @name IR - GPT Interrupt Register */
#define GPT_IR_OF1IE_MASK                        (0x1U)
#define GPT_IR_OF1IE_SHIFT                       (0U)
#define GPT_IR_OF2IE_MASK                        (0x2U)
#define GPT_IR_OF2IE_SHIFT                       (1U)
#define GPT_IR_OF3IE_MASK                        (0x4U)
#define GPT_IR_OF3IE_SHIFT                       (2U)
#define GPT_IR_IF1IE_MASK                        (0x8U)
#define GPT_IR_IF1IE_SHIFT                       (3U)
#define GPT_IR_IF2IE_MASK                        (0x10U)
#define GPT_IR_IF2IE_SHIFT                       (4U)
#define GPT_IR_ROVIE_MASK                        (0x20U)
#define GPT_IR_ROVIE_SHIFT                       (5U)

/*! @name OCR1 - GPT Output Compare Register 1 */
#define GPT_OCR1_COMP_MASK                       (0xFFFFFFFFU)
#define GPT_OCR1_COMP_SHIFT                      (0U)
#define GPT_OCR1_COMP(x)                         (((uint32_t)(((uint32_t)(x)) << GPT_OCR1_COMP_SHIFT)) & GPT_OCR1_COMP_MASK)

/*! @name OCR2 - GPT Output Compare Register 2 */
#define GPT_OCR2_COMP_MASK                       (0xFFFFFFFFU)
#define GPT_OCR2_COMP_SHIFT                      (0U)
#define GPT_OCR2_COMP(x)                         (((uint32_t)(((uint32_t)(x)) << GPT_OCR2_COMP_SHIFT)) & GPT_OCR2_COMP_MASK)

/*! @name OCR3 - GPT Output Compare Register 3 */
#define GPT_OCR3_COMP_MASK                       (0xFFFFFFFFU)
#define GPT_OCR3_COMP_SHIFT                      (0U)
#define GPT_OCR3_COMP(x)                         (((uint32_t)(((uint32_t)(x)) << GPT_OCR3_COMP_SHIFT)) & GPT_OCR3_COMP_MASK)

/*! @name ICR1 - GPT Input Capture Register 1 */
#define GPT_ICR1_CAPT_MASK                       (0xFFFFFFFFU)
#define GPT_ICR1_CAPT_SHIFT                      (0U)
#define GPT_ICR1_CAPT(x)                         (((uint32_t)(((uint32_t)(x)) << GPT_ICR1_CAPT_SHIFT)) & GPT_ICR1_CAPT_MASK)

/*! @name ICR2 - GPT Input Capture Register 2 */
#define GPT_ICR2_CAPT_MASK                       (0xFFFFFFFFU)
#define GPT_ICR2_CAPT_SHIFT                      (0U)
#define GPT_ICR2_CAPT(x)                         (((uint32_t)(((uint32_t)(x)) << GPT_ICR2_CAPT_SHIFT)) & GPT_ICR2_CAPT_MASK)

/*! @name CNT - GPT Counter Register */
#define GPT_CNT_COUNT_MASK                       (0xFFFFFFFFU)
#define GPT_CNT_COUNT_SHIFT                      (0U)
#define GPT_CNT_COUNT(x)                         (((uint32_t)(((uint32_t)(x)) << GPT_CNT_COUNT_SHIFT)) & GPT_CNT_COUNT_MASK)


/*!
 * @}
 */ /* end of group GPT_Register_Masks */


/* GPT - Peripheral instance base addresses */
/** Peripheral GPT1 base pointer */
#define GPT1_BASE_PTR                            ((GPT_MemMapPtr)0x302D0000u)
/** Peripheral GPT2 base pointer */
#define GPT2_BASE_PTR                            ((GPT_MemMapPtr)0x302E0000u)
/** Peripheral GPT3 base pointer */
#define GPT3_BASE_PTR                            ((GPT_MemMapPtr)0x302F0000u)
/** Peripheral GPT4 base pointer */
#define GPT4_BASE_PTR                            ((GPT_MemMapPtr)0x30300000u)
/** Array initializer of GPT peripheral base pointers */
#define GPT_BASE_PTRS                            { GPT1_BASE_PTR, GPT2_BASE_PTR, GPT3_BASE_PTR, GPT4_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- GPT - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPT_Register_Accessor_Macros GPT - Register accessor macros
 * @{
 */


/* GPT - Register instance definitions */
/* GPT1 */
#define GPT1_CR                                  GPT_CR_REG(GPT1_BASE_PTR)
#define GPT1_PR                                  GPT_PR_REG(GPT1_BASE_PTR)
#define GPT1_SR                                  GPT_SR_REG(GPT1_BASE_PTR)
#define GPT1_IR                                  GPT_IR_REG(GPT1_BASE_PTR)
#define GPT1_OCR1                                GPT_OCR1_REG(GPT1_BASE_PTR)
#define GPT1_OCR2                                GPT_OCR2_REG(GPT1_BASE_PTR)
#define GPT1_OCR3                                GPT_OCR3_REG(GPT1_BASE_PTR)
#define GPT1_ICR1                                GPT_ICR1_REG(GPT1_BASE_PTR)
#define GPT1_ICR2                                GPT_ICR2_REG(GPT1_BASE_PTR)
#define GPT1_CNT                                 GPT_CNT_REG(GPT1_BASE_PTR)
/* GPT2 */
#define GPT2_CR                                  GPT_CR_REG(GPT2_BASE_PTR)
#define GPT2_PR                                  GPT_PR_REG(GPT2_BASE_PTR)
#define GPT2_SR                                  GPT_SR_REG(GPT2_BASE_PTR)
#define GPT2_IR                                  GPT_IR_REG(GPT2_BASE_PTR)
#define GPT2_OCR1                                GPT_OCR1_REG(GPT2_BASE_PTR)
#define GPT2_OCR2                                GPT_OCR2_REG(GPT2_BASE_PTR)
#define GPT2_OCR3                                GPT_OCR3_REG(GPT2_BASE_PTR)
#define GPT2_ICR1                                GPT_ICR1_REG(GPT2_BASE_PTR)
#define GPT2_ICR2                                GPT_ICR2_REG(GPT2_BASE_PTR)
#define GPT2_CNT                                 GPT_CNT_REG(GPT2_BASE_PTR)
/* GPT3 */
#define GPT3_CR                                  GPT_CR_REG(GPT3_BASE_PTR)
#define GPT3_PR                                  GPT_PR_REG(GPT3_BASE_PTR)
#define GPT3_SR                                  GPT_SR_REG(GPT3_BASE_PTR)
#define GPT3_IR                                  GPT_IR_REG(GPT3_BASE_PTR)
#define GPT3_OCR1                                GPT_OCR1_REG(GPT3_BASE_PTR)
#define GPT3_OCR2                                GPT_OCR2_REG(GPT3_BASE_PTR)
#define GPT3_OCR3                                GPT_OCR3_REG(GPT3_BASE_PTR)
#define GPT3_ICR1                                GPT_ICR1_REG(GPT3_BASE_PTR)
#define GPT3_ICR2                                GPT_ICR2_REG(GPT3_BASE_PTR)
#define GPT3_CNT                                 GPT_CNT_REG(GPT3_BASE_PTR)
/* GPT4 */
#define GPT4_CR                                  GPT_CR_REG(GPT4_BASE_PTR)
#define GPT4_PR                                  GPT_PR_REG(GPT4_BASE_PTR)
#define GPT4_SR                                  GPT_SR_REG(GPT4_BASE_PTR)
#define GPT4_IR                                  GPT_IR_REG(GPT4_BASE_PTR)
#define GPT4_OCR1                                GPT_OCR1_REG(GPT4_BASE_PTR)
#define GPT4_OCR2                                GPT_OCR2_REG(GPT4_BASE_PTR)
#define GPT4_OCR3                                GPT_OCR3_REG(GPT4_BASE_PTR)
#define GPT4_ICR1                                GPT_ICR1_REG(GPT4_BASE_PTR)
#define GPT4_ICR2                                GPT_ICR2_REG(GPT4_BASE_PTR)
#define GPT4_CNT                                 GPT_CNT_REG(GPT4_BASE_PTR)

/*!
 * @}
 */ /* end of group GPT_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group GPT_Peripheral */


/* ----------------------------------------------------------------------------
   -- I2C
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2C_Peripheral I2C
 * @{
 */

/** I2C - Peripheral register structure */
typedef struct I2C_MemMap {
  uint16_t IADR;                                   /**< I2C Address Register, offset: 0x0 */
  uint8_t RESERVED_0[2];
  uint16_t IFDR;                                   /**< I2C Frequency Divider Register, offset: 0x4 */
  uint8_t RESERVED_1[2];
  uint16_t I2CR;                                   /**< I2C Control Register, offset: 0x8 */
  uint8_t RESERVED_2[2];
  uint16_t I2SR;                                   /**< I2C Status Register, offset: 0xC */
  uint8_t RESERVED_3[2];
  uint16_t I2DR;                                   /**< I2C Data I/O Register, offset: 0x10 */
} volatile *I2C_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- I2C - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2C_Register_Accessor_Macros I2C - Register accessor macros
 * @{
 */


/* I2C - Register accessors */
#define I2C_IADR_REG(base)                       ((base)->IADR)
#define I2C_IFDR_REG(base)                       ((base)->IFDR)
#define I2C_I2CR_REG(base)                       ((base)->I2CR)
#define I2C_I2SR_REG(base)                       ((base)->I2SR)
#define I2C_I2DR_REG(base)                       ((base)->I2DR)

/*!
 * @}
 */ /* end of group I2C_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- I2C Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2C_Register_Masks I2C Register Masks
 * @{
 */

/*! @name IADR - I2C Address Register */
#define I2C_IADR_ADR_MASK                        (0xFEU)
#define I2C_IADR_ADR_SHIFT                       (1U)
#define I2C_IADR_ADR(x)                          (((uint16_t)(((uint16_t)(x)) << I2C_IADR_ADR_SHIFT)) & I2C_IADR_ADR_MASK)

/*! @name IFDR - I2C Frequency Divider Register */
#define I2C_IFDR_IC_MASK                         (0x3FU)
#define I2C_IFDR_IC_SHIFT                        (0U)
#define I2C_IFDR_IC(x)                           (((uint16_t)(((uint16_t)(x)) << I2C_IFDR_IC_SHIFT)) & I2C_IFDR_IC_MASK)

/*! @name I2CR - I2C Control Register */
#define I2C_I2CR_RSTA_MASK                       (0x4U)
#define I2C_I2CR_RSTA_SHIFT                      (2U)
#define I2C_I2CR_TXAK_MASK                       (0x8U)
#define I2C_I2CR_TXAK_SHIFT                      (3U)
#define I2C_I2CR_MTX_MASK                        (0x10U)
#define I2C_I2CR_MTX_SHIFT                       (4U)
#define I2C_I2CR_MSTA_MASK                       (0x20U)
#define I2C_I2CR_MSTA_SHIFT                      (5U)
#define I2C_I2CR_IIEN_MASK                       (0x40U)
#define I2C_I2CR_IIEN_SHIFT                      (6U)
#define I2C_I2CR_IEN_MASK                        (0x80U)
#define I2C_I2CR_IEN_SHIFT                       (7U)

/*! @name I2SR - I2C Status Register */
#define I2C_I2SR_RXAK_MASK                       (0x1U)
#define I2C_I2SR_RXAK_SHIFT                      (0U)
#define I2C_I2SR_IIF_MASK                        (0x2U)
#define I2C_I2SR_IIF_SHIFT                       (1U)
#define I2C_I2SR_SRW_MASK                        (0x4U)
#define I2C_I2SR_SRW_SHIFT                       (2U)
#define I2C_I2SR_IAL_MASK                        (0x10U)
#define I2C_I2SR_IAL_SHIFT                       (4U)
#define I2C_I2SR_IBB_MASK                        (0x20U)
#define I2C_I2SR_IBB_SHIFT                       (5U)
#define I2C_I2SR_IAAS_MASK                       (0x40U)
#define I2C_I2SR_IAAS_SHIFT                      (6U)
#define I2C_I2SR_ICF_MASK                        (0x80U)
#define I2C_I2SR_ICF_SHIFT                       (7U)

/*! @name I2DR - I2C Data I/O Register */
#define I2C_I2DR_DATA_MASK                       (0xFFU)
#define I2C_I2DR_DATA_SHIFT                      (0U)
#define I2C_I2DR_DATA(x)                         (((uint16_t)(((uint16_t)(x)) << I2C_I2DR_DATA_SHIFT)) & I2C_I2DR_DATA_MASK)


/*!
 * @}
 */ /* end of group I2C_Register_Masks */


/* I2C - Peripheral instance base addresses */
/** Peripheral I2C1 base pointer */
#define I2C1_BASE_PTR                            ((I2C_MemMapPtr)0x30A20000u)
/** Peripheral I2C2 base pointer */
#define I2C2_BASE_PTR                            ((I2C_MemMapPtr)0x30A30000u)
/** Peripheral I2C3 base pointer */
#define I2C3_BASE_PTR                            ((I2C_MemMapPtr)0x30A40000u)
/** Peripheral I2C4 base pointer */
#define I2C4_BASE_PTR                            ((I2C_MemMapPtr)0x30A50000u)
/** Array initializer of I2C peripheral base pointers */
#define I2C_BASE_PTRS                            { I2C1_BASE_PTR, I2C2_BASE_PTR, I2C3_BASE_PTR, I2C4_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- I2C - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2C_Register_Accessor_Macros I2C - Register accessor macros
 * @{
 */


/* I2C - Register instance definitions */
/* I2C1 */
#define I2C1_IADR                                I2C_IADR_REG(I2C1_BASE_PTR)
#define I2C1_IFDR                                I2C_IFDR_REG(I2C1_BASE_PTR)
#define I2C1_I2CR                                I2C_I2CR_REG(I2C1_BASE_PTR)
#define I2C1_I2SR                                I2C_I2SR_REG(I2C1_BASE_PTR)
#define I2C1_I2DR                                I2C_I2DR_REG(I2C1_BASE_PTR)
/* I2C2 */
#define I2C2_IADR                                I2C_IADR_REG(I2C2_BASE_PTR)
#define I2C2_IFDR                                I2C_IFDR_REG(I2C2_BASE_PTR)
#define I2C2_I2CR                                I2C_I2CR_REG(I2C2_BASE_PTR)
#define I2C2_I2SR                                I2C_I2SR_REG(I2C2_BASE_PTR)
#define I2C2_I2DR                                I2C_I2DR_REG(I2C2_BASE_PTR)
/* I2C3 */
#define I2C3_IADR                                I2C_IADR_REG(I2C3_BASE_PTR)
#define I2C3_IFDR                                I2C_IFDR_REG(I2C3_BASE_PTR)
#define I2C3_I2CR                                I2C_I2CR_REG(I2C3_BASE_PTR)
#define I2C3_I2SR                                I2C_I2SR_REG(I2C3_BASE_PTR)
#define I2C3_I2DR                                I2C_I2DR_REG(I2C3_BASE_PTR)
/* I2C4 */
#define I2C4_IADR                                I2C_IADR_REG(I2C4_BASE_PTR)
#define I2C4_IFDR                                I2C_IFDR_REG(I2C4_BASE_PTR)
#define I2C4_I2CR                                I2C_I2CR_REG(I2C4_BASE_PTR)
#define I2C4_I2SR                                I2C_I2SR_REG(I2C4_BASE_PTR)
#define I2C4_I2DR                                I2C_I2DR_REG(I2C4_BASE_PTR)

/*!
 * @}
 */ /* end of group I2C_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group I2C_Peripheral */


/* ----------------------------------------------------------------------------
   -- I2S
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2S_Peripheral I2S
 * @{
 */

/** I2S - Peripheral register structure */
typedef struct I2S_MemMap {
  uint32_t TCSR;                                   /**< SAI Transmit Control Register, offset: 0x0 */
  uint32_t TCR1;                                   /**< SAI Transmit Configuration 1 Register, offset: 0x4 */
  uint32_t TCR2;                                   /**< SAI Transmit Configuration 2 Register, offset: 0x8 */
  uint32_t TCR3;                                   /**< SAI Transmit Configuration 3 Register, offset: 0xC */
  uint32_t TCR4;                                   /**< SAI Transmit Configuration 4 Register, offset: 0x10 */
  uint32_t TCR5;                                   /**< SAI Transmit Configuration 5 Register, offset: 0x14 */
  uint8_t RESERVED_0[8];
  uint32_t TDR[1];                                 /**< SAI Transmit Data Register, array offset: 0x20, array step: 0x4 */
  uint8_t RESERVED_1[28];
  uint32_t TFR[1];                                 /**< SAI Transmit FIFO Register, array offset: 0x40, array step: 0x4 */
  uint8_t RESERVED_2[28];
  uint32_t TMR;                                    /**< SAI Transmit Mask Register, offset: 0x60 */
  uint8_t RESERVED_3[28];
  uint32_t RCSR;                                   /**< SAI Receive Control Register, offset: 0x80 */
  uint32_t RCR1;                                   /**< SAI Receive Configuration 1 Register, offset: 0x84 */
  uint32_t RCR2;                                   /**< SAI Receive Configuration 2 Register, offset: 0x88 */
  uint32_t RCR3;                                   /**< SAI Receive Configuration 3 Register, offset: 0x8C */
  uint32_t RCR4;                                   /**< SAI Receive Configuration 4 Register, offset: 0x90 */
  uint32_t RCR5;                                   /**< SAI Receive Configuration 5 Register, offset: 0x94 */
  uint8_t RESERVED_4[8];
  uint32_t RDR[1];                                 /**< SAI Receive Data Register, array offset: 0xA0, array step: 0x4 */
  uint8_t RESERVED_5[28];
  uint32_t RFR[1];                                 /**< SAI Receive FIFO Register, array offset: 0xC0, array step: 0x4 */
  uint8_t RESERVED_6[28];
  uint32_t RMR;                                    /**< SAI Receive Mask Register, offset: 0xE0 */
} volatile *I2S_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- I2S - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2S_Register_Accessor_Macros I2S - Register accessor macros
 * @{
 */


/* I2S - Register accessors */
#define I2S_TCSR_REG(base)                       ((base)->TCSR)
#define I2S_TCR1_REG(base)                       ((base)->TCR1)
#define I2S_TCR2_REG(base)                       ((base)->TCR2)
#define I2S_TCR3_REG(base)                       ((base)->TCR3)
#define I2S_TCR4_REG(base)                       ((base)->TCR4)
#define I2S_TCR5_REG(base)                       ((base)->TCR5)
#define I2S_TDR_REG(base,index)                  ((base)->TDR[index])
#define I2S_TFR_REG(base,index)                  ((base)->TFR[index])
#define I2S_TMR_REG(base)                        ((base)->TMR)
#define I2S_RCSR_REG(base)                       ((base)->RCSR)
#define I2S_RCR1_REG(base)                       ((base)->RCR1)
#define I2S_RCR2_REG(base)                       ((base)->RCR2)
#define I2S_RCR3_REG(base)                       ((base)->RCR3)
#define I2S_RCR4_REG(base)                       ((base)->RCR4)
#define I2S_RCR5_REG(base)                       ((base)->RCR5)
#define I2S_RDR_REG(base,index)                  ((base)->RDR[index])
#define I2S_RFR_REG(base,index)                  ((base)->RFR[index])
#define I2S_RMR_REG(base)                        ((base)->RMR)

/*!
 * @}
 */ /* end of group I2S_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- I2S Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2S_Register_Masks I2S Register Masks
 * @{
 */

/*! @name TCSR - SAI Transmit Control Register */
#define I2S_TCSR_FRDE_MASK                       (0x1U)
#define I2S_TCSR_FRDE_SHIFT                      (0U)
#define I2S_TCSR_FWDE_MASK                       (0x2U)
#define I2S_TCSR_FWDE_SHIFT                      (1U)
#define I2S_TCSR_FRIE_MASK                       (0x100U)
#define I2S_TCSR_FRIE_SHIFT                      (8U)
#define I2S_TCSR_FWIE_MASK                       (0x200U)
#define I2S_TCSR_FWIE_SHIFT                      (9U)
#define I2S_TCSR_FEIE_MASK                       (0x400U)
#define I2S_TCSR_FEIE_SHIFT                      (10U)
#define I2S_TCSR_SEIE_MASK                       (0x800U)
#define I2S_TCSR_SEIE_SHIFT                      (11U)
#define I2S_TCSR_WSIE_MASK                       (0x1000U)
#define I2S_TCSR_WSIE_SHIFT                      (12U)
#define I2S_TCSR_FRF_MASK                        (0x10000U)
#define I2S_TCSR_FRF_SHIFT                       (16U)
#define I2S_TCSR_FWF_MASK                        (0x20000U)
#define I2S_TCSR_FWF_SHIFT                       (17U)
#define I2S_TCSR_FEF_MASK                        (0x40000U)
#define I2S_TCSR_FEF_SHIFT                       (18U)
#define I2S_TCSR_SEF_MASK                        (0x80000U)
#define I2S_TCSR_SEF_SHIFT                       (19U)
#define I2S_TCSR_WSF_MASK                        (0x100000U)
#define I2S_TCSR_WSF_SHIFT                       (20U)
#define I2S_TCSR_SR_MASK                         (0x1000000U)
#define I2S_TCSR_SR_SHIFT                        (24U)
#define I2S_TCSR_FR_MASK                         (0x2000000U)
#define I2S_TCSR_FR_SHIFT                        (25U)
#define I2S_TCSR_BCE_MASK                        (0x10000000U)
#define I2S_TCSR_BCE_SHIFT                       (28U)
#define I2S_TCSR_DBGE_MASK                       (0x20000000U)
#define I2S_TCSR_DBGE_SHIFT                      (29U)
#define I2S_TCSR_STOPE_MASK                      (0x40000000U)
#define I2S_TCSR_STOPE_SHIFT                     (30U)
#define I2S_TCSR_TE_MASK                         (0x80000000U)
#define I2S_TCSR_TE_SHIFT                        (31U)

/*! @name TCR1 - SAI Transmit Configuration 1 Register */
#define I2S_TCR1_TFW_MASK                        (0x1FU)
#define I2S_TCR1_TFW_SHIFT                       (0U)
#define I2S_TCR1_TFW(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_TCR1_TFW_SHIFT)) & I2S_TCR1_TFW_MASK)

/*! @name TCR2 - SAI Transmit Configuration 2 Register */
#define I2S_TCR2_DIV_MASK                        (0xFFU)
#define I2S_TCR2_DIV_SHIFT                       (0U)
#define I2S_TCR2_DIV(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_TCR2_DIV_SHIFT)) & I2S_TCR2_DIV_MASK)
#define I2S_TCR2_BCD_MASK                        (0x1000000U)
#define I2S_TCR2_BCD_SHIFT                       (24U)
#define I2S_TCR2_BCP_MASK                        (0x2000000U)
#define I2S_TCR2_BCP_SHIFT                       (25U)
#define I2S_TCR2_MSEL_MASK                       (0xC000000U)
#define I2S_TCR2_MSEL_SHIFT                      (26U)
#define I2S_TCR2_MSEL(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_TCR2_MSEL_SHIFT)) & I2S_TCR2_MSEL_MASK)
#define I2S_TCR2_BCI_MASK                        (0x10000000U)
#define I2S_TCR2_BCI_SHIFT                       (28U)
#define I2S_TCR2_BCS_MASK                        (0x20000000U)
#define I2S_TCR2_BCS_SHIFT                       (29U)
#define I2S_TCR2_SYNC_MASK                       (0xC0000000U)
#define I2S_TCR2_SYNC_SHIFT                      (30U)
#define I2S_TCR2_SYNC(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_TCR2_SYNC_SHIFT)) & I2S_TCR2_SYNC_MASK)

/*! @name TCR3 - SAI Transmit Configuration 3 Register */
#define I2S_TCR3_WDFL_MASK                       (0x1FU)
#define I2S_TCR3_WDFL_SHIFT                      (0U)
#define I2S_TCR3_WDFL(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_TCR3_WDFL_SHIFT)) & I2S_TCR3_WDFL_MASK)
#define I2S_TCR3_TCE_MASK                        (0x10000U)
#define I2S_TCR3_TCE_SHIFT                       (16U)

/*! @name TCR4 - SAI Transmit Configuration 4 Register */
#define I2S_TCR4_FSD_MASK                        (0x1U)
#define I2S_TCR4_FSD_SHIFT                       (0U)
#define I2S_TCR4_FSP_MASK                        (0x2U)
#define I2S_TCR4_FSP_SHIFT                       (1U)
#define I2S_TCR4_FSE_MASK                        (0x8U)
#define I2S_TCR4_FSE_SHIFT                       (3U)
#define I2S_TCR4_MF_MASK                         (0x10U)
#define I2S_TCR4_MF_SHIFT                        (4U)
#define I2S_TCR4_SYWD_MASK                       (0x1F00U)
#define I2S_TCR4_SYWD_SHIFT                      (8U)
#define I2S_TCR4_SYWD(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_TCR4_SYWD_SHIFT)) & I2S_TCR4_SYWD_MASK)
#define I2S_TCR4_FRSZ_MASK                       (0x1F0000U)
#define I2S_TCR4_FRSZ_SHIFT                      (16U)
#define I2S_TCR4_FRSZ(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_TCR4_FRSZ_SHIFT)) & I2S_TCR4_FRSZ_MASK)

/*! @name TCR5 - SAI Transmit Configuration 5 Register */
#define I2S_TCR5_FBT_MASK                        (0x1F00U)
#define I2S_TCR5_FBT_SHIFT                       (8U)
#define I2S_TCR5_FBT(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_TCR5_FBT_SHIFT)) & I2S_TCR5_FBT_MASK)
#define I2S_TCR5_W0W_MASK                        (0x1F0000U)
#define I2S_TCR5_W0W_SHIFT                       (16U)
#define I2S_TCR5_W0W(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_TCR5_W0W_SHIFT)) & I2S_TCR5_W0W_MASK)
#define I2S_TCR5_WNW_MASK                        (0x1F000000U)
#define I2S_TCR5_WNW_SHIFT                       (24U)
#define I2S_TCR5_WNW(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_TCR5_WNW_SHIFT)) & I2S_TCR5_WNW_MASK)

/*! @name TDR - SAI Transmit Data Register */
#define I2S_TDR_TDR_MASK                         (0xFFFFFFFFU)
#define I2S_TDR_TDR_SHIFT                        (0U)
#define I2S_TDR_TDR(x)                           (((uint32_t)(((uint32_t)(x)) << I2S_TDR_TDR_SHIFT)) & I2S_TDR_TDR_MASK)

/* The count of I2S_TDR */
#define I2S_TDR_COUNT                            (1U)

/*! @name TFR - SAI Transmit FIFO Register */
#define I2S_TFR_RFP_MASK                         (0x3FU)
#define I2S_TFR_RFP_SHIFT                        (0U)
#define I2S_TFR_RFP(x)                           (((uint32_t)(((uint32_t)(x)) << I2S_TFR_RFP_SHIFT)) & I2S_TFR_RFP_MASK)
#define I2S_TFR_WFP_MASK                         (0x3F0000U)
#define I2S_TFR_WFP_SHIFT                        (16U)
#define I2S_TFR_WFP(x)                           (((uint32_t)(((uint32_t)(x)) << I2S_TFR_WFP_SHIFT)) & I2S_TFR_WFP_MASK)

/* The count of I2S_TFR */
#define I2S_TFR_COUNT                            (1U)

/*! @name TMR - SAI Transmit Mask Register */
#define I2S_TMR_TWM_MASK                         (0xFFFFFFFFU)
#define I2S_TMR_TWM_SHIFT                        (0U)
#define I2S_TMR_TWM(x)                           (((uint32_t)(((uint32_t)(x)) << I2S_TMR_TWM_SHIFT)) & I2S_TMR_TWM_MASK)

/*! @name RCSR - SAI Receive Control Register */
#define I2S_RCSR_FRDE_MASK                       (0x1U)
#define I2S_RCSR_FRDE_SHIFT                      (0U)
#define I2S_RCSR_FWDE_MASK                       (0x2U)
#define I2S_RCSR_FWDE_SHIFT                      (1U)
#define I2S_RCSR_FRIE_MASK                       (0x100U)
#define I2S_RCSR_FRIE_SHIFT                      (8U)
#define I2S_RCSR_FWIE_MASK                       (0x200U)
#define I2S_RCSR_FWIE_SHIFT                      (9U)
#define I2S_RCSR_FEIE_MASK                       (0x400U)
#define I2S_RCSR_FEIE_SHIFT                      (10U)
#define I2S_RCSR_SEIE_MASK                       (0x800U)
#define I2S_RCSR_SEIE_SHIFT                      (11U)
#define I2S_RCSR_WSIE_MASK                       (0x1000U)
#define I2S_RCSR_WSIE_SHIFT                      (12U)
#define I2S_RCSR_FRF_MASK                        (0x10000U)
#define I2S_RCSR_FRF_SHIFT                       (16U)
#define I2S_RCSR_FWF_MASK                        (0x20000U)
#define I2S_RCSR_FWF_SHIFT                       (17U)
#define I2S_RCSR_FEF_MASK                        (0x40000U)
#define I2S_RCSR_FEF_SHIFT                       (18U)
#define I2S_RCSR_SEF_MASK                        (0x80000U)
#define I2S_RCSR_SEF_SHIFT                       (19U)
#define I2S_RCSR_WSF_MASK                        (0x100000U)
#define I2S_RCSR_WSF_SHIFT                       (20U)
#define I2S_RCSR_SR_MASK                         (0x1000000U)
#define I2S_RCSR_SR_SHIFT                        (24U)
#define I2S_RCSR_FR_MASK                         (0x2000000U)
#define I2S_RCSR_FR_SHIFT                        (25U)
#define I2S_RCSR_BCE_MASK                        (0x10000000U)
#define I2S_RCSR_BCE_SHIFT                       (28U)
#define I2S_RCSR_DBGE_MASK                       (0x20000000U)
#define I2S_RCSR_DBGE_SHIFT                      (29U)
#define I2S_RCSR_STOPE_MASK                      (0x40000000U)
#define I2S_RCSR_STOPE_SHIFT                     (30U)
#define I2S_RCSR_RE_MASK                         (0x80000000U)
#define I2S_RCSR_RE_SHIFT                        (31U)

/*! @name RCR1 - SAI Receive Configuration 1 Register */
#define I2S_RCR1_RFW_MASK                        (0x1FU)
#define I2S_RCR1_RFW_SHIFT                       (0U)
#define I2S_RCR1_RFW(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_RCR1_RFW_SHIFT)) & I2S_RCR1_RFW_MASK)

/*! @name RCR2 - SAI Receive Configuration 2 Register */
#define I2S_RCR2_DIV_MASK                        (0xFFU)
#define I2S_RCR2_DIV_SHIFT                       (0U)
#define I2S_RCR2_DIV(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_RCR2_DIV_SHIFT)) & I2S_RCR2_DIV_MASK)
#define I2S_RCR2_BCD_MASK                        (0x1000000U)
#define I2S_RCR2_BCD_SHIFT                       (24U)
#define I2S_RCR2_BCP_MASK                        (0x2000000U)
#define I2S_RCR2_BCP_SHIFT                       (25U)
#define I2S_RCR2_MSEL_MASK                       (0xC000000U)
#define I2S_RCR2_MSEL_SHIFT                      (26U)
#define I2S_RCR2_MSEL(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_RCR2_MSEL_SHIFT)) & I2S_RCR2_MSEL_MASK)
#define I2S_RCR2_BCI_MASK                        (0x10000000U)
#define I2S_RCR2_BCI_SHIFT                       (28U)
#define I2S_RCR2_BCS_MASK                        (0x20000000U)
#define I2S_RCR2_BCS_SHIFT                       (29U)
#define I2S_RCR2_SYNC_MASK                       (0xC0000000U)
#define I2S_RCR2_SYNC_SHIFT                      (30U)
#define I2S_RCR2_SYNC(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_RCR2_SYNC_SHIFT)) & I2S_RCR2_SYNC_MASK)

/*! @name RCR3 - SAI Receive Configuration 3 Register */
#define I2S_RCR3_WDFL_MASK                       (0x1FU)
#define I2S_RCR3_WDFL_SHIFT                      (0U)
#define I2S_RCR3_WDFL(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_RCR3_WDFL_SHIFT)) & I2S_RCR3_WDFL_MASK)
#define I2S_RCR3_RCE_MASK                        (0x10000U)
#define I2S_RCR3_RCE_SHIFT                       (16U)

/*! @name RCR4 - SAI Receive Configuration 4 Register */
#define I2S_RCR4_FSD_MASK                        (0x1U)
#define I2S_RCR4_FSD_SHIFT                       (0U)
#define I2S_RCR4_FSP_MASK                        (0x2U)
#define I2S_RCR4_FSP_SHIFT                       (1U)
#define I2S_RCR4_FSE_MASK                        (0x8U)
#define I2S_RCR4_FSE_SHIFT                       (3U)
#define I2S_RCR4_MF_MASK                         (0x10U)
#define I2S_RCR4_MF_SHIFT                        (4U)
#define I2S_RCR4_SYWD_MASK                       (0x1F00U)
#define I2S_RCR4_SYWD_SHIFT                      (8U)
#define I2S_RCR4_SYWD(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_RCR4_SYWD_SHIFT)) & I2S_RCR4_SYWD_MASK)
#define I2S_RCR4_FRSZ_MASK                       (0x1F0000U)
#define I2S_RCR4_FRSZ_SHIFT                      (16U)
#define I2S_RCR4_FRSZ(x)                         (((uint32_t)(((uint32_t)(x)) << I2S_RCR4_FRSZ_SHIFT)) & I2S_RCR4_FRSZ_MASK)

/*! @name RCR5 - SAI Receive Configuration 5 Register */
#define I2S_RCR5_FBT_MASK                        (0x1F00U)
#define I2S_RCR5_FBT_SHIFT                       (8U)
#define I2S_RCR5_FBT(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_RCR5_FBT_SHIFT)) & I2S_RCR5_FBT_MASK)
#define I2S_RCR5_W0W_MASK                        (0x1F0000U)
#define I2S_RCR5_W0W_SHIFT                       (16U)
#define I2S_RCR5_W0W(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_RCR5_W0W_SHIFT)) & I2S_RCR5_W0W_MASK)
#define I2S_RCR5_WNW_MASK                        (0x1F000000U)
#define I2S_RCR5_WNW_SHIFT                       (24U)
#define I2S_RCR5_WNW(x)                          (((uint32_t)(((uint32_t)(x)) << I2S_RCR5_WNW_SHIFT)) & I2S_RCR5_WNW_MASK)

/*! @name RDR - SAI Receive Data Register */
#define I2S_RDR_RDR_MASK                         (0xFFFFFFFFU)
#define I2S_RDR_RDR_SHIFT                        (0U)
#define I2S_RDR_RDR(x)                           (((uint32_t)(((uint32_t)(x)) << I2S_RDR_RDR_SHIFT)) & I2S_RDR_RDR_MASK)

/* The count of I2S_RDR */
#define I2S_RDR_COUNT                            (1U)

/*! @name RFR - SAI Receive FIFO Register */
#define I2S_RFR_RFP_MASK                         (0x3FU)
#define I2S_RFR_RFP_SHIFT                        (0U)
#define I2S_RFR_RFP(x)                           (((uint32_t)(((uint32_t)(x)) << I2S_RFR_RFP_SHIFT)) & I2S_RFR_RFP_MASK)
#define I2S_RFR_WFP_MASK                         (0x3F0000U)
#define I2S_RFR_WFP_SHIFT                        (16U)
#define I2S_RFR_WFP(x)                           (((uint32_t)(((uint32_t)(x)) << I2S_RFR_WFP_SHIFT)) & I2S_RFR_WFP_MASK)

/* The count of I2S_RFR */
#define I2S_RFR_COUNT                            (1U)

/*! @name RMR - SAI Receive Mask Register */
#define I2S_RMR_RWM_MASK                         (0xFFFFFFFFU)
#define I2S_RMR_RWM_SHIFT                        (0U)
#define I2S_RMR_RWM(x)                           (((uint32_t)(((uint32_t)(x)) << I2S_RMR_RWM_SHIFT)) & I2S_RMR_RWM_MASK)


/*!
 * @}
 */ /* end of group I2S_Register_Masks */


/* I2S - Peripheral instance base addresses */
/** Peripheral I2S1 base pointer */
#define I2S1_BASE_PTR                            ((I2S_MemMapPtr)0x308A0000u)
/** Peripheral I2S2 base pointer */
#define I2S2_BASE_PTR                            ((I2S_MemMapPtr)0x308B0000u)
/** Peripheral I2S3 base pointer */
#define I2S3_BASE_PTR                            ((I2S_MemMapPtr)0x308C0000u)
/** Array initializer of I2S peripheral base pointers */
#define I2S_BASE_PTRS                            { I2S1_BASE_PTR, I2S2_BASE_PTR, I2S3_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- I2S - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2S_Register_Accessor_Macros I2S - Register accessor macros
 * @{
 */


/* I2S - Register instance definitions */
/* I2S1 */
#define I2S1_TCSR                                I2S_TCSR_REG(I2S1_BASE_PTR)
#define I2S1_TCR1                                I2S_TCR1_REG(I2S1_BASE_PTR)
#define I2S1_TCR2                                I2S_TCR2_REG(I2S1_BASE_PTR)
#define I2S1_TCR3                                I2S_TCR3_REG(I2S1_BASE_PTR)
#define I2S1_TCR4                                I2S_TCR4_REG(I2S1_BASE_PTR)
#define I2S1_TCR5                                I2S_TCR5_REG(I2S1_BASE_PTR)
#define I2S1_TDR0                                I2S_TDR_REG(I2S1_BASE_PTR,0)
#define I2S1_TFR0                                I2S_TFR_REG(I2S1_BASE_PTR,0)
#define I2S1_TMR                                 I2S_TMR_REG(I2S1_BASE_PTR)
#define I2S1_RCSR                                I2S_RCSR_REG(I2S1_BASE_PTR)
#define I2S1_RCR1                                I2S_RCR1_REG(I2S1_BASE_PTR)
#define I2S1_RCR2                                I2S_RCR2_REG(I2S1_BASE_PTR)
#define I2S1_RCR3                                I2S_RCR3_REG(I2S1_BASE_PTR)
#define I2S1_RCR4                                I2S_RCR4_REG(I2S1_BASE_PTR)
#define I2S1_RCR5                                I2S_RCR5_REG(I2S1_BASE_PTR)
#define I2S1_RDR0                                I2S_RDR_REG(I2S1_BASE_PTR,0)
#define I2S1_RFR0                                I2S_RFR_REG(I2S1_BASE_PTR,0)
#define I2S1_RMR                                 I2S_RMR_REG(I2S1_BASE_PTR)
/* I2S2 */
#define I2S2_TCSR                                I2S_TCSR_REG(I2S2_BASE_PTR)
#define I2S2_TCR1                                I2S_TCR1_REG(I2S2_BASE_PTR)
#define I2S2_TCR2                                I2S_TCR2_REG(I2S2_BASE_PTR)
#define I2S2_TCR3                                I2S_TCR3_REG(I2S2_BASE_PTR)
#define I2S2_TCR4                                I2S_TCR4_REG(I2S2_BASE_PTR)
#define I2S2_TCR5                                I2S_TCR5_REG(I2S2_BASE_PTR)
#define I2S2_TDR0                                I2S_TDR_REG(I2S2_BASE_PTR,0)
#define I2S2_TFR0                                I2S_TFR_REG(I2S2_BASE_PTR,0)
#define I2S2_TMR                                 I2S_TMR_REG(I2S2_BASE_PTR)
#define I2S2_RCSR                                I2S_RCSR_REG(I2S2_BASE_PTR)
#define I2S2_RCR1                                I2S_RCR1_REG(I2S2_BASE_PTR)
#define I2S2_RCR2                                I2S_RCR2_REG(I2S2_BASE_PTR)
#define I2S2_RCR3                                I2S_RCR3_REG(I2S2_BASE_PTR)
#define I2S2_RCR4                                I2S_RCR4_REG(I2S2_BASE_PTR)
#define I2S2_RCR5                                I2S_RCR5_REG(I2S2_BASE_PTR)
#define I2S2_RDR0                                I2S_RDR_REG(I2S2_BASE_PTR,0)
#define I2S2_RFR0                                I2S_RFR_REG(I2S2_BASE_PTR,0)
#define I2S2_RMR                                 I2S_RMR_REG(I2S2_BASE_PTR)
/* I2S3 */
#define I2S3_TCSR                                I2S_TCSR_REG(I2S3_BASE_PTR)
#define I2S3_TCR1                                I2S_TCR1_REG(I2S3_BASE_PTR)
#define I2S3_TCR2                                I2S_TCR2_REG(I2S3_BASE_PTR)
#define I2S3_TCR3                                I2S_TCR3_REG(I2S3_BASE_PTR)
#define I2S3_TCR4                                I2S_TCR4_REG(I2S3_BASE_PTR)
#define I2S3_TCR5                                I2S_TCR5_REG(I2S3_BASE_PTR)
#define I2S3_TDR0                                I2S_TDR_REG(I2S3_BASE_PTR,0)
#define I2S3_TFR0                                I2S_TFR_REG(I2S3_BASE_PTR,0)
#define I2S3_TMR                                 I2S_TMR_REG(I2S3_BASE_PTR)
#define I2S3_RCSR                                I2S_RCSR_REG(I2S3_BASE_PTR)
#define I2S3_RCR1                                I2S_RCR1_REG(I2S3_BASE_PTR)
#define I2S3_RCR2                                I2S_RCR2_REG(I2S3_BASE_PTR)
#define I2S3_RCR3                                I2S_RCR3_REG(I2S3_BASE_PTR)
#define I2S3_RCR4                                I2S_RCR4_REG(I2S3_BASE_PTR)
#define I2S3_RCR5                                I2S_RCR5_REG(I2S3_BASE_PTR)
#define I2S3_RDR0                                I2S_RDR_REG(I2S3_BASE_PTR,0)
#define I2S3_RFR0                                I2S_RFR_REG(I2S3_BASE_PTR,0)
#define I2S3_RMR                                 I2S_RMR_REG(I2S3_BASE_PTR)

/* I2S - Register array accessors */
#define I2S1_TDR(index)                          I2S_TDR_REG(I2S1_BASE_PTR,index)
#define I2S2_TDR(index)                          I2S_TDR_REG(I2S2_BASE_PTR,index)
#define I2S3_TDR(index)                          I2S_TDR_REG(I2S3_BASE_PTR,index)
#define I2S1_TFR(index)                          I2S_TFR_REG(I2S1_BASE_PTR,index)
#define I2S2_TFR(index)                          I2S_TFR_REG(I2S2_BASE_PTR,index)
#define I2S3_TFR(index)                          I2S_TFR_REG(I2S3_BASE_PTR,index)
#define I2S1_RDR(index)                          I2S_RDR_REG(I2S1_BASE_PTR,index)
#define I2S2_RDR(index)                          I2S_RDR_REG(I2S2_BASE_PTR,index)
#define I2S3_RDR(index)                          I2S_RDR_REG(I2S3_BASE_PTR,index)
#define I2S1_RFR(index)                          I2S_RFR_REG(I2S1_BASE_PTR,index)
#define I2S2_RFR(index)                          I2S_RFR_REG(I2S2_BASE_PTR,index)
#define I2S3_RFR(index)                          I2S_RFR_REG(I2S3_BASE_PTR,index)

/*!
 * @}
 */ /* end of group I2S_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group I2S_Peripheral */


/* ----------------------------------------------------------------------------
   -- IOMUXC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_Peripheral IOMUXC
 * @{
 */

/** IOMUXC - Peripheral register structure */
typedef struct IOMUXC_MemMap {
  uint8_t RESERVED_0[20];
  uint32_t SW_MUX_CTL_PAD[150];                    /**< SW_MUX_CTL_PAD_GPIO1_IO08 SW MUX Control Register..SW_MUX_CTL_PAD_ENET1_COL SW MUX Control Register, array offset: 0x14, array step: 0x4 */
  uint32_t SW_PAD_CTL_PAD[156];                    /**< SW_PAD_CTL_PAD_GPIO1_IO08 SW PAD Control Register..SW_PAD_CTL_PAD_ENET1_COL SW PAD Control Register, array offset: 0x26C, array step: 0x4 */
  uint32_t SELECT_INPUT[153];                      /**< FLEXCAN1_RX_SELECT_INPUT DAISY Register..SD3_WP_SELECT_INPUT DAISY Register, array offset: 0x4DC, array step: 0x4 */
} volatile *IOMUXC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- IOMUXC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_Register_Accessor_Macros IOMUXC - Register accessor macros
 * @{
 */


/* IOMUXC - Register accessors */
#define IOMUXC_SW_MUX_CTL_PAD_REG(base,index)    ((base)->SW_MUX_CTL_PAD[index])
#define IOMUXC_SW_PAD_CTL_PAD_REG(base,index)    ((base)->SW_PAD_CTL_PAD[index])
#define IOMUXC_SELECT_INPUT_REG(base,index)      ((base)->SELECT_INPUT[index])

/*!
 * @}
 */ /* end of group IOMUXC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- IOMUXC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_Register_Masks IOMUXC Register Masks
 * @{
 */

/*! @name SW_MUX_CTL_PAD - SW_MUX_CTL_PAD_GPIO1_IO08 SW MUX Control Register..SW_MUX_CTL_PAD_ENET1_COL SW MUX Control Register */
#define IOMUXC_SW_MUX_CTL_PAD_MUX_MODE_MASK      (0xFU)
#define IOMUXC_SW_MUX_CTL_PAD_MUX_MODE_SHIFT     (0U)
#define IOMUXC_SW_MUX_CTL_PAD_MUX_MODE(x)        (((uint32_t)(((uint32_t)(x)) << IOMUXC_SW_MUX_CTL_PAD_MUX_MODE_SHIFT)) & IOMUXC_SW_MUX_CTL_PAD_MUX_MODE_MASK)
#define IOMUXC_SW_MUX_CTL_PAD_SION_MASK          (0x10U)
#define IOMUXC_SW_MUX_CTL_PAD_SION_SHIFT         (4U)

/* The count of IOMUXC_SW_MUX_CTL_PAD */
#define IOMUXC_SW_MUX_CTL_PAD_COUNT              (150U)

/*! @name SW_PAD_CTL_PAD - SW_PAD_CTL_PAD_GPIO1_IO08 SW PAD Control Register..SW_PAD_CTL_PAD_ENET1_COL SW PAD Control Register */
#define IOMUXC_SW_PAD_CTL_PAD_DSE_MASK           (0x3U)
#define IOMUXC_SW_PAD_CTL_PAD_DSE_SHIFT          (0U)
#define IOMUXC_SW_PAD_CTL_PAD_DSE(x)             (((uint32_t)(((uint32_t)(x)) << IOMUXC_SW_PAD_CTL_PAD_DSE_SHIFT)) & IOMUXC_SW_PAD_CTL_PAD_DSE_MASK)
#define IOMUXC_SW_PAD_CTL_PAD_SRE_MASK           (0x4U)
#define IOMUXC_SW_PAD_CTL_PAD_SRE_SHIFT          (2U)
#define IOMUXC_SW_PAD_CTL_PAD_HYS_MASK           (0x8U)
#define IOMUXC_SW_PAD_CTL_PAD_HYS_SHIFT          (3U)
#define IOMUXC_SW_PAD_CTL_PAD_PE_MASK            (0x10U)
#define IOMUXC_SW_PAD_CTL_PAD_PE_SHIFT           (4U)
#define IOMUXC_SW_PAD_CTL_PAD_PS_MASK            (0x60U)
#define IOMUXC_SW_PAD_CTL_PAD_PS_SHIFT           (5U)
#define IOMUXC_SW_PAD_CTL_PAD_PS(x)              (((uint32_t)(((uint32_t)(x)) << IOMUXC_SW_PAD_CTL_PAD_PS_SHIFT)) & IOMUXC_SW_PAD_CTL_PAD_PS_MASK)

/* The count of IOMUXC_SW_PAD_CTL_PAD */
#define IOMUXC_SW_PAD_CTL_PAD_COUNT              (156U)

/*! @name SELECT_INPUT - FLEXCAN1_RX_SELECT_INPUT DAISY Register..SD3_WP_SELECT_INPUT DAISY Register */
#define IOMUXC_SELECT_INPUT_DAISY_MASK           (0x7U)
#define IOMUXC_SELECT_INPUT_DAISY_SHIFT          (0U)
#define IOMUXC_SELECT_INPUT_DAISY(x)             (((uint32_t)(((uint32_t)(x)) << IOMUXC_SELECT_INPUT_DAISY_SHIFT)) & IOMUXC_SELECT_INPUT_DAISY_MASK)

/* The count of IOMUXC_SELECT_INPUT */
#define IOMUXC_SELECT_INPUT_COUNT                (153U)


/*!
 * @}
 */ /* end of group IOMUXC_Register_Masks */


/* IOMUXC - Peripheral instance base addresses */
/** Peripheral IOMUXC base pointer */
#define IOMUXC_BASE_PTR                          ((IOMUXC_MemMapPtr)0x30330000u)
/** Array initializer of IOMUXC peripheral base pointers */
#define IOMUXC_BASE_PTRS                         { IOMUXC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- IOMUXC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_Register_Accessor_Macros IOMUXC - Register accessor macros
 * @{
 */


/* IOMUXC - Register instance definitions */
/* IOMUXC */
#define IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,0)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,1)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,2)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,3)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,4)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,5)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,6)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,7)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,8)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,9)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,10)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,11)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,12)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,13)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,14)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,15)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,16)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,17)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,18)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,19)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,20)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,21)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,22)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,23)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,24)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,25)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,26)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,27)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,28)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,29)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,30)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,31)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,32)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,33)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,34)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,35)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,36)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,37)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,38)
#define IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT      IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,39)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_CLK            IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,40)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,41)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,42)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,43)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_RESET          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,44)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,45)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,46)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,47)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,48)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,49)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,50)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,51)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,52)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,53)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,54)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,55)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,56)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,57)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,58)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,59)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,60)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,61)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,62)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,63)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,64)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,65)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,66)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,67)
#define IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,68)
#define IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA      IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,69)
#define IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA      IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,70)
#define IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA      IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,71)
#define IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA      IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,72)
#define IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA      IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,73)
#define IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA      IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,74)
#define IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,75)
#define IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,76)
#define IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,77)
#define IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,78)
#define IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,79)
#define IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,80)
#define IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,81)
#define IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,82)
#define IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,83)
#define IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,84)
#define IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,85)
#define IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,86)
#define IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,87)
#define IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,88)
#define IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,89)
#define IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,90)
#define IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,91)
#define IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,92)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,93)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_WP             IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,94)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,95)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_CLK            IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,96)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_CMD            IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,97)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,98)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,99)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,100)
#define IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,101)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B           IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,102)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_WP             IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,103)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,104)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_CLK            IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,105)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_CMD            IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,106)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,107)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,108)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,109)
#define IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,110)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_CLK            IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,111)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_CMD            IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,112)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,113)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,114)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,115)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,116)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,117)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,118)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,119)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,120)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE         IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,121)
#define IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B        IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,122)
#define IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,123)
#define IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,124)
#define IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,125)
#define IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,126)
#define IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,127)
#define IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,128)
#define IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,129)
#define IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,130)
#define IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,131)
#define IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,132)
#define IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,133)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,134)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,135)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,136)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,137)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,138)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,139)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,140)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,141)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,142)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,143)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,144)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC    IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,145)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,146)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK       IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,147)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,148)
#define IOMUXC_SW_MUX_CTL_PAD_ENET1_COL          IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,149)
#define IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,0)
#define IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,1)
#define IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,2)
#define IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,3)
#define IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,4)
#define IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,5)
#define IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,6)
#define IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,7)
#define IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,8)
#define IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,9)
#define IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,10)
#define IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,11)
#define IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,12)
#define IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,13)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,14)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,15)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,16)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,17)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,18)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,19)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,20)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,21)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,22)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,23)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,24)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,25)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,26)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,27)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,28)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,29)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,30)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,31)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,32)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,33)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,34)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,35)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,36)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,37)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,38)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,39)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,40)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,41)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,42)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,43)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,44)
#define IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT      IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,45)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_CLK            IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,46)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,47)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,48)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,49)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_RESET          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,50)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,51)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,52)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,53)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,54)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,55)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,56)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,57)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,58)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,59)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,60)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,61)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,62)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,63)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,64)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,65)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,66)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,67)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,68)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,69)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,70)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,71)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,72)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,73)
#define IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,74)
#define IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA      IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,75)
#define IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA      IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,76)
#define IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA      IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,77)
#define IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA      IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,78)
#define IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA      IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,79)
#define IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA      IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,80)
#define IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,81)
#define IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,82)
#define IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,83)
#define IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,84)
#define IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,85)
#define IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,86)
#define IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,87)
#define IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,88)
#define IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,89)
#define IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,90)
#define IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,91)
#define IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,92)
#define IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,93)
#define IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,94)
#define IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,95)
#define IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,96)
#define IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,97)
#define IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,98)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,99)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_WP             IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,100)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,101)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_CLK            IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,102)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_CMD            IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,103)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,104)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,105)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,106)
#define IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,107)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B           IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,108)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_WP             IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,109)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,110)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_CLK            IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,111)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_CMD            IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,112)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,113)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,114)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,115)
#define IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,116)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_CLK            IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,117)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_CMD            IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,118)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,119)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,120)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,121)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,122)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,123)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,124)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,125)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,126)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE         IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,127)
#define IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B        IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,128)
#define IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,129)
#define IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,130)
#define IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,131)
#define IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,132)
#define IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,133)
#define IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,134)
#define IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,135)
#define IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,136)
#define IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,137)
#define IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,138)
#define IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,139)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,140)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,141)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,142)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,143)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,144)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,145)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,146)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,147)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,148)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,149)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,150)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC    IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,151)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,152)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK       IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,153)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,154)
#define IOMUXC_SW_PAD_CTL_PAD_ENET1_COL          IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,155)
#define IOMUXC_FLEXCAN1_RX_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,0)
#define IOMUXC_FLEXCAN2_RX_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,1)
#define IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,2)
#define IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,3)
#define IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,4)
#define IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,5)
#define IOMUXC_CCM_PMIC_READY_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,6)
#define IOMUXC_CSI_DATA2_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,7)
#define IOMUXC_CSI_DATA3_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,8)
#define IOMUXC_CSI_DATA4_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,9)
#define IOMUXC_CSI_DATA5_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,10)
#define IOMUXC_CSI_DATA6_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,11)
#define IOMUXC_CSI_DATA7_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,12)
#define IOMUXC_CSI_DATA8_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,13)
#define IOMUXC_CSI_DATA9_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,14)
#define IOMUXC_CSI_HSYNC_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,15)
#define IOMUXC_CSI_PIXCLK_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,16)
#define IOMUXC_CSI_VSYNC_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,17)
#define IOMUXC_ECSPI1_SCLK_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,18)
#define IOMUXC_ECSPI1_MISO_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,19)
#define IOMUXC_ECSPI1_MOSI_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,20)
#define IOMUXC_ECSPI1_SS0_B_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,21)
#define IOMUXC_ECSPI2_SCLK_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,22)
#define IOMUXC_ECSPI2_MISO_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,23)
#define IOMUXC_ECSPI2_MOSI_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,24)
#define IOMUXC_ECSPI2_SS0_B_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,25)
#define IOMUXC_ECSPI3_SCLK_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,26)
#define IOMUXC_ECSPI3_MISO_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,27)
#define IOMUXC_ECSPI3_MOSI_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,28)
#define IOMUXC_ECSPI3_SS0_B_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,29)
#define IOMUXC_ECSPI4_SCLK_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,30)
#define IOMUXC_ECSPI4_MISO_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,31)
#define IOMUXC_ECSPI4_MOSI_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,32)
#define IOMUXC_ECSPI4_SS0_B_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,33)
#define IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT    IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,34)
#define IOMUXC_ENET1_MDIO_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,35)
#define IOMUXC_ENET1_RX_CLK_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,36)
#define IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT    IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,37)
#define IOMUXC_ENET2_MDIO_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,38)
#define IOMUXC_ENET2_RX_CLK_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,39)
#define IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,40)
#define IOMUXC_EPDC_PWR_STAT_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,41)
#define IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,42)
#define IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,43)
#define IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,44)
#define IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,45)
#define IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,46)
#define IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,47)
#define IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,48)
#define IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,49)
#define IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,50)
#define IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,51)
#define IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,52)
#define IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,53)
#define IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,54)
#define IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,55)
#define IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,56)
#define IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,57)
#define IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,58)
#define IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,59)
#define IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,60)
#define IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT       IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,61)
#define IOMUXC_I2C1_SCL_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,62)
#define IOMUXC_I2C1_SDA_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,63)
#define IOMUXC_I2C2_SCL_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,64)
#define IOMUXC_I2C2_SDA_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,65)
#define IOMUXC_I2C3_SCL_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,66)
#define IOMUXC_I2C3_SDA_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,67)
#define IOMUXC_I2C4_SCL_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,68)
#define IOMUXC_I2C4_SDA_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,69)
#define IOMUXC_KPP_COL0_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,70)
#define IOMUXC_KPP_COL1_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,71)
#define IOMUXC_KPP_COL2_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,72)
#define IOMUXC_KPP_COL3_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,73)
#define IOMUXC_KPP_COL4_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,74)
#define IOMUXC_KPP_COL5_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,75)
#define IOMUXC_KPP_COL6_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,76)
#define IOMUXC_KPP_COL7_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,77)
#define IOMUXC_KPP_ROW0_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,78)
#define IOMUXC_KPP_ROW1_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,79)
#define IOMUXC_KPP_ROW2_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,80)
#define IOMUXC_KPP_ROW3_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,81)
#define IOMUXC_KPP_ROW4_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,82)
#define IOMUXC_KPP_ROW5_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,83)
#define IOMUXC_KPP_ROW6_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,84)
#define IOMUXC_KPP_ROW7_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,85)
#define IOMUXC_LCD_BUSY_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,86)
#define IOMUXC_LCD_DATA00_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,87)
#define IOMUXC_LCD_DATA01_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,88)
#define IOMUXC_LCD_DATA02_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,89)
#define IOMUXC_LCD_DATA03_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,90)
#define IOMUXC_LCD_DATA04_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,91)
#define IOMUXC_LCD_DATA05_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,92)
#define IOMUXC_LCD_DATA06_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,93)
#define IOMUXC_LCD_DATA07_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,94)
#define IOMUXC_LCD_DATA08_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,95)
#define IOMUXC_LCD_DATA09_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,96)
#define IOMUXC_LCD_DATA10_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,97)
#define IOMUXC_LCD_DATA11_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,98)
#define IOMUXC_LCD_DATA12_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,99)
#define IOMUXC_LCD_DATA13_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,100)
#define IOMUXC_LCD_DATA14_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,101)
#define IOMUXC_LCD_DATA15_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,102)
#define IOMUXC_LCD_DATA16_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,103)
#define IOMUXC_LCD_DATA17_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,104)
#define IOMUXC_LCD_DATA18_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,105)
#define IOMUXC_LCD_DATA19_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,106)
#define IOMUXC_LCD_DATA20_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,107)
#define IOMUXC_LCD_DATA21_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,108)
#define IOMUXC_LCD_DATA22_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,109)
#define IOMUXC_LCD_DATA23_SELECT_INPUT           IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,110)
#define IOMUXC_LCD_VSYNC_SELECT_INPUT            IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,111)
#define IOMUXC_SAI1_RX_BCLK_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,112)
#define IOMUXC_SAI1_RX_DATA_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,113)
#define IOMUXC_SAI1_RX_SYNC_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,114)
#define IOMUXC_SAI1_TX_BCLK_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,115)
#define IOMUXC_SAI1_TX_SYNC_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,116)
#define IOMUXC_SAI2_RX_BCLK_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,117)
#define IOMUXC_SAI2_RX_DATA_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,118)
#define IOMUXC_SAI2_RX_SYNC_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,119)
#define IOMUXC_SAI2_TX_BCLK_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,120)
#define IOMUXC_SAI2_TX_SYNC_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,121)
#define IOMUXC_SAI3_RX_BCLK_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,122)
#define IOMUXC_SAI3_RX_DATA_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,123)
#define IOMUXC_SAI3_RX_SYNC_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,124)
#define IOMUXC_SAI3_TX_BCLK_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,125)
#define IOMUXC_SAI3_TX_SYNC_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,126)
#define IOMUXC_SDMA_EVENTS0_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,127)
#define IOMUXC_SDMA_EVENTS1_SELECT_INPUT         IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,128)
#define IOMUXC_SIM1_PORT1_PD_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,129)
#define IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT      IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,130)
#define IOMUXC_SIM2_PORT1_PD_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,131)
#define IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT      IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,132)
#define IOMUXC_UART1_RTS_B_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,133)
#define IOMUXC_UART1_RX_DATA_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,134)
#define IOMUXC_UART2_RTS_B_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,135)
#define IOMUXC_UART2_RX_DATA_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,136)
#define IOMUXC_UART3_RTS_B_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,137)
#define IOMUXC_UART3_RX_DATA_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,138)
#define IOMUXC_UART4_RTS_B_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,139)
#define IOMUXC_UART4_RX_DATA_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,140)
#define IOMUXC_UART5_RTS_B_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,141)
#define IOMUXC_UART5_RX_DATA_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,142)
#define IOMUXC_UART6_RTS_B_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,143)
#define IOMUXC_UART6_RX_DATA_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,144)
#define IOMUXC_UART7_RTS_B_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,145)
#define IOMUXC_UART7_RX_DATA_SELECT_INPUT        IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,146)
#define IOMUXC_USB_OTG2_OC_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,147)
#define IOMUXC_USB_OTG1_OC_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,148)
#define IOMUXC_USB_OTG2_ID_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,149)
#define IOMUXC_USB_OTG1_ID_SELECT_INPUT          IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,150)
#define IOMUXC_SD3_CD_B_SELECT_INPUT             IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,151)
#define IOMUXC_SD3_WP_SELECT_INPUT               IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,152)

/* IOMUXC - Register array accessors */
#define IOMUXC_SW_MUX_CTL_PAD(index)             IOMUXC_SW_MUX_CTL_PAD_REG(IOMUXC_BASE_PTR,index)
#define IOMUXC_SW_PAD_CTL_PAD(index)             IOMUXC_SW_PAD_CTL_PAD_REG(IOMUXC_BASE_PTR,index)
#define IOMUXC_SELECT_INPUT(index)               IOMUXC_SELECT_INPUT_REG(IOMUXC_BASE_PTR,index)

/*!
 * @}
 */ /* end of group IOMUXC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group IOMUXC_Peripheral */


/* ----------------------------------------------------------------------------
   -- IOMUXC_GPR
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_GPR_Peripheral IOMUXC_GPR
 * @{
 */

/** IOMUXC_GPR - Peripheral register structure */
typedef struct IOMUXC_GPR_MemMap {
  uint32_t GPR0;                                   /**< GPR0 General Purpose Register, offset: 0x0 */
  uint32_t GPR1;                                   /**< GPR1 General Purpose Register, offset: 0x4 */
  uint32_t GPR2;                                   /**< GPR2 General Purpose Register, offset: 0x8 */
  uint32_t GPR3;                                   /**< GPR3 General Purpose Register, offset: 0xC */
  uint32_t GPR4;                                   /**< GPR4 General Purpose Register, offset: 0x10 */
  uint32_t GPR5;                                   /**< GPR5 General Purpose Register, offset: 0x14 */
  uint32_t GPR6;                                   /**< GPR6 General Purpose Register, offset: 0x18 */
  uint32_t GPR7;                                   /**< GPR7 General Purpose Register, offset: 0x1C */
  uint32_t GPR8;                                   /**< GPR8 General Purpose Register, offset: 0x20 */
  uint32_t GPR9;                                   /**< GPR9 General Purpose Register, offset: 0x24 */
  uint32_t GPR10;                                  /**< GPR10 General Purpose Register, offset: 0x28 */
  uint32_t GPR11;                                  /**< GPR11 General Purpose Register, offset: 0x2C */
  uint32_t GPR12;                                  /**< GPR12 General Purpose Register, offset: 0x30 */
  uint32_t GPR13;                                  /**< GPR13 General Purpose Register, offset: 0x34 */
  uint32_t GPR14;                                  /**< GPR14 General Purpose Register, offset: 0x38 */
  uint32_t GPR15;                                  /**< GPR15 General Purpose Register, offset: 0x3C */
  uint32_t GPR16;                                  /**< GPR16 General Purpose Register, offset: 0x40 */
  uint32_t GPR17;                                  /**< GPR17 General Purpose Register, offset: 0x44 */
  uint32_t GPR18;                                  /**< GPR18 General Purpose Register, offset: 0x48 */
  uint32_t GPR19;                                  /**< GPR19 General Purpose Register, offset: 0x4C */
  uint32_t GPR20;                                  /**< GPR20 General Purpose Register, offset: 0x50 */
  uint32_t GPR21;                                  /**< GPR21 General Purpose Register, offset: 0x54 */
  uint32_t GPR22;                                  /**< GPR22 General Purpose Register, offset: 0x58 */
} volatile *IOMUXC_GPR_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- IOMUXC_GPR - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_GPR_Register_Accessor_Macros IOMUXC_GPR - Register accessor macros
 * @{
 */


/* IOMUXC_GPR - Register accessors */
#define IOMUXC_GPR_GPR0_REG(base)                ((base)->GPR0)
#define IOMUXC_GPR_GPR1_REG(base)                ((base)->GPR1)
#define IOMUXC_GPR_GPR2_REG(base)                ((base)->GPR2)
#define IOMUXC_GPR_GPR3_REG(base)                ((base)->GPR3)
#define IOMUXC_GPR_GPR4_REG(base)                ((base)->GPR4)
#define IOMUXC_GPR_GPR5_REG(base)                ((base)->GPR5)
#define IOMUXC_GPR_GPR6_REG(base)                ((base)->GPR6)
#define IOMUXC_GPR_GPR7_REG(base)                ((base)->GPR7)
#define IOMUXC_GPR_GPR8_REG(base)                ((base)->GPR8)
#define IOMUXC_GPR_GPR9_REG(base)                ((base)->GPR9)
#define IOMUXC_GPR_GPR10_REG(base)               ((base)->GPR10)
#define IOMUXC_GPR_GPR11_REG(base)               ((base)->GPR11)
#define IOMUXC_GPR_GPR12_REG(base)               ((base)->GPR12)
#define IOMUXC_GPR_GPR13_REG(base)               ((base)->GPR13)
#define IOMUXC_GPR_GPR14_REG(base)               ((base)->GPR14)
#define IOMUXC_GPR_GPR15_REG(base)               ((base)->GPR15)
#define IOMUXC_GPR_GPR16_REG(base)               ((base)->GPR16)
#define IOMUXC_GPR_GPR17_REG(base)               ((base)->GPR17)
#define IOMUXC_GPR_GPR18_REG(base)               ((base)->GPR18)
#define IOMUXC_GPR_GPR19_REG(base)               ((base)->GPR19)
#define IOMUXC_GPR_GPR20_REG(base)               ((base)->GPR20)
#define IOMUXC_GPR_GPR21_REG(base)               ((base)->GPR21)
#define IOMUXC_GPR_GPR22_REG(base)               ((base)->GPR22)

/*!
 * @}
 */ /* end of group IOMUXC_GPR_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- IOMUXC_GPR Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_GPR_Register_Masks IOMUXC_GPR Register Masks
 * @{
 */

/*! @name GPR0 - GPR0 General Purpose Register */
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0_MASK     (0x1U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0_SHIFT    (0U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1_MASK     (0x2U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1_SHIFT    (1U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2_MASK     (0x4U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2_SHIFT    (2U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3_MASK     (0x8U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3_SHIFT    (3U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4_MASK     (0x10U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4_SHIFT    (4U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5_MASK     (0x20U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5_SHIFT    (5U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6_MASK     (0x40U)
#define IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6_SHIFT    (6U)

/*! @name GPR1 - GPR1 General Purpose Register */
#define IOMUXC_GPR_GPR1_WEIM_ACT_CS0_MASK        (0x1U)
#define IOMUXC_GPR_GPR1_WEIM_ACT_CS0_SHIFT       (0U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS0_MASK         (0x6U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS0_SHIFT        (1U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS0(x)           (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR1_WEIM_ADDRS0_SHIFT)) & IOMUXC_GPR_GPR1_WEIM_ADDRS0_MASK)
#define IOMUXC_GPR_GPR1_WEIM_ACT_CS1_MASK        (0x8U)
#define IOMUXC_GPR_GPR1_WEIM_ACT_CS1_SHIFT       (3U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS1_MASK         (0x30U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS1_SHIFT        (4U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS1(x)           (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR1_WEIM_ADDRS1_SHIFT)) & IOMUXC_GPR_GPR1_WEIM_ADDRS1_MASK)
#define IOMUXC_GPR_GPR1_WEIM_ACT_CS2_MASK        (0x40U)
#define IOMUXC_GPR_GPR1_WEIM_ACT_CS2_SHIFT       (6U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS2_MASK         (0x180U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS2_SHIFT        (7U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS2(x)           (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR1_WEIM_ADDRS2_SHIFT)) & IOMUXC_GPR_GPR1_WEIM_ADDRS2_MASK)
#define IOMUXC_GPR_GPR1_WEIM_ACT_CS3_MASK        (0x200U)
#define IOMUXC_GPR_GPR1_WEIM_ACT_CS3_SHIFT       (9U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS3_MASK         (0xC00U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS3_SHIFT        (10U)
#define IOMUXC_GPR_GPR1_WEIM_ADDRS3(x)           (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR1_WEIM_ADDRS3_SHIFT)) & IOMUXC_GPR_GPR1_WEIM_ADDRS3_MASK)
#define IOMUXC_GPR_GPR1_IRQ_MASK                 (0x1000U)
#define IOMUXC_GPR_GPR1_IRQ_SHIFT                (12U)
#define IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL_MASK    (0x2000U)
#define IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL_SHIFT   (13U)
#define IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL_MASK    (0x4000U)
#define IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL_SHIFT   (14U)
#define IOMUXC_GPR_GPR1_PAD_ADD_DS_MASK          (0x10000U)
#define IOMUXC_GPR_GPR1_PAD_ADD_DS_SHIFT         (16U)
#define IOMUXC_GPR_GPR1_ENET1_CLK_DIR_MASK       (0x20000U)
#define IOMUXC_GPR_GPR1_ENET1_CLK_DIR_SHIFT      (17U)
#define IOMUXC_GPR_GPR1_ENET2_CLK_DIR_MASK       (0x40000U)
#define IOMUXC_GPR_GPR1_ENET2_CLK_DIR_SHIFT      (18U)
#define IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN_MASK     (0x400000U)
#define IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN_SHIFT    (22U)
#define IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK_MASK (0x800000U)
#define IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK_SHIFT (23U)
#define IOMUXC_GPR_GPR1_DBG_ACK_MASK             (0x30000000U)
#define IOMUXC_GPR_GPR1_DBG_ACK_SHIFT            (28U)
#define IOMUXC_GPR_GPR1_DBG_ACK(x)               (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR1_DBG_ACK_SHIFT)) & IOMUXC_GPR_GPR1_DBG_ACK_MASK)
#define IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC_MASK   (0x40000000U)
#define IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC_SHIFT  (30U)

/*! @name GPR2 - GPR2 General Purpose Register */
#define IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER_MASK    (0x1U)
#define IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER_SHIFT   (0U)
#define IOMUXC_GPR_GPR2_MEM_PXP_SD_MASK          (0x2U)
#define IOMUXC_GPR_GPR2_MEM_PXP_SD_SHIFT         (1U)
#define IOMUXC_GPR_GPR2_MEM_PXP_DS_MASK          (0x4U)
#define IOMUXC_GPR_GPR2_MEM_PXP_DS_SHIFT         (2U)
#define IOMUXC_GPR_GPR2_MEM_PXP_LS_MASK          (0x8U)
#define IOMUXC_GPR_GPR2_MEM_PXP_LS_SHIFT         (3U)
#define IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER_MASK  (0x10U)
#define IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER_SHIFT (4U)
#define IOMUXC_GPR_GPR2_MEM_LCDIF_SD_MASK        (0x20U)
#define IOMUXC_GPR_GPR2_MEM_LCDIF_SD_SHIFT       (5U)
#define IOMUXC_GPR_GPR2_MEM_LCDIF_DS_MASK        (0x40U)
#define IOMUXC_GPR_GPR2_MEM_LCDIF_DS_SHIFT       (6U)
#define IOMUXC_GPR_GPR2_MEM_LCDIF_LS_MASK        (0x80U)
#define IOMUXC_GPR_GPR2_MEM_LCDIF_LS_SHIFT       (7U)
#define IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER_MASK   (0x100U)
#define IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER_SHIFT  (8U)
#define IOMUXC_GPR_GPR2_MEM_EPDC_SD_MASK         (0x200U)
#define IOMUXC_GPR_GPR2_MEM_EPDC_SD_SHIFT        (9U)
#define IOMUXC_GPR_GPR2_MEM_EPDC_DS_MASK         (0x400U)
#define IOMUXC_GPR_GPR2_MEM_EPDC_DS_SHIFT        (10U)
#define IOMUXC_GPR_GPR2_MEM_EPDC_LS_MASK         (0x800U)
#define IOMUXC_GPR_GPR2_MEM_EPDC_LS_SHIFT        (11U)
#define IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER_MASK    (0x1000U)
#define IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER_SHIFT   (12U)
#define IOMUXC_GPR_GPR2_MEM_CPU_SD_MASK          (0x2000U)
#define IOMUXC_GPR_GPR2_MEM_CPU_SD_SHIFT         (13U)
#define IOMUXC_GPR_GPR2_MEM_CPU_DS_MASK          (0x4000U)
#define IOMUXC_GPR_GPR2_MEM_CPU_DS_SHIFT         (14U)
#define IOMUXC_GPR_GPR2_MEM_CPU_LS_MASK          (0x8000U)
#define IOMUXC_GPR_GPR2_MEM_CPU_LS_SHIFT         (15U)
#define IOMUXC_GPR_GPR2_MQS_CLK_DIV_MASK         (0xFF0000U)
#define IOMUXC_GPR_GPR2_MQS_CLK_DIV_SHIFT        (16U)
#define IOMUXC_GPR_GPR2_MQS_CLK_DIV(x)           (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR2_MQS_CLK_DIV_SHIFT)) & IOMUXC_GPR_GPR2_MQS_CLK_DIV_MASK)
#define IOMUXC_GPR_GPR2_MQS_SW_RST_MASK          (0x1000000U)
#define IOMUXC_GPR_GPR2_MQS_SW_RST_SHIFT         (24U)
#define IOMUXC_GPR_GPR2_MQS_EN_MASK              (0x2000000U)
#define IOMUXC_GPR_GPR2_MQS_EN_SHIFT             (25U)
#define IOMUXC_GPR_GPR2_MQS_OVERSAMPLE_MASK      (0x4000000U)
#define IOMUXC_GPR_GPR2_MQS_OVERSAMPLE_SHIFT     (26U)
#define IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS_MASK   (0x8000000U)
#define IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS_SHIFT  (27U)
#define IOMUXC_GPR_GPR2_DRAM_RESET_MASK          (0x10000000U)
#define IOMUXC_GPR_GPR2_DRAM_RESET_SHIFT         (28U)
#define IOMUXC_GPR_GPR2_DRAM_CKE0_MASK           (0x20000000U)
#define IOMUXC_GPR_GPR2_DRAM_CKE0_SHIFT          (29U)
#define IOMUXC_GPR_GPR2_DRAM_CKE1_MASK           (0x40000000U)
#define IOMUXC_GPR_GPR2_DRAM_CKE1_SHIFT          (30U)
#define IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS_MASK     (0x80000000U)
#define IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS_SHIFT    (31U)

/*! @name GPR3 - GPR3 General Purpose Register */
#define IOMUXC_GPR_GPR3_RDATA_WAIT_EN_MASK       (0x1U)
#define IOMUXC_GPR_GPR3_RDATA_WAIT_EN_SHIFT      (0U)
#define IOMUXC_GPR_GPR3_RADDR_PIPE_EN_MASK       (0x2U)
#define IOMUXC_GPR_GPR3_RADDR_PIPE_EN_SHIFT      (1U)
#define IOMUXC_GPR_GPR3_WDATA_PIPE_EN_MASK       (0x4U)
#define IOMUXC_GPR_GPR3_WDATA_PIPE_EN_SHIFT      (2U)
#define IOMUXC_GPR_GPR3_WADDR_PIPE_EN_MASK       (0x8U)
#define IOMUXC_GPR_GPR3_WADDR_PIPE_EN_SHIFT      (3U)
#define IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_MASK     (0x10U)
#define IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_SHIFT    (4U)
#define IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_MASK     (0x20U)
#define IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_SHIFT    (5U)
#define IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_MASK     (0x40U)
#define IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_SHIFT    (6U)
#define IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_MASK     (0x80U)
#define IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_SHIFT    (7U)
#define IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_MASK     (0x100U)
#define IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_SHIFT    (8U)
#define IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_MASK     (0x200U)
#define IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_SHIFT    (9U)
#define IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_MASK     (0x400U)
#define IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_SHIFT    (10U)
#define IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_MASK     (0x800U)
#define IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_SHIFT    (11U)
#define IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_MASK     (0x1000U)
#define IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_SHIFT    (12U)
#define IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_MASK     (0x2000U)
#define IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_SHIFT    (13U)
#define IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_MASK     (0x4000U)
#define IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_SHIFT    (14U)
#define IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_MASK     (0x8000U)
#define IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_SHIFT    (15U)
#define IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG_MASK   (0x10000U)
#define IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG_SHIFT  (16U)
#define IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG_MASK   (0x20000U)
#define IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG_SHIFT  (17U)
#define IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG_MASK   (0x40000U)
#define IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG_SHIFT  (18U)
#define IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG_MASK  (0x80000U)
#define IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG_SHIFT (19U)
#define IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG_MASK (0x100000U)
#define IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG_SHIFT (20U)
#define IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG_MASK (0x200000U)
#define IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG_SHIFT (21U)
#define IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG_MASK (0x400000U)
#define IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG_SHIFT (22U)
#define IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG_MASK (0x800000U)
#define IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG_SHIFT (23U)
#define IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG_MASK (0x1000000U)
#define IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG_SHIFT (24U)
#define IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG_MASK (0x2000000U)
#define IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG_SHIFT (25U)
#define IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG_MASK (0x4000000U)
#define IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG_SHIFT (26U)
#define IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG_MASK (0x8000000U)
#define IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG_SHIFT (27U)
#define IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG_MASK (0x10000000U)
#define IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG_SHIFT (28U)
#define IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG_MASK (0x20000000U)
#define IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG_SHIFT (29U)
#define IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG_MASK (0x40000000U)
#define IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG_SHIFT (30U)
#define IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG_MASK (0x80000000U)
#define IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG_SHIFT (31U)

/*! @name GPR4 - GPR4 General Purpose Register */
#define IOMUXC_GPR_GPR4_SDMA_IPG_STOP_MASK       (0x1U)
#define IOMUXC_GPR_GPR4_SDMA_IPG_STOP_SHIFT      (0U)
#define IOMUXC_GPR_GPR4_CAN1_IPG_STOP_MASK       (0x2U)
#define IOMUXC_GPR_GPR4_CAN1_IPG_STOP_SHIFT      (1U)
#define IOMUXC_GPR_GPR4_CAN2_IPG_STOP_MASK       (0x4U)
#define IOMUXC_GPR_GPR4_CAN2_IPG_STOP_SHIFT      (2U)
#define IOMUXC_GPR_GPR4_ENET1_IPG_STOP_MASK      (0x8U)
#define IOMUXC_GPR_GPR4_ENET1_IPG_STOP_SHIFT     (3U)
#define IOMUXC_GPR_GPR4_ENET2_IPG_STOP_MASK      (0x10U)
#define IOMUXC_GPR_GPR4_ENET2_IPG_STOP_SHIFT     (4U)
#define IOMUXC_GPR_GPR4_SAI1_IPG_STOP_MASK       (0x20U)
#define IOMUXC_GPR_GPR4_SAI1_IPG_STOP_SHIFT      (5U)
#define IOMUXC_GPR_GPR4_SAI2_IPG_STOP_MASK       (0x40U)
#define IOMUXC_GPR_GPR4_SAI2_IPG_STOP_SHIFT      (6U)
#define IOMUXC_GPR_GPR4_SAI3_IPG_STOP_MASK       (0x80U)
#define IOMUXC_GPR_GPR4_SAI3_IPG_STOP_SHIFT      (7U)
#define IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK_MASK   (0x10000U)
#define IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK_SHIFT  (16U)
#define IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK_MASK   (0x20000U)
#define IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK_SHIFT  (17U)
#define IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK_MASK   (0x40000U)
#define IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK_SHIFT  (18U)
#define IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK_MASK  (0x80000U)
#define IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK_SHIFT (19U)
#define IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK_MASK  (0x100000U)
#define IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK_SHIFT (20U)
#define IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK_MASK   (0x200000U)
#define IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK_SHIFT  (21U)
#define IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK_MASK   (0x400000U)
#define IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK_SHIFT  (22U)
#define IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK_MASK   (0x800000U)
#define IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK_SHIFT  (23U)
#define IOMUXC_GPR_GPR4_CPU_STANDBYWFI_MASK      (0x6000000U)
#define IOMUXC_GPR_GPR4_CPU_STANDBYWFI_SHIFT     (25U)
#define IOMUXC_GPR_GPR4_CPU_STANDBYWFI(x)        (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR4_CPU_STANDBYWFI_SHIFT)) & IOMUXC_GPR_GPR4_CPU_STANDBYWFI_MASK)
#define IOMUXC_GPR_GPR4_CPU_STANDBYWFE_MASK      (0x18000000U)
#define IOMUXC_GPR_GPR4_CPU_STANDBYWFE_SHIFT     (27U)
#define IOMUXC_GPR_GPR4_CPU_STANDBYWFE(x)        (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR4_CPU_STANDBYWFE_SHIFT)) & IOMUXC_GPR_GPR4_CPU_STANDBYWFE_MASK)

/*! @name GPR5 - GPR5 General Purpose Register */
#define IOMUXC_GPR_GPR5_CSI_MUX_CONTROL_MASK     (0x10U)
#define IOMUXC_GPR_GPR5_CSI_MUX_CONTROL_SHIFT    (4U)
#define IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL_MASK    (0x20U)
#define IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL_SHIFT   (5U)
#define IOMUXC_GPR_GPR5_WDOG1_MASK_MASK          (0x40U)
#define IOMUXC_GPR_GPR5_WDOG1_MASK_SHIFT         (6U)
#define IOMUXC_GPR_GPR5_WDOG2_MASK_MASK          (0x80U)
#define IOMUXC_GPR_GPR5_WDOG2_MASK_SHIFT         (7U)
#define IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_MASK     (0x1000U)
#define IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_SHIFT    (12U)
#define IOMUXC_GPR_GPR5_PCIE_BTNRST_MASK         (0x80000U)
#define IOMUXC_GPR_GPR5_PCIE_BTNRST_SHIFT        (19U)
#define IOMUXC_GPR_GPR5_WDOG3_MASK_MASK          (0x100000U)
#define IOMUXC_GPR_GPR5_WDOG3_MASK_SHIFT         (20U)
#define IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL_MASK (0x200000U)
#define IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL_SHIFT (21U)
#define IOMUXC_GPR_GPR5_WDOG4_MASK_MASK          (0x400000U)
#define IOMUXC_GPR_GPR5_WDOG4_MASK_SHIFT         (22U)
#define IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL_MASK     (0x1000000U)
#define IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL_SHIFT    (24U)
#define IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL_MASK     (0x2000000U)
#define IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL_SHIFT    (25U)
#define IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL_MASK  (0x4000000U)
#define IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL_SHIFT (26U)
#define IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL_MASK  (0x8000000U)
#define IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL_SHIFT (27U)
#define IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1_MASK     (0x10000000U)
#define IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1_SHIFT    (28U)
#define IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2_MASK     (0x20000000U)
#define IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2_SHIFT    (29U)
#define IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3_MASK     (0x40000000U)
#define IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3_SHIFT    (30U)
#define IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4_MASK     (0x80000000U)
#define IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4_SHIFT    (31U)

/*! @name GPR6 - GPR6 General Purpose Register */
#define IOMUXC_GPR_GPR6_ARCACHE_PXP6_MASK        (0x1U)
#define IOMUXC_GPR_GPR6_ARCACHE_PXP6_SHIFT       (0U)
#define IOMUXC_GPR_GPR6_AWCACHE_PXP6_MASK        (0x2U)
#define IOMUXC_GPR_GPR6_AWCACHE_PXP6_SHIFT       (1U)
#define IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN_MASK     (0x4U)
#define IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN_SHIFT    (2U)
#define IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN_MASK     (0x8U)
#define IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN_SHIFT    (3U)

/*! @name GPR7 - GPR7 General Purpose Register */
#define IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD_MASK (0x8U)
#define IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD_SHIFT (3U)
#define IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD_MASK (0x200U)
#define IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD_SHIFT (9U)

/*! @name GPR8 - GPR8 General Purpose Register */
#define IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP_MASK (0xF8U)
#define IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP_SHIFT (3U)
#define IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP_SHIFT)) & IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP_MASK)
#define IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START_MASK (0x100U)
#define IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START_SHIFT (8U)

/*! @name GPR9 - GPR9 General Purpose Register */
#define IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL_MASK  (0x1U)
#define IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL_SHIFT (0U)
#define IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD_MASK     (0x3EU)
#define IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD_SHIFT    (1U)
#define IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD(x)       (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD_SHIFT)) & IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD_MASK)

/*! @name GPR10 - GPR10 General Purpose Register */
#define IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN_MASK    (0x4U)
#define IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN_SHIFT   (2U)
#define IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN_MASK   (0x8U)
#define IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN_SHIFT  (3U)
#define IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR_MASK (0x3F0U)
#define IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR_SHIFT (4U)
#define IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR_SHIFT)) & IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR_MASK)
#define IOMUXC_GPR_GPR10_GPR10_LOCK_MASK         (0xFFFFFC00U)
#define IOMUXC_GPR_GPR10_GPR10_LOCK_SHIFT        (10U)
#define IOMUXC_GPR_GPR10_GPR10_LOCK(x)           (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR10_GPR10_LOCK_SHIFT)) & IOMUXC_GPR_GPR10_GPR10_LOCK_MASK)

/*! @name GPR11 - GPR11 General Purpose Register */
#define IOMUXC_GPR_GPR11_OCRAM_TZ_EN_MASK        (0x1U)
#define IOMUXC_GPR_GPR11_OCRAM_TZ_EN_SHIFT       (0U)
#define IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR_MASK      (0x3EU)
#define IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR_SHIFT     (1U)
#define IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR(x)        (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR_SHIFT)) & IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR_MASK)
#define IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN_MASK    (0x40U)
#define IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN_SHIFT   (6U)
#define IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR_MASK  (0x380U)
#define IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR_SHIFT (7U)
#define IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR(x)    (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR_SHIFT)) & IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR_MASK)
#define IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN_MASK      (0x400U)
#define IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN_SHIFT     (10U)
#define IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR_MASK    (0x3800U)
#define IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR_SHIFT   (11U)
#define IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(x)      (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR_SHIFT)) & IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR_MASK)
#define IOMUXC_GPR_GPR11_GPR11_LOCK_MASK         (0xFFFFC000U)
#define IOMUXC_GPR_GPR11_GPR11_LOCK_SHIFT        (14U)
#define IOMUXC_GPR_GPR11_GPR11_LOCK(x)           (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR11_GPR11_LOCK_SHIFT)) & IOMUXC_GPR_GPR11_GPR11_LOCK_MASK)

/*! @name GPR12 - GPR12 General Purpose Register */
#define IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0_MASK (0x1U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0_SHIFT (0U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0_MASK (0x2U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0_SHIFT (1U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN_MASK    (0x8U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN_SHIFT   (3U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST_MASK (0x10U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST_SHIFT (4U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL_MASK (0x20U)
#define IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL_SHIFT (5U)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE_MASK (0xF000U)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE_SHIFT (12U)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE_SHIFT)) & IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE_MASK)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT_MASK (0x1E0000U)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT_SHIFT (17U)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT_SHIFT)) & IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT_MASK)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS_MASK (0xE00000U)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS_SHIFT (21U)
#define IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS_SHIFT)) & IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS_MASK)

/*! @name GPR13 - GPR13 General Purpose Register */
#define IOMUXC_GPR_GPR13_ARCACHE_USDHC_MASK      (0x1U)
#define IOMUXC_GPR_GPR13_ARCACHE_USDHC_SHIFT     (0U)
#define IOMUXC_GPR_GPR13_AWCACHE_USDHC_MASK      (0x2U)
#define IOMUXC_GPR_GPR13_AWCACHE_USDHC_SHIFT     (1U)
#define IOMUXC_GPR_GPR13_ARCACHE_PXP_MASK        (0x4U)
#define IOMUXC_GPR_GPR13_ARCACHE_PXP_SHIFT       (2U)
#define IOMUXC_GPR_GPR13_AWCACHE_PXP_MASK        (0x8U)
#define IOMUXC_GPR_GPR13_AWCACHE_PXP_SHIFT       (3U)
#define IOMUXC_GPR_GPR13_ARCACHE_PCIE_MASK       (0x10U)
#define IOMUXC_GPR_GPR13_ARCACHE_PCIE_SHIFT      (4U)
#define IOMUXC_GPR_GPR13_AWCACHE_PCIE_MASK       (0x20U)
#define IOMUXC_GPR_GPR13_AWCACHE_PCIE_SHIFT      (5U)
#define IOMUXC_GPR_GPR13_ARCACHE_LCDIF_MASK      (0x40U)
#define IOMUXC_GPR_GPR13_ARCACHE_LCDIF_SHIFT     (6U)
#define IOMUXC_GPR_GPR13_ARCACHE_EPDC_MASK       (0x80U)
#define IOMUXC_GPR_GPR13_ARCACHE_EPDC_SHIFT      (7U)
#define IOMUXC_GPR_GPR13_ARCACHE_PXP_EN_MASK     (0x100U)
#define IOMUXC_GPR_GPR13_ARCACHE_PXP_EN_SHIFT    (8U)
#define IOMUXC_GPR_GPR13_AWCACHE_PXP_EN_MASK     (0x200U)
#define IOMUXC_GPR_GPR13_AWCACHE_PXP_EN_SHIFT    (9U)
#define IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN_MASK    (0x400U)
#define IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN_SHIFT   (10U)
#define IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN_MASK    (0x800U)
#define IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN_SHIFT   (11U)
#define IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN_MASK   (0x1000U)
#define IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN_SHIFT  (12U)
#define IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN_MASK    (0x2000U)
#define IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN_SHIFT   (13U)
#define IOMUXC_GPR_GPR13_AWCACHE_EPDC_MASK       (0x4000U)
#define IOMUXC_GPR_GPR13_AWCACHE_EPDC_SHIFT      (14U)
#define IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN_MASK    (0x8000U)
#define IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN_SHIFT   (15U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0_MASK (0xFF0000U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0_SHIFT (16U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0_SHIFT)) & IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0_MASK)
#define IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND_MASK  (0xF000000U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND_SHIFT (24U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND(x)    (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND_SHIFT)) & IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND_MASK)
#define IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0_MASK (0x10000000U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0_SHIFT (28U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0_MASK (0x20000000U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0_SHIFT (29U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0_MASK (0x40000000U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0_SHIFT (30U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE_MASK (0x80000000U)
#define IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE_SHIFT (31U)

/*! @name GPR14 - GPR14 General Purpose Register */
#define IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL_MASK (0x1U)
#define IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL_SHIFT (0U)
#define IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL_MASK (0x2U)
#define IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL_SHIFT (1U)

/*! @name GPR15 - GPR15 General Purpose Register */
#define IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG_MASK   (0x1U)
#define IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG_SHIFT  (0U)
#define IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL_MASK    (0x2U)
#define IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL_SHIFT   (1U)
#define IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET_MASK (0x3FFCU)
#define IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET_SHIFT (2U)
#define IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET_SHIFT)) & IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET_MASK)
#define IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET_MASK (0x3F0000U)
#define IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET_SHIFT (16U)
#define IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET_SHIFT)) & IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET_MASK)

/*! @name GPR16 - GPR16 General Purpose Register */
#define IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR_MASK  (0x3U)
#define IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR_SHIFT (0U)
#define IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR(x)    (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR_SHIFT)) & IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR_MASK)
#define IOMUXC_GPR_GPR16_LVDS_SEL_DATABF_MASK    (0x4U)
#define IOMUXC_GPR_GPR16_LVDS_SEL_DATABF_SHIFT   (2U)
#define IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY_MASK     (0x8U)
#define IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY_SHIFT    (3U)
#define IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H_MASK     (0x10U)
#define IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H_SHIFT    (4U)
#define IOMUXC_GPR_GPR16_LVDS_SKEWINI_MASK       (0x20U)
#define IOMUXC_GPR_GPR16_LVDS_SKEWINI_SHIFT      (5U)
#define IOMUXC_GPR_GPR16_LVDS_SK_BIAS_MASK       (0x3C0U)
#define IOMUXC_GPR_GPR16_LVDS_SK_BIAS_SHIFT      (6U)
#define IOMUXC_GPR_GPR16_LVDS_SK_BIAS(x)         (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR16_LVDS_SK_BIAS_SHIFT)) & IOMUXC_GPR_GPR16_LVDS_SK_BIAS_MASK)
#define IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL_MASK  (0x400U)
#define IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL_SHIFT (10U)
#define IOMUXC_GPR_GPR16_LVDS_LOCK_CNT_MASK      (0x800U)
#define IOMUXC_GPR_GPR16_LVDS_LOCK_CNT_SHIFT     (11U)
#define IOMUXC_GPR_GPR16_LVDS_OUTCON_MASK        (0x1000U)
#define IOMUXC_GPR_GPR16_LVDS_OUTCON_SHIFT       (12U)
#define IOMUXC_GPR_GPR16_LVDS_FC_CODE_MASK       (0xE000U)
#define IOMUXC_GPR_GPR16_LVDS_FC_CODE_SHIFT      (13U)
#define IOMUXC_GPR_GPR16_LVDS_FC_CODE(x)         (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR16_LVDS_FC_CODE_SHIFT)) & IOMUXC_GPR_GPR16_LVDS_FC_CODE_MASK)
#define IOMUXC_GPR_GPR16_LVDS_SRC_TRH_MASK       (0x10000U)
#define IOMUXC_GPR_GPR16_LVDS_SRC_TRH_SHIFT      (16U)
#define IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S_MASK    (0x20000U)
#define IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S_SHIFT   (17U)
#define IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT_MASK     (0x180000U)
#define IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT_SHIFT    (19U)
#define IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT(x)       (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT_SHIFT)) & IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT_MASK)
#define IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL_MASK (0x200000U)
#define IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL_SHIFT (21U)
#define IOMUXC_GPR_GPR16_LVDS_FLT_CNT_MASK       (0x400000U)
#define IOMUXC_GPR_GPR16_LVDS_FLT_CNT_SHIFT      (22U)
#define IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT_MASK  (0x800000U)
#define IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT_SHIFT (23U)

/*! @name GPR17 - GPR17 General Purpose Register */
#define IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H_MASK     (0xFFU)
#define IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H_SHIFT    (0U)
#define IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H(x)       (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H_SHIFT)) & IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H_MASK)
#define IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H_MASK     (0xFF00U)
#define IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H_SHIFT    (8U)
#define IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H(x)       (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H_SHIFT)) & IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H_MASK)

/*! @name GPR18 - GPR18 General Purpose Register */
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL_MASK (0x7U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL_SHIFT (0U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL_SHIFT)) & IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL_MASK)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV_MASK (0x18U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV_SHIFT (3U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV_SHIFT)) & IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV_MASK)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV_MASK (0x60U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV_SHIFT (5U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV_SHIFT)) & IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV_MASK)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL_MASK (0x3F00U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL_SHIFT (8U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL_SHIFT)) & IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL_MASK)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR_MASK (0x4000U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR_SHIFT (14U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN_MASK (0x7F0000U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN_SHIFT (16U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN_SHIFT)) & IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN_MASK)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL_MASK (0x3000000U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL_SHIFT (24U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL_SHIFT)) & IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL_MASK)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_EN_MASK     (0x4000000U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_EN_SHIFT    (26U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB_MASK (0x8000000U)
#define IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB_SHIFT (27U)
#define IOMUXC_GPR_GPR18_LVDS_DLYS_BST_MASK      (0x10000000U)
#define IOMUXC_GPR_GPR18_LVDS_DLYS_BST_SHIFT     (28U)
#define IOMUXC_GPR_GPR18_LVDS_SKINI_BST_MASK     (0x20000000U)
#define IOMUXC_GPR_GPR18_LVDS_SKINI_BST_SHIFT    (29U)

/*! @name GPR19 - GPR19 General Purpose Register */
#define IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS_MASK (0x1U)
#define IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS_SHIFT (0U)
#define IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT_MASK (0xFF00U)
#define IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT_SHIFT (8U)
#define IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT_SHIFT)) & IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT_MASK)
#define IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC_MASK   (0x10000U)
#define IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC_SHIFT  (16U)
#define IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT_MASK (0x20000U)
#define IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT_SHIFT (17U)

/*! @name GPR20 - GPR20 General Purpose Register */
#define IOMUXC_GPR_GPR20_LVDS_P_MASK             (0x3FU)
#define IOMUXC_GPR_GPR20_LVDS_P_SHIFT            (0U)
#define IOMUXC_GPR_GPR20_LVDS_P(x)               (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR20_LVDS_P_SHIFT)) & IOMUXC_GPR_GPR20_LVDS_P_MASK)
#define IOMUXC_GPR_GPR20_LVDS_M_MASK             (0x3F00U)
#define IOMUXC_GPR_GPR20_LVDS_M_SHIFT            (8U)
#define IOMUXC_GPR_GPR20_LVDS_M(x)               (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR20_LVDS_M_SHIFT)) & IOMUXC_GPR_GPR20_LVDS_M_MASK)
#define IOMUXC_GPR_GPR20_LVDS_S_MASK             (0x30000U)
#define IOMUXC_GPR_GPR20_LVDS_S_SHIFT            (16U)
#define IOMUXC_GPR_GPR20_LVDS_S(x)               (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR20_LVDS_S_SHIFT)) & IOMUXC_GPR_GPR20_LVDS_S_MASK)
#define IOMUXC_GPR_GPR20_LVDS_VSEL_MASK          (0x1000000U)
#define IOMUXC_GPR_GPR20_LVDS_VSEL_SHIFT         (24U)
#define IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL_MASK    (0x2000000U)
#define IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL_SHIFT   (25U)
#define IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY_MASK (0x38000000U)
#define IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY_SHIFT (27U)
#define IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY_SHIFT)) & IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY_MASK)

/*! @name GPR21 - GPR21 General Purpose Register */
#define IOMUXC_GPR_GPR21_LVDS_SKC0_MASK          (0x7U)
#define IOMUXC_GPR_GPR21_LVDS_SKC0_SHIFT         (0U)
#define IOMUXC_GPR_GPR21_LVDS_SKC0(x)            (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR21_LVDS_SKC0_SHIFT)) & IOMUXC_GPR_GPR21_LVDS_SKC0_MASK)
#define IOMUXC_GPR_GPR21_LVDS_SKC1_MASK          (0x38U)
#define IOMUXC_GPR_GPR21_LVDS_SKC1_SHIFT         (3U)
#define IOMUXC_GPR_GPR21_LVDS_SKC1(x)            (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR21_LVDS_SKC1_SHIFT)) & IOMUXC_GPR_GPR21_LVDS_SKC1_MASK)
#define IOMUXC_GPR_GPR21_LVDS_SKC2_MASK          (0x1C0U)
#define IOMUXC_GPR_GPR21_LVDS_SKC2_SHIFT         (6U)
#define IOMUXC_GPR_GPR21_LVDS_SKC2(x)            (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR21_LVDS_SKC2_SHIFT)) & IOMUXC_GPR_GPR21_LVDS_SKC2_MASK)
#define IOMUXC_GPR_GPR21_LVDS_SKCCK_MASK         (0xE00U)
#define IOMUXC_GPR_GPR21_LVDS_SKCCK_SHIFT        (9U)
#define IOMUXC_GPR_GPR21_LVDS_SKCCK(x)           (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR21_LVDS_SKCCK_SHIFT)) & IOMUXC_GPR_GPR21_LVDS_SKCCK_MASK)
#define IOMUXC_GPR_GPR21_LVDS_SKC3_MASK          (0x7000U)
#define IOMUXC_GPR_GPR21_LVDS_SKC3_SHIFT         (12U)
#define IOMUXC_GPR_GPR21_LVDS_SKC3(x)            (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR21_LVDS_SKC3_SHIFT)) & IOMUXC_GPR_GPR21_LVDS_SKC3_MASK)
#define IOMUXC_GPR_GPR21_LVDS_SKC4_MASK          (0x38000U)
#define IOMUXC_GPR_GPR21_LVDS_SKC4_SHIFT         (15U)
#define IOMUXC_GPR_GPR21_LVDS_SKC4(x)            (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR21_LVDS_SKC4_SHIFT)) & IOMUXC_GPR_GPR21_LVDS_SKC4_MASK)
#define IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC_MASK  (0x40000U)
#define IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC_SHIFT (18U)
#define IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC_MASK  (0x80000U)
#define IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC_SHIFT (19U)

/*! @name GPR22 - GPR22 General Purpose Register */
#define IOMUXC_GPR_GPR22_DDRC_MRR_DATA_MASK      (0xFF0000U)
#define IOMUXC_GPR_GPR22_DDRC_MRR_DATA_SHIFT     (16U)
#define IOMUXC_GPR_GPR22_DDRC_MRR_DATA(x)        (((uint32_t)(((uint32_t)(x)) << IOMUXC_GPR_GPR22_DDRC_MRR_DATA_SHIFT)) & IOMUXC_GPR_GPR22_DDRC_MRR_DATA_MASK)
#define IOMUXC_GPR_GPR22_DDRC_MRR_VALID_MASK     (0x1000000U)
#define IOMUXC_GPR_GPR22_DDRC_MRR_VALID_SHIFT    (24U)
#define IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE_MASK  (0x2000000U)
#define IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE_SHIFT (25U)
#define IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE_MASK   (0x4000000U)
#define IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE_SHIFT  (26U)
#define IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1_MASK     (0x8000000U)
#define IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1_SHIFT    (27U)
#define IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE_MASK   (0x10000000U)
#define IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE_SHIFT  (28U)
#define IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1_MASK     (0x20000000U)
#define IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1_SHIFT    (29U)
#define IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED_MASK (0x80000000U)
#define IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED_SHIFT (31U)


/*!
 * @}
 */ /* end of group IOMUXC_GPR_Register_Masks */


/* IOMUXC_GPR - Peripheral instance base addresses */
/** Peripheral IOMUXC_GPR base pointer */
#define IOMUXC_GPR_BASE_PTR                      ((IOMUXC_GPR_MemMapPtr)0x30340000u)
/** Array initializer of IOMUXC_GPR peripheral base pointers */
#define IOMUXC_GPR_BASE_PTRS                     { IOMUXC_GPR_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- IOMUXC_GPR - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_GPR_Register_Accessor_Macros IOMUXC_GPR - Register accessor macros
 * @{
 */


/* IOMUXC_GPR - Register instance definitions */
/* IOMUXC_GPR */
#define IOMUXC_GPR_GPR0                          IOMUXC_GPR_GPR0_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR1                          IOMUXC_GPR_GPR1_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR2                          IOMUXC_GPR_GPR2_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR3                          IOMUXC_GPR_GPR3_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR4                          IOMUXC_GPR_GPR4_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR5                          IOMUXC_GPR_GPR5_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR6                          IOMUXC_GPR_GPR6_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR7                          IOMUXC_GPR_GPR7_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR8                          IOMUXC_GPR_GPR8_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR9                          IOMUXC_GPR_GPR9_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR10                         IOMUXC_GPR_GPR10_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR11                         IOMUXC_GPR_GPR11_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR12                         IOMUXC_GPR_GPR12_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR13                         IOMUXC_GPR_GPR13_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR14                         IOMUXC_GPR_GPR14_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR15                         IOMUXC_GPR_GPR15_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR16                         IOMUXC_GPR_GPR16_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR17                         IOMUXC_GPR_GPR17_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR18                         IOMUXC_GPR_GPR18_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR19                         IOMUXC_GPR_GPR19_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR20                         IOMUXC_GPR_GPR20_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR21                         IOMUXC_GPR_GPR21_REG(IOMUXC_GPR_BASE_PTR)
#define IOMUXC_GPR_GPR22                         IOMUXC_GPR_GPR22_REG(IOMUXC_GPR_BASE_PTR)

/*!
 * @}
 */ /* end of group IOMUXC_GPR_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group IOMUXC_GPR_Peripheral */


/* ----------------------------------------------------------------------------
   -- IOMUXC_LPSR
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_LPSR_Peripheral IOMUXC_LPSR
 * @{
 */

/** IOMUXC_LPSR - Peripheral register structure */
typedef struct IOMUXC_LPSR_MemMap {
  uint32_t SW_MUX_CTL_PAD[8];                      /**< SW_MUX_CTL_PAD_GPIO1_IO00 SW MUX Control Register..SW_MUX_CTL_PAD_GPIO1_IO07 SW MUX Control Register, array offset: 0x0, array step: 0x4 */
  uint32_t SW_PAD_CTL_PAD[12];                     /**< SW_PAD_CTL_PAD_TEST_MODE SW PAD Control Register..SW_PAD_CTL_PAD_GPIO1_IO07 SW PAD Control Register, array offset: 0x20, array step: 0x4 */
} volatile *IOMUXC_LPSR_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- IOMUXC_LPSR - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_LPSR_Register_Accessor_Macros IOMUXC_LPSR - Register accessor macros
 * @{
 */


/* IOMUXC_LPSR - Register accessors */
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(base,index) ((base)->SW_MUX_CTL_PAD[index])
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(base,index) ((base)->SW_PAD_CTL_PAD[index])

/*!
 * @}
 */ /* end of group IOMUXC_LPSR_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- IOMUXC_LPSR Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_LPSR_Register_Masks IOMUXC_LPSR Register Masks
 * @{
 */

/*! @name SW_MUX_CTL_PAD - SW_MUX_CTL_PAD_GPIO1_IO00 SW MUX Control Register..SW_MUX_CTL_PAD_GPIO1_IO07 SW MUX Control Register */
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_MUX_MODE_MASK (0x7U)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_MUX_MODE_SHIFT (0U)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_MUX_MODE(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_SW_MUX_CTL_PAD_MUX_MODE_SHIFT)) & IOMUXC_LPSR_SW_MUX_CTL_PAD_MUX_MODE_MASK)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_SION_MASK     (0x10U)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_SION_SHIFT    (4U)

/* The count of IOMUXC_LPSR_SW_MUX_CTL_PAD */
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_COUNT         (8U)

/*! @name SW_PAD_CTL_PAD - SW_PAD_CTL_PAD_TEST_MODE SW PAD Control Register..SW_PAD_CTL_PAD_GPIO1_IO07 SW PAD Control Register */
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_DSE_MASK      (0x3U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_DSE_SHIFT     (0U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_DSE(x)        (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_SW_PAD_CTL_PAD_DSE_SHIFT)) & IOMUXC_LPSR_SW_PAD_CTL_PAD_DSE_MASK)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_SRE_MASK      (0x4U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_SRE_SHIFT     (2U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_HYS_MASK      (0x8U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_HYS_SHIFT     (3U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_PE_MASK       (0x10U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_PE_SHIFT      (4U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_PS_MASK       (0x60U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_PS_SHIFT      (5U)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_PS(x)         (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_SW_PAD_CTL_PAD_PS_SHIFT)) & IOMUXC_LPSR_SW_PAD_CTL_PAD_PS_MASK)

/* The count of IOMUXC_LPSR_SW_PAD_CTL_PAD */
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_COUNT         (12U)


/*!
 * @}
 */ /* end of group IOMUXC_LPSR_Register_Masks */


/* IOMUXC_LPSR - Peripheral instance base addresses */
/** Peripheral IOMUXC_LPSR base pointer */
#define IOMUXC_LPSR_BASE_PTR                     ((IOMUXC_LPSR_MemMapPtr)0x302C0000u)
/** Array initializer of IOMUXC_LPSR peripheral base pointers */
#define IOMUXC_LPSR_BASE_PTRS                    { IOMUXC_LPSR_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- IOMUXC_LPSR - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_LPSR_Register_Accessor_Macros IOMUXC_LPSR - Register accessor macros
 * @{
 */


/* IOMUXC_LPSR - Register instance definitions */
/* IOMUXC_LPSR */
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00    IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,0)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01    IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,1)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02    IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,2)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03    IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,3)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04    IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,4)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05    IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,5)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06    IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,6)
#define IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07    IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,7)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE     IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,0)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B     IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,1)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,2)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,3)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,4)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,5)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,6)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,7)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,8)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,9)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,10)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07    IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,11)

/* IOMUXC_LPSR - Register array accessors */
#define IOMUXC_LPSR_SW_MUX_CTL_PAD(index)        IOMUXC_LPSR_SW_MUX_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,index)
#define IOMUXC_LPSR_SW_PAD_CTL_PAD(index)        IOMUXC_LPSR_SW_PAD_CTL_PAD_REG(IOMUXC_LPSR_BASE_PTR,index)

/*!
 * @}
 */ /* end of group IOMUXC_LPSR_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group IOMUXC_LPSR_Peripheral */


/* ----------------------------------------------------------------------------
   -- IOMUXC_LPSR_GPR
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_LPSR_GPR_Peripheral IOMUXC_LPSR_GPR
 * @{
 */

/** IOMUXC_LPSR_GPR - Peripheral register structure */
typedef struct IOMUXC_LPSR_GPR_MemMap {
  uint32_t IOMUXC_LPSR_GPR0;                       /**< IOMUXC_LPSR General Purpose Register 0, offset: 0x0 */
  uint32_t IOMUXC_LPSR_GPR1;                       /**< IOMUXC_LPSR General Purpose Register 1, offset: 0x4 */
  uint32_t IOMUXC_LPSR_GPR2;                       /**< IOMUXC_LPSR General Purpose Register 2, offset: 0x8 */
  uint32_t IOMUXC_LPSR_GPR3;                       /**< IOMUXC_LPSR General Purpose Register 3, offset: 0xC */
  uint32_t IOMUXC_LPSR_GPR4;                       /**< IOMUXC_LPSR General Purpose Register 4, offset: 0x10 */
  uint32_t IOMUXC_LPSR_GPR5;                       /**< IOMUXC_LPSR General Purpose Register 5, offset: 0x14 */
  uint32_t IOMUXC_LPSR_GPR6;                       /**< IOMUXC_LPSR General Purpose Register 6, offset: 0x18 */
  uint32_t IOMUXC_LPSR_GPR7;                       /**< IOMUXC_LPSR General Purpose Register 7, offset: 0x1C */
  uint32_t IOMUXC_LPSR_GPR8;                       /**< IOMUXC_LPSR General Purpose Register 8, offset: 0x20 */
  uint32_t IOMUXC_LPSR_GPR9;                       /**< IOMUXC_LPSR General Purpose Register 9, offset: 0x24 */
  uint32_t IOMUXC_LPSR_GPR10;                      /**< IOMUXC_LPSR General Purpose Register 10, offset: 0x28 */
  uint32_t IOMUXC_LPSR_GPR11;                      /**< IOMUXC_LPSR General Purpose Register 11, offset: 0x2C */
  uint32_t IOMUXC_LPSR_GPR12;                      /**< IOMUXC_LPSR General Purpose Register 12, offset: 0x30 */
  uint32_t IOMUXC_LPSR_GPR13;                      /**< IOMUXC_LPSR General Purpose Register 13, offset: 0x34 */
  uint32_t IOMUXC_LPSR_GPR14;                      /**< IOMUXC_LPSR General Purpose Register 14, offset: 0x38 */
  uint32_t IOMUXC_LPSR_GPR15;                      /**< IOMUXC_LPSR General Purpose Register 15, offset: 0x3C */
  uint32_t IOMUXC_LPSR_GPR16;                      /**< IOMUXC_LPSR General Purpose Register 16, offset: 0x40 */
  uint32_t IOMUXC_LPSR_GPR17;                      /**< IOMUXC_LPSR General Purpose Register 17, offset: 0x44 */
  uint32_t IOMUXC_LPSR_GPR18;                      /**< IOMUXC_LPSR General Purpose Register 18, offset: 0x48 */
  uint32_t IOMUXC_LPSR_GPR19;                      /**< IOMUXC_LPSR General Purpose Register 19, offset: 0x4C */
  uint32_t IOMUXC_LPSR_GPR20;                      /**< IOMUXC_LPSR General Purpose Register 20, offset: 0x50 */
  uint32_t IOMUXC_LPSR_GPR21;                      /**< IOMUXC_LPSR General Purpose Register 21, offset: 0x54 */
  uint32_t IOMUXC_LPSR_GPR22;                      /**< IOMUXC_LPSR General Purpose Register 22, offset: 0x58 */
} volatile *IOMUXC_LPSR_GPR_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- IOMUXC_LPSR_GPR - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_LPSR_GPR_Register_Accessor_Macros IOMUXC_LPSR_GPR - Register accessor macros
 * @{
 */


/* IOMUXC_LPSR_GPR - Register accessors */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_REG(base) ((base)->IOMUXC_LPSR_GPR0)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_REG(base) ((base)->IOMUXC_LPSR_GPR1)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_REG(base) ((base)->IOMUXC_LPSR_GPR2)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_REG(base) ((base)->IOMUXC_LPSR_GPR3)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_REG(base) ((base)->IOMUXC_LPSR_GPR4)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_REG(base) ((base)->IOMUXC_LPSR_GPR5)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_REG(base) ((base)->IOMUXC_LPSR_GPR6)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_REG(base) ((base)->IOMUXC_LPSR_GPR7)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_REG(base) ((base)->IOMUXC_LPSR_GPR8)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_REG(base) ((base)->IOMUXC_LPSR_GPR9)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_REG(base) ((base)->IOMUXC_LPSR_GPR10)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_REG(base) ((base)->IOMUXC_LPSR_GPR11)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_REG(base) ((base)->IOMUXC_LPSR_GPR12)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_REG(base) ((base)->IOMUXC_LPSR_GPR13)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_REG(base) ((base)->IOMUXC_LPSR_GPR14)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_REG(base) ((base)->IOMUXC_LPSR_GPR15)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_REG(base) ((base)->IOMUXC_LPSR_GPR16)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_REG(base) ((base)->IOMUXC_LPSR_GPR17)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_REG(base) ((base)->IOMUXC_LPSR_GPR18)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_REG(base) ((base)->IOMUXC_LPSR_GPR19)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_REG(base) ((base)->IOMUXC_LPSR_GPR20)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_REG(base) ((base)->IOMUXC_LPSR_GPR21)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_REG(base) ((base)->IOMUXC_LPSR_GPR22)

/*!
 * @}
 */ /* end of group IOMUXC_LPSR_GPR_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- IOMUXC_LPSR_GPR Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_LPSR_GPR_Register_Masks IOMUXC_LPSR_GPR Register Masks
 * @{
 */

/*! @name IOMUXC_LPSR_GPR0 - IOMUXC_LPSR General Purpose Register 0 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP_MASK)

/*! @name IOMUXC_LPSR_GPR1 - IOMUXC_LPSR General Purpose Register 1 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP_MASK)

/*! @name IOMUXC_LPSR_GPR2 - IOMUXC_LPSR General Purpose Register 2 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP_MASK)

/*! @name IOMUXC_LPSR_GPR3 - IOMUXC_LPSR General Purpose Register 3 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP_MASK (0xFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO_MASK (0xFFFF0000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO_SHIFT (16U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO_MASK)

/*! @name IOMUXC_LPSR_GPR4 - IOMUXC_LPSR General Purpose Register 4 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP_MASK (0xFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO_MASK (0xFFFF0000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO_SHIFT (16U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO_MASK)

/*! @name IOMUXC_LPSR_GPR5 - IOMUXC_LPSR General Purpose Register 5 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP_MASK)

/*! @name IOMUXC_LPSR_GPR6 - IOMUXC_LPSR General Purpose Register 6 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP_MASK)

/*! @name IOMUXC_LPSR_GPR7 - IOMUXC_LPSR General Purpose Register 7 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP_MASK)

/*! @name IOMUXC_LPSR_GPR8 - IOMUXC_LPSR General Purpose Register 8 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP(x)   (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP_MASK)

/*! @name IOMUXC_LPSR_GPR9 - IOMUXC_LPSR General Purpose Register 9 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY_MASK)

/*! @name IOMUXC_LPSR_GPR10 - IOMUXC_LPSR General Purpose Register 10 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK_MASK (0xFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY_MASK (0xFFFF0000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY_SHIFT (16U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY_MASK)

/*! @name IOMUXC_LPSR_GPR11 - IOMUXC_LPSR General Purpose Register 11 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK_MASK (0xFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY_MASK (0xFFFF0000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY_SHIFT (16U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY_MASK)

/*! @name IOMUXC_LPSR_GPR12 - IOMUXC_LPSR General Purpose Register 12 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP_MASK)

/*! @name IOMUXC_LPSR_GPR13 - IOMUXC_LPSR General Purpose Register 13 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP_MASK (0xFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO_MASK (0xFFFF0000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO_SHIFT (16U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO_MASK)

/*! @name IOMUXC_LPSR_GPR14 - IOMUXC_LPSR General Purpose Register 14 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP_MASK)

/*! @name IOMUXC_LPSR_GPR15 - IOMUXC_LPSR General Purpose Register 15 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP_MASK)

/*! @name IOMUXC_LPSR_GPR16 - IOMUXC_LPSR General Purpose Register 16 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP_MASK)

/*! @name IOMUXC_LPSR_GPR17 - IOMUXC_LPSR General Purpose Register 17 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP_MASK)

/*! @name IOMUXC_LPSR_GPR18 - IOMUXC_LPSR General Purpose Register 18 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP_MASK)

/*! @name IOMUXC_LPSR_GPR19 - IOMUXC_LPSR General Purpose Register 19 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP_MASK (0xFFFFFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP_MASK)

/*! @name IOMUXC_LPSR_GPR20 - IOMUXC_LPSR General Purpose Register 20 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE_MASK (0x3U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE_MASK (0x4U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE_SHIFT (2U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS_MASK (0x8U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS_SHIFT (3U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE_MASK (0x10U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE_SHIFT (4U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS_MASK (0x60U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS_SHIFT (5U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL_MASK (0x80U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL_SHIFT (7U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE_MASK (0x300U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE_SHIFT (8U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE_MASK (0x400U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE_SHIFT (10U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS_MASK (0x800U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS_SHIFT (11U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE_MASK (0x1000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE_SHIFT (12U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS_MASK (0x6000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS_SHIFT (13U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL_MASK (0x8000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL_SHIFT (15U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE_MASK (0x30000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE_SHIFT (16U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE_MASK (0x40000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE_SHIFT (18U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS_MASK (0x80000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS_SHIFT (19U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE_MASK (0x100000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE_SHIFT (20U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS_MASK (0x600000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS_SHIFT (21U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL_MASK (0x800000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL_SHIFT (23U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE_MASK (0x3000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE_SHIFT (24U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE_MASK (0x4000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE_SHIFT (26U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS_MASK (0x8000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS_SHIFT (27U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE_MASK (0x10000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE_SHIFT (28U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS_MASK (0x60000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS_SHIFT (29U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL_MASK (0x80000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL_SHIFT (31U)

/*! @name IOMUXC_LPSR_GPR21 - IOMUXC_LPSR General Purpose Register 21 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE_MASK (0x3U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE_MASK (0x4U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE_SHIFT (2U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS_MASK (0x8U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS_SHIFT (3U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE_MASK (0x10U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE_SHIFT (4U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS_MASK (0x60U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS_SHIFT (5U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL_MASK (0x80U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL_SHIFT (7U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE_MASK (0x300U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE_SHIFT (8U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE_MASK (0x400U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE_SHIFT (10U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS_MASK (0x800U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS_SHIFT (11U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE_MASK (0x1000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE_SHIFT (12U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS_MASK (0x6000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS_SHIFT (13U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL_MASK (0x8000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL_SHIFT (15U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE_MASK (0x30000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE_SHIFT (16U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE_MASK (0x40000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE_SHIFT (18U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS_MASK (0x80000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS_SHIFT (19U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE_MASK (0x100000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE_SHIFT (20U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS_MASK (0x600000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS_SHIFT (21U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL_MASK (0x800000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL_SHIFT (23U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE_MASK (0x3000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE_SHIFT (24U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE_MASK (0x4000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE_SHIFT (26U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS_MASK (0x8000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS_SHIFT (27U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE_MASK (0x10000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE_SHIFT (28U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS_MASK (0x60000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS_SHIFT (29U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS(x) (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL_MASK (0x80000000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL_SHIFT (31U)

/*! @name IOMUXC_LPSR_GPR22 - IOMUXC_LPSR General Purpose Register 22 */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP_MASK (0xFFFFU)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP_SHIFT (0U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP_MASK)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO_MASK (0xFFFF0000U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO_SHIFT (16U)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO(x)  (((uint32_t)(((uint32_t)(x)) << IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO_SHIFT)) & IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO_MASK)


/*!
 * @}
 */ /* end of group IOMUXC_LPSR_GPR_Register_Masks */


/* IOMUXC_LPSR_GPR - Peripheral instance base addresses */
/** Peripheral IOMUXC_LPSR_GPR base pointer */
#define IOMUXC_LPSR_GPR_BASE_PTR                 ((IOMUXC_LPSR_GPR_MemMapPtr)0x30270000u)
/** Array initializer of IOMUXC_LPSR_GPR peripheral base pointers */
#define IOMUXC_LPSR_GPR_BASE_PTRS                { IOMUXC_LPSR_GPR_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- IOMUXC_LPSR_GPR - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup IOMUXC_LPSR_GPR_Register_Accessor_Macros IOMUXC_LPSR_GPR - Register accessor macros
 * @{
 */


/* IOMUXC_LPSR_GPR - Register instance definitions */
/* IOMUXC_LPSR_GPR */
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9         IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_REG(IOMUXC_LPSR_GPR_BASE_PTR)
#define IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22        IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_REG(IOMUXC_LPSR_GPR_BASE_PTR)

/*!
 * @}
 */ /* end of group IOMUXC_LPSR_GPR_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group IOMUXC_LPSR_GPR_Peripheral */


/* ----------------------------------------------------------------------------
   -- KPP
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup KPP_Peripheral KPP
 * @{
 */

/** KPP - Peripheral register structure */
typedef struct KPP_MemMap {
  uint16_t KPCR;                                   /**< Keypad Control Register, offset: 0x0 */
  uint16_t KPSR;                                   /**< Keypad Status Register, offset: 0x2 */
  uint16_t KDDR;                                   /**< Keypad Data Direction Register, offset: 0x4 */
  uint16_t KPDR;                                   /**< Keypad Data Register, offset: 0x6 */
} volatile *KPP_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- KPP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup KPP_Register_Accessor_Macros KPP - Register accessor macros
 * @{
 */


/* KPP - Register accessors */
#define KPP_KPCR_REG(base)                       ((base)->KPCR)
#define KPP_KPSR_REG(base)                       ((base)->KPSR)
#define KPP_KDDR_REG(base)                       ((base)->KDDR)
#define KPP_KPDR_REG(base)                       ((base)->KPDR)

/*!
 * @}
 */ /* end of group KPP_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- KPP Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup KPP_Register_Masks KPP Register Masks
 * @{
 */

/*! @name KPCR - Keypad Control Register */
#define KPP_KPCR_KRE_MASK                        (0xFFU)
#define KPP_KPCR_KRE_SHIFT                       (0U)
#define KPP_KPCR_KRE(x)                          (((uint16_t)(((uint16_t)(x)) << KPP_KPCR_KRE_SHIFT)) & KPP_KPCR_KRE_MASK)
#define KPP_KPCR_KCO_MASK                        (0xFF00U)
#define KPP_KPCR_KCO_SHIFT                       (8U)
#define KPP_KPCR_KCO(x)                          (((uint16_t)(((uint16_t)(x)) << KPP_KPCR_KCO_SHIFT)) & KPP_KPCR_KCO_MASK)

/*! @name KPSR - Keypad Status Register */
#define KPP_KPSR_KPKD_MASK                       (0x1U)
#define KPP_KPSR_KPKD_SHIFT                      (0U)
#define KPP_KPSR_KPKR_MASK                       (0x2U)
#define KPP_KPSR_KPKR_SHIFT                      (1U)
#define KPP_KPSR_KDSC_MASK                       (0x4U)
#define KPP_KPSR_KDSC_SHIFT                      (2U)
#define KPP_KPSR_KRSS_MASK                       (0x8U)
#define KPP_KPSR_KRSS_SHIFT                      (3U)
#define KPP_KPSR_KDIE_MASK                       (0x100U)
#define KPP_KPSR_KDIE_SHIFT                      (8U)
#define KPP_KPSR_KRIE_MASK                       (0x200U)
#define KPP_KPSR_KRIE_SHIFT                      (9U)

/*! @name KDDR - Keypad Data Direction Register */
#define KPP_KDDR_KRDD_MASK                       (0xFFU)
#define KPP_KDDR_KRDD_SHIFT                      (0U)
#define KPP_KDDR_KRDD(x)                         (((uint16_t)(((uint16_t)(x)) << KPP_KDDR_KRDD_SHIFT)) & KPP_KDDR_KRDD_MASK)
#define KPP_KDDR_KCDD_MASK                       (0xFF00U)
#define KPP_KDDR_KCDD_SHIFT                      (8U)
#define KPP_KDDR_KCDD(x)                         (((uint16_t)(((uint16_t)(x)) << KPP_KDDR_KCDD_SHIFT)) & KPP_KDDR_KCDD_MASK)

/*! @name KPDR - Keypad Data Register */
#define KPP_KPDR_KRD_MASK                        (0xFFU)
#define KPP_KPDR_KRD_SHIFT                       (0U)
#define KPP_KPDR_KRD(x)                          (((uint16_t)(((uint16_t)(x)) << KPP_KPDR_KRD_SHIFT)) & KPP_KPDR_KRD_MASK)
#define KPP_KPDR_KCD_MASK                        (0xFF00U)
#define KPP_KPDR_KCD_SHIFT                       (8U)
#define KPP_KPDR_KCD(x)                          (((uint16_t)(((uint16_t)(x)) << KPP_KPDR_KCD_SHIFT)) & KPP_KPDR_KCD_MASK)


/*!
 * @}
 */ /* end of group KPP_Register_Masks */


/* KPP - Peripheral instance base addresses */
/** Peripheral KPP base pointer */
#define KPP_BASE_PTR                             ((KPP_MemMapPtr)0x30320000u)
/** Array initializer of KPP peripheral base pointers */
#define KPP_BASE_PTRS                            { KPP_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- KPP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup KPP_Register_Accessor_Macros KPP - Register accessor macros
 * @{
 */


/* KPP - Register instance definitions */
/* KPP */
#define KPP_KPCR                                 KPP_KPCR_REG(KPP_BASE_PTR)
#define KPP_KPSR                                 KPP_KPSR_REG(KPP_BASE_PTR)
#define KPP_KDDR                                 KPP_KDDR_REG(KPP_BASE_PTR)
#define KPP_KPDR                                 KPP_KPDR_REG(KPP_BASE_PTR)

/*!
 * @}
 */ /* end of group KPP_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group KPP_Peripheral */


/* ----------------------------------------------------------------------------
   -- LCDIF
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LCDIF_Peripheral LCDIF
 * @{
 */

/** LCDIF - Peripheral register structure */
typedef struct LCDIF_MemMap {
  uint32_t CTRL;                                   /**< eLCDIF General Control Register, offset: 0x0 */
  uint32_t CTRL_SET;                               /**< eLCDIF General Control Register, offset: 0x4 */
  uint32_t CTRL_CLR;                               /**< eLCDIF General Control Register, offset: 0x8 */
  uint32_t CTRL_TOG;                               /**< eLCDIF General Control Register, offset: 0xC */
  uint32_t CTRL1;                                  /**< eLCDIF General Control1 Register, offset: 0x10 */
  uint32_t CTRL1_SET;                              /**< eLCDIF General Control1 Register, offset: 0x14 */
  uint32_t CTRL1_CLR;                              /**< eLCDIF General Control1 Register, offset: 0x18 */
  uint32_t CTRL1_TOG;                              /**< eLCDIF General Control1 Register, offset: 0x1C */
  uint32_t CTRL2;                                  /**< eLCDIF General Control2 Register, offset: 0x20 */
  uint32_t CTRL2_SET;                              /**< eLCDIF General Control2 Register, offset: 0x24 */
  uint32_t CTRL2_CLR;                              /**< eLCDIF General Control2 Register, offset: 0x28 */
  uint32_t CTRL2_TOG;                              /**< eLCDIF General Control2 Register, offset: 0x2C */
  uint32_t TRANSFER_COUNT;                         /**< eLCDIF Horizontal and Vertical Valid Data Count Register, offset: 0x30 */
  uint8_t RESERVED_0[12];
  uint32_t CUR_BUF;                                /**< LCD Interface Current Buffer Address Register, offset: 0x40 */
  uint8_t RESERVED_1[12];
  uint32_t NEXT_BUF;                               /**< LCD Interface Next Buffer Address Register, offset: 0x50 */
  uint8_t RESERVED_2[12];
  uint32_t TIMING;                                 /**< LCD Interface Timing Register, offset: 0x60 */
  uint8_t RESERVED_3[12];
  uint32_t VDCTRL0;                                /**< eLCDIF VSYNC Mode and Dotclk Mode Control Register0, offset: 0x70 */
  uint32_t VDCTRL0_SET;                            /**< eLCDIF VSYNC Mode and Dotclk Mode Control Register0, offset: 0x74 */
  uint32_t VDCTRL0_CLR;                            /**< eLCDIF VSYNC Mode and Dotclk Mode Control Register0, offset: 0x78 */
  uint32_t VDCTRL0_TOG;                            /**< eLCDIF VSYNC Mode and Dotclk Mode Control Register0, offset: 0x7C */
  uint32_t VDCTRL1;                                /**< eLCDIF VSYNC Mode and Dotclk Mode Control Register1, offset: 0x80 */
  uint8_t RESERVED_4[12];
  uint32_t VDCTRL2;                                /**< LCDIF VSYNC Mode and Dotclk Mode Control Register2, offset: 0x90 */
  uint8_t RESERVED_5[12];
  uint32_t VDCTRL3;                                /**< eLCDIF VSYNC Mode and Dotclk Mode Control Register3, offset: 0xA0 */
  uint8_t RESERVED_6[12];
  uint32_t VDCTRL4;                                /**< eLCDIF VSYNC Mode and Dotclk Mode Control Register4, offset: 0xB0 */
  uint8_t RESERVED_7[12];
  uint32_t DVICTRL0;                               /**< Digital Video Interface Control0 Register, offset: 0xC0 */
  uint8_t RESERVED_8[12];
  uint32_t DVICTRL1;                               /**< Digital Video Interface Control1 Register, offset: 0xD0 */
  uint8_t RESERVED_9[12];
  uint32_t DVICTRL2;                               /**< Digital Video Interface Control2 Register, offset: 0xE0 */
  uint8_t RESERVED_10[12];
  uint32_t DVICTRL3;                               /**< Digital Video Interface Control3 Register, offset: 0xF0 */
  uint8_t RESERVED_11[12];
  uint32_t DVICTRL4;                               /**< Digital Video Interface Control4 Register, offset: 0x100 */
  uint8_t RESERVED_12[12];
  uint32_t CSC_COEFF0;                             /**< RGB to YCbCr 4:2:2 CSC Coefficient0 Register, offset: 0x110 */
  uint8_t RESERVED_13[12];
  uint32_t CSC_COEFF1;                             /**< RGB to YCbCr 4:2:2 CSC Coefficient1 Register, offset: 0x120 */
  uint8_t RESERVED_14[12];
  uint32_t CSC_COEFF2;                             /**< RGB to YCbCr 4:2:2 CSC Coefficent2 Register, offset: 0x130 */
  uint8_t RESERVED_15[12];
  uint32_t CSC_COEFF3;                             /**< RGB to YCbCr 4:2:2 CSC Coefficient3 Register, offset: 0x140 */
  uint8_t RESERVED_16[12];
  uint32_t CSC_COEFF4;                             /**< RGB to YCbCr 4:2:2 CSC Coefficient4 Register, offset: 0x150 */
  uint8_t RESERVED_17[12];
  uint32_t CSC_OFFSET;                             /**< RGB to YCbCr 4:2:2 CSC Offset Register, offset: 0x160 */
  uint8_t RESERVED_18[12];
  uint32_t CSC_LIMIT;                              /**< RGB to YCbCr 4:2:2 CSC Limit Register, offset: 0x170 */
  uint8_t RESERVED_19[12];
  uint32_t DATA;                                   /**< LCD Interface Data Register, offset: 0x180 */
  uint8_t RESERVED_20[12];
  uint32_t BM_ERROR_STAT;                          /**< Bus Master Error Status Register, offset: 0x190 */
  uint8_t RESERVED_21[12];
  uint32_t CRC_STAT;                               /**< CRC Status Register, offset: 0x1A0 */
  uint8_t RESERVED_22[12];
  uint32_t STAT;                                   /**< LCD Interface Status Register, offset: 0x1B0 */
  uint8_t RESERVED_23[12];
  uint32_t VERSION;                                /**< LCD Interface Version Register, offset: 0x1C0 */
  uint8_t RESERVED_24[12];
  uint32_t DEBUG0;                                 /**< LCD Interface Debug0 Register, offset: 0x1D0 */
  uint8_t RESERVED_25[12];
  uint32_t DEBUG1;                                 /**< LCD Interface Debug1 Register, offset: 0x1E0 */
  uint8_t RESERVED_26[12];
  uint32_t DEBUG2;                                 /**< LCD Interface Debug2 Register, offset: 0x1F0 */
  uint8_t RESERVED_27[12];
  uint32_t THRES;                                  /**< eLCDIF Threshold Register, offset: 0x200 */
  uint8_t RESERVED_28[12];
  uint32_t AS_CTRL;                                /**< eLCDIF AS Buffer Control Register, offset: 0x210 */
  uint8_t RESERVED_29[12];
  uint32_t AS_BUF;                                 /**< Alpha Surface Buffer Pointer, offset: 0x220 */
  uint8_t RESERVED_30[12];
  uint32_t AS_NEXT_BUF;                            /**< , offset: 0x230 */
  uint8_t RESERVED_31[12];
  uint32_t AS_CLRKEYLOW;                           /**< eLCDIF Overlay Color Key Low, offset: 0x240 */
  uint8_t RESERVED_32[12];
  uint32_t AS_CLRKEYHIGH;                          /**< eLCDIF Overlay Color Key High, offset: 0x250 */
  uint8_t RESERVED_33[12];
  uint32_t SYNC_DELAY;                             /**< LCD working insync mode with CSI for VSYNC delay, offset: 0x260 */
  uint8_t RESERVED_34[12];
  uint32_t DEBUG3;                                 /**< eLCDIF Interface Debug3 Register, offset: 0x270 */
  uint8_t RESERVED_35[12];
  uint32_t DEBUG4;                                 /**< LCD Interface Debug4, offset: 0x280 */
  uint8_t RESERVED_36[12];
  uint32_t DEBUG5;                                 /**< LCD Interface Debug5, offset: 0x290 */
} volatile *LCDIF_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- LCDIF - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LCDIF_Register_Accessor_Macros LCDIF - Register accessor macros
 * @{
 */


/* LCDIF - Register accessors */
#define LCDIF_CTRL_REG(base)                     ((base)->CTRL)
#define LCDIF_CTRL_SET_REG(base)                 ((base)->CTRL_SET)
#define LCDIF_CTRL_CLR_REG(base)                 ((base)->CTRL_CLR)
#define LCDIF_CTRL_TOG_REG(base)                 ((base)->CTRL_TOG)
#define LCDIF_CTRL1_REG(base)                    ((base)->CTRL1)
#define LCDIF_CTRL1_SET_REG(base)                ((base)->CTRL1_SET)
#define LCDIF_CTRL1_CLR_REG(base)                ((base)->CTRL1_CLR)
#define LCDIF_CTRL1_TOG_REG(base)                ((base)->CTRL1_TOG)
#define LCDIF_CTRL2_REG(base)                    ((base)->CTRL2)
#define LCDIF_CTRL2_SET_REG(base)                ((base)->CTRL2_SET)
#define LCDIF_CTRL2_CLR_REG(base)                ((base)->CTRL2_CLR)
#define LCDIF_CTRL2_TOG_REG(base)                ((base)->CTRL2_TOG)
#define LCDIF_TRANSFER_COUNT_REG(base)           ((base)->TRANSFER_COUNT)
#define LCDIF_CUR_BUF_REG(base)                  ((base)->CUR_BUF)
#define LCDIF_NEXT_BUF_REG(base)                 ((base)->NEXT_BUF)
#define LCDIF_TIMING_REG(base)                   ((base)->TIMING)
#define LCDIF_VDCTRL0_REG(base)                  ((base)->VDCTRL0)
#define LCDIF_VDCTRL0_SET_REG(base)              ((base)->VDCTRL0_SET)
#define LCDIF_VDCTRL0_CLR_REG(base)              ((base)->VDCTRL0_CLR)
#define LCDIF_VDCTRL0_TOG_REG(base)              ((base)->VDCTRL0_TOG)
#define LCDIF_VDCTRL1_REG(base)                  ((base)->VDCTRL1)
#define LCDIF_VDCTRL2_REG(base)                  ((base)->VDCTRL2)
#define LCDIF_VDCTRL3_REG(base)                  ((base)->VDCTRL3)
#define LCDIF_VDCTRL4_REG(base)                  ((base)->VDCTRL4)
#define LCDIF_DVICTRL0_REG(base)                 ((base)->DVICTRL0)
#define LCDIF_DVICTRL1_REG(base)                 ((base)->DVICTRL1)
#define LCDIF_DVICTRL2_REG(base)                 ((base)->DVICTRL2)
#define LCDIF_DVICTRL3_REG(base)                 ((base)->DVICTRL3)
#define LCDIF_DVICTRL4_REG(base)                 ((base)->DVICTRL4)
#define LCDIF_CSC_COEFF0_REG(base)               ((base)->CSC_COEFF0)
#define LCDIF_CSC_COEFF1_REG(base)               ((base)->CSC_COEFF1)
#define LCDIF_CSC_COEFF2_REG(base)               ((base)->CSC_COEFF2)
#define LCDIF_CSC_COEFF3_REG(base)               ((base)->CSC_COEFF3)
#define LCDIF_CSC_COEFF4_REG(base)               ((base)->CSC_COEFF4)
#define LCDIF_CSC_OFFSET_REG(base)               ((base)->CSC_OFFSET)
#define LCDIF_CSC_LIMIT_REG(base)                ((base)->CSC_LIMIT)
#define LCDIF_DATA_REG(base)                     ((base)->DATA)
#define LCDIF_BM_ERROR_STAT_REG(base)            ((base)->BM_ERROR_STAT)
#define LCDIF_CRC_STAT_REG(base)                 ((base)->CRC_STAT)
#define LCDIF_STAT_REG(base)                     ((base)->STAT)
#define LCDIF_VERSION_REG(base)                  ((base)->VERSION)
#define LCDIF_DEBUG0_REG(base)                   ((base)->DEBUG0)
#define LCDIF_DEBUG1_REG(base)                   ((base)->DEBUG1)
#define LCDIF_DEBUG2_REG(base)                   ((base)->DEBUG2)
#define LCDIF_THRES_REG(base)                    ((base)->THRES)
#define LCDIF_AS_CTRL_REG(base)                  ((base)->AS_CTRL)
#define LCDIF_AS_BUF_REG(base)                   ((base)->AS_BUF)
#define LCDIF_AS_NEXT_BUF_REG(base)              ((base)->AS_NEXT_BUF)
#define LCDIF_AS_CLRKEYLOW_REG(base)             ((base)->AS_CLRKEYLOW)
#define LCDIF_AS_CLRKEYHIGH_REG(base)            ((base)->AS_CLRKEYHIGH)
#define LCDIF_SYNC_DELAY_REG(base)               ((base)->SYNC_DELAY)
#define LCDIF_DEBUG3_REG(base)                   ((base)->DEBUG3)
#define LCDIF_DEBUG4_REG(base)                   ((base)->DEBUG4)
#define LCDIF_DEBUG5_REG(base)                   ((base)->DEBUG5)

/*!
 * @}
 */ /* end of group LCDIF_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- LCDIF Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LCDIF_Register_Masks LCDIF Register Masks
 * @{
 */

/*! @name CTRL - eLCDIF General Control Register */
#define LCDIF_CTRL_RUN_MASK                      (0x1U)
#define LCDIF_CTRL_RUN_SHIFT                     (0U)
#define LCDIF_CTRL_DATA_FORMAT_24_BIT_MASK       (0x2U)
#define LCDIF_CTRL_DATA_FORMAT_24_BIT_SHIFT      (1U)
#define LCDIF_CTRL_DATA_FORMAT_18_BIT_MASK       (0x4U)
#define LCDIF_CTRL_DATA_FORMAT_18_BIT_SHIFT      (2U)
#define LCDIF_CTRL_DATA_FORMAT_16_BIT_MASK       (0x8U)
#define LCDIF_CTRL_DATA_FORMAT_16_BIT_SHIFT      (3U)
#define LCDIF_CTRL_RSRVD0_MASK                   (0x10U)
#define LCDIF_CTRL_RSRVD0_SHIFT                  (4U)
#define LCDIF_CTRL_MASTER_MASK                   (0x20U)
#define LCDIF_CTRL_MASTER_SHIFT                  (5U)
#define LCDIF_CTRL_ENABLE_PXP_HANDSHAKE_MASK     (0x40U)
#define LCDIF_CTRL_ENABLE_PXP_HANDSHAKE_SHIFT    (6U)
#define LCDIF_CTRL_RGB_TO_YCBCR422_CSC_MASK      (0x80U)
#define LCDIF_CTRL_RGB_TO_YCBCR422_CSC_SHIFT     (7U)
#define LCDIF_CTRL_WORD_LENGTH_MASK              (0x300U)
#define LCDIF_CTRL_WORD_LENGTH_SHIFT             (8U)
#define LCDIF_CTRL_WORD_LENGTH(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_WORD_LENGTH_SHIFT)) & LCDIF_CTRL_WORD_LENGTH_MASK)
#define LCDIF_CTRL_LCD_DATABUS_WIDTH_MASK        (0xC00U)
#define LCDIF_CTRL_LCD_DATABUS_WIDTH_SHIFT       (10U)
#define LCDIF_CTRL_LCD_DATABUS_WIDTH(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_LCD_DATABUS_WIDTH_SHIFT)) & LCDIF_CTRL_LCD_DATABUS_WIDTH_MASK)
#define LCDIF_CTRL_CSC_DATA_SWIZZLE_MASK         (0x3000U)
#define LCDIF_CTRL_CSC_DATA_SWIZZLE_SHIFT        (12U)
#define LCDIF_CTRL_CSC_DATA_SWIZZLE(x)           (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_CSC_DATA_SWIZZLE_SHIFT)) & LCDIF_CTRL_CSC_DATA_SWIZZLE_MASK)
#define LCDIF_CTRL_INPUT_DATA_SWIZZLE_MASK       (0xC000U)
#define LCDIF_CTRL_INPUT_DATA_SWIZZLE_SHIFT      (14U)
#define LCDIF_CTRL_INPUT_DATA_SWIZZLE(x)         (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_INPUT_DATA_SWIZZLE_SHIFT)) & LCDIF_CTRL_INPUT_DATA_SWIZZLE_MASK)
#define LCDIF_CTRL_DATA_SELECT_MASK              (0x10000U)
#define LCDIF_CTRL_DATA_SELECT_SHIFT             (16U)
#define LCDIF_CTRL_DOTCLK_MODE_MASK              (0x20000U)
#define LCDIF_CTRL_DOTCLK_MODE_SHIFT             (17U)
#define LCDIF_CTRL_VSYNC_MODE_MASK               (0x40000U)
#define LCDIF_CTRL_VSYNC_MODE_SHIFT              (18U)
#define LCDIF_CTRL_BYPASS_COUNT_MASK             (0x80000U)
#define LCDIF_CTRL_BYPASS_COUNT_SHIFT            (19U)
#define LCDIF_CTRL_DVI_MODE_MASK                 (0x100000U)
#define LCDIF_CTRL_DVI_MODE_SHIFT                (20U)
#define LCDIF_CTRL_SHIFT_NUM_BITS_MASK           (0x3E00000U)
#define LCDIF_CTRL_SHIFT_NUM_BITS_SHIFT          (21U)
#define LCDIF_CTRL_SHIFT_NUM_BITS(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_SHIFT_NUM_BITS_SHIFT)) & LCDIF_CTRL_SHIFT_NUM_BITS_MASK)
#define LCDIF_CTRL_DATA_SHIFT_DIR_MASK           (0x4000000U)
#define LCDIF_CTRL_DATA_SHIFT_DIR_SHIFT          (26U)
#define LCDIF_CTRL_WAIT_FOR_VSYNC_EDGE_MASK      (0x8000000U)
#define LCDIF_CTRL_WAIT_FOR_VSYNC_EDGE_SHIFT     (27U)
#define LCDIF_CTRL_READ_WRITEB_MASK              (0x10000000U)
#define LCDIF_CTRL_READ_WRITEB_SHIFT             (28U)
#define LCDIF_CTRL_YCBCR422_INPUT_MASK           (0x20000000U)
#define LCDIF_CTRL_YCBCR422_INPUT_SHIFT          (29U)
#define LCDIF_CTRL_CLKGATE_MASK                  (0x40000000U)
#define LCDIF_CTRL_CLKGATE_SHIFT                 (30U)
#define LCDIF_CTRL_SFTRST_MASK                   (0x80000000U)
#define LCDIF_CTRL_SFTRST_SHIFT                  (31U)

/*! @name CTRL_SET - eLCDIF General Control Register */
#define LCDIF_CTRL_SET_RUN_MASK                  (0x1U)
#define LCDIF_CTRL_SET_RUN_SHIFT                 (0U)
#define LCDIF_CTRL_SET_DATA_FORMAT_24_BIT_MASK   (0x2U)
#define LCDIF_CTRL_SET_DATA_FORMAT_24_BIT_SHIFT  (1U)
#define LCDIF_CTRL_SET_DATA_FORMAT_18_BIT_MASK   (0x4U)
#define LCDIF_CTRL_SET_DATA_FORMAT_18_BIT_SHIFT  (2U)
#define LCDIF_CTRL_SET_DATA_FORMAT_16_BIT_MASK   (0x8U)
#define LCDIF_CTRL_SET_DATA_FORMAT_16_BIT_SHIFT  (3U)
#define LCDIF_CTRL_SET_RSRVD0_MASK               (0x10U)
#define LCDIF_CTRL_SET_RSRVD0_SHIFT              (4U)
#define LCDIF_CTRL_SET_MASTER_MASK               (0x20U)
#define LCDIF_CTRL_SET_MASTER_SHIFT              (5U)
#define LCDIF_CTRL_SET_ENABLE_PXP_HANDSHAKE_MASK (0x40U)
#define LCDIF_CTRL_SET_ENABLE_PXP_HANDSHAKE_SHIFT (6U)
#define LCDIF_CTRL_SET_RGB_TO_YCBCR422_CSC_MASK  (0x80U)
#define LCDIF_CTRL_SET_RGB_TO_YCBCR422_CSC_SHIFT (7U)
#define LCDIF_CTRL_SET_WORD_LENGTH_MASK          (0x300U)
#define LCDIF_CTRL_SET_WORD_LENGTH_SHIFT         (8U)
#define LCDIF_CTRL_SET_WORD_LENGTH(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_SET_WORD_LENGTH_SHIFT)) & LCDIF_CTRL_SET_WORD_LENGTH_MASK)
#define LCDIF_CTRL_SET_LCD_DATABUS_WIDTH_MASK    (0xC00U)
#define LCDIF_CTRL_SET_LCD_DATABUS_WIDTH_SHIFT   (10U)
#define LCDIF_CTRL_SET_LCD_DATABUS_WIDTH(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_SET_LCD_DATABUS_WIDTH_SHIFT)) & LCDIF_CTRL_SET_LCD_DATABUS_WIDTH_MASK)
#define LCDIF_CTRL_SET_CSC_DATA_SWIZZLE_MASK     (0x3000U)
#define LCDIF_CTRL_SET_CSC_DATA_SWIZZLE_SHIFT    (12U)
#define LCDIF_CTRL_SET_CSC_DATA_SWIZZLE(x)       (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_SET_CSC_DATA_SWIZZLE_SHIFT)) & LCDIF_CTRL_SET_CSC_DATA_SWIZZLE_MASK)
#define LCDIF_CTRL_SET_INPUT_DATA_SWIZZLE_MASK   (0xC000U)
#define LCDIF_CTRL_SET_INPUT_DATA_SWIZZLE_SHIFT  (14U)
#define LCDIF_CTRL_SET_INPUT_DATA_SWIZZLE(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_SET_INPUT_DATA_SWIZZLE_SHIFT)) & LCDIF_CTRL_SET_INPUT_DATA_SWIZZLE_MASK)
#define LCDIF_CTRL_SET_DATA_SELECT_MASK          (0x10000U)
#define LCDIF_CTRL_SET_DATA_SELECT_SHIFT         (16U)
#define LCDIF_CTRL_SET_DOTCLK_MODE_MASK          (0x20000U)
#define LCDIF_CTRL_SET_DOTCLK_MODE_SHIFT         (17U)
#define LCDIF_CTRL_SET_VSYNC_MODE_MASK           (0x40000U)
#define LCDIF_CTRL_SET_VSYNC_MODE_SHIFT          (18U)
#define LCDIF_CTRL_SET_BYPASS_COUNT_MASK         (0x80000U)
#define LCDIF_CTRL_SET_BYPASS_COUNT_SHIFT        (19U)
#define LCDIF_CTRL_SET_DVI_MODE_MASK             (0x100000U)
#define LCDIF_CTRL_SET_DVI_MODE_SHIFT            (20U)
#define LCDIF_CTRL_SET_SHIFT_NUM_BITS_MASK       (0x3E00000U)
#define LCDIF_CTRL_SET_SHIFT_NUM_BITS_SHIFT      (21U)
#define LCDIF_CTRL_SET_SHIFT_NUM_BITS(x)         (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_SET_SHIFT_NUM_BITS_SHIFT)) & LCDIF_CTRL_SET_SHIFT_NUM_BITS_MASK)
#define LCDIF_CTRL_SET_DATA_SHIFT_DIR_MASK       (0x4000000U)
#define LCDIF_CTRL_SET_DATA_SHIFT_DIR_SHIFT      (26U)
#define LCDIF_CTRL_SET_WAIT_FOR_VSYNC_EDGE_MASK  (0x8000000U)
#define LCDIF_CTRL_SET_WAIT_FOR_VSYNC_EDGE_SHIFT (27U)
#define LCDIF_CTRL_SET_READ_WRITEB_MASK          (0x10000000U)
#define LCDIF_CTRL_SET_READ_WRITEB_SHIFT         (28U)
#define LCDIF_CTRL_SET_YCBCR422_INPUT_MASK       (0x20000000U)
#define LCDIF_CTRL_SET_YCBCR422_INPUT_SHIFT      (29U)
#define LCDIF_CTRL_SET_CLKGATE_MASK              (0x40000000U)
#define LCDIF_CTRL_SET_CLKGATE_SHIFT             (30U)
#define LCDIF_CTRL_SET_SFTRST_MASK               (0x80000000U)
#define LCDIF_CTRL_SET_SFTRST_SHIFT              (31U)

/*! @name CTRL_CLR - eLCDIF General Control Register */
#define LCDIF_CTRL_CLR_RUN_MASK                  (0x1U)
#define LCDIF_CTRL_CLR_RUN_SHIFT                 (0U)
#define LCDIF_CTRL_CLR_DATA_FORMAT_24_BIT_MASK   (0x2U)
#define LCDIF_CTRL_CLR_DATA_FORMAT_24_BIT_SHIFT  (1U)
#define LCDIF_CTRL_CLR_DATA_FORMAT_18_BIT_MASK   (0x4U)
#define LCDIF_CTRL_CLR_DATA_FORMAT_18_BIT_SHIFT  (2U)
#define LCDIF_CTRL_CLR_DATA_FORMAT_16_BIT_MASK   (0x8U)
#define LCDIF_CTRL_CLR_DATA_FORMAT_16_BIT_SHIFT  (3U)
#define LCDIF_CTRL_CLR_RSRVD0_MASK               (0x10U)
#define LCDIF_CTRL_CLR_RSRVD0_SHIFT              (4U)
#define LCDIF_CTRL_CLR_MASTER_MASK               (0x20U)
#define LCDIF_CTRL_CLR_MASTER_SHIFT              (5U)
#define LCDIF_CTRL_CLR_ENABLE_PXP_HANDSHAKE_MASK (0x40U)
#define LCDIF_CTRL_CLR_ENABLE_PXP_HANDSHAKE_SHIFT (6U)
#define LCDIF_CTRL_CLR_RGB_TO_YCBCR422_CSC_MASK  (0x80U)
#define LCDIF_CTRL_CLR_RGB_TO_YCBCR422_CSC_SHIFT (7U)
#define LCDIF_CTRL_CLR_WORD_LENGTH_MASK          (0x300U)
#define LCDIF_CTRL_CLR_WORD_LENGTH_SHIFT         (8U)
#define LCDIF_CTRL_CLR_WORD_LENGTH(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_CLR_WORD_LENGTH_SHIFT)) & LCDIF_CTRL_CLR_WORD_LENGTH_MASK)
#define LCDIF_CTRL_CLR_LCD_DATABUS_WIDTH_MASK    (0xC00U)
#define LCDIF_CTRL_CLR_LCD_DATABUS_WIDTH_SHIFT   (10U)
#define LCDIF_CTRL_CLR_LCD_DATABUS_WIDTH(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_CLR_LCD_DATABUS_WIDTH_SHIFT)) & LCDIF_CTRL_CLR_LCD_DATABUS_WIDTH_MASK)
#define LCDIF_CTRL_CLR_CSC_DATA_SWIZZLE_MASK     (0x3000U)
#define LCDIF_CTRL_CLR_CSC_DATA_SWIZZLE_SHIFT    (12U)
#define LCDIF_CTRL_CLR_CSC_DATA_SWIZZLE(x)       (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_CLR_CSC_DATA_SWIZZLE_SHIFT)) & LCDIF_CTRL_CLR_CSC_DATA_SWIZZLE_MASK)
#define LCDIF_CTRL_CLR_INPUT_DATA_SWIZZLE_MASK   (0xC000U)
#define LCDIF_CTRL_CLR_INPUT_DATA_SWIZZLE_SHIFT  (14U)
#define LCDIF_CTRL_CLR_INPUT_DATA_SWIZZLE(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_CLR_INPUT_DATA_SWIZZLE_SHIFT)) & LCDIF_CTRL_CLR_INPUT_DATA_SWIZZLE_MASK)
#define LCDIF_CTRL_CLR_DATA_SELECT_MASK          (0x10000U)
#define LCDIF_CTRL_CLR_DATA_SELECT_SHIFT         (16U)
#define LCDIF_CTRL_CLR_DOTCLK_MODE_MASK          (0x20000U)
#define LCDIF_CTRL_CLR_DOTCLK_MODE_SHIFT         (17U)
#define LCDIF_CTRL_CLR_VSYNC_MODE_MASK           (0x40000U)
#define LCDIF_CTRL_CLR_VSYNC_MODE_SHIFT          (18U)
#define LCDIF_CTRL_CLR_BYPASS_COUNT_MASK         (0x80000U)
#define LCDIF_CTRL_CLR_BYPASS_COUNT_SHIFT        (19U)
#define LCDIF_CTRL_CLR_DVI_MODE_MASK             (0x100000U)
#define LCDIF_CTRL_CLR_DVI_MODE_SHIFT            (20U)
#define LCDIF_CTRL_CLR_SHIFT_NUM_BITS_MASK       (0x3E00000U)
#define LCDIF_CTRL_CLR_SHIFT_NUM_BITS_SHIFT      (21U)
#define LCDIF_CTRL_CLR_SHIFT_NUM_BITS(x)         (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_CLR_SHIFT_NUM_BITS_SHIFT)) & LCDIF_CTRL_CLR_SHIFT_NUM_BITS_MASK)
#define LCDIF_CTRL_CLR_DATA_SHIFT_DIR_MASK       (0x4000000U)
#define LCDIF_CTRL_CLR_DATA_SHIFT_DIR_SHIFT      (26U)
#define LCDIF_CTRL_CLR_WAIT_FOR_VSYNC_EDGE_MASK  (0x8000000U)
#define LCDIF_CTRL_CLR_WAIT_FOR_VSYNC_EDGE_SHIFT (27U)
#define LCDIF_CTRL_CLR_READ_WRITEB_MASK          (0x10000000U)
#define LCDIF_CTRL_CLR_READ_WRITEB_SHIFT         (28U)
#define LCDIF_CTRL_CLR_YCBCR422_INPUT_MASK       (0x20000000U)
#define LCDIF_CTRL_CLR_YCBCR422_INPUT_SHIFT      (29U)
#define LCDIF_CTRL_CLR_CLKGATE_MASK              (0x40000000U)
#define LCDIF_CTRL_CLR_CLKGATE_SHIFT             (30U)
#define LCDIF_CTRL_CLR_SFTRST_MASK               (0x80000000U)
#define LCDIF_CTRL_CLR_SFTRST_SHIFT              (31U)

/*! @name CTRL_TOG - eLCDIF General Control Register */
#define LCDIF_CTRL_TOG_RUN_MASK                  (0x1U)
#define LCDIF_CTRL_TOG_RUN_SHIFT                 (0U)
#define LCDIF_CTRL_TOG_DATA_FORMAT_24_BIT_MASK   (0x2U)
#define LCDIF_CTRL_TOG_DATA_FORMAT_24_BIT_SHIFT  (1U)
#define LCDIF_CTRL_TOG_DATA_FORMAT_18_BIT_MASK   (0x4U)
#define LCDIF_CTRL_TOG_DATA_FORMAT_18_BIT_SHIFT  (2U)
#define LCDIF_CTRL_TOG_DATA_FORMAT_16_BIT_MASK   (0x8U)
#define LCDIF_CTRL_TOG_DATA_FORMAT_16_BIT_SHIFT  (3U)
#define LCDIF_CTRL_TOG_RSRVD0_MASK               (0x10U)
#define LCDIF_CTRL_TOG_RSRVD0_SHIFT              (4U)
#define LCDIF_CTRL_TOG_MASTER_MASK               (0x20U)
#define LCDIF_CTRL_TOG_MASTER_SHIFT              (5U)
#define LCDIF_CTRL_TOG_ENABLE_PXP_HANDSHAKE_MASK (0x40U)
#define LCDIF_CTRL_TOG_ENABLE_PXP_HANDSHAKE_SHIFT (6U)
#define LCDIF_CTRL_TOG_RGB_TO_YCBCR422_CSC_MASK  (0x80U)
#define LCDIF_CTRL_TOG_RGB_TO_YCBCR422_CSC_SHIFT (7U)
#define LCDIF_CTRL_TOG_WORD_LENGTH_MASK          (0x300U)
#define LCDIF_CTRL_TOG_WORD_LENGTH_SHIFT         (8U)
#define LCDIF_CTRL_TOG_WORD_LENGTH(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_TOG_WORD_LENGTH_SHIFT)) & LCDIF_CTRL_TOG_WORD_LENGTH_MASK)
#define LCDIF_CTRL_TOG_LCD_DATABUS_WIDTH_MASK    (0xC00U)
#define LCDIF_CTRL_TOG_LCD_DATABUS_WIDTH_SHIFT   (10U)
#define LCDIF_CTRL_TOG_LCD_DATABUS_WIDTH(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_TOG_LCD_DATABUS_WIDTH_SHIFT)) & LCDIF_CTRL_TOG_LCD_DATABUS_WIDTH_MASK)
#define LCDIF_CTRL_TOG_CSC_DATA_SWIZZLE_MASK     (0x3000U)
#define LCDIF_CTRL_TOG_CSC_DATA_SWIZZLE_SHIFT    (12U)
#define LCDIF_CTRL_TOG_CSC_DATA_SWIZZLE(x)       (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_TOG_CSC_DATA_SWIZZLE_SHIFT)) & LCDIF_CTRL_TOG_CSC_DATA_SWIZZLE_MASK)
#define LCDIF_CTRL_TOG_INPUT_DATA_SWIZZLE_MASK   (0xC000U)
#define LCDIF_CTRL_TOG_INPUT_DATA_SWIZZLE_SHIFT  (14U)
#define LCDIF_CTRL_TOG_INPUT_DATA_SWIZZLE(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_TOG_INPUT_DATA_SWIZZLE_SHIFT)) & LCDIF_CTRL_TOG_INPUT_DATA_SWIZZLE_MASK)
#define LCDIF_CTRL_TOG_DATA_SELECT_MASK          (0x10000U)
#define LCDIF_CTRL_TOG_DATA_SELECT_SHIFT         (16U)
#define LCDIF_CTRL_TOG_DOTCLK_MODE_MASK          (0x20000U)
#define LCDIF_CTRL_TOG_DOTCLK_MODE_SHIFT         (17U)
#define LCDIF_CTRL_TOG_VSYNC_MODE_MASK           (0x40000U)
#define LCDIF_CTRL_TOG_VSYNC_MODE_SHIFT          (18U)
#define LCDIF_CTRL_TOG_BYPASS_COUNT_MASK         (0x80000U)
#define LCDIF_CTRL_TOG_BYPASS_COUNT_SHIFT        (19U)
#define LCDIF_CTRL_TOG_DVI_MODE_MASK             (0x100000U)
#define LCDIF_CTRL_TOG_DVI_MODE_SHIFT            (20U)
#define LCDIF_CTRL_TOG_SHIFT_NUM_BITS_MASK       (0x3E00000U)
#define LCDIF_CTRL_TOG_SHIFT_NUM_BITS_SHIFT      (21U)
#define LCDIF_CTRL_TOG_SHIFT_NUM_BITS(x)         (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL_TOG_SHIFT_NUM_BITS_SHIFT)) & LCDIF_CTRL_TOG_SHIFT_NUM_BITS_MASK)
#define LCDIF_CTRL_TOG_DATA_SHIFT_DIR_MASK       (0x4000000U)
#define LCDIF_CTRL_TOG_DATA_SHIFT_DIR_SHIFT      (26U)
#define LCDIF_CTRL_TOG_WAIT_FOR_VSYNC_EDGE_MASK  (0x8000000U)
#define LCDIF_CTRL_TOG_WAIT_FOR_VSYNC_EDGE_SHIFT (27U)
#define LCDIF_CTRL_TOG_READ_WRITEB_MASK          (0x10000000U)
#define LCDIF_CTRL_TOG_READ_WRITEB_SHIFT         (28U)
#define LCDIF_CTRL_TOG_YCBCR422_INPUT_MASK       (0x20000000U)
#define LCDIF_CTRL_TOG_YCBCR422_INPUT_SHIFT      (29U)
#define LCDIF_CTRL_TOG_CLKGATE_MASK              (0x40000000U)
#define LCDIF_CTRL_TOG_CLKGATE_SHIFT             (30U)
#define LCDIF_CTRL_TOG_SFTRST_MASK               (0x80000000U)
#define LCDIF_CTRL_TOG_SFTRST_SHIFT              (31U)

/*! @name CTRL1 - eLCDIF General Control1 Register */
#define LCDIF_CTRL1_RESET_MASK                   (0x1U)
#define LCDIF_CTRL1_RESET_SHIFT                  (0U)
#define LCDIF_CTRL1_MODE86_MASK                  (0x2U)
#define LCDIF_CTRL1_MODE86_SHIFT                 (1U)
#define LCDIF_CTRL1_BUSY_ENABLE_MASK             (0x4U)
#define LCDIF_CTRL1_BUSY_ENABLE_SHIFT            (2U)
#define LCDIF_CTRL1_RSRVD0_MASK                  (0xF8U)
#define LCDIF_CTRL1_RSRVD0_SHIFT                 (3U)
#define LCDIF_CTRL1_RSRVD0(x)                    (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_RSRVD0_SHIFT)) & LCDIF_CTRL1_RSRVD0_MASK)
#define LCDIF_CTRL1_VSYNC_EDGE_IRQ_MASK          (0x100U)
#define LCDIF_CTRL1_VSYNC_EDGE_IRQ_SHIFT         (8U)
#define LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_MASK      (0x200U)
#define LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_SHIFT     (9U)
#define LCDIF_CTRL1_UNDERFLOW_IRQ_MASK           (0x400U)
#define LCDIF_CTRL1_UNDERFLOW_IRQ_SHIFT          (10U)
#define LCDIF_CTRL1_OVERFLOW_IRQ_MASK            (0x800U)
#define LCDIF_CTRL1_OVERFLOW_IRQ_SHIFT           (11U)
#define LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN_MASK       (0x1000U)
#define LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN_SHIFT      (12U)
#define LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN_MASK   (0x2000U)
#define LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN_SHIFT  (13U)
#define LCDIF_CTRL1_UNDERFLOW_IRQ_EN_MASK        (0x4000U)
#define LCDIF_CTRL1_UNDERFLOW_IRQ_EN_SHIFT       (14U)
#define LCDIF_CTRL1_OVERFLOW_IRQ_EN_MASK         (0x8000U)
#define LCDIF_CTRL1_OVERFLOW_IRQ_EN_SHIFT        (15U)
#define LCDIF_CTRL1_BYTE_PACKING_FORMAT_MASK     (0xF0000U)
#define LCDIF_CTRL1_BYTE_PACKING_FORMAT_SHIFT    (16U)
#define LCDIF_CTRL1_BYTE_PACKING_FORMAT(x)       (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_BYTE_PACKING_FORMAT_SHIFT)) & LCDIF_CTRL1_BYTE_PACKING_FORMAT_MASK)
#define LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS_MASK (0x100000U)
#define LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS_SHIFT (20U)
#define LCDIF_CTRL1_FIFO_CLEAR_MASK              (0x200000U)
#define LCDIF_CTRL1_FIFO_CLEAR_SHIFT             (21U)
#define LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD_MASK (0x400000U)
#define LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD_SHIFT (22U)
#define LCDIF_CTRL1_INTERLACE_FIELDS_MASK        (0x800000U)
#define LCDIF_CTRL1_INTERLACE_FIELDS_SHIFT       (23U)
#define LCDIF_CTRL1_RECOVER_ON_UNDERFLOW_MASK    (0x1000000U)
#define LCDIF_CTRL1_RECOVER_ON_UNDERFLOW_SHIFT   (24U)
#define LCDIF_CTRL1_BM_ERROR_IRQ_MASK            (0x2000000U)
#define LCDIF_CTRL1_BM_ERROR_IRQ_SHIFT           (25U)
#define LCDIF_CTRL1_BM_ERROR_IRQ_EN_MASK         (0x4000000U)
#define LCDIF_CTRL1_BM_ERROR_IRQ_EN_SHIFT        (26U)
#define LCDIF_CTRL1_COMBINE_MPU_WR_STRB_MASK     (0x8000000U)
#define LCDIF_CTRL1_COMBINE_MPU_WR_STRB_SHIFT    (27U)
#define LCDIF_CTRL1_RSRVD1_MASK                  (0xF0000000U)
#define LCDIF_CTRL1_RSRVD1_SHIFT                 (28U)
#define LCDIF_CTRL1_RSRVD1(x)                    (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_RSRVD1_SHIFT)) & LCDIF_CTRL1_RSRVD1_MASK)

/*! @name CTRL1_SET - eLCDIF General Control1 Register */
#define LCDIF_CTRL1_SET_RESET_MASK               (0x1U)
#define LCDIF_CTRL1_SET_RESET_SHIFT              (0U)
#define LCDIF_CTRL1_SET_MODE86_MASK              (0x2U)
#define LCDIF_CTRL1_SET_MODE86_SHIFT             (1U)
#define LCDIF_CTRL1_SET_BUSY_ENABLE_MASK         (0x4U)
#define LCDIF_CTRL1_SET_BUSY_ENABLE_SHIFT        (2U)
#define LCDIF_CTRL1_SET_RSRVD0_MASK              (0xF8U)
#define LCDIF_CTRL1_SET_RSRVD0_SHIFT             (3U)
#define LCDIF_CTRL1_SET_RSRVD0(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_SET_RSRVD0_SHIFT)) & LCDIF_CTRL1_SET_RSRVD0_MASK)
#define LCDIF_CTRL1_SET_VSYNC_EDGE_IRQ_MASK      (0x100U)
#define LCDIF_CTRL1_SET_VSYNC_EDGE_IRQ_SHIFT     (8U)
#define LCDIF_CTRL1_SET_CUR_FRAME_DONE_IRQ_MASK  (0x200U)
#define LCDIF_CTRL1_SET_CUR_FRAME_DONE_IRQ_SHIFT (9U)
#define LCDIF_CTRL1_SET_UNDERFLOW_IRQ_MASK       (0x400U)
#define LCDIF_CTRL1_SET_UNDERFLOW_IRQ_SHIFT      (10U)
#define LCDIF_CTRL1_SET_OVERFLOW_IRQ_MASK        (0x800U)
#define LCDIF_CTRL1_SET_OVERFLOW_IRQ_SHIFT       (11U)
#define LCDIF_CTRL1_SET_VSYNC_EDGE_IRQ_EN_MASK   (0x1000U)
#define LCDIF_CTRL1_SET_VSYNC_EDGE_IRQ_EN_SHIFT  (12U)
#define LCDIF_CTRL1_SET_CUR_FRAME_DONE_IRQ_EN_MASK (0x2000U)
#define LCDIF_CTRL1_SET_CUR_FRAME_DONE_IRQ_EN_SHIFT (13U)
#define LCDIF_CTRL1_SET_UNDERFLOW_IRQ_EN_MASK    (0x4000U)
#define LCDIF_CTRL1_SET_UNDERFLOW_IRQ_EN_SHIFT   (14U)
#define LCDIF_CTRL1_SET_OVERFLOW_IRQ_EN_MASK     (0x8000U)
#define LCDIF_CTRL1_SET_OVERFLOW_IRQ_EN_SHIFT    (15U)
#define LCDIF_CTRL1_SET_BYTE_PACKING_FORMAT_MASK (0xF0000U)
#define LCDIF_CTRL1_SET_BYTE_PACKING_FORMAT_SHIFT (16U)
#define LCDIF_CTRL1_SET_BYTE_PACKING_FORMAT(x)   (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_SET_BYTE_PACKING_FORMAT_SHIFT)) & LCDIF_CTRL1_SET_BYTE_PACKING_FORMAT_MASK)
#define LCDIF_CTRL1_SET_IRQ_ON_ALTERNATE_FIELDS_MASK (0x100000U)
#define LCDIF_CTRL1_SET_IRQ_ON_ALTERNATE_FIELDS_SHIFT (20U)
#define LCDIF_CTRL1_SET_FIFO_CLEAR_MASK          (0x200000U)
#define LCDIF_CTRL1_SET_FIFO_CLEAR_SHIFT         (21U)
#define LCDIF_CTRL1_SET_START_INTERLACE_FROM_SECOND_FIELD_MASK (0x400000U)
#define LCDIF_CTRL1_SET_START_INTERLACE_FROM_SECOND_FIELD_SHIFT (22U)
#define LCDIF_CTRL1_SET_INTERLACE_FIELDS_MASK    (0x800000U)
#define LCDIF_CTRL1_SET_INTERLACE_FIELDS_SHIFT   (23U)
#define LCDIF_CTRL1_SET_RECOVER_ON_UNDERFLOW_MASK (0x1000000U)
#define LCDIF_CTRL1_SET_RECOVER_ON_UNDERFLOW_SHIFT (24U)
#define LCDIF_CTRL1_SET_BM_ERROR_IRQ_MASK        (0x2000000U)
#define LCDIF_CTRL1_SET_BM_ERROR_IRQ_SHIFT       (25U)
#define LCDIF_CTRL1_SET_BM_ERROR_IRQ_EN_MASK     (0x4000000U)
#define LCDIF_CTRL1_SET_BM_ERROR_IRQ_EN_SHIFT    (26U)
#define LCDIF_CTRL1_SET_COMBINE_MPU_WR_STRB_MASK (0x8000000U)
#define LCDIF_CTRL1_SET_COMBINE_MPU_WR_STRB_SHIFT (27U)
#define LCDIF_CTRL1_SET_RSRVD1_MASK              (0xF0000000U)
#define LCDIF_CTRL1_SET_RSRVD1_SHIFT             (28U)
#define LCDIF_CTRL1_SET_RSRVD1(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_SET_RSRVD1_SHIFT)) & LCDIF_CTRL1_SET_RSRVD1_MASK)

/*! @name CTRL1_CLR - eLCDIF General Control1 Register */
#define LCDIF_CTRL1_CLR_RESET_MASK               (0x1U)
#define LCDIF_CTRL1_CLR_RESET_SHIFT              (0U)
#define LCDIF_CTRL1_CLR_MODE86_MASK              (0x2U)
#define LCDIF_CTRL1_CLR_MODE86_SHIFT             (1U)
#define LCDIF_CTRL1_CLR_BUSY_ENABLE_MASK         (0x4U)
#define LCDIF_CTRL1_CLR_BUSY_ENABLE_SHIFT        (2U)
#define LCDIF_CTRL1_CLR_RSRVD0_MASK              (0xF8U)
#define LCDIF_CTRL1_CLR_RSRVD0_SHIFT             (3U)
#define LCDIF_CTRL1_CLR_RSRVD0(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_CLR_RSRVD0_SHIFT)) & LCDIF_CTRL1_CLR_RSRVD0_MASK)
#define LCDIF_CTRL1_CLR_VSYNC_EDGE_IRQ_MASK      (0x100U)
#define LCDIF_CTRL1_CLR_VSYNC_EDGE_IRQ_SHIFT     (8U)
#define LCDIF_CTRL1_CLR_CUR_FRAME_DONE_IRQ_MASK  (0x200U)
#define LCDIF_CTRL1_CLR_CUR_FRAME_DONE_IRQ_SHIFT (9U)
#define LCDIF_CTRL1_CLR_UNDERFLOW_IRQ_MASK       (0x400U)
#define LCDIF_CTRL1_CLR_UNDERFLOW_IRQ_SHIFT      (10U)
#define LCDIF_CTRL1_CLR_OVERFLOW_IRQ_MASK        (0x800U)
#define LCDIF_CTRL1_CLR_OVERFLOW_IRQ_SHIFT       (11U)
#define LCDIF_CTRL1_CLR_VSYNC_EDGE_IRQ_EN_MASK   (0x1000U)
#define LCDIF_CTRL1_CLR_VSYNC_EDGE_IRQ_EN_SHIFT  (12U)
#define LCDIF_CTRL1_CLR_CUR_FRAME_DONE_IRQ_EN_MASK (0x2000U)
#define LCDIF_CTRL1_CLR_CUR_FRAME_DONE_IRQ_EN_SHIFT (13U)
#define LCDIF_CTRL1_CLR_UNDERFLOW_IRQ_EN_MASK    (0x4000U)
#define LCDIF_CTRL1_CLR_UNDERFLOW_IRQ_EN_SHIFT   (14U)
#define LCDIF_CTRL1_CLR_OVERFLOW_IRQ_EN_MASK     (0x8000U)
#define LCDIF_CTRL1_CLR_OVERFLOW_IRQ_EN_SHIFT    (15U)
#define LCDIF_CTRL1_CLR_BYTE_PACKING_FORMAT_MASK (0xF0000U)
#define LCDIF_CTRL1_CLR_BYTE_PACKING_FORMAT_SHIFT (16U)
#define LCDIF_CTRL1_CLR_BYTE_PACKING_FORMAT(x)   (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_CLR_BYTE_PACKING_FORMAT_SHIFT)) & LCDIF_CTRL1_CLR_BYTE_PACKING_FORMAT_MASK)
#define LCDIF_CTRL1_CLR_IRQ_ON_ALTERNATE_FIELDS_MASK (0x100000U)
#define LCDIF_CTRL1_CLR_IRQ_ON_ALTERNATE_FIELDS_SHIFT (20U)
#define LCDIF_CTRL1_CLR_FIFO_CLEAR_MASK          (0x200000U)
#define LCDIF_CTRL1_CLR_FIFO_CLEAR_SHIFT         (21U)
#define LCDIF_CTRL1_CLR_START_INTERLACE_FROM_SECOND_FIELD_MASK (0x400000U)
#define LCDIF_CTRL1_CLR_START_INTERLACE_FROM_SECOND_FIELD_SHIFT (22U)
#define LCDIF_CTRL1_CLR_INTERLACE_FIELDS_MASK    (0x800000U)
#define LCDIF_CTRL1_CLR_INTERLACE_FIELDS_SHIFT   (23U)
#define LCDIF_CTRL1_CLR_RECOVER_ON_UNDERFLOW_MASK (0x1000000U)
#define LCDIF_CTRL1_CLR_RECOVER_ON_UNDERFLOW_SHIFT (24U)
#define LCDIF_CTRL1_CLR_BM_ERROR_IRQ_MASK        (0x2000000U)
#define LCDIF_CTRL1_CLR_BM_ERROR_IRQ_SHIFT       (25U)
#define LCDIF_CTRL1_CLR_BM_ERROR_IRQ_EN_MASK     (0x4000000U)
#define LCDIF_CTRL1_CLR_BM_ERROR_IRQ_EN_SHIFT    (26U)
#define LCDIF_CTRL1_CLR_COMBINE_MPU_WR_STRB_MASK (0x8000000U)
#define LCDIF_CTRL1_CLR_COMBINE_MPU_WR_STRB_SHIFT (27U)
#define LCDIF_CTRL1_CLR_RSRVD1_MASK              (0xF0000000U)
#define LCDIF_CTRL1_CLR_RSRVD1_SHIFT             (28U)
#define LCDIF_CTRL1_CLR_RSRVD1(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_CLR_RSRVD1_SHIFT)) & LCDIF_CTRL1_CLR_RSRVD1_MASK)

/*! @name CTRL1_TOG - eLCDIF General Control1 Register */
#define LCDIF_CTRL1_TOG_RESET_MASK               (0x1U)
#define LCDIF_CTRL1_TOG_RESET_SHIFT              (0U)
#define LCDIF_CTRL1_TOG_MODE86_MASK              (0x2U)
#define LCDIF_CTRL1_TOG_MODE86_SHIFT             (1U)
#define LCDIF_CTRL1_TOG_BUSY_ENABLE_MASK         (0x4U)
#define LCDIF_CTRL1_TOG_BUSY_ENABLE_SHIFT        (2U)
#define LCDIF_CTRL1_TOG_RSRVD0_MASK              (0xF8U)
#define LCDIF_CTRL1_TOG_RSRVD0_SHIFT             (3U)
#define LCDIF_CTRL1_TOG_RSRVD0(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_TOG_RSRVD0_SHIFT)) & LCDIF_CTRL1_TOG_RSRVD0_MASK)
#define LCDIF_CTRL1_TOG_VSYNC_EDGE_IRQ_MASK      (0x100U)
#define LCDIF_CTRL1_TOG_VSYNC_EDGE_IRQ_SHIFT     (8U)
#define LCDIF_CTRL1_TOG_CUR_FRAME_DONE_IRQ_MASK  (0x200U)
#define LCDIF_CTRL1_TOG_CUR_FRAME_DONE_IRQ_SHIFT (9U)
#define LCDIF_CTRL1_TOG_UNDERFLOW_IRQ_MASK       (0x400U)
#define LCDIF_CTRL1_TOG_UNDERFLOW_IRQ_SHIFT      (10U)
#define LCDIF_CTRL1_TOG_OVERFLOW_IRQ_MASK        (0x800U)
#define LCDIF_CTRL1_TOG_OVERFLOW_IRQ_SHIFT       (11U)
#define LCDIF_CTRL1_TOG_VSYNC_EDGE_IRQ_EN_MASK   (0x1000U)
#define LCDIF_CTRL1_TOG_VSYNC_EDGE_IRQ_EN_SHIFT  (12U)
#define LCDIF_CTRL1_TOG_CUR_FRAME_DONE_IRQ_EN_MASK (0x2000U)
#define LCDIF_CTRL1_TOG_CUR_FRAME_DONE_IRQ_EN_SHIFT (13U)
#define LCDIF_CTRL1_TOG_UNDERFLOW_IRQ_EN_MASK    (0x4000U)
#define LCDIF_CTRL1_TOG_UNDERFLOW_IRQ_EN_SHIFT   (14U)
#define LCDIF_CTRL1_TOG_OVERFLOW_IRQ_EN_MASK     (0x8000U)
#define LCDIF_CTRL1_TOG_OVERFLOW_IRQ_EN_SHIFT    (15U)
#define LCDIF_CTRL1_TOG_BYTE_PACKING_FORMAT_MASK (0xF0000U)
#define LCDIF_CTRL1_TOG_BYTE_PACKING_FORMAT_SHIFT (16U)
#define LCDIF_CTRL1_TOG_BYTE_PACKING_FORMAT(x)   (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_TOG_BYTE_PACKING_FORMAT_SHIFT)) & LCDIF_CTRL1_TOG_BYTE_PACKING_FORMAT_MASK)
#define LCDIF_CTRL1_TOG_IRQ_ON_ALTERNATE_FIELDS_MASK (0x100000U)
#define LCDIF_CTRL1_TOG_IRQ_ON_ALTERNATE_FIELDS_SHIFT (20U)
#define LCDIF_CTRL1_TOG_FIFO_CLEAR_MASK          (0x200000U)
#define LCDIF_CTRL1_TOG_FIFO_CLEAR_SHIFT         (21U)
#define LCDIF_CTRL1_TOG_START_INTERLACE_FROM_SECOND_FIELD_MASK (0x400000U)
#define LCDIF_CTRL1_TOG_START_INTERLACE_FROM_SECOND_FIELD_SHIFT (22U)
#define LCDIF_CTRL1_TOG_INTERLACE_FIELDS_MASK    (0x800000U)
#define LCDIF_CTRL1_TOG_INTERLACE_FIELDS_SHIFT   (23U)
#define LCDIF_CTRL1_TOG_RECOVER_ON_UNDERFLOW_MASK (0x1000000U)
#define LCDIF_CTRL1_TOG_RECOVER_ON_UNDERFLOW_SHIFT (24U)
#define LCDIF_CTRL1_TOG_BM_ERROR_IRQ_MASK        (0x2000000U)
#define LCDIF_CTRL1_TOG_BM_ERROR_IRQ_SHIFT       (25U)
#define LCDIF_CTRL1_TOG_BM_ERROR_IRQ_EN_MASK     (0x4000000U)
#define LCDIF_CTRL1_TOG_BM_ERROR_IRQ_EN_SHIFT    (26U)
#define LCDIF_CTRL1_TOG_COMBINE_MPU_WR_STRB_MASK (0x8000000U)
#define LCDIF_CTRL1_TOG_COMBINE_MPU_WR_STRB_SHIFT (27U)
#define LCDIF_CTRL1_TOG_RSRVD1_MASK              (0xF0000000U)
#define LCDIF_CTRL1_TOG_RSRVD1_SHIFT             (28U)
#define LCDIF_CTRL1_TOG_RSRVD1(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL1_TOG_RSRVD1_SHIFT)) & LCDIF_CTRL1_TOG_RSRVD1_MASK)

/*! @name CTRL2 - eLCDIF General Control2 Register */
#define LCDIF_CTRL2_RSRVD0_MASK                  (0x1U)
#define LCDIF_CTRL2_RSRVD0_SHIFT                 (0U)
#define LCDIF_CTRL2_INITIAL_DUMMY_READ_MASK      (0xEU)
#define LCDIF_CTRL2_INITIAL_DUMMY_READ_SHIFT     (1U)
#define LCDIF_CTRL2_INITIAL_DUMMY_READ(x)        (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_INITIAL_DUMMY_READ_SHIFT)) & LCDIF_CTRL2_INITIAL_DUMMY_READ_MASK)
#define LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS_MASK (0x70U)
#define LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS_SHIFT (4U)
#define LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(x) (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS_SHIFT)) & LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS_MASK)
#define LCDIF_CTRL2_RSRVD1_MASK                  (0x80U)
#define LCDIF_CTRL2_RSRVD1_SHIFT                 (7U)
#define LCDIF_CTRL2_READ_MODE_6_BIT_INPUT_MASK   (0x100U)
#define LCDIF_CTRL2_READ_MODE_6_BIT_INPUT_SHIFT  (8U)
#define LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT_MASK (0x200U)
#define LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT_SHIFT (9U)
#define LCDIF_CTRL2_READ_PACK_DIR_MASK           (0x400U)
#define LCDIF_CTRL2_READ_PACK_DIR_SHIFT          (10U)
#define LCDIF_CTRL2_RSRVD2_MASK                  (0x800U)
#define LCDIF_CTRL2_RSRVD2_SHIFT                 (11U)
#define LCDIF_CTRL2_EVEN_LINE_PATTERN_MASK       (0x7000U)
#define LCDIF_CTRL2_EVEN_LINE_PATTERN_SHIFT      (12U)
#define LCDIF_CTRL2_EVEN_LINE_PATTERN(x)         (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_EVEN_LINE_PATTERN_SHIFT)) & LCDIF_CTRL2_EVEN_LINE_PATTERN_MASK)
#define LCDIF_CTRL2_RSRVD3_MASK                  (0x8000U)
#define LCDIF_CTRL2_RSRVD3_SHIFT                 (15U)
#define LCDIF_CTRL2_ODD_LINE_PATTERN_MASK        (0x70000U)
#define LCDIF_CTRL2_ODD_LINE_PATTERN_SHIFT       (16U)
#define LCDIF_CTRL2_ODD_LINE_PATTERN(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_ODD_LINE_PATTERN_SHIFT)) & LCDIF_CTRL2_ODD_LINE_PATTERN_MASK)
#define LCDIF_CTRL2_RSRVD4_MASK                  (0x80000U)
#define LCDIF_CTRL2_RSRVD4_SHIFT                 (19U)
#define LCDIF_CTRL2_BURST_LEN_8_MASK             (0x100000U)
#define LCDIF_CTRL2_BURST_LEN_8_SHIFT            (20U)
#define LCDIF_CTRL2_OUTSTANDING_REQS_MASK        (0xE00000U)
#define LCDIF_CTRL2_OUTSTANDING_REQS_SHIFT       (21U)
#define LCDIF_CTRL2_OUTSTANDING_REQS(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_OUTSTANDING_REQS_SHIFT)) & LCDIF_CTRL2_OUTSTANDING_REQS_MASK)
#define LCDIF_CTRL2_RSRVD5_MASK                  (0xFF000000U)
#define LCDIF_CTRL2_RSRVD5_SHIFT                 (24U)
#define LCDIF_CTRL2_RSRVD5(x)                    (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_RSRVD5_SHIFT)) & LCDIF_CTRL2_RSRVD5_MASK)

/*! @name CTRL2_SET - eLCDIF General Control2 Register */
#define LCDIF_CTRL2_SET_RSRVD0_MASK              (0x1U)
#define LCDIF_CTRL2_SET_RSRVD0_SHIFT             (0U)
#define LCDIF_CTRL2_SET_INITIAL_DUMMY_READ_MASK  (0xEU)
#define LCDIF_CTRL2_SET_INITIAL_DUMMY_READ_SHIFT (1U)
#define LCDIF_CTRL2_SET_INITIAL_DUMMY_READ(x)    (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_SET_INITIAL_DUMMY_READ_SHIFT)) & LCDIF_CTRL2_SET_INITIAL_DUMMY_READ_MASK)
#define LCDIF_CTRL2_SET_READ_MODE_NUM_PACKED_SUBWORDS_MASK (0x70U)
#define LCDIF_CTRL2_SET_READ_MODE_NUM_PACKED_SUBWORDS_SHIFT (4U)
#define LCDIF_CTRL2_SET_READ_MODE_NUM_PACKED_SUBWORDS(x) (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_SET_READ_MODE_NUM_PACKED_SUBWORDS_SHIFT)) & LCDIF_CTRL2_SET_READ_MODE_NUM_PACKED_SUBWORDS_MASK)
#define LCDIF_CTRL2_SET_RSRVD1_MASK              (0x80U)
#define LCDIF_CTRL2_SET_RSRVD1_SHIFT             (7U)
#define LCDIF_CTRL2_SET_READ_MODE_6_BIT_INPUT_MASK (0x100U)
#define LCDIF_CTRL2_SET_READ_MODE_6_BIT_INPUT_SHIFT (8U)
#define LCDIF_CTRL2_SET_READ_MODE_OUTPUT_IN_RGB_FORMAT_MASK (0x200U)
#define LCDIF_CTRL2_SET_READ_MODE_OUTPUT_IN_RGB_FORMAT_SHIFT (9U)
#define LCDIF_CTRL2_SET_READ_PACK_DIR_MASK       (0x400U)
#define LCDIF_CTRL2_SET_READ_PACK_DIR_SHIFT      (10U)
#define LCDIF_CTRL2_SET_RSRVD2_MASK              (0x800U)
#define LCDIF_CTRL2_SET_RSRVD2_SHIFT             (11U)
#define LCDIF_CTRL2_SET_EVEN_LINE_PATTERN_MASK   (0x7000U)
#define LCDIF_CTRL2_SET_EVEN_LINE_PATTERN_SHIFT  (12U)
#define LCDIF_CTRL2_SET_EVEN_LINE_PATTERN(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_SET_EVEN_LINE_PATTERN_SHIFT)) & LCDIF_CTRL2_SET_EVEN_LINE_PATTERN_MASK)
#define LCDIF_CTRL2_SET_RSRVD3_MASK              (0x8000U)
#define LCDIF_CTRL2_SET_RSRVD3_SHIFT             (15U)
#define LCDIF_CTRL2_SET_ODD_LINE_PATTERN_MASK    (0x70000U)
#define LCDIF_CTRL2_SET_ODD_LINE_PATTERN_SHIFT   (16U)
#define LCDIF_CTRL2_SET_ODD_LINE_PATTERN(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_SET_ODD_LINE_PATTERN_SHIFT)) & LCDIF_CTRL2_SET_ODD_LINE_PATTERN_MASK)
#define LCDIF_CTRL2_SET_RSRVD4_MASK              (0x80000U)
#define LCDIF_CTRL2_SET_RSRVD4_SHIFT             (19U)
#define LCDIF_CTRL2_SET_BURST_LEN_8_MASK         (0x100000U)
#define LCDIF_CTRL2_SET_BURST_LEN_8_SHIFT        (20U)
#define LCDIF_CTRL2_SET_OUTSTANDING_REQS_MASK    (0xE00000U)
#define LCDIF_CTRL2_SET_OUTSTANDING_REQS_SHIFT   (21U)
#define LCDIF_CTRL2_SET_OUTSTANDING_REQS(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_SET_OUTSTANDING_REQS_SHIFT)) & LCDIF_CTRL2_SET_OUTSTANDING_REQS_MASK)
#define LCDIF_CTRL2_SET_RSRVD5_MASK              (0xFF000000U)
#define LCDIF_CTRL2_SET_RSRVD5_SHIFT             (24U)
#define LCDIF_CTRL2_SET_RSRVD5(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_SET_RSRVD5_SHIFT)) & LCDIF_CTRL2_SET_RSRVD5_MASK)

/*! @name CTRL2_CLR - eLCDIF General Control2 Register */
#define LCDIF_CTRL2_CLR_RSRVD0_MASK              (0x1U)
#define LCDIF_CTRL2_CLR_RSRVD0_SHIFT             (0U)
#define LCDIF_CTRL2_CLR_INITIAL_DUMMY_READ_MASK  (0xEU)
#define LCDIF_CTRL2_CLR_INITIAL_DUMMY_READ_SHIFT (1U)
#define LCDIF_CTRL2_CLR_INITIAL_DUMMY_READ(x)    (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_CLR_INITIAL_DUMMY_READ_SHIFT)) & LCDIF_CTRL2_CLR_INITIAL_DUMMY_READ_MASK)
#define LCDIF_CTRL2_CLR_READ_MODE_NUM_PACKED_SUBWORDS_MASK (0x70U)
#define LCDIF_CTRL2_CLR_READ_MODE_NUM_PACKED_SUBWORDS_SHIFT (4U)
#define LCDIF_CTRL2_CLR_READ_MODE_NUM_PACKED_SUBWORDS(x) (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_CLR_READ_MODE_NUM_PACKED_SUBWORDS_SHIFT)) & LCDIF_CTRL2_CLR_READ_MODE_NUM_PACKED_SUBWORDS_MASK)
#define LCDIF_CTRL2_CLR_RSRVD1_MASK              (0x80U)
#define LCDIF_CTRL2_CLR_RSRVD1_SHIFT             (7U)
#define LCDIF_CTRL2_CLR_READ_MODE_6_BIT_INPUT_MASK (0x100U)
#define LCDIF_CTRL2_CLR_READ_MODE_6_BIT_INPUT_SHIFT (8U)
#define LCDIF_CTRL2_CLR_READ_MODE_OUTPUT_IN_RGB_FORMAT_MASK (0x200U)
#define LCDIF_CTRL2_CLR_READ_MODE_OUTPUT_IN_RGB_FORMAT_SHIFT (9U)
#define LCDIF_CTRL2_CLR_READ_PACK_DIR_MASK       (0x400U)
#define LCDIF_CTRL2_CLR_READ_PACK_DIR_SHIFT      (10U)
#define LCDIF_CTRL2_CLR_RSRVD2_MASK              (0x800U)
#define LCDIF_CTRL2_CLR_RSRVD2_SHIFT             (11U)
#define LCDIF_CTRL2_CLR_EVEN_LINE_PATTERN_MASK   (0x7000U)
#define LCDIF_CTRL2_CLR_EVEN_LINE_PATTERN_SHIFT  (12U)
#define LCDIF_CTRL2_CLR_EVEN_LINE_PATTERN(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_CLR_EVEN_LINE_PATTERN_SHIFT)) & LCDIF_CTRL2_CLR_EVEN_LINE_PATTERN_MASK)
#define LCDIF_CTRL2_CLR_RSRVD3_MASK              (0x8000U)
#define LCDIF_CTRL2_CLR_RSRVD3_SHIFT             (15U)
#define LCDIF_CTRL2_CLR_ODD_LINE_PATTERN_MASK    (0x70000U)
#define LCDIF_CTRL2_CLR_ODD_LINE_PATTERN_SHIFT   (16U)
#define LCDIF_CTRL2_CLR_ODD_LINE_PATTERN(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_CLR_ODD_LINE_PATTERN_SHIFT)) & LCDIF_CTRL2_CLR_ODD_LINE_PATTERN_MASK)
#define LCDIF_CTRL2_CLR_RSRVD4_MASK              (0x80000U)
#define LCDIF_CTRL2_CLR_RSRVD4_SHIFT             (19U)
#define LCDIF_CTRL2_CLR_BURST_LEN_8_MASK         (0x100000U)
#define LCDIF_CTRL2_CLR_BURST_LEN_8_SHIFT        (20U)
#define LCDIF_CTRL2_CLR_OUTSTANDING_REQS_MASK    (0xE00000U)
#define LCDIF_CTRL2_CLR_OUTSTANDING_REQS_SHIFT   (21U)
#define LCDIF_CTRL2_CLR_OUTSTANDING_REQS(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_CLR_OUTSTANDING_REQS_SHIFT)) & LCDIF_CTRL2_CLR_OUTSTANDING_REQS_MASK)
#define LCDIF_CTRL2_CLR_RSRVD5_MASK              (0xFF000000U)
#define LCDIF_CTRL2_CLR_RSRVD5_SHIFT             (24U)
#define LCDIF_CTRL2_CLR_RSRVD5(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_CLR_RSRVD5_SHIFT)) & LCDIF_CTRL2_CLR_RSRVD5_MASK)

/*! @name CTRL2_TOG - eLCDIF General Control2 Register */
#define LCDIF_CTRL2_TOG_RSRVD0_MASK              (0x1U)
#define LCDIF_CTRL2_TOG_RSRVD0_SHIFT             (0U)
#define LCDIF_CTRL2_TOG_INITIAL_DUMMY_READ_MASK  (0xEU)
#define LCDIF_CTRL2_TOG_INITIAL_DUMMY_READ_SHIFT (1U)
#define LCDIF_CTRL2_TOG_INITIAL_DUMMY_READ(x)    (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_TOG_INITIAL_DUMMY_READ_SHIFT)) & LCDIF_CTRL2_TOG_INITIAL_DUMMY_READ_MASK)
#define LCDIF_CTRL2_TOG_READ_MODE_NUM_PACKED_SUBWORDS_MASK (0x70U)
#define LCDIF_CTRL2_TOG_READ_MODE_NUM_PACKED_SUBWORDS_SHIFT (4U)
#define LCDIF_CTRL2_TOG_READ_MODE_NUM_PACKED_SUBWORDS(x) (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_TOG_READ_MODE_NUM_PACKED_SUBWORDS_SHIFT)) & LCDIF_CTRL2_TOG_READ_MODE_NUM_PACKED_SUBWORDS_MASK)
#define LCDIF_CTRL2_TOG_RSRVD1_MASK              (0x80U)
#define LCDIF_CTRL2_TOG_RSRVD1_SHIFT             (7U)
#define LCDIF_CTRL2_TOG_READ_MODE_6_BIT_INPUT_MASK (0x100U)
#define LCDIF_CTRL2_TOG_READ_MODE_6_BIT_INPUT_SHIFT (8U)
#define LCDIF_CTRL2_TOG_READ_MODE_OUTPUT_IN_RGB_FORMAT_MASK (0x200U)
#define LCDIF_CTRL2_TOG_READ_MODE_OUTPUT_IN_RGB_FORMAT_SHIFT (9U)
#define LCDIF_CTRL2_TOG_READ_PACK_DIR_MASK       (0x400U)
#define LCDIF_CTRL2_TOG_READ_PACK_DIR_SHIFT      (10U)
#define LCDIF_CTRL2_TOG_RSRVD2_MASK              (0x800U)
#define LCDIF_CTRL2_TOG_RSRVD2_SHIFT             (11U)
#define LCDIF_CTRL2_TOG_EVEN_LINE_PATTERN_MASK   (0x7000U)
#define LCDIF_CTRL2_TOG_EVEN_LINE_PATTERN_SHIFT  (12U)
#define LCDIF_CTRL2_TOG_EVEN_LINE_PATTERN(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_TOG_EVEN_LINE_PATTERN_SHIFT)) & LCDIF_CTRL2_TOG_EVEN_LINE_PATTERN_MASK)
#define LCDIF_CTRL2_TOG_RSRVD3_MASK              (0x8000U)
#define LCDIF_CTRL2_TOG_RSRVD3_SHIFT             (15U)
#define LCDIF_CTRL2_TOG_ODD_LINE_PATTERN_MASK    (0x70000U)
#define LCDIF_CTRL2_TOG_ODD_LINE_PATTERN_SHIFT   (16U)
#define LCDIF_CTRL2_TOG_ODD_LINE_PATTERN(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_TOG_ODD_LINE_PATTERN_SHIFT)) & LCDIF_CTRL2_TOG_ODD_LINE_PATTERN_MASK)
#define LCDIF_CTRL2_TOG_RSRVD4_MASK              (0x80000U)
#define LCDIF_CTRL2_TOG_RSRVD4_SHIFT             (19U)
#define LCDIF_CTRL2_TOG_BURST_LEN_8_MASK         (0x100000U)
#define LCDIF_CTRL2_TOG_BURST_LEN_8_SHIFT        (20U)
#define LCDIF_CTRL2_TOG_OUTSTANDING_REQS_MASK    (0xE00000U)
#define LCDIF_CTRL2_TOG_OUTSTANDING_REQS_SHIFT   (21U)
#define LCDIF_CTRL2_TOG_OUTSTANDING_REQS(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_TOG_OUTSTANDING_REQS_SHIFT)) & LCDIF_CTRL2_TOG_OUTSTANDING_REQS_MASK)
#define LCDIF_CTRL2_TOG_RSRVD5_MASK              (0xFF000000U)
#define LCDIF_CTRL2_TOG_RSRVD5_SHIFT             (24U)
#define LCDIF_CTRL2_TOG_RSRVD5(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_CTRL2_TOG_RSRVD5_SHIFT)) & LCDIF_CTRL2_TOG_RSRVD5_MASK)

/*! @name TRANSFER_COUNT - eLCDIF Horizontal and Vertical Valid Data Count Register */
#define LCDIF_TRANSFER_COUNT_H_COUNT_MASK        (0xFFFFU)
#define LCDIF_TRANSFER_COUNT_H_COUNT_SHIFT       (0U)
#define LCDIF_TRANSFER_COUNT_H_COUNT(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_TRANSFER_COUNT_H_COUNT_SHIFT)) & LCDIF_TRANSFER_COUNT_H_COUNT_MASK)
#define LCDIF_TRANSFER_COUNT_V_COUNT_MASK        (0xFFFF0000U)
#define LCDIF_TRANSFER_COUNT_V_COUNT_SHIFT       (16U)
#define LCDIF_TRANSFER_COUNT_V_COUNT(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_TRANSFER_COUNT_V_COUNT_SHIFT)) & LCDIF_TRANSFER_COUNT_V_COUNT_MASK)

/*! @name CUR_BUF - LCD Interface Current Buffer Address Register */
#define LCDIF_CUR_BUF_ADDR_MASK                  (0xFFFFFFFFU)
#define LCDIF_CUR_BUF_ADDR_SHIFT                 (0U)
#define LCDIF_CUR_BUF_ADDR(x)                    (((uint32_t)(((uint32_t)(x)) << LCDIF_CUR_BUF_ADDR_SHIFT)) & LCDIF_CUR_BUF_ADDR_MASK)

/*! @name NEXT_BUF - LCD Interface Next Buffer Address Register */
#define LCDIF_NEXT_BUF_ADDR_MASK                 (0xFFFFFFFFU)
#define LCDIF_NEXT_BUF_ADDR_SHIFT                (0U)
#define LCDIF_NEXT_BUF_ADDR(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_NEXT_BUF_ADDR_SHIFT)) & LCDIF_NEXT_BUF_ADDR_MASK)

/*! @name TIMING - LCD Interface Timing Register */
#define LCDIF_TIMING_DATA_SETUP_MASK             (0xFFU)
#define LCDIF_TIMING_DATA_SETUP_SHIFT            (0U)
#define LCDIF_TIMING_DATA_SETUP(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_TIMING_DATA_SETUP_SHIFT)) & LCDIF_TIMING_DATA_SETUP_MASK)
#define LCDIF_TIMING_DATA_HOLD_MASK              (0xFF00U)
#define LCDIF_TIMING_DATA_HOLD_SHIFT             (8U)
#define LCDIF_TIMING_DATA_HOLD(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_TIMING_DATA_HOLD_SHIFT)) & LCDIF_TIMING_DATA_HOLD_MASK)
#define LCDIF_TIMING_CMD_SETUP_MASK              (0xFF0000U)
#define LCDIF_TIMING_CMD_SETUP_SHIFT             (16U)
#define LCDIF_TIMING_CMD_SETUP(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_TIMING_CMD_SETUP_SHIFT)) & LCDIF_TIMING_CMD_SETUP_MASK)
#define LCDIF_TIMING_CMD_HOLD_MASK               (0xFF000000U)
#define LCDIF_TIMING_CMD_HOLD_SHIFT              (24U)
#define LCDIF_TIMING_CMD_HOLD(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_TIMING_CMD_HOLD_SHIFT)) & LCDIF_TIMING_CMD_HOLD_MASK)

/*! @name VDCTRL0 - eLCDIF VSYNC Mode and Dotclk Mode Control Register0 */
#define LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_MASK     (0x3FFFFU)
#define LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_SHIFT    (0U)
#define LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(x)       (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_SHIFT)) & LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_MASK)
#define LCDIF_VDCTRL0_HALF_LINE_MODE_MASK        (0x40000U)
#define LCDIF_VDCTRL0_HALF_LINE_MODE_SHIFT       (18U)
#define LCDIF_VDCTRL0_HALF_LINE_MASK             (0x80000U)
#define LCDIF_VDCTRL0_HALF_LINE_SHIFT            (19U)
#define LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT_MASK (0x100000U)
#define LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT_SHIFT (20U)
#define LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT_MASK     (0x200000U)
#define LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT_SHIFT    (21U)
#define LCDIF_VDCTRL0_RSRVD1_MASK                (0xC00000U)
#define LCDIF_VDCTRL0_RSRVD1_SHIFT               (22U)
#define LCDIF_VDCTRL0_RSRVD1(x)                  (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_RSRVD1_SHIFT)) & LCDIF_VDCTRL0_RSRVD1_MASK)
#define LCDIF_VDCTRL0_ENABLE_POL_MASK            (0x1000000U)
#define LCDIF_VDCTRL0_ENABLE_POL_SHIFT           (24U)
#define LCDIF_VDCTRL0_DOTCLK_POL_MASK            (0x2000000U)
#define LCDIF_VDCTRL0_DOTCLK_POL_SHIFT           (25U)
#define LCDIF_VDCTRL0_HSYNC_POL_MASK             (0x4000000U)
#define LCDIF_VDCTRL0_HSYNC_POL_SHIFT            (26U)
#define LCDIF_VDCTRL0_VSYNC_POL_MASK             (0x8000000U)
#define LCDIF_VDCTRL0_VSYNC_POL_SHIFT            (27U)
#define LCDIF_VDCTRL0_ENABLE_PRESENT_MASK        (0x10000000U)
#define LCDIF_VDCTRL0_ENABLE_PRESENT_SHIFT       (28U)
#define LCDIF_VDCTRL0_VSYNC_OEB_MASK             (0x20000000U)
#define LCDIF_VDCTRL0_VSYNC_OEB_SHIFT            (29U)
#define LCDIF_VDCTRL0_RSRVD2_MASK                (0xC0000000U)
#define LCDIF_VDCTRL0_RSRVD2_SHIFT               (30U)
#define LCDIF_VDCTRL0_RSRVD2(x)                  (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_RSRVD2_SHIFT)) & LCDIF_VDCTRL0_RSRVD2_MASK)

/*! @name VDCTRL0_SET - eLCDIF VSYNC Mode and Dotclk Mode Control Register0 */
#define LCDIF_VDCTRL0_SET_VSYNC_PULSE_WIDTH_MASK (0x3FFFFU)
#define LCDIF_VDCTRL0_SET_VSYNC_PULSE_WIDTH_SHIFT (0U)
#define LCDIF_VDCTRL0_SET_VSYNC_PULSE_WIDTH(x)   (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_SET_VSYNC_PULSE_WIDTH_SHIFT)) & LCDIF_VDCTRL0_SET_VSYNC_PULSE_WIDTH_MASK)
#define LCDIF_VDCTRL0_SET_HALF_LINE_MODE_MASK    (0x40000U)
#define LCDIF_VDCTRL0_SET_HALF_LINE_MODE_SHIFT   (18U)
#define LCDIF_VDCTRL0_SET_HALF_LINE_MASK         (0x80000U)
#define LCDIF_VDCTRL0_SET_HALF_LINE_SHIFT        (19U)
#define LCDIF_VDCTRL0_SET_VSYNC_PULSE_WIDTH_UNIT_MASK (0x100000U)
#define LCDIF_VDCTRL0_SET_VSYNC_PULSE_WIDTH_UNIT_SHIFT (20U)
#define LCDIF_VDCTRL0_SET_VSYNC_PERIOD_UNIT_MASK (0x200000U)
#define LCDIF_VDCTRL0_SET_VSYNC_PERIOD_UNIT_SHIFT (21U)
#define LCDIF_VDCTRL0_SET_RSRVD1_MASK            (0xC00000U)
#define LCDIF_VDCTRL0_SET_RSRVD1_SHIFT           (22U)
#define LCDIF_VDCTRL0_SET_RSRVD1(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_SET_RSRVD1_SHIFT)) & LCDIF_VDCTRL0_SET_RSRVD1_MASK)
#define LCDIF_VDCTRL0_SET_ENABLE_POL_MASK        (0x1000000U)
#define LCDIF_VDCTRL0_SET_ENABLE_POL_SHIFT       (24U)
#define LCDIF_VDCTRL0_SET_DOTCLK_POL_MASK        (0x2000000U)
#define LCDIF_VDCTRL0_SET_DOTCLK_POL_SHIFT       (25U)
#define LCDIF_VDCTRL0_SET_HSYNC_POL_MASK         (0x4000000U)
#define LCDIF_VDCTRL0_SET_HSYNC_POL_SHIFT        (26U)
#define LCDIF_VDCTRL0_SET_VSYNC_POL_MASK         (0x8000000U)
#define LCDIF_VDCTRL0_SET_VSYNC_POL_SHIFT        (27U)
#define LCDIF_VDCTRL0_SET_ENABLE_PRESENT_MASK    (0x10000000U)
#define LCDIF_VDCTRL0_SET_ENABLE_PRESENT_SHIFT   (28U)
#define LCDIF_VDCTRL0_SET_VSYNC_OEB_MASK         (0x20000000U)
#define LCDIF_VDCTRL0_SET_VSYNC_OEB_SHIFT        (29U)
#define LCDIF_VDCTRL0_SET_RSRVD2_MASK            (0xC0000000U)
#define LCDIF_VDCTRL0_SET_RSRVD2_SHIFT           (30U)
#define LCDIF_VDCTRL0_SET_RSRVD2(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_SET_RSRVD2_SHIFT)) & LCDIF_VDCTRL0_SET_RSRVD2_MASK)

/*! @name VDCTRL0_CLR - eLCDIF VSYNC Mode and Dotclk Mode Control Register0 */
#define LCDIF_VDCTRL0_CLR_VSYNC_PULSE_WIDTH_MASK (0x3FFFFU)
#define LCDIF_VDCTRL0_CLR_VSYNC_PULSE_WIDTH_SHIFT (0U)
#define LCDIF_VDCTRL0_CLR_VSYNC_PULSE_WIDTH(x)   (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_CLR_VSYNC_PULSE_WIDTH_SHIFT)) & LCDIF_VDCTRL0_CLR_VSYNC_PULSE_WIDTH_MASK)
#define LCDIF_VDCTRL0_CLR_HALF_LINE_MODE_MASK    (0x40000U)
#define LCDIF_VDCTRL0_CLR_HALF_LINE_MODE_SHIFT   (18U)
#define LCDIF_VDCTRL0_CLR_HALF_LINE_MASK         (0x80000U)
#define LCDIF_VDCTRL0_CLR_HALF_LINE_SHIFT        (19U)
#define LCDIF_VDCTRL0_CLR_VSYNC_PULSE_WIDTH_UNIT_MASK (0x100000U)
#define LCDIF_VDCTRL0_CLR_VSYNC_PULSE_WIDTH_UNIT_SHIFT (20U)
#define LCDIF_VDCTRL0_CLR_VSYNC_PERIOD_UNIT_MASK (0x200000U)
#define LCDIF_VDCTRL0_CLR_VSYNC_PERIOD_UNIT_SHIFT (21U)
#define LCDIF_VDCTRL0_CLR_RSRVD1_MASK            (0xC00000U)
#define LCDIF_VDCTRL0_CLR_RSRVD1_SHIFT           (22U)
#define LCDIF_VDCTRL0_CLR_RSRVD1(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_CLR_RSRVD1_SHIFT)) & LCDIF_VDCTRL0_CLR_RSRVD1_MASK)
#define LCDIF_VDCTRL0_CLR_ENABLE_POL_MASK        (0x1000000U)
#define LCDIF_VDCTRL0_CLR_ENABLE_POL_SHIFT       (24U)
#define LCDIF_VDCTRL0_CLR_DOTCLK_POL_MASK        (0x2000000U)
#define LCDIF_VDCTRL0_CLR_DOTCLK_POL_SHIFT       (25U)
#define LCDIF_VDCTRL0_CLR_HSYNC_POL_MASK         (0x4000000U)
#define LCDIF_VDCTRL0_CLR_HSYNC_POL_SHIFT        (26U)
#define LCDIF_VDCTRL0_CLR_VSYNC_POL_MASK         (0x8000000U)
#define LCDIF_VDCTRL0_CLR_VSYNC_POL_SHIFT        (27U)
#define LCDIF_VDCTRL0_CLR_ENABLE_PRESENT_MASK    (0x10000000U)
#define LCDIF_VDCTRL0_CLR_ENABLE_PRESENT_SHIFT   (28U)
#define LCDIF_VDCTRL0_CLR_VSYNC_OEB_MASK         (0x20000000U)
#define LCDIF_VDCTRL0_CLR_VSYNC_OEB_SHIFT        (29U)
#define LCDIF_VDCTRL0_CLR_RSRVD2_MASK            (0xC0000000U)
#define LCDIF_VDCTRL0_CLR_RSRVD2_SHIFT           (30U)
#define LCDIF_VDCTRL0_CLR_RSRVD2(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_CLR_RSRVD2_SHIFT)) & LCDIF_VDCTRL0_CLR_RSRVD2_MASK)

/*! @name VDCTRL0_TOG - eLCDIF VSYNC Mode and Dotclk Mode Control Register0 */
#define LCDIF_VDCTRL0_TOG_VSYNC_PULSE_WIDTH_MASK (0x3FFFFU)
#define LCDIF_VDCTRL0_TOG_VSYNC_PULSE_WIDTH_SHIFT (0U)
#define LCDIF_VDCTRL0_TOG_VSYNC_PULSE_WIDTH(x)   (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_TOG_VSYNC_PULSE_WIDTH_SHIFT)) & LCDIF_VDCTRL0_TOG_VSYNC_PULSE_WIDTH_MASK)
#define LCDIF_VDCTRL0_TOG_HALF_LINE_MODE_MASK    (0x40000U)
#define LCDIF_VDCTRL0_TOG_HALF_LINE_MODE_SHIFT   (18U)
#define LCDIF_VDCTRL0_TOG_HALF_LINE_MASK         (0x80000U)
#define LCDIF_VDCTRL0_TOG_HALF_LINE_SHIFT        (19U)
#define LCDIF_VDCTRL0_TOG_VSYNC_PULSE_WIDTH_UNIT_MASK (0x100000U)
#define LCDIF_VDCTRL0_TOG_VSYNC_PULSE_WIDTH_UNIT_SHIFT (20U)
#define LCDIF_VDCTRL0_TOG_VSYNC_PERIOD_UNIT_MASK (0x200000U)
#define LCDIF_VDCTRL0_TOG_VSYNC_PERIOD_UNIT_SHIFT (21U)
#define LCDIF_VDCTRL0_TOG_RSRVD1_MASK            (0xC00000U)
#define LCDIF_VDCTRL0_TOG_RSRVD1_SHIFT           (22U)
#define LCDIF_VDCTRL0_TOG_RSRVD1(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_TOG_RSRVD1_SHIFT)) & LCDIF_VDCTRL0_TOG_RSRVD1_MASK)
#define LCDIF_VDCTRL0_TOG_ENABLE_POL_MASK        (0x1000000U)
#define LCDIF_VDCTRL0_TOG_ENABLE_POL_SHIFT       (24U)
#define LCDIF_VDCTRL0_TOG_DOTCLK_POL_MASK        (0x2000000U)
#define LCDIF_VDCTRL0_TOG_DOTCLK_POL_SHIFT       (25U)
#define LCDIF_VDCTRL0_TOG_HSYNC_POL_MASK         (0x4000000U)
#define LCDIF_VDCTRL0_TOG_HSYNC_POL_SHIFT        (26U)
#define LCDIF_VDCTRL0_TOG_VSYNC_POL_MASK         (0x8000000U)
#define LCDIF_VDCTRL0_TOG_VSYNC_POL_SHIFT        (27U)
#define LCDIF_VDCTRL0_TOG_ENABLE_PRESENT_MASK    (0x10000000U)
#define LCDIF_VDCTRL0_TOG_ENABLE_PRESENT_SHIFT   (28U)
#define LCDIF_VDCTRL0_TOG_VSYNC_OEB_MASK         (0x20000000U)
#define LCDIF_VDCTRL0_TOG_VSYNC_OEB_SHIFT        (29U)
#define LCDIF_VDCTRL0_TOG_RSRVD2_MASK            (0xC0000000U)
#define LCDIF_VDCTRL0_TOG_RSRVD2_SHIFT           (30U)
#define LCDIF_VDCTRL0_TOG_RSRVD2(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL0_TOG_RSRVD2_SHIFT)) & LCDIF_VDCTRL0_TOG_RSRVD2_MASK)

/*! @name VDCTRL1 - eLCDIF VSYNC Mode and Dotclk Mode Control Register1 */
#define LCDIF_VDCTRL1_VSYNC_PERIOD_MASK          (0xFFFFFFFFU)
#define LCDIF_VDCTRL1_VSYNC_PERIOD_SHIFT         (0U)
#define LCDIF_VDCTRL1_VSYNC_PERIOD(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL1_VSYNC_PERIOD_SHIFT)) & LCDIF_VDCTRL1_VSYNC_PERIOD_MASK)

/*! @name VDCTRL2 - LCDIF VSYNC Mode and Dotclk Mode Control Register2 */
#define LCDIF_VDCTRL2_HSYNC_PERIOD_MASK          (0x3FFFFU)
#define LCDIF_VDCTRL2_HSYNC_PERIOD_SHIFT         (0U)
#define LCDIF_VDCTRL2_HSYNC_PERIOD(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL2_HSYNC_PERIOD_SHIFT)) & LCDIF_VDCTRL2_HSYNC_PERIOD_MASK)
#define LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH_MASK     (0xFFFC0000U)
#define LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH_SHIFT    (18U)
#define LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(x)       (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH_SHIFT)) & LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH_MASK)

/*! @name VDCTRL3 - eLCDIF VSYNC Mode and Dotclk Mode Control Register3 */
#define LCDIF_VDCTRL3_VERTICAL_WAIT_CNT_MASK     (0xFFFFU)
#define LCDIF_VDCTRL3_VERTICAL_WAIT_CNT_SHIFT    (0U)
#define LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(x)       (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL3_VERTICAL_WAIT_CNT_SHIFT)) & LCDIF_VDCTRL3_VERTICAL_WAIT_CNT_MASK)
#define LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT_MASK   (0xFFF0000U)
#define LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT_SHIFT  (16U)
#define LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT_SHIFT)) & LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT_MASK)
#define LCDIF_VDCTRL3_VSYNC_ONLY_MASK            (0x10000000U)
#define LCDIF_VDCTRL3_VSYNC_ONLY_SHIFT           (28U)
#define LCDIF_VDCTRL3_MUX_SYNC_SIGNALS_MASK      (0x20000000U)
#define LCDIF_VDCTRL3_MUX_SYNC_SIGNALS_SHIFT     (29U)
#define LCDIF_VDCTRL3_RSRVD0_MASK                (0xC0000000U)
#define LCDIF_VDCTRL3_RSRVD0_SHIFT               (30U)
#define LCDIF_VDCTRL3_RSRVD0(x)                  (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL3_RSRVD0_SHIFT)) & LCDIF_VDCTRL3_RSRVD0_MASK)

/*! @name VDCTRL4 - eLCDIF VSYNC Mode and Dotclk Mode Control Register4 */
#define LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT_MASK (0x3FFFFU)
#define LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT_SHIFT (0U)
#define LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(x) (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT_SHIFT)) & LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT_MASK)
#define LCDIF_VDCTRL4_SYNC_SIGNALS_ON_MASK       (0x40000U)
#define LCDIF_VDCTRL4_SYNC_SIGNALS_ON_SHIFT      (18U)
#define LCDIF_VDCTRL4_RSRVD0_MASK                (0x1FF80000U)
#define LCDIF_VDCTRL4_RSRVD0_SHIFT               (19U)
#define LCDIF_VDCTRL4_RSRVD0(x)                  (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL4_RSRVD0_SHIFT)) & LCDIF_VDCTRL4_RSRVD0_MASK)
#define LCDIF_VDCTRL4_DOTCLK_DLY_SEL_MASK        (0xE0000000U)
#define LCDIF_VDCTRL4_DOTCLK_DLY_SEL_SHIFT       (29U)
#define LCDIF_VDCTRL4_DOTCLK_DLY_SEL(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_VDCTRL4_DOTCLK_DLY_SEL_SHIFT)) & LCDIF_VDCTRL4_DOTCLK_DLY_SEL_MASK)

/*! @name DVICTRL0 - Digital Video Interface Control0 Register */
#define LCDIF_DVICTRL0_H_BLANKING_CNT_MASK       (0xFFFU)
#define LCDIF_DVICTRL0_H_BLANKING_CNT_SHIFT      (0U)
#define LCDIF_DVICTRL0_H_BLANKING_CNT(x)         (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL0_H_BLANKING_CNT_SHIFT)) & LCDIF_DVICTRL0_H_BLANKING_CNT_MASK)
#define LCDIF_DVICTRL0_RSRVD0_MASK               (0xF000U)
#define LCDIF_DVICTRL0_RSRVD0_SHIFT              (12U)
#define LCDIF_DVICTRL0_RSRVD0(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL0_RSRVD0_SHIFT)) & LCDIF_DVICTRL0_RSRVD0_MASK)
#define LCDIF_DVICTRL0_H_ACTIVE_CNT_MASK         (0xFFF0000U)
#define LCDIF_DVICTRL0_H_ACTIVE_CNT_SHIFT        (16U)
#define LCDIF_DVICTRL0_H_ACTIVE_CNT(x)           (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL0_H_ACTIVE_CNT_SHIFT)) & LCDIF_DVICTRL0_H_ACTIVE_CNT_MASK)
#define LCDIF_DVICTRL0_RSRVD1_MASK               (0xF0000000U)
#define LCDIF_DVICTRL0_RSRVD1_SHIFT              (28U)
#define LCDIF_DVICTRL0_RSRVD1(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL0_RSRVD1_SHIFT)) & LCDIF_DVICTRL0_RSRVD1_MASK)

/*! @name DVICTRL1 - Digital Video Interface Control1 Register */
#define LCDIF_DVICTRL1_F2_START_LINE_MASK        (0x3FFU)
#define LCDIF_DVICTRL1_F2_START_LINE_SHIFT       (0U)
#define LCDIF_DVICTRL1_F2_START_LINE(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL1_F2_START_LINE_SHIFT)) & LCDIF_DVICTRL1_F2_START_LINE_MASK)
#define LCDIF_DVICTRL1_F1_END_LINE_MASK          (0xFFC00U)
#define LCDIF_DVICTRL1_F1_END_LINE_SHIFT         (10U)
#define LCDIF_DVICTRL1_F1_END_LINE(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL1_F1_END_LINE_SHIFT)) & LCDIF_DVICTRL1_F1_END_LINE_MASK)
#define LCDIF_DVICTRL1_F1_START_LINE_MASK        (0x3FF00000U)
#define LCDIF_DVICTRL1_F1_START_LINE_SHIFT       (20U)
#define LCDIF_DVICTRL1_F1_START_LINE(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL1_F1_START_LINE_SHIFT)) & LCDIF_DVICTRL1_F1_START_LINE_MASK)
#define LCDIF_DVICTRL1_RSRVD0_MASK               (0xC0000000U)
#define LCDIF_DVICTRL1_RSRVD0_SHIFT              (30U)
#define LCDIF_DVICTRL1_RSRVD0(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL1_RSRVD0_SHIFT)) & LCDIF_DVICTRL1_RSRVD0_MASK)

/*! @name DVICTRL2 - Digital Video Interface Control2 Register */
#define LCDIF_DVICTRL2_V1_BLANK_END_LINE_MASK    (0x3FFU)
#define LCDIF_DVICTRL2_V1_BLANK_END_LINE_SHIFT   (0U)
#define LCDIF_DVICTRL2_V1_BLANK_END_LINE(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL2_V1_BLANK_END_LINE_SHIFT)) & LCDIF_DVICTRL2_V1_BLANK_END_LINE_MASK)
#define LCDIF_DVICTRL2_V1_BLANK_START_LINE_MASK  (0xFFC00U)
#define LCDIF_DVICTRL2_V1_BLANK_START_LINE_SHIFT (10U)
#define LCDIF_DVICTRL2_V1_BLANK_START_LINE(x)    (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL2_V1_BLANK_START_LINE_SHIFT)) & LCDIF_DVICTRL2_V1_BLANK_START_LINE_MASK)
#define LCDIF_DVICTRL2_F2_END_LINE_MASK          (0x3FF00000U)
#define LCDIF_DVICTRL2_F2_END_LINE_SHIFT         (20U)
#define LCDIF_DVICTRL2_F2_END_LINE(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL2_F2_END_LINE_SHIFT)) & LCDIF_DVICTRL2_F2_END_LINE_MASK)
#define LCDIF_DVICTRL2_RSRVD0_MASK               (0xC0000000U)
#define LCDIF_DVICTRL2_RSRVD0_SHIFT              (30U)
#define LCDIF_DVICTRL2_RSRVD0(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL2_RSRVD0_SHIFT)) & LCDIF_DVICTRL2_RSRVD0_MASK)

/*! @name DVICTRL3 - Digital Video Interface Control3 Register */
#define LCDIF_DVICTRL3_V_LINES_CNT_MASK          (0x3FFU)
#define LCDIF_DVICTRL3_V_LINES_CNT_SHIFT         (0U)
#define LCDIF_DVICTRL3_V_LINES_CNT(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL3_V_LINES_CNT_SHIFT)) & LCDIF_DVICTRL3_V_LINES_CNT_MASK)
#define LCDIF_DVICTRL3_V2_BLANK_END_LINE_MASK    (0xFFC00U)
#define LCDIF_DVICTRL3_V2_BLANK_END_LINE_SHIFT   (10U)
#define LCDIF_DVICTRL3_V2_BLANK_END_LINE(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL3_V2_BLANK_END_LINE_SHIFT)) & LCDIF_DVICTRL3_V2_BLANK_END_LINE_MASK)
#define LCDIF_DVICTRL3_V2_BLANK_START_LINE_MASK  (0x3FF00000U)
#define LCDIF_DVICTRL3_V2_BLANK_START_LINE_SHIFT (20U)
#define LCDIF_DVICTRL3_V2_BLANK_START_LINE(x)    (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL3_V2_BLANK_START_LINE_SHIFT)) & LCDIF_DVICTRL3_V2_BLANK_START_LINE_MASK)
#define LCDIF_DVICTRL3_RSRVD0_MASK               (0xC0000000U)
#define LCDIF_DVICTRL3_RSRVD0_SHIFT              (30U)
#define LCDIF_DVICTRL3_RSRVD0(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL3_RSRVD0_SHIFT)) & LCDIF_DVICTRL3_RSRVD0_MASK)

/*! @name DVICTRL4 - Digital Video Interface Control4 Register */
#define LCDIF_DVICTRL4_H_FILL_CNT_MASK           (0xFFU)
#define LCDIF_DVICTRL4_H_FILL_CNT_SHIFT          (0U)
#define LCDIF_DVICTRL4_H_FILL_CNT(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL4_H_FILL_CNT_SHIFT)) & LCDIF_DVICTRL4_H_FILL_CNT_MASK)
#define LCDIF_DVICTRL4_CR_FILL_VALUE_MASK        (0xFF00U)
#define LCDIF_DVICTRL4_CR_FILL_VALUE_SHIFT       (8U)
#define LCDIF_DVICTRL4_CR_FILL_VALUE(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL4_CR_FILL_VALUE_SHIFT)) & LCDIF_DVICTRL4_CR_FILL_VALUE_MASK)
#define LCDIF_DVICTRL4_CB_FILL_VALUE_MASK        (0xFF0000U)
#define LCDIF_DVICTRL4_CB_FILL_VALUE_SHIFT       (16U)
#define LCDIF_DVICTRL4_CB_FILL_VALUE(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL4_CB_FILL_VALUE_SHIFT)) & LCDIF_DVICTRL4_CB_FILL_VALUE_MASK)
#define LCDIF_DVICTRL4_Y_FILL_VALUE_MASK         (0xFF000000U)
#define LCDIF_DVICTRL4_Y_FILL_VALUE_SHIFT        (24U)
#define LCDIF_DVICTRL4_Y_FILL_VALUE(x)           (((uint32_t)(((uint32_t)(x)) << LCDIF_DVICTRL4_Y_FILL_VALUE_SHIFT)) & LCDIF_DVICTRL4_Y_FILL_VALUE_MASK)

/*! @name CSC_COEFF0 - RGB to YCbCr 4:2:2 CSC Coefficient0 Register */
#define LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_MASK (0x3U)
#define LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_SHIFT (0U)
#define LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(x) (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_SHIFT)) & LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_MASK)
#define LCDIF_CSC_COEFF0_RSRVD0_MASK             (0xFFFCU)
#define LCDIF_CSC_COEFF0_RSRVD0_SHIFT            (2U)
#define LCDIF_CSC_COEFF0_RSRVD0(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF0_RSRVD0_SHIFT)) & LCDIF_CSC_COEFF0_RSRVD0_MASK)
#define LCDIF_CSC_COEFF0_C0_MASK                 (0x3FF0000U)
#define LCDIF_CSC_COEFF0_C0_SHIFT                (16U)
#define LCDIF_CSC_COEFF0_C0(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF0_C0_SHIFT)) & LCDIF_CSC_COEFF0_C0_MASK)
#define LCDIF_CSC_COEFF0_RSRVD1_MASK             (0xFC000000U)
#define LCDIF_CSC_COEFF0_RSRVD1_SHIFT            (26U)
#define LCDIF_CSC_COEFF0_RSRVD1(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF0_RSRVD1_SHIFT)) & LCDIF_CSC_COEFF0_RSRVD1_MASK)

/*! @name CSC_COEFF1 - RGB to YCbCr 4:2:2 CSC Coefficient1 Register */
#define LCDIF_CSC_COEFF1_C1_MASK                 (0x3FFU)
#define LCDIF_CSC_COEFF1_C1_SHIFT                (0U)
#define LCDIF_CSC_COEFF1_C1(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF1_C1_SHIFT)) & LCDIF_CSC_COEFF1_C1_MASK)
#define LCDIF_CSC_COEFF1_RSRVD0_MASK             (0xFC00U)
#define LCDIF_CSC_COEFF1_RSRVD0_SHIFT            (10U)
#define LCDIF_CSC_COEFF1_RSRVD0(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF1_RSRVD0_SHIFT)) & LCDIF_CSC_COEFF1_RSRVD0_MASK)
#define LCDIF_CSC_COEFF1_C2_MASK                 (0x3FF0000U)
#define LCDIF_CSC_COEFF1_C2_SHIFT                (16U)
#define LCDIF_CSC_COEFF1_C2(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF1_C2_SHIFT)) & LCDIF_CSC_COEFF1_C2_MASK)
#define LCDIF_CSC_COEFF1_RSRVD1_MASK             (0xFC000000U)
#define LCDIF_CSC_COEFF1_RSRVD1_SHIFT            (26U)
#define LCDIF_CSC_COEFF1_RSRVD1(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF1_RSRVD1_SHIFT)) & LCDIF_CSC_COEFF1_RSRVD1_MASK)

/*! @name CSC_COEFF2 - RGB to YCbCr 4:2:2 CSC Coefficent2 Register */
#define LCDIF_CSC_COEFF2_C3_MASK                 (0x3FFU)
#define LCDIF_CSC_COEFF2_C3_SHIFT                (0U)
#define LCDIF_CSC_COEFF2_C3(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF2_C3_SHIFT)) & LCDIF_CSC_COEFF2_C3_MASK)
#define LCDIF_CSC_COEFF2_RSRVD0_MASK             (0xFC00U)
#define LCDIF_CSC_COEFF2_RSRVD0_SHIFT            (10U)
#define LCDIF_CSC_COEFF2_RSRVD0(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF2_RSRVD0_SHIFT)) & LCDIF_CSC_COEFF2_RSRVD0_MASK)
#define LCDIF_CSC_COEFF2_C4_MASK                 (0x3FF0000U)
#define LCDIF_CSC_COEFF2_C4_SHIFT                (16U)
#define LCDIF_CSC_COEFF2_C4(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF2_C4_SHIFT)) & LCDIF_CSC_COEFF2_C4_MASK)
#define LCDIF_CSC_COEFF2_RSRVD1_MASK             (0xFC000000U)
#define LCDIF_CSC_COEFF2_RSRVD1_SHIFT            (26U)
#define LCDIF_CSC_COEFF2_RSRVD1(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF2_RSRVD1_SHIFT)) & LCDIF_CSC_COEFF2_RSRVD1_MASK)

/*! @name CSC_COEFF3 - RGB to YCbCr 4:2:2 CSC Coefficient3 Register */
#define LCDIF_CSC_COEFF3_C5_MASK                 (0x3FFU)
#define LCDIF_CSC_COEFF3_C5_SHIFT                (0U)
#define LCDIF_CSC_COEFF3_C5(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF3_C5_SHIFT)) & LCDIF_CSC_COEFF3_C5_MASK)
#define LCDIF_CSC_COEFF3_RSRVD0_MASK             (0xFC00U)
#define LCDIF_CSC_COEFF3_RSRVD0_SHIFT            (10U)
#define LCDIF_CSC_COEFF3_RSRVD0(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF3_RSRVD0_SHIFT)) & LCDIF_CSC_COEFF3_RSRVD0_MASK)
#define LCDIF_CSC_COEFF3_C6_MASK                 (0x3FF0000U)
#define LCDIF_CSC_COEFF3_C6_SHIFT                (16U)
#define LCDIF_CSC_COEFF3_C6(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF3_C6_SHIFT)) & LCDIF_CSC_COEFF3_C6_MASK)
#define LCDIF_CSC_COEFF3_RSRVD1_MASK             (0xFC000000U)
#define LCDIF_CSC_COEFF3_RSRVD1_SHIFT            (26U)
#define LCDIF_CSC_COEFF3_RSRVD1(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF3_RSRVD1_SHIFT)) & LCDIF_CSC_COEFF3_RSRVD1_MASK)

/*! @name CSC_COEFF4 - RGB to YCbCr 4:2:2 CSC Coefficient4 Register */
#define LCDIF_CSC_COEFF4_C7_MASK                 (0x3FFU)
#define LCDIF_CSC_COEFF4_C7_SHIFT                (0U)
#define LCDIF_CSC_COEFF4_C7(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF4_C7_SHIFT)) & LCDIF_CSC_COEFF4_C7_MASK)
#define LCDIF_CSC_COEFF4_RSRVD0_MASK             (0xFC00U)
#define LCDIF_CSC_COEFF4_RSRVD0_SHIFT            (10U)
#define LCDIF_CSC_COEFF4_RSRVD0(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF4_RSRVD0_SHIFT)) & LCDIF_CSC_COEFF4_RSRVD0_MASK)
#define LCDIF_CSC_COEFF4_C8_MASK                 (0x3FF0000U)
#define LCDIF_CSC_COEFF4_C8_SHIFT                (16U)
#define LCDIF_CSC_COEFF4_C8(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF4_C8_SHIFT)) & LCDIF_CSC_COEFF4_C8_MASK)
#define LCDIF_CSC_COEFF4_RSRVD1_MASK             (0xFC000000U)
#define LCDIF_CSC_COEFF4_RSRVD1_SHIFT            (26U)
#define LCDIF_CSC_COEFF4_RSRVD1(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_COEFF4_RSRVD1_SHIFT)) & LCDIF_CSC_COEFF4_RSRVD1_MASK)

/*! @name CSC_OFFSET - RGB to YCbCr 4:2:2 CSC Offset Register */
#define LCDIF_CSC_OFFSET_Y_OFFSET_MASK           (0x1FFU)
#define LCDIF_CSC_OFFSET_Y_OFFSET_SHIFT          (0U)
#define LCDIF_CSC_OFFSET_Y_OFFSET(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_OFFSET_Y_OFFSET_SHIFT)) & LCDIF_CSC_OFFSET_Y_OFFSET_MASK)
#define LCDIF_CSC_OFFSET_RSRVD0_MASK             (0xFE00U)
#define LCDIF_CSC_OFFSET_RSRVD0_SHIFT            (9U)
#define LCDIF_CSC_OFFSET_RSRVD0(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_OFFSET_RSRVD0_SHIFT)) & LCDIF_CSC_OFFSET_RSRVD0_MASK)
#define LCDIF_CSC_OFFSET_CBCR_OFFSET_MASK        (0x1FF0000U)
#define LCDIF_CSC_OFFSET_CBCR_OFFSET_SHIFT       (16U)
#define LCDIF_CSC_OFFSET_CBCR_OFFSET(x)          (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_OFFSET_CBCR_OFFSET_SHIFT)) & LCDIF_CSC_OFFSET_CBCR_OFFSET_MASK)
#define LCDIF_CSC_OFFSET_RSRVD1_MASK             (0xFE000000U)
#define LCDIF_CSC_OFFSET_RSRVD1_SHIFT            (25U)
#define LCDIF_CSC_OFFSET_RSRVD1(x)               (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_OFFSET_RSRVD1_SHIFT)) & LCDIF_CSC_OFFSET_RSRVD1_MASK)

/*! @name CSC_LIMIT - RGB to YCbCr 4:2:2 CSC Limit Register */
#define LCDIF_CSC_LIMIT_Y_MAX_MASK               (0xFFU)
#define LCDIF_CSC_LIMIT_Y_MAX_SHIFT              (0U)
#define LCDIF_CSC_LIMIT_Y_MAX(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_LIMIT_Y_MAX_SHIFT)) & LCDIF_CSC_LIMIT_Y_MAX_MASK)
#define LCDIF_CSC_LIMIT_Y_MIN_MASK               (0xFF00U)
#define LCDIF_CSC_LIMIT_Y_MIN_SHIFT              (8U)
#define LCDIF_CSC_LIMIT_Y_MIN(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_LIMIT_Y_MIN_SHIFT)) & LCDIF_CSC_LIMIT_Y_MIN_MASK)
#define LCDIF_CSC_LIMIT_CBCR_MAX_MASK            (0xFF0000U)
#define LCDIF_CSC_LIMIT_CBCR_MAX_SHIFT           (16U)
#define LCDIF_CSC_LIMIT_CBCR_MAX(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_LIMIT_CBCR_MAX_SHIFT)) & LCDIF_CSC_LIMIT_CBCR_MAX_MASK)
#define LCDIF_CSC_LIMIT_CBCR_MIN_MASK            (0xFF000000U)
#define LCDIF_CSC_LIMIT_CBCR_MIN_SHIFT           (24U)
#define LCDIF_CSC_LIMIT_CBCR_MIN(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_CSC_LIMIT_CBCR_MIN_SHIFT)) & LCDIF_CSC_LIMIT_CBCR_MIN_MASK)

/*! @name DATA - LCD Interface Data Register */
#define LCDIF_DATA_DATA_ZERO_MASK                (0xFFU)
#define LCDIF_DATA_DATA_ZERO_SHIFT               (0U)
#define LCDIF_DATA_DATA_ZERO(x)                  (((uint32_t)(((uint32_t)(x)) << LCDIF_DATA_DATA_ZERO_SHIFT)) & LCDIF_DATA_DATA_ZERO_MASK)
#define LCDIF_DATA_DATA_ONE_MASK                 (0xFF00U)
#define LCDIF_DATA_DATA_ONE_SHIFT                (8U)
#define LCDIF_DATA_DATA_ONE(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_DATA_DATA_ONE_SHIFT)) & LCDIF_DATA_DATA_ONE_MASK)
#define LCDIF_DATA_DATA_TWO_MASK                 (0xFF0000U)
#define LCDIF_DATA_DATA_TWO_SHIFT                (16U)
#define LCDIF_DATA_DATA_TWO(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_DATA_DATA_TWO_SHIFT)) & LCDIF_DATA_DATA_TWO_MASK)
#define LCDIF_DATA_DATA_THREE_MASK               (0xFF000000U)
#define LCDIF_DATA_DATA_THREE_SHIFT              (24U)
#define LCDIF_DATA_DATA_THREE(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_DATA_DATA_THREE_SHIFT)) & LCDIF_DATA_DATA_THREE_MASK)

/*! @name BM_ERROR_STAT - Bus Master Error Status Register */
#define LCDIF_BM_ERROR_STAT_ADDR_MASK            (0xFFFFFFFFU)
#define LCDIF_BM_ERROR_STAT_ADDR_SHIFT           (0U)
#define LCDIF_BM_ERROR_STAT_ADDR(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_BM_ERROR_STAT_ADDR_SHIFT)) & LCDIF_BM_ERROR_STAT_ADDR_MASK)

/*! @name CRC_STAT - CRC Status Register */
#define LCDIF_CRC_STAT_CRC_VALUE_MASK            (0xFFFFFFFFU)
#define LCDIF_CRC_STAT_CRC_VALUE_SHIFT           (0U)
#define LCDIF_CRC_STAT_CRC_VALUE(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_CRC_STAT_CRC_VALUE_SHIFT)) & LCDIF_CRC_STAT_CRC_VALUE_MASK)

/*! @name STAT - LCD Interface Status Register */
#define LCDIF_STAT_LFIFO_COUNT_MASK              (0x1FFU)
#define LCDIF_STAT_LFIFO_COUNT_SHIFT             (0U)
#define LCDIF_STAT_LFIFO_COUNT(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_STAT_LFIFO_COUNT_SHIFT)) & LCDIF_STAT_LFIFO_COUNT_MASK)
#define LCDIF_STAT_RSRVD0_MASK                   (0xFFFE00U)
#define LCDIF_STAT_RSRVD0_SHIFT                  (9U)
#define LCDIF_STAT_RSRVD0(x)                     (((uint32_t)(((uint32_t)(x)) << LCDIF_STAT_RSRVD0_SHIFT)) & LCDIF_STAT_RSRVD0_MASK)
#define LCDIF_STAT_DVI_CURRENT_FIELD_MASK        (0x1000000U)
#define LCDIF_STAT_DVI_CURRENT_FIELD_SHIFT       (24U)
#define LCDIF_STAT_BUSY_MASK                     (0x2000000U)
#define LCDIF_STAT_BUSY_SHIFT                    (25U)
#define LCDIF_STAT_TXFIFO_EMPTY_MASK             (0x4000000U)
#define LCDIF_STAT_TXFIFO_EMPTY_SHIFT            (26U)
#define LCDIF_STAT_TXFIFO_FULL_MASK              (0x8000000U)
#define LCDIF_STAT_TXFIFO_FULL_SHIFT             (27U)
#define LCDIF_STAT_LFIFO_EMPTY_MASK              (0x10000000U)
#define LCDIF_STAT_LFIFO_EMPTY_SHIFT             (28U)
#define LCDIF_STAT_LFIFO_FULL_MASK               (0x20000000U)
#define LCDIF_STAT_LFIFO_FULL_SHIFT              (29U)
#define LCDIF_STAT_PRESENT_MASK                  (0x80000000U)
#define LCDIF_STAT_PRESENT_SHIFT                 (31U)

/*! @name VERSION - LCD Interface Version Register */
#define LCDIF_VERSION_STEP_MASK                  (0xFFFFU)
#define LCDIF_VERSION_STEP_SHIFT                 (0U)
#define LCDIF_VERSION_STEP(x)                    (((uint32_t)(((uint32_t)(x)) << LCDIF_VERSION_STEP_SHIFT)) & LCDIF_VERSION_STEP_MASK)
#define LCDIF_VERSION_MINOR_MASK                 (0xFF0000U)
#define LCDIF_VERSION_MINOR_SHIFT                (16U)
#define LCDIF_VERSION_MINOR(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_VERSION_MINOR_SHIFT)) & LCDIF_VERSION_MINOR_MASK)
#define LCDIF_VERSION_MAJOR_MASK                 (0xFF000000U)
#define LCDIF_VERSION_MAJOR_SHIFT                (24U)
#define LCDIF_VERSION_MAJOR(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_VERSION_MAJOR_SHIFT)) & LCDIF_VERSION_MAJOR_MASK)

/*! @name DEBUG0 - LCD Interface Debug0 Register */
#define LCDIF_DEBUG0_MST_WORDS_MASK              (0xFU)
#define LCDIF_DEBUG0_MST_WORDS_SHIFT             (0U)
#define LCDIF_DEBUG0_MST_WORDS(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG0_MST_WORDS_SHIFT)) & LCDIF_DEBUG0_MST_WORDS_MASK)
#define LCDIF_DEBUG0_MST_OUTSTANDING_REQS_MASK   (0x1F0U)
#define LCDIF_DEBUG0_MST_OUTSTANDING_REQS_SHIFT  (4U)
#define LCDIF_DEBUG0_MST_OUTSTANDING_REQS(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG0_MST_OUTSTANDING_REQS_SHIFT)) & LCDIF_DEBUG0_MST_OUTSTANDING_REQS_MASK)
#define LCDIF_DEBUG0_MST_AVALID_MASK             (0x200U)
#define LCDIF_DEBUG0_MST_AVALID_SHIFT            (9U)
#define LCDIF_DEBUG0_CUR_REQ_STATE_MASK          (0xC00U)
#define LCDIF_DEBUG0_CUR_REQ_STATE_SHIFT         (10U)
#define LCDIF_DEBUG0_CUR_REQ_STATE(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG0_CUR_REQ_STATE_SHIFT)) & LCDIF_DEBUG0_CUR_REQ_STATE_MASK)
#define LCDIF_DEBUG0_PXP_B1_DONE_MASK            (0x1000U)
#define LCDIF_DEBUG0_PXP_B1_DONE_SHIFT           (12U)
#define LCDIF_DEBUG0_PXP_LCDIF_B1_READY_MASK     (0x2000U)
#define LCDIF_DEBUG0_PXP_LCDIF_B1_READY_SHIFT    (13U)
#define LCDIF_DEBUG0_PXP_B0_DONE_MASK            (0x4000U)
#define LCDIF_DEBUG0_PXP_B0_DONE_SHIFT           (14U)
#define LCDIF_DEBUG0_PXP_LCDIF_B0_READY_MASK     (0x8000U)
#define LCDIF_DEBUG0_PXP_LCDIF_B0_READY_SHIFT    (15U)
#define LCDIF_DEBUG0_CUR_STATE_MASK              (0x7F0000U)
#define LCDIF_DEBUG0_CUR_STATE_SHIFT             (16U)
#define LCDIF_DEBUG0_CUR_STATE(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG0_CUR_STATE_SHIFT)) & LCDIF_DEBUG0_CUR_STATE_MASK)
#define LCDIF_DEBUG0_EMPTY_WORD_MASK             (0x800000U)
#define LCDIF_DEBUG0_EMPTY_WORD_SHIFT            (23U)
#define LCDIF_DEBUG0_CUR_FRAME_TX_MASK           (0x1000000U)
#define LCDIF_DEBUG0_CUR_FRAME_TX_SHIFT          (24U)
#define LCDIF_DEBUG0_VSYNC_MASK                  (0x2000000U)
#define LCDIF_DEBUG0_VSYNC_SHIFT                 (25U)
#define LCDIF_DEBUG0_HSYNC_MASK                  (0x4000000U)
#define LCDIF_DEBUG0_HSYNC_SHIFT                 (26U)
#define LCDIF_DEBUG0_ENABLE_MASK                 (0x8000000U)
#define LCDIF_DEBUG0_ENABLE_SHIFT                (27U)
#define LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG_MASK    (0x20000000U)
#define LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG_SHIFT   (29U)
#define LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT_MASK (0x40000000U)
#define LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT_SHIFT (30U)
#define LCDIF_DEBUG0_STREAMING_END_DETECTED_MASK (0x80000000U)
#define LCDIF_DEBUG0_STREAMING_END_DETECTED_SHIFT (31U)

/*! @name DEBUG1 - LCD Interface Debug1 Register */
#define LCDIF_DEBUG1_V_DATA_COUNT_MASK           (0xFFFFU)
#define LCDIF_DEBUG1_V_DATA_COUNT_SHIFT          (0U)
#define LCDIF_DEBUG1_V_DATA_COUNT(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG1_V_DATA_COUNT_SHIFT)) & LCDIF_DEBUG1_V_DATA_COUNT_MASK)
#define LCDIF_DEBUG1_H_DATA_COUNT_MASK           (0xFFFF0000U)
#define LCDIF_DEBUG1_H_DATA_COUNT_SHIFT          (16U)
#define LCDIF_DEBUG1_H_DATA_COUNT(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG1_H_DATA_COUNT_SHIFT)) & LCDIF_DEBUG1_H_DATA_COUNT_MASK)

/*! @name DEBUG2 - LCD Interface Debug2 Register */
#define LCDIF_DEBUG2_MST_ADDRESS_MASK            (0xFFFFFFFFU)
#define LCDIF_DEBUG2_MST_ADDRESS_SHIFT           (0U)
#define LCDIF_DEBUG2_MST_ADDRESS(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG2_MST_ADDRESS_SHIFT)) & LCDIF_DEBUG2_MST_ADDRESS_MASK)

/*! @name THRES - eLCDIF Threshold Register */
#define LCDIF_THRES_PANIC_MASK                   (0x1FFU)
#define LCDIF_THRES_PANIC_SHIFT                  (0U)
#define LCDIF_THRES_PANIC(x)                     (((uint32_t)(((uint32_t)(x)) << LCDIF_THRES_PANIC_SHIFT)) & LCDIF_THRES_PANIC_MASK)
#define LCDIF_THRES_RSRVD1_MASK                  (0xFE00U)
#define LCDIF_THRES_RSRVD1_SHIFT                 (9U)
#define LCDIF_THRES_RSRVD1(x)                    (((uint32_t)(((uint32_t)(x)) << LCDIF_THRES_RSRVD1_SHIFT)) & LCDIF_THRES_RSRVD1_MASK)
#define LCDIF_THRES_FASTCLOCK_MASK               (0x1FF0000U)
#define LCDIF_THRES_FASTCLOCK_SHIFT              (16U)
#define LCDIF_THRES_FASTCLOCK(x)                 (((uint32_t)(((uint32_t)(x)) << LCDIF_THRES_FASTCLOCK_SHIFT)) & LCDIF_THRES_FASTCLOCK_MASK)
#define LCDIF_THRES_RSRVD2_MASK                  (0xFE000000U)
#define LCDIF_THRES_RSRVD2_SHIFT                 (25U)
#define LCDIF_THRES_RSRVD2(x)                    (((uint32_t)(((uint32_t)(x)) << LCDIF_THRES_RSRVD2_SHIFT)) & LCDIF_THRES_RSRVD2_MASK)

/*! @name AS_CTRL - eLCDIF AS Buffer Control Register */
#define LCDIF_AS_CTRL_AS_ENABLE_MASK             (0x1U)
#define LCDIF_AS_CTRL_AS_ENABLE_SHIFT            (0U)
#define LCDIF_AS_CTRL_ALPHA_CTRL_MASK            (0x6U)
#define LCDIF_AS_CTRL_ALPHA_CTRL_SHIFT           (1U)
#define LCDIF_AS_CTRL_ALPHA_CTRL(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CTRL_ALPHA_CTRL_SHIFT)) & LCDIF_AS_CTRL_ALPHA_CTRL_MASK)
#define LCDIF_AS_CTRL_ENABLE_COLORKEY_MASK       (0x8U)
#define LCDIF_AS_CTRL_ENABLE_COLORKEY_SHIFT      (3U)
#define LCDIF_AS_CTRL_FORMAT_MASK                (0xF0U)
#define LCDIF_AS_CTRL_FORMAT_SHIFT               (4U)
#define LCDIF_AS_CTRL_FORMAT(x)                  (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CTRL_FORMAT_SHIFT)) & LCDIF_AS_CTRL_FORMAT_MASK)
#define LCDIF_AS_CTRL_ALPHA_MASK                 (0xFF00U)
#define LCDIF_AS_CTRL_ALPHA_SHIFT                (8U)
#define LCDIF_AS_CTRL_ALPHA(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CTRL_ALPHA_SHIFT)) & LCDIF_AS_CTRL_ALPHA_MASK)
#define LCDIF_AS_CTRL_ROP_MASK                   (0xF0000U)
#define LCDIF_AS_CTRL_ROP_SHIFT                  (16U)
#define LCDIF_AS_CTRL_ROP(x)                     (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CTRL_ROP_SHIFT)) & LCDIF_AS_CTRL_ROP_MASK)
#define LCDIF_AS_CTRL_ALPHA_INVERT_MASK          (0x100000U)
#define LCDIF_AS_CTRL_ALPHA_INVERT_SHIFT         (20U)
#define LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE_MASK    (0x600000U)
#define LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE_SHIFT   (21U)
#define LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(x)      (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE_SHIFT)) & LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE_MASK)
#define LCDIF_AS_CTRL_PS_DISABLE_MASK            (0x800000U)
#define LCDIF_AS_CTRL_PS_DISABLE_SHIFT           (23U)
#define LCDIF_AS_CTRL_RVDS1_MASK                 (0x7000000U)
#define LCDIF_AS_CTRL_RVDS1_SHIFT                (24U)
#define LCDIF_AS_CTRL_RVDS1(x)                   (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CTRL_RVDS1_SHIFT)) & LCDIF_AS_CTRL_RVDS1_MASK)
#define LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_MASK       (0x8000000U)
#define LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_SHIFT      (27U)
#define LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN_MASK    (0x10000000U)
#define LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN_SHIFT   (28U)
#define LCDIF_AS_CTRL_CSI_VSYNC_MODE_MASK        (0x20000000U)
#define LCDIF_AS_CTRL_CSI_VSYNC_MODE_SHIFT       (29U)
#define LCDIF_AS_CTRL_CSI_VSYNC_POL_MASK         (0x40000000U)
#define LCDIF_AS_CTRL_CSI_VSYNC_POL_SHIFT        (30U)
#define LCDIF_AS_CTRL_CSI_VSYNC_ENABLE_MASK      (0x80000000U)
#define LCDIF_AS_CTRL_CSI_VSYNC_ENABLE_SHIFT     (31U)

/*! @name AS_BUF - Alpha Surface Buffer Pointer */
#define LCDIF_AS_BUF_ADDR_MASK                   (0xFFFFFFFFU)
#define LCDIF_AS_BUF_ADDR_SHIFT                  (0U)
#define LCDIF_AS_BUF_ADDR(x)                     (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_BUF_ADDR_SHIFT)) & LCDIF_AS_BUF_ADDR_MASK)

/*! @name AS_NEXT_BUF -  */
#define LCDIF_AS_NEXT_BUF_ADDR_MASK              (0xFFFFFFFFU)
#define LCDIF_AS_NEXT_BUF_ADDR_SHIFT             (0U)
#define LCDIF_AS_NEXT_BUF_ADDR(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_NEXT_BUF_ADDR_SHIFT)) & LCDIF_AS_NEXT_BUF_ADDR_MASK)

/*! @name AS_CLRKEYLOW - eLCDIF Overlay Color Key Low */
#define LCDIF_AS_CLRKEYLOW_PIXEL_MASK            (0xFFFFFFU)
#define LCDIF_AS_CLRKEYLOW_PIXEL_SHIFT           (0U)
#define LCDIF_AS_CLRKEYLOW_PIXEL(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CLRKEYLOW_PIXEL_SHIFT)) & LCDIF_AS_CLRKEYLOW_PIXEL_MASK)
#define LCDIF_AS_CLRKEYLOW_RSVD1_MASK            (0xFF000000U)
#define LCDIF_AS_CLRKEYLOW_RSVD1_SHIFT           (24U)
#define LCDIF_AS_CLRKEYLOW_RSVD1(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CLRKEYLOW_RSVD1_SHIFT)) & LCDIF_AS_CLRKEYLOW_RSVD1_MASK)

/*! @name AS_CLRKEYHIGH - eLCDIF Overlay Color Key High */
#define LCDIF_AS_CLRKEYHIGH_PIXEL_MASK           (0xFFFFFFU)
#define LCDIF_AS_CLRKEYHIGH_PIXEL_SHIFT          (0U)
#define LCDIF_AS_CLRKEYHIGH_PIXEL(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CLRKEYHIGH_PIXEL_SHIFT)) & LCDIF_AS_CLRKEYHIGH_PIXEL_MASK)
#define LCDIF_AS_CLRKEYHIGH_RSVD1_MASK           (0xFF000000U)
#define LCDIF_AS_CLRKEYHIGH_RSVD1_SHIFT          (24U)
#define LCDIF_AS_CLRKEYHIGH_RSVD1(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_AS_CLRKEYHIGH_RSVD1_SHIFT)) & LCDIF_AS_CLRKEYHIGH_RSVD1_MASK)

/*! @name SYNC_DELAY - LCD working insync mode with CSI for VSYNC delay */
#define LCDIF_SYNC_DELAY_H_COUNT_DELAY_MASK      (0xFFFFU)
#define LCDIF_SYNC_DELAY_H_COUNT_DELAY_SHIFT     (0U)
#define LCDIF_SYNC_DELAY_H_COUNT_DELAY(x)        (((uint32_t)(((uint32_t)(x)) << LCDIF_SYNC_DELAY_H_COUNT_DELAY_SHIFT)) & LCDIF_SYNC_DELAY_H_COUNT_DELAY_MASK)
#define LCDIF_SYNC_DELAY_V_COUNT_DELAY_MASK      (0xFFFF0000U)
#define LCDIF_SYNC_DELAY_V_COUNT_DELAY_SHIFT     (16U)
#define LCDIF_SYNC_DELAY_V_COUNT_DELAY(x)        (((uint32_t)(((uint32_t)(x)) << LCDIF_SYNC_DELAY_V_COUNT_DELAY_SHIFT)) & LCDIF_SYNC_DELAY_V_COUNT_DELAY_MASK)

/*! @name DEBUG3 - eLCDIF Interface Debug3 Register */
#define LCDIF_DEBUG3_MST_WORDS_MASK              (0xFU)
#define LCDIF_DEBUG3_MST_WORDS_SHIFT             (0U)
#define LCDIF_DEBUG3_MST_WORDS(x)                (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG3_MST_WORDS_SHIFT)) & LCDIF_DEBUG3_MST_WORDS_MASK)
#define LCDIF_DEBUG3_MST_OUTSTANDING_REQS_MASK   (0x1F0U)
#define LCDIF_DEBUG3_MST_OUTSTANDING_REQS_SHIFT  (4U)
#define LCDIF_DEBUG3_MST_OUTSTANDING_REQS(x)     (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG3_MST_OUTSTANDING_REQS_SHIFT)) & LCDIF_DEBUG3_MST_OUTSTANDING_REQS_MASK)
#define LCDIF_DEBUG3_MST_AVALID_MASK             (0x200U)
#define LCDIF_DEBUG3_MST_AVALID_SHIFT            (9U)
#define LCDIF_DEBUG3_CUR_REQ_STATE_MASK          (0xC00U)
#define LCDIF_DEBUG3_CUR_REQ_STATE_SHIFT         (10U)
#define LCDIF_DEBUG3_CUR_REQ_STATE(x)            (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG3_CUR_REQ_STATE_SHIFT)) & LCDIF_DEBUG3_CUR_REQ_STATE_MASK)
#define LCDIF_DEBUG3_RSVD0_MASK                  (0xFFFFF000U)
#define LCDIF_DEBUG3_RSVD0_SHIFT                 (12U)
#define LCDIF_DEBUG3_RSVD0(x)                    (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG3_RSVD0_SHIFT)) & LCDIF_DEBUG3_RSVD0_MASK)

/*! @name DEBUG4 - LCD Interface Debug4 */
#define LCDIF_DEBUG4_V_DATA_COUNT_MASK           (0xFFFFU)
#define LCDIF_DEBUG4_V_DATA_COUNT_SHIFT          (0U)
#define LCDIF_DEBUG4_V_DATA_COUNT(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG4_V_DATA_COUNT_SHIFT)) & LCDIF_DEBUG4_V_DATA_COUNT_MASK)
#define LCDIF_DEBUG4_H_DATA_COUNT_MASK           (0xFFFF0000U)
#define LCDIF_DEBUG4_H_DATA_COUNT_SHIFT          (16U)
#define LCDIF_DEBUG4_H_DATA_COUNT(x)             (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG4_H_DATA_COUNT_SHIFT)) & LCDIF_DEBUG4_H_DATA_COUNT_MASK)

/*! @name DEBUG5 - LCD Interface Debug5 */
#define LCDIF_DEBUG5_MST_ADDRESS_MASK            (0xFFFFFFFFU)
#define LCDIF_DEBUG5_MST_ADDRESS_SHIFT           (0U)
#define LCDIF_DEBUG5_MST_ADDRESS(x)              (((uint32_t)(((uint32_t)(x)) << LCDIF_DEBUG5_MST_ADDRESS_SHIFT)) & LCDIF_DEBUG5_MST_ADDRESS_MASK)


/*!
 * @}
 */ /* end of group LCDIF_Register_Masks */


/* LCDIF - Peripheral instance base addresses */
/** Peripheral LCDIF base pointer */
#define LCDIF_BASE_PTR                           ((LCDIF_MemMapPtr)0x30730000u)
/** Array initializer of LCDIF peripheral base pointers */
#define LCDIF_BASE_PTRS                          { LCDIF_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- LCDIF - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LCDIF_Register_Accessor_Macros LCDIF - Register accessor macros
 * @{
 */


/* LCDIF - Register instance definitions */
/* LCDIF */
#define LCDIF_CTRL                               LCDIF_CTRL_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL_SET                           LCDIF_CTRL_SET_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL_CLR                           LCDIF_CTRL_CLR_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL_TOG                           LCDIF_CTRL_TOG_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL1                              LCDIF_CTRL1_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL1_SET                          LCDIF_CTRL1_SET_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL1_CLR                          LCDIF_CTRL1_CLR_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL1_TOG                          LCDIF_CTRL1_TOG_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL2                              LCDIF_CTRL2_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL2_SET                          LCDIF_CTRL2_SET_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL2_CLR                          LCDIF_CTRL2_CLR_REG(LCDIF_BASE_PTR)
#define LCDIF_CTRL2_TOG                          LCDIF_CTRL2_TOG_REG(LCDIF_BASE_PTR)
#define LCDIF_TRANSFER_COUNT                     LCDIF_TRANSFER_COUNT_REG(LCDIF_BASE_PTR)
#define LCDIF_CUR_BUF                            LCDIF_CUR_BUF_REG(LCDIF_BASE_PTR)
#define LCDIF_NEXT_BUF                           LCDIF_NEXT_BUF_REG(LCDIF_BASE_PTR)
#define LCDIF_TIMING                             LCDIF_TIMING_REG(LCDIF_BASE_PTR)
#define LCDIF_VDCTRL0                            LCDIF_VDCTRL0_REG(LCDIF_BASE_PTR)
#define LCDIF_VDCTRL0_SET                        LCDIF_VDCTRL0_SET_REG(LCDIF_BASE_PTR)
#define LCDIF_VDCTRL0_CLR                        LCDIF_VDCTRL0_CLR_REG(LCDIF_BASE_PTR)
#define LCDIF_VDCTRL0_TOG                        LCDIF_VDCTRL0_TOG_REG(LCDIF_BASE_PTR)
#define LCDIF_VDCTRL1                            LCDIF_VDCTRL1_REG(LCDIF_BASE_PTR)
#define LCDIF_VDCTRL2                            LCDIF_VDCTRL2_REG(LCDIF_BASE_PTR)
#define LCDIF_VDCTRL3                            LCDIF_VDCTRL3_REG(LCDIF_BASE_PTR)
#define LCDIF_VDCTRL4                            LCDIF_VDCTRL4_REG(LCDIF_BASE_PTR)
#define LCDIF_DVICTRL0                           LCDIF_DVICTRL0_REG(LCDIF_BASE_PTR)
#define LCDIF_DVICTRL1                           LCDIF_DVICTRL1_REG(LCDIF_BASE_PTR)
#define LCDIF_DVICTRL2                           LCDIF_DVICTRL2_REG(LCDIF_BASE_PTR)
#define LCDIF_DVICTRL3                           LCDIF_DVICTRL3_REG(LCDIF_BASE_PTR)
#define LCDIF_DVICTRL4                           LCDIF_DVICTRL4_REG(LCDIF_BASE_PTR)
#define LCDIF_CSC_COEFF0                         LCDIF_CSC_COEFF0_REG(LCDIF_BASE_PTR)
#define LCDIF_CSC_COEFF1                         LCDIF_CSC_COEFF1_REG(LCDIF_BASE_PTR)
#define LCDIF_CSC_COEFF2                         LCDIF_CSC_COEFF2_REG(LCDIF_BASE_PTR)
#define LCDIF_CSC_COEFF3                         LCDIF_CSC_COEFF3_REG(LCDIF_BASE_PTR)
#define LCDIF_CSC_COEFF4                         LCDIF_CSC_COEFF4_REG(LCDIF_BASE_PTR)
#define LCDIF_CSC_OFFSET                         LCDIF_CSC_OFFSET_REG(LCDIF_BASE_PTR)
#define LCDIF_CSC_LIMIT                          LCDIF_CSC_LIMIT_REG(LCDIF_BASE_PTR)
#define LCDIF_DATA                               LCDIF_DATA_REG(LCDIF_BASE_PTR)
#define LCDIF_BM_ERROR_STAT                      LCDIF_BM_ERROR_STAT_REG(LCDIF_BASE_PTR)
#define LCDIF_CRC_STAT                           LCDIF_CRC_STAT_REG(LCDIF_BASE_PTR)
#define LCDIF_STAT                               LCDIF_STAT_REG(LCDIF_BASE_PTR)
#define LCDIF_VERSION                            LCDIF_VERSION_REG(LCDIF_BASE_PTR)
#define LCDIF_DEBUG0                             LCDIF_DEBUG0_REG(LCDIF_BASE_PTR)
#define LCDIF_DEBUG1                             LCDIF_DEBUG1_REG(LCDIF_BASE_PTR)
#define LCDIF_DEBUG2                             LCDIF_DEBUG2_REG(LCDIF_BASE_PTR)
#define LCDIF_THRES                              LCDIF_THRES_REG(LCDIF_BASE_PTR)
#define LCDIF_AS_CTRL                            LCDIF_AS_CTRL_REG(LCDIF_BASE_PTR)
#define LCDIF_AS_BUF                             LCDIF_AS_BUF_REG(LCDIF_BASE_PTR)
#define LCDIF_AS_NEXT_BUF                        LCDIF_AS_NEXT_BUF_REG(LCDIF_BASE_PTR)
#define LCDIF_AS_CLRKEYLOW                       LCDIF_AS_CLRKEYLOW_REG(LCDIF_BASE_PTR)
#define LCDIF_AS_CLRKEYHIGH                      LCDIF_AS_CLRKEYHIGH_REG(LCDIF_BASE_PTR)
#define LCDIF_SYNC_DELAY                         LCDIF_SYNC_DELAY_REG(LCDIF_BASE_PTR)
#define LCDIF_DEBUG3                             LCDIF_DEBUG3_REG(LCDIF_BASE_PTR)
#define LCDIF_DEBUG4                             LCDIF_DEBUG4_REG(LCDIF_BASE_PTR)
#define LCDIF_DEBUG5                             LCDIF_DEBUG5_REG(LCDIF_BASE_PTR)

/*!
 * @}
 */ /* end of group LCDIF_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group LCDIF_Peripheral */


/* ----------------------------------------------------------------------------
   -- MIPI_CSI2
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MIPI_CSI2_Peripheral MIPI_CSI2
 * @{
 */

/** MIPI_CSI2 - Peripheral register structure */
typedef struct MIPI_CSI2_MemMap {
  uint8_t RESERVED_0[4];
  uint32_t CSIS_CMN_CTRL;                          /**< CSIS Common Control, offset: 0x4 */
  uint32_t CSIS_CLK_CTRL;                          /**< CSIS Clock gate Control, offset: 0x8 */
  uint8_t RESERVED_1[4];
  uint32_t CSIS_INT_MSK;                           /**< CSIS Interrupt Mask, offset: 0x10 */
  uint32_t CSIS_INT_SRC;                           /**< CSIS Interrupt Source, offset: 0x14 */
  uint8_t RESERVED_2[8];
  uint32_t DPHY_STATUS;                            /**< D-PHY Status, offset: 0x20 */
  uint32_t DPHY_CMN_CTRL;                          /**< D-PHY Common Control, offset: 0x24 */
  uint8_t RESERVED_3[8];
  uint32_t DPHY_BCTRL_L;                           /**< D-PHY Master and Slave Control register low, offset: 0x30 */
  uint32_t DPHY_BCTRL_H;                           /**< D-PHY Master and Slave Control register high, offset: 0x34 */
  uint32_t DPHY_SCTRL_L;                           /**< D-PHY Slave Control register low, offset: 0x38 */
  uint32_t DPHY_SCTRL_H;                           /**< D-PHY Slave Control register high, offset: 0x3C */
  uint32_t ISP_CONFIG_CH0;                         /**< ISP Configuration register of CH0, offset: 0x40 */
  uint32_t ISP_RESOL_CH0;                          /**< ISP Image Resolution register of CH0, offset: 0x44 */
  uint32_t ISP_SYNC_CH0;                           /**< ISP SYNC register of CH0, offset: 0x48 */
  uint8_t RESERVED_4[52];
  uint32_t SDW_CONFIG_CH0;                         /**< Shadow Configuration register of CH0, offset: 0x80 */
  uint32_t SDW_RESOL_CH0;                          /**< Shadow Resolution register of CH0, offset: 0x84 */
  uint32_t SDW_SYNC_CH0;                           /**< Shadow SYNC register of CH0, offset: 0x88 */
  uint8_t RESERVED_5[52];
  uint32_t DBG_CTRL;                               /**< Debug Control register, offset: 0xC0 */
  uint32_t DBG_INTR_MSK;                           /**< Debug Interrupt Mask, offset: 0xC4 */
  uint32_t DBG_INTR_SRC;                           /**< Debug Interrupt Mask, offset: 0xC8 */
  uint8_t RESERVED_6[7988];
  uint32_t NON_IMG_DATA;                           /**< Non Image Data, offset: 0x2000 */
} volatile *MIPI_CSI2_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- MIPI_CSI2 - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MIPI_CSI2_Register_Accessor_Macros MIPI_CSI2 - Register accessor macros
 * @{
 */


/* MIPI_CSI2 - Register accessors */
#define MIPI_CSI2_CSIS_CMN_CTRL_REG(base)        ((base)->CSIS_CMN_CTRL)
#define MIPI_CSI2_CSIS_CLK_CTRL_REG(base)        ((base)->CSIS_CLK_CTRL)
#define MIPI_CSI2_CSIS_INT_MSK_REG(base)         ((base)->CSIS_INT_MSK)
#define MIPI_CSI2_CSIS_INT_SRC_REG(base)         ((base)->CSIS_INT_SRC)
#define MIPI_CSI2_DPHY_STATUS_REG(base)          ((base)->DPHY_STATUS)
#define MIPI_CSI2_DPHY_CMN_CTRL_REG(base)        ((base)->DPHY_CMN_CTRL)
#define MIPI_CSI2_DPHY_BCTRL_L_REG(base)         ((base)->DPHY_BCTRL_L)
#define MIPI_CSI2_DPHY_BCTRL_H_REG(base)         ((base)->DPHY_BCTRL_H)
#define MIPI_CSI2_DPHY_SCTRL_L_REG(base)         ((base)->DPHY_SCTRL_L)
#define MIPI_CSI2_DPHY_SCTRL_H_REG(base)         ((base)->DPHY_SCTRL_H)
#define MIPI_CSI2_ISP_CONFIG_CH0_REG(base)       ((base)->ISP_CONFIG_CH0)
#define MIPI_CSI2_ISP_RESOL_CH0_REG(base)        ((base)->ISP_RESOL_CH0)
#define MIPI_CSI2_ISP_SYNC_CH0_REG(base)         ((base)->ISP_SYNC_CH0)
#define MIPI_CSI2_SDW_CONFIG_CH0_REG(base)       ((base)->SDW_CONFIG_CH0)
#define MIPI_CSI2_SDW_RESOL_CH0_REG(base)        ((base)->SDW_RESOL_CH0)
#define MIPI_CSI2_SDW_SYNC_CH0_REG(base)         ((base)->SDW_SYNC_CH0)
#define MIPI_CSI2_DBG_CTRL_REG(base)             ((base)->DBG_CTRL)
#define MIPI_CSI2_DBG_INTR_MSK_REG(base)         ((base)->DBG_INTR_MSK)
#define MIPI_CSI2_DBG_INTR_SRC_REG(base)         ((base)->DBG_INTR_SRC)
#define MIPI_CSI2_NON_IMG_DATA_REG(base)         ((base)->NON_IMG_DATA)

/*!
 * @}
 */ /* end of group MIPI_CSI2_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- MIPI_CSI2 Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MIPI_CSI2_Register_Masks MIPI_CSI2 Register Masks
 * @{
 */

/*! @name CSIS_CMN_CTRL - CSIS Common Control */
#define MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN_MASK      (0x1U)
#define MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN_SHIFT     (0U)
#define MIPI_CSI2_CSIS_CMN_CTRL_SW_REST_MASK     (0x2U)
#define MIPI_CSI2_CSIS_CMN_CTRL_SW_REST_SHIFT    (1U)
#define MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL_MASK (0x4U)
#define MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL_SHIFT (2U)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD3_MASK       (0xF8U)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD3_SHIFT      (3U)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD3(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CMN_CTRL_RSVD3_SHIFT)) & MIPI_CSI2_CSIS_CMN_CTRL_RSVD3_MASK)
#define MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER_MASK (0x300U)
#define MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER_SHIFT (8U)
#define MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER(x)   (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER_SHIFT)) & MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER_MASK)
#define MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE_MASK (0xC00U)
#define MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE_SHIFT (10U)
#define MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE_SHIFT)) & MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE_MASK)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD2_MASK       (0xF000U)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD2_SHIFT      (12U)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD2(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CMN_CTRL_RSVD2_SHIFT)) & MIPI_CSI2_CSIS_CMN_CTRL_RSVD2_MASK)
#define MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_MASK (0xF0000U)
#define MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_SHIFT (16U)
#define MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_SHIFT)) & MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_MASK)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD1_MASK       (0xFFF00000U)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD1_SHIFT      (20U)
#define MIPI_CSI2_CSIS_CMN_CTRL_RSVD1(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CMN_CTRL_RSVD1_SHIFT)) & MIPI_CSI2_CSIS_CMN_CTRL_RSVD1_MASK)

/*! @name CSIS_CLK_CTRL - CSIS Clock gate Control */
#define MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC_MASK    (0xFU)
#define MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC_SHIFT   (0U)
#define MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC(x)      (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC_SHIFT)) & MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC_MASK)
#define MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN_MASK  (0xF0U)
#define MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN_SHIFT (4U)
#define MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN_SHIFT)) & MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN_MASK)
#define MIPI_CSI2_CSIS_CLK_CTRL_RSVD4_MASK       (0xFF00U)
#define MIPI_CSI2_CSIS_CLK_CTRL_RSVD4_SHIFT      (8U)
#define MIPI_CSI2_CSIS_CLK_CTRL_RSVD4(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CLK_CTRL_RSVD4_SHIFT)) & MIPI_CSI2_CSIS_CLK_CTRL_RSVD4_MASK)
#define MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL_MASK (0xFFFF0000U)
#define MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL_SHIFT (16U)
#define MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL_SHIFT)) & MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL_MASK)

/*! @name CSIS_INT_MSK - CSIS Interrupt Mask */
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id_MASK   (0x1U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id_SHIFT  (0U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC_MASK  (0x2U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC_SHIFT (1U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC_MASK  (0x4U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC_SHIFT (2U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG_MASK (0x8U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG_SHIFT (3U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER_MASK (0xF0U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER_SHIFT (4U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER(x)   (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER_SHIFT)) & MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER_MASK)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE_MASK (0xF00U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE_SHIFT (8U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE_SHIFT)) & MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE_MASK)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS_MASK (0xF000U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS_SHIFT (12U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS_SHIFT)) & MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS_MASK)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS_MASK (0xF0000U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS_SHIFT (16U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS_SHIFT)) & MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS_MASK)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND_MASK (0xF00000U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND_SHIFT (20U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND(x)   (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND_SHIFT)) & MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND_MASK)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART_MASK (0xF000000U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART_SHIFT (24U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART_SHIFT)) & MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART_MASK)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER_MASK (0x10000000U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER_SHIFT (28U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE_MASK (0x20000000U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE_SHIFT (29U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER_MASK (0x40000000U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER_SHIFT (30U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE_MASK (0x80000000U)
#define MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE_SHIFT (31U)

/*! @name CSIS_INT_SRC - CSIS Interrupt Source */
#define MIPI_CSI2_CSIS_INT_SRC_ERR_ID_MASK       (0x1U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_ID_SHIFT      (0U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_CRC_MASK      (0x2U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_CRC_SHIFT     (1U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_ECC_MASK      (0x4U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_ECC_SHIFT     (2U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG_MASK (0x8U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG_SHIFT (3U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_OVER_MASK     (0xF0U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_OVER_SHIFT    (4U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_OVER(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_SRC_ERR_OVER_SHIFT)) & MIPI_CSI2_CSIS_INT_SRC_ERR_OVER_MASK)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE_MASK  (0xF00U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE_SHIFT (8U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE_SHIFT)) & MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE_MASK)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS_MASK  (0xF000U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS_SHIFT (12U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS_SHIFT)) & MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS_MASK)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS_MASK   (0xF0000U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS_SHIFT  (16U)
#define MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS_SHIFT)) & MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS_MASK)
#define MIPI_CSI2_CSIS_INT_SRC_FRAMEEND_MASK     (0xF00000U)
#define MIPI_CSI2_CSIS_INT_SRC_FRAMEEND_SHIFT    (20U)
#define MIPI_CSI2_CSIS_INT_SRC_FRAMEEND(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_SRC_FRAMEEND_SHIFT)) & MIPI_CSI2_CSIS_INT_SRC_FRAMEEND_MASK)
#define MIPI_CSI2_CSIS_INT_SRC_FRAMESTART_MASK   (0xF000000U)
#define MIPI_CSI2_CSIS_INT_SRC_FRAMESTART_SHIFT  (24U)
#define MIPI_CSI2_CSIS_INT_SRC_FRAMESTART(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_CSIS_INT_SRC_FRAMESTART_SHIFT)) & MIPI_CSI2_CSIS_INT_SRC_FRAMESTART_MASK)
#define MIPI_CSI2_CSIS_INT_SRC_ODDAFTER_MASK     (0x10000000U)
#define MIPI_CSI2_CSIS_INT_SRC_ODDAFTER_SHIFT    (28U)
#define MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE_MASK    (0x20000000U)
#define MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE_SHIFT   (29U)
#define MIPI_CSI2_CSIS_INT_SRC_EVENAFTER_MASK    (0x40000000U)
#define MIPI_CSI2_CSIS_INT_SRC_EVENAFTER_SHIFT   (30U)
#define MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE_MASK   (0x80000000U)
#define MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE_SHIFT  (31U)

/*! @name DPHY_STATUS - D-PHY Status */
#define MIPI_CSI2_DPHY_STATUS_STOPSTATECLK_MASK  (0x1U)
#define MIPI_CSI2_DPHY_STATUS_STOPSTATECLK_SHIFT (0U)
#define MIPI_CSI2_DPHY_STATUS_ULPSCLK_MASK       (0x2U)
#define MIPI_CSI2_DPHY_STATUS_ULPSCLK_SHIFT      (1U)
#define MIPI_CSI2_DPHY_STATUS_RSVD6_MASK         (0xCU)
#define MIPI_CSI2_DPHY_STATUS_RSVD6_SHIFT        (2U)
#define MIPI_CSI2_DPHY_STATUS_RSVD6(x)           (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_STATUS_RSVD6_SHIFT)) & MIPI_CSI2_DPHY_STATUS_RSVD6_MASK)
#define MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT_MASK  (0xF0U)
#define MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT_SHIFT (4U)
#define MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT_SHIFT)) & MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT_MASK)
#define MIPI_CSI2_DPHY_STATUS_ULPSDAT_MASK       (0xF00U)
#define MIPI_CSI2_DPHY_STATUS_ULPSDAT_SHIFT      (8U)
#define MIPI_CSI2_DPHY_STATUS_ULPSDAT(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_STATUS_ULPSDAT_SHIFT)) & MIPI_CSI2_DPHY_STATUS_ULPSDAT_MASK)
#define MIPI_CSI2_DPHY_STATUS_RSVD5_MASK         (0xFFFFF000U)
#define MIPI_CSI2_DPHY_STATUS_RSVD5_SHIFT        (12U)
#define MIPI_CSI2_DPHY_STATUS_RSVD5(x)           (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_STATUS_RSVD5_SHIFT)) & MIPI_CSI2_DPHY_STATUS_RSVD5_MASK)

/*! @name DPHY_CMN_CTRL - D-PHY Common Control */
#define MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK_MASK  (0x1U)
#define MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK_SHIFT (0U)
#define MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT_MASK  (0x1EU)
#define MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT_SHIFT (1U)
#define MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT_SHIFT)) & MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT_MASK)
#define MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT_MASK (0x20U)
#define MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT_SHIFT (5U)
#define MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK_MASK (0x40U)
#define MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK_SHIFT (6U)
#define MIPI_CSI2_DPHY_CMN_CTRL_RSVD7_MASK       (0x3FFF80U)
#define MIPI_CSI2_DPHY_CMN_CTRL_RSVD7_SHIFT      (7U)
#define MIPI_CSI2_DPHY_CMN_CTRL_RSVD7(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_CMN_CTRL_RSVD7_SHIFT)) & MIPI_CSI2_DPHY_CMN_CTRL_RSVD7_MASK)
#define MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL_MASK (0xC00000U)
#define MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL_SHIFT (22U)
#define MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL_SHIFT)) & MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL_MASK)
#define MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE_MASK    (0xFF000000U)
#define MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE_SHIFT   (24U)
#define MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE(x)      (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE_SHIFT)) & MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE_MASK)

/*! @name DPHY_BCTRL_L - D-PHY Master and Slave Control register low */
#define MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL_MASK   (0xFFFFFFFFU)
#define MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL_SHIFT  (0U)
#define MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL_SHIFT)) & MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL_MASK)

/*! @name DPHY_BCTRL_H - D-PHY Master and Slave Control register high */
#define MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL_MASK   (0xFFFFFFFFU)
#define MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL_SHIFT  (0U)
#define MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL_SHIFT)) & MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL_MASK)

/*! @name DPHY_SCTRL_L - D-PHY Slave Control register low */
#define MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL_MASK   (0xFFFFFFFFU)
#define MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL_SHIFT  (0U)
#define MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL_SHIFT)) & MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL_MASK)

/*! @name DPHY_SCTRL_H - D-PHY Slave Control register high */
#define MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL_MASK   (0xFFFFFFFFU)
#define MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL_SHIFT  (0U)
#define MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL_SHIFT)) & MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL_MASK)

/*! @name ISP_CONFIG_CH0 - ISP Configuration register of CH0 */
#define MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL_MASK (0x3U)
#define MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL_SHIFT (0U)
#define MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL_SHIFT)) & MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL_MASK)
#define MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT_MASK (0xFCU)
#define MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT_SHIFT (2U)
#define MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT(x)   (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT_SHIFT)) & MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT_MASK)
#define MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN_MASK  (0x100U)
#define MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN_SHIFT (8U)
#define MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT_MASK (0x200U)
#define MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT_SHIFT (9U)
#define MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP_MASK   (0x400U)
#define MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP_SHIFT  (10U)
#define MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL_MASK   (0x800U)
#define MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL_SHIFT  (11U)
#define MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT_MASK (0x1000U)
#define MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT_SHIFT (12U)
#define MIPI_CSI2_ISP_CONFIG_CH0_RSVD8_MASK      (0xFFE000U)
#define MIPI_CSI2_ISP_CONFIG_CH0_RSVD8_SHIFT     (13U)
#define MIPI_CSI2_ISP_CONFIG_CH0_RSVD8(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_CONFIG_CH0_RSVD8_SHIFT)) & MIPI_CSI2_ISP_CONFIG_CH0_RSVD8_MASK)
#define MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP_MASK (0xFF000000U)
#define MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP_SHIFT (24U)
#define MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP_SHIFT)) & MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP_MASK)

/*! @name ISP_RESOL_CH0 - ISP Image Resolution register of CH0 */
#define MIPI_CSI2_ISP_RESOL_CH0_HRESOL_MASK      (0xFFFFU)
#define MIPI_CSI2_ISP_RESOL_CH0_HRESOL_SHIFT     (0U)
#define MIPI_CSI2_ISP_RESOL_CH0_HRESOL(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_RESOL_CH0_HRESOL_SHIFT)) & MIPI_CSI2_ISP_RESOL_CH0_HRESOL_MASK)
#define MIPI_CSI2_ISP_RESOL_CH0_VRESOL_MASK      (0xFFFF0000U)
#define MIPI_CSI2_ISP_RESOL_CH0_VRESOL_SHIFT     (16U)
#define MIPI_CSI2_ISP_RESOL_CH0_VRESOL(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_RESOL_CH0_VRESOL_SHIFT)) & MIPI_CSI2_ISP_RESOL_CH0_VRESOL_MASK)

/*! @name ISP_SYNC_CH0 - ISP SYNC register of CH0 */
#define MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV_MASK  (0xFFFU)
#define MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV_SHIFT (0U)
#define MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV_SHIFT)) & MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV_MASK)
#define MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV_MASK  (0x3F000U)
#define MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV_SHIFT (12U)
#define MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV_SHIFT)) & MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV_MASK)
#define MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV_MASK  (0xFC0000U)
#define MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV_SHIFT (18U)
#define MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV_SHIFT)) & MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV_MASK)
#define MIPI_CSI2_ISP_SYNC_CH0_RSVD9_MASK        (0xFF000000U)
#define MIPI_CSI2_ISP_SYNC_CH0_RSVD9_SHIFT       (24U)
#define MIPI_CSI2_ISP_SYNC_CH0_RSVD9(x)          (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_ISP_SYNC_CH0_RSVD9_SHIFT)) & MIPI_CSI2_ISP_SYNC_CH0_RSVD9_MASK)

/*! @name SDW_CONFIG_CH0 - Shadow Configuration register of CH0 */
#define MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL_MASK (0x3U)
#define MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL_SHIFT (0U)
#define MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL_SHIFT)) & MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL_MASK)
#define MIPI_CSI2_SDW_CONFIG_CH0_DataFormat_MASK (0xFCU)
#define MIPI_CSI2_SDW_CONFIG_CH0_DataFormat_SHIFT (2U)
#define MIPI_CSI2_SDW_CONFIG_CH0_DataFormat(x)   (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_CONFIG_CH0_DataFormat_SHIFT)) & MIPI_CSI2_SDW_CONFIG_CH0_DataFormat_MASK)
#define MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW_MASK (0x100U)
#define MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW_SHIFT (8U)
#define MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW_MASK (0x200U)
#define MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW_SHIFT (9U)
#define MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW_MASK (0x400U)
#define MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW_SHIFT (10U)
#define MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW_MASK (0x800U)
#define MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW_SHIFT (11U)
#define MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW_MASK (0x1000U)
#define MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW_SHIFT (12U)
#define MIPI_CSI2_SDW_CONFIG_CH0_RSVD10_MASK     (0xFFE000U)
#define MIPI_CSI2_SDW_CONFIG_CH0_RSVD10_SHIFT    (13U)
#define MIPI_CSI2_SDW_CONFIG_CH0_RSVD10(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_CONFIG_CH0_RSVD10_SHIFT)) & MIPI_CSI2_SDW_CONFIG_CH0_RSVD10_MASK)
#define MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW_MASK (0xFF000000U)
#define MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW_SHIFT (24U)
#define MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW_SHIFT)) & MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW_MASK)

/*! @name SDW_RESOL_CH0 - Shadow Resolution register of CH0 */
#define MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW_MASK  (0xFFFFU)
#define MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW_SHIFT (0U)
#define MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW_SHIFT)) & MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW_MASK)
#define MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW_MASK  (0xFFFF0000U)
#define MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW_SHIFT (16U)
#define MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW_SHIFT)) & MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW_MASK)

/*! @name SDW_SYNC_CH0 - Shadow SYNC register of CH0 */
#define MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW_MASK (0xFFFU)
#define MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW_SHIFT (0U)
#define MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW_SHIFT)) & MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW_MASK)
#define MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW_MASK (0x3F000U)
#define MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW_SHIFT (12U)
#define MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW_SHIFT)) & MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW_MASK)
#define MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW_MASK (0xFC0000U)
#define MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW_SHIFT (18U)
#define MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW_SHIFT)) & MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW_MASK)
#define MIPI_CSI2_SDW_SYNC_CH0_RSVD11_MASK       (0xFF000000U)
#define MIPI_CSI2_SDW_SYNC_CH0_RSVD11_SHIFT      (24U)
#define MIPI_CSI2_SDW_SYNC_CH0_RSVD11(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_SDW_SYNC_CH0_RSVD11_SHIFT)) & MIPI_CSI2_SDW_SYNC_CH0_RSVD11_MASK)

/*! @name DBG_CTRL - Debug Control register */
#define MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT_MASK    (0xFU)
#define MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT_SHIFT   (0U)
#define MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT(x)      (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT_SHIFT)) & MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT_MASK)
#define MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME_MASK (0xF0U)
#define MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME_SHIFT (4U)
#define MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME(x)  (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME_SHIFT)) & MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME_MASK)
#define MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE_MASK (0xF00U)
#define MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE_SHIFT (8U)
#define MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE_SHIFT)) & MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE_MASK)
#define MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE_MASK (0xF000U)
#define MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE_SHIFT (12U)
#define MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE(x)   (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE_SHIFT)) & MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE_MASK)
#define MIPI_CSI2_DBG_CTRL_RSVD12_MASK           (0xFFFF0000U)
#define MIPI_CSI2_DBG_CTRL_RSVD12_SHIFT          (16U)
#define MIPI_CSI2_DBG_CTRL_RSVD12(x)             (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_CTRL_RSVD12_SHIFT)) & MIPI_CSI2_DBG_CTRL_RSVD12_MASK)

/*! @name DBG_INTR_MSK - Debug Interrupt Mask */
#define MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE_MASK (0xFU)
#define MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE_SHIFT (0U)
#define MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE_SHIFT)) & MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE_MASK)
#define MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL_MASK (0xF0U)
#define MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL_SHIFT (4U)
#define MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL_SHIFT)) & MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL_MASK)
#define MIPI_CSI2_DBG_INTR_MSK_EARLY_FS_MASK     (0xF00U)
#define MIPI_CSI2_DBG_INTR_MSK_EARLY_FS_SHIFT    (8U)
#define MIPI_CSI2_DBG_INTR_MSK_EARLY_FS(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_MSK_EARLY_FS_SHIFT)) & MIPI_CSI2_DBG_INTR_MSK_EARLY_FS_MASK)
#define MIPI_CSI2_DBG_INTR_MSK_EARLY_FE_MASK     (0xF000U)
#define MIPI_CSI2_DBG_INTR_MSK_EARLY_FE_SHIFT    (12U)
#define MIPI_CSI2_DBG_INTR_MSK_EARLY_FE(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_MSK_EARLY_FE_SHIFT)) & MIPI_CSI2_DBG_INTR_MSK_EARLY_FE_MASK)
#define MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME_MASK (0xF0000U)
#define MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME_SHIFT (16U)
#define MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME_SHIFT)) & MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME_MASK)
#define MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE_MASK (0xF00000U)
#define MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE_SHIFT (20U)
#define MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE_SHIFT)) & MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE_MASK)
#define MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE_MASK    (0x1000000U)
#define MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE_SHIFT   (24U)
#define MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT_MASK (0x2000000U)
#define MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT_SHIFT (25U)
#define MIPI_CSI2_DBG_INTR_MSK_RSVD13_MASK       (0xFC000000U)
#define MIPI_CSI2_DBG_INTR_MSK_RSVD13_SHIFT      (26U)
#define MIPI_CSI2_DBG_INTR_MSK_RSVD13(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_MSK_RSVD13_SHIFT)) & MIPI_CSI2_DBG_INTR_MSK_RSVD13_MASK)

/*! @name DBG_INTR_SRC - Debug Interrupt Mask */
#define MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE_MASK (0xFU)
#define MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE_SHIFT (0U)
#define MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE_SHIFT)) & MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE_MASK)
#define MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL_MASK (0xF0U)
#define MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL_SHIFT (4U)
#define MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL_SHIFT)) & MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL_MASK)
#define MIPI_CSI2_DBG_INTR_SRC_EARLY_FS_MASK     (0xF00U)
#define MIPI_CSI2_DBG_INTR_SRC_EARLY_FS_SHIFT    (8U)
#define MIPI_CSI2_DBG_INTR_SRC_EARLY_FS(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_SRC_EARLY_FS_SHIFT)) & MIPI_CSI2_DBG_INTR_SRC_EARLY_FS_MASK)
#define MIPI_CSI2_DBG_INTR_SRC_EARLY_FE_MASK     (0xF000U)
#define MIPI_CSI2_DBG_INTR_SRC_EARLY_FE_SHIFT    (12U)
#define MIPI_CSI2_DBG_INTR_SRC_EARLY_FE(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_SRC_EARLY_FE_SHIFT)) & MIPI_CSI2_DBG_INTR_SRC_EARLY_FE_MASK)
#define MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME_MASK (0xF0000U)
#define MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME_SHIFT (16U)
#define MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME_SHIFT)) & MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME_MASK)
#define MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE_MASK (0xF00000U)
#define MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE_SHIFT (20U)
#define MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE(x) (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE_SHIFT)) & MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE_MASK)
#define MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE_MASK    (0x1000000U)
#define MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE_SHIFT   (24U)
#define MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT_MASK (0x2000000U)
#define MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT_SHIFT (25U)
#define MIPI_CSI2_DBG_INTR_SRC_RSVD14_MASK       (0xFC000000U)
#define MIPI_CSI2_DBG_INTR_SRC_RSVD14_SHIFT      (26U)
#define MIPI_CSI2_DBG_INTR_SRC_RSVD14(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_DBG_INTR_SRC_RSVD14_SHIFT)) & MIPI_CSI2_DBG_INTR_SRC_RSVD14_MASK)

/*! @name NON_IMG_DATA - Non Image Data */
#define MIPI_CSI2_NON_IMG_DATA_NONIMGDATA_MASK   (0xFFFFFFFFU)
#define MIPI_CSI2_NON_IMG_DATA_NONIMGDATA_SHIFT  (0U)
#define MIPI_CSI2_NON_IMG_DATA_NONIMGDATA(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_CSI2_NON_IMG_DATA_NONIMGDATA_SHIFT)) & MIPI_CSI2_NON_IMG_DATA_NONIMGDATA_MASK)


/*!
 * @}
 */ /* end of group MIPI_CSI2_Register_Masks */


/* MIPI_CSI2 - Peripheral instance base addresses */
/** Peripheral MIPI_CSI2 base pointer */
#define MIPI_CSI2_BASE_PTR                       ((MIPI_CSI2_MemMapPtr)0x30750000u)
/** Array initializer of MIPI_CSI2 peripheral base pointers */
#define MIPI_CSI2_BASE_PTRS                      { MIPI_CSI2_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- MIPI_CSI2 - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MIPI_CSI2_Register_Accessor_Macros MIPI_CSI2 - Register accessor macros
 * @{
 */


/* MIPI_CSI2 - Register instance definitions */
/* MIPI_CSI2 */
#define MIPI_CSI2_CSIS_CMN_CTRL                  MIPI_CSI2_CSIS_CMN_CTRL_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_CSIS_CLK_CTRL                  MIPI_CSI2_CSIS_CLK_CTRL_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_CSIS_INT_MSK                   MIPI_CSI2_CSIS_INT_MSK_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_CSIS_INT_SRC                   MIPI_CSI2_CSIS_INT_SRC_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DPHY_STATUS                    MIPI_CSI2_DPHY_STATUS_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DPHY_CMN_CTRL                  MIPI_CSI2_DPHY_CMN_CTRL_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DPHY_BCTRL_L                   MIPI_CSI2_DPHY_BCTRL_L_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DPHY_BCTRL_H                   MIPI_CSI2_DPHY_BCTRL_H_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DPHY_SCTRL_L                   MIPI_CSI2_DPHY_SCTRL_L_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DPHY_SCTRL_H                   MIPI_CSI2_DPHY_SCTRL_H_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_ISP_CONFIG_CH0                 MIPI_CSI2_ISP_CONFIG_CH0_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_ISP_RESOL_CH0                  MIPI_CSI2_ISP_RESOL_CH0_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_ISP_SYNC_CH0                   MIPI_CSI2_ISP_SYNC_CH0_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_SDW_CONFIG_CH0                 MIPI_CSI2_SDW_CONFIG_CH0_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_SDW_RESOL_CH0                  MIPI_CSI2_SDW_RESOL_CH0_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_SDW_SYNC_CH0                   MIPI_CSI2_SDW_SYNC_CH0_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DBG_CTRL                       MIPI_CSI2_DBG_CTRL_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DBG_INTR_MSK                   MIPI_CSI2_DBG_INTR_MSK_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_DBG_INTR_SRC                   MIPI_CSI2_DBG_INTR_SRC_REG(MIPI_CSI2_BASE_PTR)
#define MIPI_CSI2_NON_IMG_DATA                   MIPI_CSI2_NON_IMG_DATA_REG(MIPI_CSI2_BASE_PTR)

/*!
 * @}
 */ /* end of group MIPI_CSI2_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group MIPI_CSI2_Peripheral */


/* ----------------------------------------------------------------------------
   -- MIPI_DSI
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MIPI_DSI_Peripheral MIPI_DSI
 * @{
 */

/** MIPI_DSI - Peripheral register structure */
typedef struct MIPI_DSI_MemMap {
  uint32_t VERSION;                                /**< Version Register, offset: 0x0 */
  uint32_t STATUS;                                 /**< , offset: 0x4 */
  uint32_t RGB_STATUS;                             /**< RGB Status Register, offset: 0x8 */
  uint32_t SWRST;                                  /**< , offset: 0xC */
  uint32_t CLKCTRL;                                /**< Clock Control Register, offset: 0x10 */
  uint32_t TIMEOUT;                                /**< , offset: 0x14 */
  uint32_t CONFIG;                                 /**< , offset: 0x18 */
  uint32_t ESCMODE;                                /**< Escape Mode Register, offset: 0x1C */
  uint32_t MDRESOL;                                /**< Main Display Image Resolution Register, offset: 0x20 */
  uint32_t MVPORCH;                                /**< Main Display VPORCH Register, offset: 0x24 */
  uint32_t MHPORCH;                                /**< , offset: 0x28 */
  uint32_t MSYNC;                                  /**< , offset: 0x2C */
  uint32_t SDRESOL;                                /**< Sub Display Image Resolution Register, offset: 0x30 */
  uint32_t INTSRC;                                 /**< Interrupt Source Register, offset: 0x34 */
  uint32_t INTMSK;                                 /**< Interrupt Mask Register, offset: 0x38 */
  uint32_t PKTHDR;                                 /**< Packet Header FIFO Register, offset: 0x3C */
  uint32_t PAYLOAD;                                /**< Payload FIFO Register, offset: 0x40 */
  uint32_t RXFIFO;                                 /**< Payload FIFO Register, offset: 0x44 */
  uint32_t FIFOTHLD;                               /**< FIFO Threshold Level Register, offset: 0x48 */
  uint32_t FIFOCTRL;                               /**< FIFO Status and Control Register, offset: 0x4C */
  uint32_t MEMACCHR;                               /**< FIFO Memory AC Characteristic Register, offset: 0x50 */
  uint8_t RESERVED_0[36];
  uint32_t MULTI_PKT;                              /**< , offset: 0x78 */
  uint8_t RESERVED_1[20];
  uint32_t PLLCTRL_1G;                             /**< 1 Gbps D-PHY PLL Control Register, offset: 0x90 */
  uint32_t PLLCTRL;                                /**< PLL Control register, offset: 0x94 */
  uint32_t PLLCTRL1;                               /**< PLL Control Register 1, offset: 0x98 */
  uint32_t PLLCTRL2;                               /**< PLL control register 2, offset: 0x9C */
  uint32_t PLLTMR;                                 /**< PLL Timer Register, offset: 0xA0 */
  uint32_t PHYCTRL_B1;                             /**< D-PHY Master and Slave Analog Block Control Register 1, offset: 0xA4 */
  uint32_t PHYCTRL_B2;                             /**< D-PHY Master and Slave Analog Block Control Register 2, offset: 0xA8 */
  uint32_t PHYCTRL_M1;                             /**< D-PHY Master Analog Block Control Register 1, offset: 0xAC */
  uint32_t PHYCTRL_M2;                             /**< D-PHY Master Analog Block Control Register 1, offset: 0xB0 */
  uint32_t PHYTIMING;                              /**< D-PHY Timing register, offset: 0xB4 */
  uint32_t PHYTIMING1;                             /**< , offset: 0xB8 */
  uint32_t PHYTIMING2;                             /**< D-PHY Timing Register 2, offset: 0xBC */
} volatile *MIPI_DSI_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- MIPI_DSI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MIPI_DSI_Register_Accessor_Macros MIPI_DSI - Register accessor macros
 * @{
 */


/* MIPI_DSI - Register accessors */
#define MIPI_DSI_VERSION_REG(base)               ((base)->VERSION)
#define MIPI_DSI_STATUS_REG(base)                ((base)->STATUS)
#define MIPI_DSI_RGB_STATUS_REG(base)            ((base)->RGB_STATUS)
#define MIPI_DSI_SWRST_REG(base)                 ((base)->SWRST)
#define MIPI_DSI_CLKCTRL_REG(base)               ((base)->CLKCTRL)
#define MIPI_DSI_TIMEOUT_REG(base)               ((base)->TIMEOUT)
#define MIPI_DSI_CONFIG_REG(base)                ((base)->CONFIG)
#define MIPI_DSI_ESCMODE_REG(base)               ((base)->ESCMODE)
#define MIPI_DSI_MDRESOL_REG(base)               ((base)->MDRESOL)
#define MIPI_DSI_MVPORCH_REG(base)               ((base)->MVPORCH)
#define MIPI_DSI_MHPORCH_REG(base)               ((base)->MHPORCH)
#define MIPI_DSI_MSYNC_REG(base)                 ((base)->MSYNC)
#define MIPI_DSI_SDRESOL_REG(base)               ((base)->SDRESOL)
#define MIPI_DSI_INTSRC_REG(base)                ((base)->INTSRC)
#define MIPI_DSI_INTMSK_REG(base)                ((base)->INTMSK)
#define MIPI_DSI_PKTHDR_REG(base)                ((base)->PKTHDR)
#define MIPI_DSI_PAYLOAD_REG(base)               ((base)->PAYLOAD)
#define MIPI_DSI_RXFIFO_REG(base)                ((base)->RXFIFO)
#define MIPI_DSI_FIFOTHLD_REG(base)              ((base)->FIFOTHLD)
#define MIPI_DSI_FIFOCTRL_REG(base)              ((base)->FIFOCTRL)
#define MIPI_DSI_MEMACCHR_REG(base)              ((base)->MEMACCHR)
#define MIPI_DSI_MULTI_PKT_REG(base)             ((base)->MULTI_PKT)
#define MIPI_DSI_PLLCTRL_1G_REG(base)            ((base)->PLLCTRL_1G)
#define MIPI_DSI_PLLCTRL_REG(base)               ((base)->PLLCTRL)
#define MIPI_DSI_PLLCTRL1_REG(base)              ((base)->PLLCTRL1)
#define MIPI_DSI_PLLCTRL2_REG(base)              ((base)->PLLCTRL2)
#define MIPI_DSI_PLLTMR_REG(base)                ((base)->PLLTMR)
#define MIPI_DSI_PHYCTRL_B1_REG(base)            ((base)->PHYCTRL_B1)
#define MIPI_DSI_PHYCTRL_B2_REG(base)            ((base)->PHYCTRL_B2)
#define MIPI_DSI_PHYCTRL_M1_REG(base)            ((base)->PHYCTRL_M1)
#define MIPI_DSI_PHYCTRL_M2_REG(base)            ((base)->PHYCTRL_M2)
#define MIPI_DSI_PHYTIMING_REG(base)             ((base)->PHYTIMING)
#define MIPI_DSI_PHYTIMING1_REG(base)            ((base)->PHYTIMING1)
#define MIPI_DSI_PHYTIMING2_REG(base)            ((base)->PHYTIMING2)

/*!
 * @}
 */ /* end of group MIPI_DSI_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- MIPI_DSI Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MIPI_DSI_Register_Masks MIPI_DSI Register Masks
 * @{
 */

/*! @name VERSION - Version Register */
#define MIPI_DSI_VERSION_VERSION_MASK            (0xFFFFFFFFU)
#define MIPI_DSI_VERSION_VERSION_SHIFT           (0U)
#define MIPI_DSI_VERSION_VERSION(x)              (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_VERSION_VERSION_SHIFT)) & MIPI_DSI_VERSION_VERSION_MASK)

/*! @name STATUS -  */
#define MIPI_DSI_STATUS_STOPSTATEDAT_MASK        (0xFU)
#define MIPI_DSI_STATUS_STOPSTATEDAT_SHIFT       (0U)
#define MIPI_DSI_STATUS_STOPSTATEDAT(x)          (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_STATUS_STOPSTATEDAT_SHIFT)) & MIPI_DSI_STATUS_STOPSTATEDAT_MASK)
#define MIPI_DSI_STATUS_ULPSDAT_MASK             (0xF0U)
#define MIPI_DSI_STATUS_ULPSDAT_SHIFT            (4U)
#define MIPI_DSI_STATUS_ULPSDAT(x)               (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_STATUS_ULPSDAT_SHIFT)) & MIPI_DSI_STATUS_ULPSDAT_MASK)
#define MIPI_DSI_STATUS_STOPSTATECLK_MASK        (0x100U)
#define MIPI_DSI_STATUS_STOPSTATECLK_SHIFT       (8U)
#define MIPI_DSI_STATUS_ULPSCLK_MASK             (0x200U)
#define MIPI_DSI_STATUS_ULPSCLK_SHIFT            (9U)
#define MIPI_DSI_STATUS_TXREADYHSCLK_MASK        (0x400U)
#define MIPI_DSI_STATUS_TXREADYHSCLK_SHIFT       (10U)
#define MIPI_DSI_STATUS_DIRECTION_MASK           (0x10000U)
#define MIPI_DSI_STATUS_DIRECTION_SHIFT          (16U)
#define MIPI_DSI_STATUS_SWRSTRLS_MASK            (0x100000U)
#define MIPI_DSI_STATUS_SWRSTRLS_SHIFT           (20U)
#define MIPI_DSI_STATUS_PLLSTABLE_MASK           (0x80000000U)
#define MIPI_DSI_STATUS_PLLSTABLE_SHIFT          (31U)

/*! @name RGB_STATUS - RGB Status Register */
#define MIPI_DSI_RGB_STATUS_RGBSTATE_MASK        (0x1FFFU)
#define MIPI_DSI_RGB_STATUS_RGBSTATE_SHIFT       (0U)
#define MIPI_DSI_RGB_STATUS_RGBSTATE(x)          (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_RGB_STATUS_RGBSTATE_SHIFT)) & MIPI_DSI_RGB_STATUS_RGBSTATE_MASK)
#define MIPI_DSI_RGB_STATUS_CMDMODE_INSEL_MASK   (0x80000000U)
#define MIPI_DSI_RGB_STATUS_CMDMODE_INSEL_SHIFT  (31U)

/*! @name SWRST -  */
#define MIPI_DSI_SWRST_SWRST_MASK                (0x1U)
#define MIPI_DSI_SWRST_SWRST_SHIFT               (0U)
#define MIPI_DSI_SWRST_FUNCRST_MASK              (0x10000U)
#define MIPI_DSI_SWRST_FUNCRST_SHIFT             (16U)

/*! @name CLKCTRL - Clock Control Register */
#define MIPI_DSI_CLKCTRL_ESCPRESCALER_MASK       (0xFFFFU)
#define MIPI_DSI_CLKCTRL_ESCPRESCALER_SHIFT      (0U)
#define MIPI_DSI_CLKCTRL_ESCPRESCALER(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CLKCTRL_ESCPRESCALER_SHIFT)) & MIPI_DSI_CLKCTRL_ESCPRESCALER_MASK)
#define MIPI_DSI_CLKCTRL_LANEESCCLKEN_MASK       (0xF80000U)
#define MIPI_DSI_CLKCTRL_LANEESCCLKEN_SHIFT      (19U)
#define MIPI_DSI_CLKCTRL_LANEESCCLKEN(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CLKCTRL_LANEESCCLKEN_SHIFT)) & MIPI_DSI_CLKCTRL_LANEESCCLKEN_MASK)
#define MIPI_DSI_CLKCTRL_ByteClkEn_MASK          (0x1000000U)
#define MIPI_DSI_CLKCTRL_ByteClkEn_SHIFT         (24U)
#define MIPI_DSI_CLKCTRL_BYTECLKSRC_MASK         (0x6000000U)
#define MIPI_DSI_CLKCTRL_BYTECLKSRC_SHIFT        (25U)
#define MIPI_DSI_CLKCTRL_BYTECLKSRC(x)           (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CLKCTRL_BYTECLKSRC_SHIFT)) & MIPI_DSI_CLKCTRL_BYTECLKSRC_MASK)
#define MIPI_DSI_CLKCTRL_PLLBYPASS_MASK          (0x8000000U)
#define MIPI_DSI_CLKCTRL_PLLBYPASS_SHIFT         (27U)
#define MIPI_DSI_CLKCTRL_ESCCLKEN_MASK           (0x10000000U)
#define MIPI_DSI_CLKCTRL_ESCCLKEN_SHIFT          (28U)
#define MIPI_DSI_CLKCTRL_DPHY_SEL_MASK           (0x20000000U)
#define MIPI_DSI_CLKCTRL_DPHY_SEL_SHIFT          (29U)
#define MIPI_DSI_CLKCTRL_TXREQUESTHSCLK_MASK     (0x80000000U)
#define MIPI_DSI_CLKCTRL_TXREQUESTHSCLK_SHIFT    (31U)

/*! @name TIMEOUT -  */
#define MIPI_DSI_TIMEOUT_LPDRTOUT_MASK           (0xFFFFU)
#define MIPI_DSI_TIMEOUT_LPDRTOUT_SHIFT          (0U)
#define MIPI_DSI_TIMEOUT_LPDRTOUT(x)             (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_TIMEOUT_LPDRTOUT_SHIFT)) & MIPI_DSI_TIMEOUT_LPDRTOUT_MASK)
#define MIPI_DSI_TIMEOUT_BTAOUT_MASK             (0xFF0000U)
#define MIPI_DSI_TIMEOUT_BTAOUT_SHIFT            (16U)
#define MIPI_DSI_TIMEOUT_BTAOUT(x)               (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_TIMEOUT_BTAOUT_SHIFT)) & MIPI_DSI_TIMEOUT_BTAOUT_MASK)

/*! @name CONFIG -  */
#define MIPI_DSI_CONFIG_LANEEN_MASK              (0x1FU)
#define MIPI_DSI_CONFIG_LANEEN_SHIFT             (0U)
#define MIPI_DSI_CONFIG_LANEEN(x)                (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CONFIG_LANEEN_SHIFT)) & MIPI_DSI_CONFIG_LANEEN_MASK)
#define MIPI_DSI_CONFIG_NUMOFDATLANE_MASK        (0x60U)
#define MIPI_DSI_CONFIG_NUMOFDATLANE_SHIFT       (5U)
#define MIPI_DSI_CONFIG_NUMOFDATLANE(x)          (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CONFIG_NUMOFDATLANE_SHIFT)) & MIPI_DSI_CONFIG_NUMOFDATLANE_MASK)
#define MIPI_DSI_CONFIG_SUBPIXFORMAT_MASK        (0x700U)
#define MIPI_DSI_CONFIG_SUBPIXFORMAT_SHIFT       (8U)
#define MIPI_DSI_CONFIG_SUBPIXFORMAT(x)          (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CONFIG_SUBPIXFORMAT_SHIFT)) & MIPI_DSI_CONFIG_SUBPIXFORMAT_MASK)
#define MIPI_DSI_CONFIG_MAINPIXFORMAT_MASK       (0x7000U)
#define MIPI_DSI_CONFIG_MAINPIXFORMAT_SHIFT      (12U)
#define MIPI_DSI_CONFIG_MAINPIXFORMAT(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CONFIG_MAINPIXFORMAT_SHIFT)) & MIPI_DSI_CONFIG_MAINPIXFORMAT_MASK)
#define MIPI_DSI_CONFIG_SUBVC_MASK               (0x30000U)
#define MIPI_DSI_CONFIG_SUBVC_SHIFT              (16U)
#define MIPI_DSI_CONFIG_SUBVC(x)                 (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CONFIG_SUBVC_SHIFT)) & MIPI_DSI_CONFIG_SUBVC_MASK)
#define MIPI_DSI_CONFIG_MAINVC_MASK              (0xC0000U)
#define MIPI_DSI_CONFIG_MAINVC_SHIFT             (18U)
#define MIPI_DSI_CONFIG_MAINVC(x)                (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_CONFIG_MAINVC_SHIFT)) & MIPI_DSI_CONFIG_MAINVC_MASK)
#define MIPI_DSI_CONFIG_HSADISABLEMODE_MASK      (0x100000U)
#define MIPI_DSI_CONFIG_HSADISABLEMODE_SHIFT     (20U)
#define MIPI_DSI_CONFIG_HBPDISABLEMODE_MASK      (0x200000U)
#define MIPI_DSI_CONFIG_HBPDISABLEMODE_SHIFT     (21U)
#define MIPI_DSI_CONFIG_HFPDISABLEMODE_MASK      (0x400000U)
#define MIPI_DSI_CONFIG_HFPDISABLEMODE_SHIFT     (22U)
#define MIPI_DSI_CONFIG_HSEDISABLEMODE_MASK      (0x800000U)
#define MIPI_DSI_CONFIG_HSEDISABLEMODE_SHIFT     (23U)
#define MIPI_DSI_CONFIG_AUTOMODE_MASK            (0x1000000U)
#define MIPI_DSI_CONFIG_AUTOMODE_SHIFT           (24U)
#define MIPI_DSI_CONFIG_VIDEOMODE_MASK           (0x2000000U)
#define MIPI_DSI_CONFIG_VIDEOMODE_SHIFT          (25U)
#define MIPI_DSI_CONFIG_BURSTMODE_MASK           (0x4000000U)
#define MIPI_DSI_CONFIG_BURSTMODE_SHIFT          (26U)
#define MIPI_DSI_CONFIG_SYNCINFORM_MASK          (0x8000000U)
#define MIPI_DSI_CONFIG_SYNCINFORM_SHIFT         (27U)
#define MIPI_DSI_CONFIG_EOT_R03_MASK             (0x10000000U)
#define MIPI_DSI_CONFIG_EOT_R03_SHIFT            (28U)
#define MIPI_DSI_CONFIG_MFLUSH_VS_MASK           (0x20000000U)
#define MIPI_DSI_CONFIG_MFLUSH_VS_SHIFT          (29U)
#define MIPI_DSI_CONFIG_CLKLANE_STOP_START_MASK  (0x40000000U)
#define MIPI_DSI_CONFIG_CLKLANE_STOP_START_SHIFT (30U)
#define MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE_MASK (0x80000000U)
#define MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE_SHIFT (31U)

/*! @name ESCMODE - Escape Mode Register */
#define MIPI_DSI_ESCMODE_TXULPSCLKEXIT_MASK      (0x1U)
#define MIPI_DSI_ESCMODE_TXULPSCLKEXIT_SHIFT     (0U)
#define MIPI_DSI_ESCMODE_TXULPSCLK_MASK          (0x2U)
#define MIPI_DSI_ESCMODE_TXULPSCLK_SHIFT         (1U)
#define MIPI_DSI_ESCMODE_TXULPSEXIT_MASK         (0x4U)
#define MIPI_DSI_ESCMODE_TXULPSEXIT_SHIFT        (2U)
#define MIPI_DSI_ESCMODE_TXULPSDAT_MASK          (0x8U)
#define MIPI_DSI_ESCMODE_TXULPSDAT_SHIFT         (3U)
#define MIPI_DSI_ESCMODE_TXTRIGGERRST_MASK       (0x10U)
#define MIPI_DSI_ESCMODE_TXTRIGGERRST_SHIFT      (4U)
#define MIPI_DSI_ESCMODE_TXLPDT_MASK             (0x40U)
#define MIPI_DSI_ESCMODE_TXLPDT_SHIFT            (6U)
#define MIPI_DSI_ESCMODE_CMDLPDT_MASK            (0x80U)
#define MIPI_DSI_ESCMODE_CMDLPDT_SHIFT           (7U)
#define MIPI_DSI_ESCMODE_FORCEBTA_MASK           (0x10000U)
#define MIPI_DSI_ESCMODE_FORCEBTA_SHIFT          (16U)
#define MIPI_DSI_ESCMODE_FORCESTOPSTATE_MASK     (0x100000U)
#define MIPI_DSI_ESCMODE_FORCESTOPSTATE_SHIFT    (20U)
#define MIPI_DSI_ESCMODE_STOPSTATE_CNT_MASK      (0xFFE00000U)
#define MIPI_DSI_ESCMODE_STOPSTATE_CNT_SHIFT     (21U)
#define MIPI_DSI_ESCMODE_STOPSTATE_CNT(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_ESCMODE_STOPSTATE_CNT_SHIFT)) & MIPI_DSI_ESCMODE_STOPSTATE_CNT_MASK)

/*! @name MDRESOL - Main Display Image Resolution Register */
#define MIPI_DSI_MDRESOL_MAINHRESOL_MASK         (0xFFFU)
#define MIPI_DSI_MDRESOL_MAINHRESOL_SHIFT        (0U)
#define MIPI_DSI_MDRESOL_MAINHRESOL(x)           (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MDRESOL_MAINHRESOL_SHIFT)) & MIPI_DSI_MDRESOL_MAINHRESOL_MASK)
#define MIPI_DSI_MDRESOL_MainVResol_MASK         (0xFFF0000U)
#define MIPI_DSI_MDRESOL_MainVResol_SHIFT        (16U)
#define MIPI_DSI_MDRESOL_MainVResol(x)           (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MDRESOL_MainVResol_SHIFT)) & MIPI_DSI_MDRESOL_MainVResol_MASK)
#define MIPI_DSI_MDRESOL_MAINSTANDBY_MASK        (0x80000000U)
#define MIPI_DSI_MDRESOL_MAINSTANDBY_SHIFT       (31U)

/*! @name MVPORCH - Main Display VPORCH Register */
#define MIPI_DSI_MVPORCH_MAINVBP_MASK            (0x7FFU)
#define MIPI_DSI_MVPORCH_MAINVBP_SHIFT           (0U)
#define MIPI_DSI_MVPORCH_MAINVBP(x)              (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MVPORCH_MAINVBP_SHIFT)) & MIPI_DSI_MVPORCH_MAINVBP_MASK)
#define MIPI_DSI_MVPORCH_STABLEVFP_MASK          (0x7FF0000U)
#define MIPI_DSI_MVPORCH_STABLEVFP_SHIFT         (16U)
#define MIPI_DSI_MVPORCH_STABLEVFP(x)            (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MVPORCH_STABLEVFP_SHIFT)) & MIPI_DSI_MVPORCH_STABLEVFP_MASK)
#define MIPI_DSI_MVPORCH_CMDALLOW_MASK           (0xF0000000U)
#define MIPI_DSI_MVPORCH_CMDALLOW_SHIFT          (28U)
#define MIPI_DSI_MVPORCH_CMDALLOW(x)             (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MVPORCH_CMDALLOW_SHIFT)) & MIPI_DSI_MVPORCH_CMDALLOW_MASK)

/*! @name MHPORCH -  */
#define MIPI_DSI_MHPORCH_MAINHBP_MASK            (0xFFFFU)
#define MIPI_DSI_MHPORCH_MAINHBP_SHIFT           (0U)
#define MIPI_DSI_MHPORCH_MAINHBP(x)              (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MHPORCH_MAINHBP_SHIFT)) & MIPI_DSI_MHPORCH_MAINHBP_MASK)
#define MIPI_DSI_MHPORCH_MAINHFP_MASK            (0xFFFF0000U)
#define MIPI_DSI_MHPORCH_MAINHFP_SHIFT           (16U)
#define MIPI_DSI_MHPORCH_MAINHFP(x)              (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MHPORCH_MAINHFP_SHIFT)) & MIPI_DSI_MHPORCH_MAINHFP_MASK)

/*! @name MSYNC -  */
#define MIPI_DSI_MSYNC_MAINHSA_MASK              (0xFFFFU)
#define MIPI_DSI_MSYNC_MAINHSA_SHIFT             (0U)
#define MIPI_DSI_MSYNC_MAINHSA(x)                (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MSYNC_MAINHSA_SHIFT)) & MIPI_DSI_MSYNC_MAINHSA_MASK)
#define MIPI_DSI_MSYNC_MAINVSA_MASK              (0xFFC00000U)
#define MIPI_DSI_MSYNC_MAINVSA_SHIFT             (22U)
#define MIPI_DSI_MSYNC_MAINVSA(x)                (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MSYNC_MAINVSA_SHIFT)) & MIPI_DSI_MSYNC_MAINVSA_MASK)

/*! @name SDRESOL - Sub Display Image Resolution Register */
#define MIPI_DSI_SDRESOL_SUBHRESOL_MASK          (0x7FFU)
#define MIPI_DSI_SDRESOL_SUBHRESOL_SHIFT         (0U)
#define MIPI_DSI_SDRESOL_SUBHRESOL(x)            (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_SDRESOL_SUBHRESOL_SHIFT)) & MIPI_DSI_SDRESOL_SUBHRESOL_MASK)
#define MIPI_DSI_SDRESOL_SUBVRESOL_MASK          (0x7FF0000U)
#define MIPI_DSI_SDRESOL_SUBVRESOL_SHIFT         (16U)
#define MIPI_DSI_SDRESOL_SUBVRESOL(x)            (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_SDRESOL_SUBVRESOL_SHIFT)) & MIPI_DSI_SDRESOL_SUBVRESOL_MASK)
#define MIPI_DSI_SDRESOL_SUBSTANDBY_MASK         (0x80000000U)
#define MIPI_DSI_SDRESOL_SUBSTANDBY_SHIFT        (31U)

/*! @name INTSRC - Interrupt Source Register */
#define MIPI_DSI_INTSRC_ERRCONTENTLP1_MASK       (0x1U)
#define MIPI_DSI_INTSRC_ERRCONTENTLP1_SHIFT      (0U)
#define MIPI_DSI_INTSRC_ERRCONTENTLP0_MASK       (0x2U)
#define MIPI_DSI_INTSRC_ERRCONTENTLP0_SHIFT      (1U)
#define MIPI_DSI_INTSRC_ERRCONTROL0_MASK         (0x4U)
#define MIPI_DSI_INTSRC_ERRCONTROL0_SHIFT        (2U)
#define MIPI_DSI_INTSRC_ERRCONTROL1_MASK         (0x8U)
#define MIPI_DSI_INTSRC_ERRCONTROL1_SHIFT        (3U)
#define MIPI_DSI_INTSRC_ERRSYNC0_MASK            (0x40U)
#define MIPI_DSI_INTSRC_ERRSYNC0_SHIFT           (6U)
#define MIPI_DSI_INTSRC_ERRSYNC1_MASK            (0x80U)
#define MIPI_DSI_INTSRC_ERRSYNC1_SHIFT           (7U)
#define MIPI_DSI_INTSRC_ERRESC0_MASK             (0x400U)
#define MIPI_DSI_INTSRC_ERRESC0_SHIFT            (10U)
#define MIPI_DSI_INTSRC_ERRESC1_MASK             (0x800U)
#define MIPI_DSI_INTSRC_ERRESC1_SHIFT            (11U)
#define MIPI_DSI_INTSRC_ERRRXCRC_MASK            (0x4000U)
#define MIPI_DSI_INTSRC_ERRRXCRC_SHIFT           (14U)
#define MIPI_DSI_INTSRC_ERRRXECC_MASK            (0x8000U)
#define MIPI_DSI_INTSRC_ERRRXECC_SHIFT           (15U)
#define MIPI_DSI_INTSRC_RXACK_MASK               (0x10000U)
#define MIPI_DSI_INTSRC_RXACK_SHIFT              (16U)
#define MIPI_DSI_INTSRC_RXTE_MASK                (0x20000U)
#define MIPI_DSI_INTSRC_RXTE_SHIFT               (17U)
#define MIPI_DSI_INTSRC_RXDATDONE_MASK           (0x40000U)
#define MIPI_DSI_INTSRC_RXDATDONE_SHIFT          (18U)
#define MIPI_DSI_INTSRC_TATOUT_MASK              (0x100000U)
#define MIPI_DSI_INTSRC_TATOUT_SHIFT             (20U)
#define MIPI_DSI_INTSRC_LPDRTOUT_MASK            (0x200000U)
#define MIPI_DSI_INTSRC_LPDRTOUT_SHIFT           (21U)
#define MIPI_DSI_INTSRC_FRAMEDONE_MASK           (0x1000000U)
#define MIPI_DSI_INTSRC_FRAMEDONE_SHIFT          (24U)
#define MIPI_DSI_INTSRC_BUSTURNOVER_MASK         (0x2000000U)
#define MIPI_DSI_INTSRC_BUSTURNOVER_SHIFT        (25U)
#define MIPI_DSI_INTSRC_SYNCOVERRIDE_MASK        (0x8000000U)
#define MIPI_DSI_INTSRC_SYNCOVERRIDE_SHIFT       (27U)
#define MIPI_DSI_INTSRC_SFRPHFIFOEMPTY_MASK      (0x10000000U)
#define MIPI_DSI_INTSRC_SFRPHFIFOEMPTY_SHIFT     (28U)
#define MIPI_DSI_INTSRC_SFRPLFIFOEMPTY_MASK      (0x20000000U)
#define MIPI_DSI_INTSRC_SFRPLFIFOEMPTY_SHIFT     (29U)
#define MIPI_DSI_INTSRC_SWRSTRELEASE_MASK        (0x40000000U)
#define MIPI_DSI_INTSRC_SWRSTRELEASE_SHIFT       (30U)
#define MIPI_DSI_INTSRC_PLLSTABLE_MASK           (0x80000000U)
#define MIPI_DSI_INTSRC_PLLSTABLE_SHIFT          (31U)

/*! @name INTMSK - Interrupt Mask Register */
#define MIPI_DSI_INTMSK_MSKCONTENTLP1_MASK       (0x1U)
#define MIPI_DSI_INTMSK_MSKCONTENTLP1_SHIFT      (0U)
#define MIPI_DSI_INTMSK_MSKCONTENTLP0_MASK       (0x2U)
#define MIPI_DSI_INTMSK_MSKCONTENTLP0_SHIFT      (1U)
#define MIPI_DSI_INTMSK_MSKCONTROL0_MASK         (0x4U)
#define MIPI_DSI_INTMSK_MSKCONTROL0_SHIFT        (2U)
#define MIPI_DSI_INTMSK_MSKCONTROL1_MASK         (0x8U)
#define MIPI_DSI_INTMSK_MSKCONTROL1_SHIFT        (3U)
#define MIPI_DSI_INTMSK_MSKSYNC0_MASK            (0x40U)
#define MIPI_DSI_INTMSK_MSKSYNC0_SHIFT           (6U)
#define MIPI_DSI_INTMSK_MSKSYNC1_MASK            (0x80U)
#define MIPI_DSI_INTMSK_MSKSYNC1_SHIFT           (7U)
#define MIPI_DSI_INTMSK_MSKESC0_MASK             (0x400U)
#define MIPI_DSI_INTMSK_MSKESC0_SHIFT            (10U)
#define MIPI_DSI_INTMSK_MSKESC1_MASK             (0x800U)
#define MIPI_DSI_INTMSK_MSKESC1_SHIFT            (11U)
#define MIPI_DSI_INTMSK_MSKRXCRC_MASK            (0x4000U)
#define MIPI_DSI_INTMSK_MSKRXCRC_SHIFT           (14U)
#define MIPI_DSI_INTMSK_MSKRXECC_MASK            (0x8000U)
#define MIPI_DSI_INTMSK_MSKRXECC_SHIFT           (15U)
#define MIPI_DSI_INTMSK_MSKRXACK_MASK            (0x10000U)
#define MIPI_DSI_INTMSK_MSKRXACK_SHIFT           (16U)
#define MIPI_DSI_INTMSK_MSKRXTE_MASK             (0x20000U)
#define MIPI_DSI_INTMSK_MSKRXTE_SHIFT            (17U)
#define MIPI_DSI_INTMSK_MSKRXDATDONE_MASK        (0x40000U)
#define MIPI_DSI_INTMSK_MSKRXDATDONE_SHIFT       (18U)
#define MIPI_DSI_INTMSK_MSKTATOUT_MASK           (0x100000U)
#define MIPI_DSI_INTMSK_MSKTATOUT_SHIFT          (20U)
#define MIPI_DSI_INTMSK_MSKLPDRTOUT_MASK         (0x200000U)
#define MIPI_DSI_INTMSK_MSKLPDRTOUT_SHIFT        (21U)
#define MIPI_DSI_INTMSK_MSKFRAMEDONE_MASK        (0x1000000U)
#define MIPI_DSI_INTMSK_MSKFRAMEDONE_SHIFT       (24U)
#define MIPI_DSI_INTMSK_MSKBUSTURNOVER_MASK      (0x2000000U)
#define MIPI_DSI_INTMSK_MSKBUSTURNOVER_SHIFT     (25U)
#define MIPI_DSI_INTMSK_MSKSYNCOVERRIDE_MASK     (0x8000000U)
#define MIPI_DSI_INTMSK_MSKSYNCOVERRIDE_SHIFT    (27U)
#define MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY_MASK   (0x10000000U)
#define MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY_SHIFT  (28U)
#define MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY_MASK   (0x20000000U)
#define MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY_SHIFT  (29U)
#define MIPI_DSI_INTMSK_MSKSWRSTRELEASE_MASK     (0x40000000U)
#define MIPI_DSI_INTMSK_MSKSWRSTRELEASE_SHIFT    (30U)
#define MIPI_DSI_INTMSK_MSKPLLSTABLE_MASK        (0x80000000U)
#define MIPI_DSI_INTMSK_MSKPLLSTABLE_SHIFT       (31U)

/*! @name PKTHDR - Packet Header FIFO Register */
#define MIPI_DSI_PKTHDR_PACKETHEADER_MASK        (0xFFFFFFU)
#define MIPI_DSI_PKTHDR_PACKETHEADER_SHIFT       (0U)
#define MIPI_DSI_PKTHDR_PACKETHEADER(x)          (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PKTHDR_PACKETHEADER_SHIFT)) & MIPI_DSI_PKTHDR_PACKETHEADER_MASK)

/*! @name PAYLOAD - Payload FIFO Register */
#define MIPI_DSI_PAYLOAD_PAYLOAD_MASK            (0xFFFFFFFFU)
#define MIPI_DSI_PAYLOAD_PAYLOAD_SHIFT           (0U)
#define MIPI_DSI_PAYLOAD_PAYLOAD(x)              (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PAYLOAD_PAYLOAD_SHIFT)) & MIPI_DSI_PAYLOAD_PAYLOAD_MASK)

/*! @name RXFIFO - Payload FIFO Register */
#define MIPI_DSI_RXFIFO_RXFIFO_MASK              (0xFFFFFFFFU)
#define MIPI_DSI_RXFIFO_RXFIFO_SHIFT             (0U)
#define MIPI_DSI_RXFIFO_RXFIFO(x)                (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_RXFIFO_RXFIFO_SHIFT)) & MIPI_DSI_RXFIFO_RXFIFO_MASK)

/*! @name FIFOTHLD - FIFO Threshold Level Register */
#define MIPI_DSI_FIFOTHLD_WFULLLEVELSFR_MASK     (0x1FFU)
#define MIPI_DSI_FIFOTHLD_WFULLLEVELSFR_SHIFT    (0U)
#define MIPI_DSI_FIFOTHLD_WFULLLEVELSFR(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_FIFOTHLD_WFULLLEVELSFR_SHIFT)) & MIPI_DSI_FIFOTHLD_WFULLLEVELSFR_MASK)

/*! @name FIFOCTRL - FIFO Status and Control Register */
#define MIPI_DSI_FIFOCTRL_NINITMAIN_MASK         (0x1U)
#define MIPI_DSI_FIFOCTRL_NINITMAIN_SHIFT        (0U)
#define MIPI_DSI_FIFOCTRL_NINITSUB_MASK          (0x2U)
#define MIPI_DSI_FIFOCTRL_NINITSUB_SHIFT         (1U)
#define MIPI_DSI_FIFOCTRL_NLNITL80_MASK          (0x4U)
#define MIPI_DSI_FIFOCTRL_NLNITL80_SHIFT         (2U)
#define MIPI_DSI_FIFOCTRL_NINITSFR_MASK          (0x8U)
#define MIPI_DSI_FIFOCTRL_NINITSFR_SHIFT         (3U)
#define MIPI_DSI_FIFOCTRL_NINITRX_MASK           (0x10U)
#define MIPI_DSI_FIFOCTRL_NINITRX_SHIFT          (4U)
#define MIPI_DSI_FIFOCTRL_EMPTYLMAIN_MASK        (0x100U)
#define MIPI_DSI_FIFOCTRL_EMPTYLMAIN_SHIFT       (8U)
#define MIPI_DSI_FIFOCTRL_FULLLMAIN_MASK         (0x200U)
#define MIPI_DSI_FIFOCTRL_FULLLMAIN_SHIFT        (9U)
#define MIPI_DSI_FIFOCTRL_EMPTYHMAIN_MASK        (0x400U)
#define MIPI_DSI_FIFOCTRL_EMPTYHMAIN_SHIFT       (10U)
#define MIPI_DSI_FIFOCTRL_FULLHMAIN_MASK         (0x800U)
#define MIPI_DSI_FIFOCTRL_FULLHMAIN_SHIFT        (11U)
#define MIPI_DSI_FIFOCTRL_EMPTYLSUB_MASK         (0x1000U)
#define MIPI_DSI_FIFOCTRL_EMPTYLSUB_SHIFT        (12U)
#define MIPI_DSI_FIFOCTRL_FULLLSUB_MASK          (0x2000U)
#define MIPI_DSI_FIFOCTRL_FULLLSUB_SHIFT         (13U)
#define MIPI_DSI_FIFOCTRL_EMPTYHSUB_MASK         (0x4000U)
#define MIPI_DSI_FIFOCTRL_EMPTYHSUB_SHIFT        (14U)
#define MIPI_DSI_FIFOCTRL_FULLHSUB_MASK          (0x8000U)
#define MIPI_DSI_FIFOCTRL_FULLHSUB_SHIFT         (15U)
#define MIPI_DSI_FIFOCTRL_EMPTYLI80_MASK         (0x10000U)
#define MIPI_DSI_FIFOCTRL_EMPTYLI80_SHIFT        (16U)
#define MIPI_DSI_FIFOCTRL_FULLLI80_MASK          (0x20000U)
#define MIPI_DSI_FIFOCTRL_FULLLI80_SHIFT         (17U)
#define MIPI_DSI_FIFOCTRL_EMPTYHI80_MASK         (0x40000U)
#define MIPI_DSI_FIFOCTRL_EMPTYHI80_SHIFT        (18U)
#define MIPI_DSI_FIFOCTRL_FULLHI80_MASK          (0x80000U)
#define MIPI_DSI_FIFOCTRL_FULLHI80_SHIFT         (19U)
#define MIPI_DSI_FIFOCTRL_EMPTYLSFR_MASK         (0x100000U)
#define MIPI_DSI_FIFOCTRL_EMPTYLSFR_SHIFT        (20U)
#define MIPI_DSI_FIFOCTRL_FULLLSFR_MASK          (0x200000U)
#define MIPI_DSI_FIFOCTRL_FULLLSFR_SHIFT         (21U)
#define MIPI_DSI_FIFOCTRL_EMPTYHSFR_MASK         (0x400000U)
#define MIPI_DSI_FIFOCTRL_EMPTYHSFR_SHIFT        (22U)
#define MIPI_DSI_FIFOCTRL_FullHSfr_MASK          (0x800000U)
#define MIPI_DSI_FIFOCTRL_FullHSfr_SHIFT         (23U)
#define MIPI_DSI_FIFOCTRL_EMPTYRX_MASK           (0x1000000U)
#define MIPI_DSI_FIFOCTRL_EMPTYRX_SHIFT          (24U)
#define MIPI_DSI_FIFOCTRL_FULLRX_MASK            (0x2000000U)
#define MIPI_DSI_FIFOCTRL_FULLRX_SHIFT           (25U)

/*! @name MEMACCHR - FIFO Memory AC Characteristic Register */
#define MIPI_DSI_MEMACCHR_EMAA_MD_MASK           (0x7U)
#define MIPI_DSI_MEMACCHR_EMAA_MD_SHIFT          (0U)
#define MIPI_DSI_MEMACCHR_EMAA_MD(x)             (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MEMACCHR_EMAA_MD_SHIFT)) & MIPI_DSI_MEMACCHR_EMAA_MD_MASK)
#define MIPI_DSI_MEMACCHR_EMAB_MD_MASK           (0x38U)
#define MIPI_DSI_MEMACCHR_EMAB_MD_SHIFT          (3U)
#define MIPI_DSI_MEMACCHR_EMAB_MD(x)             (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MEMACCHR_EMAB_MD_SHIFT)) & MIPI_DSI_MEMACCHR_EMAB_MD_MASK)
#define MIPI_DSI_MEMACCHR_RETN_MD_MASK           (0x40U)
#define MIPI_DSI_MEMACCHR_RETN_MD_SHIFT          (6U)
#define MIPI_DSI_MEMACCHR_PGEN_MD_MASK           (0x80U)
#define MIPI_DSI_MEMACCHR_PGEN_MD_SHIFT          (7U)
#define MIPI_DSI_MEMACCHR_EMAA_SD_MASK           (0x700U)
#define MIPI_DSI_MEMACCHR_EMAA_SD_SHIFT          (8U)
#define MIPI_DSI_MEMACCHR_EMAA_SD(x)             (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MEMACCHR_EMAA_SD_SHIFT)) & MIPI_DSI_MEMACCHR_EMAA_SD_MASK)
#define MIPI_DSI_MEMACCHR_EMAB_SD_MASK           (0x3800U)
#define MIPI_DSI_MEMACCHR_EMAB_SD_SHIFT          (11U)
#define MIPI_DSI_MEMACCHR_EMAB_SD(x)             (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MEMACCHR_EMAB_SD_SHIFT)) & MIPI_DSI_MEMACCHR_EMAB_SD_MASK)
#define MIPI_DSI_MEMACCHR_RETN_SD_MASK           (0x4000U)
#define MIPI_DSI_MEMACCHR_RETN_SD_SHIFT          (14U)
#define MIPI_DSI_MEMACCHR_PGEN_SD_MASK           (0x8000U)
#define MIPI_DSI_MEMACCHR_PGEN_SD_SHIFT          (15U)

/*! @name MULTI_PKT -  */
#define MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF_MASK (0xFFFFU)
#define MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF_SHIFT (0U)
#define MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF(x)  (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF_SHIFT)) & MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF_MASK)
#define MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF_MASK (0xFFF0000U)
#define MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF_SHIFT (16U)
#define MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF(x)   (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF_SHIFT)) & MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF_MASK)
#define MIPI_DSI_MULTI_PKT_PKT_GO_RDY_MASK       (0x10000000U)
#define MIPI_DSI_MULTI_PKT_PKT_GO_RDY_SHIFT      (28U)
#define MIPI_DSI_MULTI_PKT_PKT_GO_EN_MASK        (0x20000000U)
#define MIPI_DSI_MULTI_PKT_PKT_GO_EN_SHIFT       (29U)
#define MIPI_DSI_MULTI_PKT_MULTI_PKT_EN_MASK     (0x40000000U)
#define MIPI_DSI_MULTI_PKT_MULTI_PKT_EN_SHIFT    (30U)

/*! @name PLLCTRL_1G - 1 Gbps D-PHY PLL Control Register */
#define MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK_MASK      (0x7U)
#define MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK_SHIFT     (0U)
#define MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK_SHIFT)) & MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK_MASK)
#define MIPI_DSI_PLLCTRL_1G_PREPRCTL_MASK        (0x70U)
#define MIPI_DSI_PLLCTRL_1G_PREPRCTL_SHIFT       (4U)
#define MIPI_DSI_PLLCTRL_1G_PREPRCTL(x)          (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PLLCTRL_1G_PREPRCTL_SHIFT)) & MIPI_DSI_PLLCTRL_1G_PREPRCTL_MASK)
#define MIPI_DSI_PLLCTRL_1G_FREQ_BAND_MASK       (0xF00U)
#define MIPI_DSI_PLLCTRL_1G_FREQ_BAND_SHIFT      (8U)
#define MIPI_DSI_PLLCTRL_1G_FREQ_BAND(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PLLCTRL_1G_FREQ_BAND_SHIFT)) & MIPI_DSI_PLLCTRL_1G_FREQ_BAND_MASK)
#define MIPI_DSI_PLLCTRL_1G_HSZEROCTL_MASK       (0xF000U)
#define MIPI_DSI_PLLCTRL_1G_HSZEROCTL_SHIFT      (12U)
#define MIPI_DSI_PLLCTRL_1G_HSZEROCTL(x)         (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PLLCTRL_1G_HSZEROCTL_SHIFT)) & MIPI_DSI_PLLCTRL_1G_HSZEROCTL_MASK)

/*! @name PLLCTRL - PLL Control register */
#define MIPI_DSI_PLLCTRL_PMS_MASK                (0xFFFFEU)
#define MIPI_DSI_PLLCTRL_PMS_SHIFT               (1U)
#define MIPI_DSI_PLLCTRL_PMS(x)                  (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PLLCTRL_PMS_SHIFT)) & MIPI_DSI_PLLCTRL_PMS_MASK)
#define MIPI_DSI_PLLCTRL_PLLEN_MASK              (0x800000U)
#define MIPI_DSI_PLLCTRL_PLLEN_SHIFT             (23U)
#define MIPI_DSI_PLLCTRL_DPDNSWAP_DAT_MASK       (0x1000000U)
#define MIPI_DSI_PLLCTRL_DPDNSWAP_DAT_SHIFT      (24U)
#define MIPI_DSI_PLLCTRL_DPDNSWAP_CLK_MASK       (0x2000000U)
#define MIPI_DSI_PLLCTRL_DPDNSWAP_CLK_SHIFT      (25U)

/*! @name PLLCTRL1 - PLL Control Register 1 */
#define MIPI_DSI_PLLCTRL1_M_PLLCTL0_MASK         (0xFFFFFFFFU)
#define MIPI_DSI_PLLCTRL1_M_PLLCTL0_SHIFT        (0U)
#define MIPI_DSI_PLLCTRL1_M_PLLCTL0(x)           (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PLLCTRL1_M_PLLCTL0_SHIFT)) & MIPI_DSI_PLLCTRL1_M_PLLCTL0_MASK)

/*! @name PLLCTRL2 - PLL control register 2 */
#define MIPI_DSI_PLLCTRL2_M_PLLCTL1_MASK         (0xFFU)
#define MIPI_DSI_PLLCTRL2_M_PLLCTL1_SHIFT        (0U)
#define MIPI_DSI_PLLCTRL2_M_PLLCTL1(x)           (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PLLCTRL2_M_PLLCTL1_SHIFT)) & MIPI_DSI_PLLCTRL2_M_PLLCTL1_MASK)

/*! @name PLLTMR - PLL Timer Register */
#define MIPI_DSI_PLLTMR_PLLTIMER_MASK            (0xFFFFFFFFU)
#define MIPI_DSI_PLLTMR_PLLTIMER_SHIFT           (0U)
#define MIPI_DSI_PLLTMR_PLLTIMER(x)              (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PLLTMR_PLLTIMER_SHIFT)) & MIPI_DSI_PLLTMR_PLLTIMER_MASK)

/*! @name PHYCTRL_B1 - D-PHY Master and Slave Analog Block Control Register 1 */
#define MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0_MASK      (0xFFFFFFFFU)
#define MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0_SHIFT     (0U)
#define MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0_SHIFT)) & MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0_MASK)

/*! @name PHYCTRL_B2 - D-PHY Master and Slave Analog Block Control Register 2 */
#define MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1_MASK      (0xFFFFFFFFU)
#define MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1_SHIFT     (0U)
#define MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1_SHIFT)) & MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1_MASK)

/*! @name PHYCTRL_M1 - D-PHY Master Analog Block Control Register 1 */
#define MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0_MASK      (0xFFFFFFFFU)
#define MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0_SHIFT     (0U)
#define MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0_SHIFT)) & MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0_MASK)

/*! @name PHYCTRL_M2 - D-PHY Master Analog Block Control Register 1 */
#define MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1_MASK      (0xFFFFFFFFU)
#define MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1_SHIFT     (0U)
#define MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1(x)        (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1_SHIFT)) & MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1_MASK)

/*! @name PHYTIMING - D-PHY Timing register */
#define MIPI_DSI_PHYTIMING_M_THSEXITCTL_MASK     (0xFFU)
#define MIPI_DSI_PHYTIMING_M_THSEXITCTL_SHIFT    (0U)
#define MIPI_DSI_PHYTIMING_M_THSEXITCTL(x)       (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING_M_THSEXITCTL_SHIFT)) & MIPI_DSI_PHYTIMING_M_THSEXITCTL_MASK)
#define MIPI_DSI_PHYTIMING_M_TLPXCTL_MASK        (0xFF00U)
#define MIPI_DSI_PHYTIMING_M_TLPXCTL_SHIFT       (8U)
#define MIPI_DSI_PHYTIMING_M_TLPXCTL(x)          (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING_M_TLPXCTL_SHIFT)) & MIPI_DSI_PHYTIMING_M_TLPXCTL_MASK)

/*! @name PHYTIMING1 -  */
#define MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL_MASK  (0xFFU)
#define MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL_SHIFT (0U)
#define MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL(x)    (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL_SHIFT)) & MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL_MASK)
#define MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL_MASK   (0xFF00U)
#define MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL_SHIFT  (8U)
#define MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL_SHIFT)) & MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL_MASK)
#define MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL_MASK   (0xFF0000U)
#define MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL_SHIFT  (16U)
#define MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL_SHIFT)) & MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL_MASK)
#define MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL_MASK   (0xFF000000U)
#define MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL_SHIFT  (24U)
#define MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL_SHIFT)) & MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL_MASK)

/*! @name PHYTIMING2 - D-PHY Timing Register 2 */
#define MIPI_DSI_PHYTIMING2_M_THSTRAILCTL_MASK   (0xFFU)
#define MIPI_DSI_PHYTIMING2_M_THSTRAILCTL_SHIFT  (0U)
#define MIPI_DSI_PHYTIMING2_M_THSTRAILCTL(x)     (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING2_M_THSTRAILCTL_SHIFT)) & MIPI_DSI_PHYTIMING2_M_THSTRAILCTL_MASK)
#define MIPI_DSI_PHYTIMING2_M_THSZEROCTL_MASK    (0xFF00U)
#define MIPI_DSI_PHYTIMING2_M_THSZEROCTL_SHIFT   (8U)
#define MIPI_DSI_PHYTIMING2_M_THSZEROCTL(x)      (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING2_M_THSZEROCTL_SHIFT)) & MIPI_DSI_PHYTIMING2_M_THSZEROCTL_MASK)
#define MIPI_DSI_PHYTIMING2_M_THSPRPRCTL_MASK    (0xFF0000U)
#define MIPI_DSI_PHYTIMING2_M_THSPRPRCTL_SHIFT   (16U)
#define MIPI_DSI_PHYTIMING2_M_THSPRPRCTL(x)      (((uint32_t)(((uint32_t)(x)) << MIPI_DSI_PHYTIMING2_M_THSPRPRCTL_SHIFT)) & MIPI_DSI_PHYTIMING2_M_THSPRPRCTL_MASK)


/*!
 * @}
 */ /* end of group MIPI_DSI_Register_Masks */


/* MIPI_DSI - Peripheral instance base addresses */
/** Peripheral MIPI_DSI base pointer */
#define MIPI_DSI_BASE_PTR                        ((MIPI_DSI_MemMapPtr)0x30760000u)
/** Array initializer of MIPI_DSI peripheral base pointers */
#define MIPI_DSI_BASE_PTRS                       { MIPI_DSI_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- MIPI_DSI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MIPI_DSI_Register_Accessor_Macros MIPI_DSI - Register accessor macros
 * @{
 */


/* MIPI_DSI - Register instance definitions */
/* MIPI_DSI */
#define MIPI_DSI_VERSION                         MIPI_DSI_VERSION_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_STATUS                          MIPI_DSI_STATUS_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_RGB_STATUS                      MIPI_DSI_RGB_STATUS_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_SWRST                           MIPI_DSI_SWRST_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_CLKCTRL                         MIPI_DSI_CLKCTRL_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_TIMEOUT                         MIPI_DSI_TIMEOUT_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_CONFIG                          MIPI_DSI_CONFIG_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_ESCMODE                         MIPI_DSI_ESCMODE_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_MDRESOL                         MIPI_DSI_MDRESOL_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_MVPORCH                         MIPI_DSI_MVPORCH_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_MHPORCH                         MIPI_DSI_MHPORCH_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_MSYNC                           MIPI_DSI_MSYNC_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_SDRESOL                         MIPI_DSI_SDRESOL_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_INTSRC                          MIPI_DSI_INTSRC_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_INTMSK                          MIPI_DSI_INTMSK_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PKTHDR                          MIPI_DSI_PKTHDR_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PAYLOAD                         MIPI_DSI_PAYLOAD_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_RXFIFO                          MIPI_DSI_RXFIFO_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_FIFOTHLD                        MIPI_DSI_FIFOTHLD_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_FIFOCTRL                        MIPI_DSI_FIFOCTRL_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_MEMACCHR                        MIPI_DSI_MEMACCHR_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_MULTI_PKT                       MIPI_DSI_MULTI_PKT_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PLLCTRL_1G                      MIPI_DSI_PLLCTRL_1G_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PLLCTRL                         MIPI_DSI_PLLCTRL_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PLLCTRL1                        MIPI_DSI_PLLCTRL1_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PLLCTRL2                        MIPI_DSI_PLLCTRL2_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PLLTMR                          MIPI_DSI_PLLTMR_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PHYCTRL_B1                      MIPI_DSI_PHYCTRL_B1_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PHYCTRL_B2                      MIPI_DSI_PHYCTRL_B2_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PHYCTRL_M1                      MIPI_DSI_PHYCTRL_M1_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PHYCTRL_M2                      MIPI_DSI_PHYCTRL_M2_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PHYTIMING                       MIPI_DSI_PHYTIMING_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PHYTIMING1                      MIPI_DSI_PHYTIMING1_REG(MIPI_DSI_BASE_PTR)
#define MIPI_DSI_PHYTIMING2                      MIPI_DSI_PHYTIMING2_REG(MIPI_DSI_BASE_PTR)

/*!
 * @}
 */ /* end of group MIPI_DSI_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group MIPI_DSI_Peripheral */


/* ----------------------------------------------------------------------------
   -- MU
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MU_Peripheral MU
 * @{
 */

/** MU - Peripheral register structure */
typedef struct MU_MemMap {
  uint32_t BTR0;                                   /**< Processor B Transmit Register 0, offset: 0x0 */
  uint32_t BTR1;                                   /**< Processor B Transmit Register 1, offset: 0x4 */
  uint32_t BTR2;                                   /**< Processor B Transmit Register 2, offset: 0x8 */
  uint32_t BTR3;                                   /**< Processor B Transmit Register 3, offset: 0xC */
  uint32_t BRR0;                                   /**< Processor B Receive Register 0, offset: 0x10 */
  uint32_t BRR1;                                   /**< Processor B Receive Register 1, offset: 0x14 */
  uint32_t BRR2;                                   /**< Processor B Receive Register 2, offset: 0x18 */
  uint32_t BRR3;                                   /**< Processor B Receive Register 3, offset: 0x1C */
  uint32_t BSR;                                    /**< Processor B Status Register, offset: 0x20 */
  uint32_t BCR;                                    /**< Processor B Control Register, offset: 0x24 */
} volatile *MU_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- MU - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MU_Register_Accessor_Macros MU - Register accessor macros
 * @{
 */


/* MU - Register accessors */
#define MU_BTR0_REG(base)                        ((base)->BTR0)
#define MU_BTR1_REG(base)                        ((base)->BTR1)
#define MU_BTR2_REG(base)                        ((base)->BTR2)
#define MU_BTR3_REG(base)                        ((base)->BTR3)
#define MU_BRR0_REG(base)                        ((base)->BRR0)
#define MU_BRR1_REG(base)                        ((base)->BRR1)
#define MU_BRR2_REG(base)                        ((base)->BRR2)
#define MU_BRR3_REG(base)                        ((base)->BRR3)
#define MU_BSR_REG(base)                         ((base)->BSR)
#define MU_BCR_REG(base)                         ((base)->BCR)

/*!
 * @}
 */ /* end of group MU_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- MU Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MU_Register_Masks MU Register Masks
 * @{
 */

/*! @name BTR0 - Processor B Transmit Register 0 */
#define MU_BTR0_BTR0_MASK                        (0xFFFFFFFFU)
#define MU_BTR0_BTR0_SHIFT                       (0U)
#define MU_BTR0_BTR0(x)                          (((uint32_t)(((uint32_t)(x)) << MU_BTR0_BTR0_SHIFT)) & MU_BTR0_BTR0_MASK)

/*! @name BTR1 - Processor B Transmit Register 1 */
#define MU_BTR1_BTR1_MASK                        (0xFFFFFFFFU)
#define MU_BTR1_BTR1_SHIFT                       (0U)
#define MU_BTR1_BTR1(x)                          (((uint32_t)(((uint32_t)(x)) << MU_BTR1_BTR1_SHIFT)) & MU_BTR1_BTR1_MASK)

/*! @name BTR2 - Processor B Transmit Register 2 */
#define MU_BTR2_BTR2_MASK                        (0xFFFFFFFFU)
#define MU_BTR2_BTR2_SHIFT                       (0U)
#define MU_BTR2_BTR2(x)                          (((uint32_t)(((uint32_t)(x)) << MU_BTR2_BTR2_SHIFT)) & MU_BTR2_BTR2_MASK)

/*! @name BTR3 - Processor B Transmit Register 3 */
#define MU_BTR3_BTR3_MASK                        (0xFFFFFFFFU)
#define MU_BTR3_BTR3_SHIFT                       (0U)
#define MU_BTR3_BTR3(x)                          (((uint32_t)(((uint32_t)(x)) << MU_BTR3_BTR3_SHIFT)) & MU_BTR3_BTR3_MASK)

/*! @name BRR0 - Processor B Receive Register 0 */
#define MU_BRR0_BRR0_MASK                        (0xFFFFFFFFU)
#define MU_BRR0_BRR0_SHIFT                       (0U)
#define MU_BRR0_BRR0(x)                          (((uint32_t)(((uint32_t)(x)) << MU_BRR0_BRR0_SHIFT)) & MU_BRR0_BRR0_MASK)

/*! @name BRR1 - Processor B Receive Register 1 */
#define MU_BRR1_BRR1_MASK                        (0xFFFFFFFFU)
#define MU_BRR1_BRR1_SHIFT                       (0U)
#define MU_BRR1_BRR1(x)                          (((uint32_t)(((uint32_t)(x)) << MU_BRR1_BRR1_SHIFT)) & MU_BRR1_BRR1_MASK)

/*! @name BRR2 - Processor B Receive Register 2 */
#define MU_BRR2_BRR2_MASK                        (0xFFFFFFFFU)
#define MU_BRR2_BRR2_SHIFT                       (0U)
#define MU_BRR2_BRR2(x)                          (((uint32_t)(((uint32_t)(x)) << MU_BRR2_BRR2_SHIFT)) & MU_BRR2_BRR2_MASK)

/*! @name BRR3 - Processor B Receive Register 3 */
#define MU_BRR3_BRR3_MASK                        (0xFFFFFFFFU)
#define MU_BRR3_BRR3_SHIFT                       (0U)
#define MU_BRR3_BRR3(x)                          (((uint32_t)(((uint32_t)(x)) << MU_BRR3_BRR3_SHIFT)) & MU_BRR3_BRR3_MASK)

/*! @name BSR - Processor B Status Register */
#define MU_BSR_Fn_MASK                           (0x7U)
#define MU_BSR_Fn_SHIFT                          (0U)
#define MU_BSR_Fn(x)                             (((uint32_t)(((uint32_t)(x)) << MU_BSR_Fn_SHIFT)) & MU_BSR_Fn_MASK)
#define MU_BSR_EP_MASK                           (0x10U)
#define MU_BSR_EP_SHIFT                          (4U)
#define MU_BSR_APM_MASK                          (0x60U)
#define MU_BSR_APM_SHIFT                         (5U)
#define MU_BSR_APM(x)                            (((uint32_t)(((uint32_t)(x)) << MU_BSR_APM_SHIFT)) & MU_BSR_APM_MASK)
#define MU_BSR_ARS_MASK                          (0x80U)
#define MU_BSR_ARS_SHIFT                         (7U)
#define MU_BSR_FUP_MASK                          (0x100U)
#define MU_BSR_FUP_SHIFT                         (8U)
#define MU_BSR_TEn_MASK                          (0xF00000U)
#define MU_BSR_TEn_SHIFT                         (20U)
#define MU_BSR_TEn(x)                            (((uint32_t)(((uint32_t)(x)) << MU_BSR_TEn_SHIFT)) & MU_BSR_TEn_MASK)
#define MU_BSR_RFn_MASK                          (0xF000000U)
#define MU_BSR_RFn_SHIFT                         (24U)
#define MU_BSR_RFn(x)                            (((uint32_t)(((uint32_t)(x)) << MU_BSR_RFn_SHIFT)) & MU_BSR_RFn_MASK)
#define MU_BSR_GIPn_MASK                         (0xF0000000U)
#define MU_BSR_GIPn_SHIFT                        (28U)
#define MU_BSR_GIPn(x)                           (((uint32_t)(((uint32_t)(x)) << MU_BSR_GIPn_SHIFT)) & MU_BSR_GIPn_MASK)

/*! @name BCR - Processor B Control Register */
#define MU_BCR_BAFn_MASK                         (0x7U)
#define MU_BCR_BAFn_SHIFT                        (0U)
#define MU_BCR_BAFn(x)                           (((uint32_t)(((uint32_t)(x)) << MU_BCR_BAFn_SHIFT)) & MU_BCR_BAFn_MASK)
#define MU_BCR_HRM_MASK                          (0x10U)
#define MU_BCR_HRM_SHIFT                         (4U)
#define MU_BCR_GIRn_MASK                         (0xF0000U)
#define MU_BCR_GIRn_SHIFT                        (16U)
#define MU_BCR_GIRn(x)                           (((uint32_t)(((uint32_t)(x)) << MU_BCR_GIRn_SHIFT)) & MU_BCR_GIRn_MASK)
#define MU_BCR_TIEn_MASK                         (0xF00000U)
#define MU_BCR_TIEn_SHIFT                        (20U)
#define MU_BCR_TIEn(x)                           (((uint32_t)(((uint32_t)(x)) << MU_BCR_TIEn_SHIFT)) & MU_BCR_TIEn_MASK)
#define MU_BCR_RIEn_MASK                         (0xF000000U)
#define MU_BCR_RIEn_SHIFT                        (24U)
#define MU_BCR_RIEn(x)                           (((uint32_t)(((uint32_t)(x)) << MU_BCR_RIEn_SHIFT)) & MU_BCR_RIEn_MASK)
#define MU_BCR_GIEn_MASK                         (0xF0000000U)
#define MU_BCR_GIEn_SHIFT                        (28U)
#define MU_BCR_GIEn(x)                           (((uint32_t)(((uint32_t)(x)) << MU_BCR_GIEn_SHIFT)) & MU_BCR_GIEn_MASK)


/*!
 * @}
 */ /* end of group MU_Register_Masks */


/* MU - Peripheral instance base addresses */
/** Peripheral MUB base pointer */
#define MUB_BASE_PTR                             ((MU_MemMapPtr)0x30AB0000u)
/** Array initializer of MU peripheral base pointers */
#define MU_BASE_PTRS                             { MUB_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- MU - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MU_Register_Accessor_Macros MU - Register accessor macros
 * @{
 */


/* MU - Register instance definitions */
/* MUB */
#define MUB_BTR0                                 MU_BTR0_REG(MUB_BASE_PTR)
#define MUB_BTR1                                 MU_BTR1_REG(MUB_BASE_PTR)
#define MUB_BTR2                                 MU_BTR2_REG(MUB_BASE_PTR)
#define MUB_BTR3                                 MU_BTR3_REG(MUB_BASE_PTR)
#define MUB_BRR0                                 MU_BRR0_REG(MUB_BASE_PTR)
#define MUB_BRR1                                 MU_BRR1_REG(MUB_BASE_PTR)
#define MUB_BRR2                                 MU_BRR2_REG(MUB_BASE_PTR)
#define MUB_BRR3                                 MU_BRR3_REG(MUB_BASE_PTR)
#define MUB_BSR                                  MU_BSR_REG(MUB_BASE_PTR)
#define MUB_BCR                                  MU_BCR_REG(MUB_BASE_PTR)

/*!
 * @}
 */ /* end of group MU_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group MU_Peripheral */


/* ----------------------------------------------------------------------------
   -- OCOTP
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup OCOTP_Peripheral OCOTP
 * @{
 */

/** OCOTP - Peripheral register structure */
typedef struct OCOTP_MemMap {
  uint32_t CTRL;                                   /**< OTP Controller Control Register, offset: 0x0 */
  uint32_t CTRL_SET;                               /**< OTP Controller Control Register, offset: 0x4 */
  uint32_t CTRL_CLR;                               /**< OTP Controller Control Register, offset: 0x8 */
  uint32_t CTRL_TOG;                               /**< OTP Controller Control Register, offset: 0xC */
  uint32_t TIMING;                                 /**< OTP Controller Timing Register, offset: 0x10 */
  uint8_t RESERVED_0[12];
  uint32_t DATA0;                                  /**< OTP Controller Write Data Register, offset: 0x20 */
  uint8_t RESERVED_1[12];
  uint32_t DATA1;                                  /**< OTP Controller Write Data Register, offset: 0x30 */
  uint8_t RESERVED_2[12];
  uint32_t DATA2;                                  /**< OTP Controller Write Data Register, offset: 0x40 */
  uint8_t RESERVED_3[12];
  uint32_t DATA3;                                  /**< OTP Controller Write Data Register, offset: 0x50 */
  uint8_t RESERVED_4[12];
  uint32_t READ_CTRL;                              /**< OTP Controller Write Data Register, offset: 0x60 */
  uint8_t RESERVED_5[12];
  uint32_t READ_FUSE_DATA0;                        /**< OTP Controller Read Data Register, offset: 0x70 */
  uint8_t RESERVED_6[12];
  uint32_t READ_FUSE_DATA1;                        /**< OTP Controller Read Data Register, offset: 0x80 */
  uint8_t RESERVED_7[12];
  uint32_t READ_FUSE_DATA2;                        /**< OTP Controller Read Data Register, offset: 0x90 */
  uint8_t RESERVED_8[12];
  uint32_t READ_FUSE_DATA3;                        /**< OTP Controller Read Data Register, offset: 0xA0 */
  uint8_t RESERVED_9[12];
  uint32_t SW_STICKY;                              /**< Sticky bit Register, offset: 0xB0 */
  uint8_t RESERVED_10[12];
  uint32_t SCS;                                    /**< Software Controllable Signals Register, offset: 0xC0 */
  uint32_t SCS_SET;                                /**< Software Controllable Signals Register, offset: 0xC4 */
  uint32_t SCS_CLR;                                /**< Software Controllable Signals Register, offset: 0xC8 */
  uint32_t SCS_TOG;                                /**< Software Controllable Signals Register, offset: 0xCC */
  uint32_t CRC_ADDR;                               /**< OTP Controller CRC test address, offset: 0xD0 */
  uint8_t RESERVED_11[12];
  uint32_t CRC_VALUE;                              /**< OTP Controller CRC Value Register, offset: 0xE0 */
  uint8_t RESERVED_12[12];
  uint32_t VERSION;                                /**< OTP Controller Version Register, offset: 0xF0 */
  uint8_t RESERVED_13[780];
  uint32_t LOCK;                                   /**< Value of OTP Bank0 Word0 (Lock controls), offset: 0x400 */
  uint8_t RESERVED_14[12];
  uint32_t TESTER0;                                /**< Value of OTP Bank0 Word1 (Tester Information), offset: 0x410 */
  uint8_t RESERVED_15[12];
  uint32_t TESTER1;                                /**< Value of OTP Bank0 Word2 (Tester Information), offset: 0x420 */
  uint8_t RESERVED_16[12];
  uint32_t TESTER2;                                /**< Value of OTP Bank0 Word3 (Tester Information), offset: 0x430 */
  uint8_t RESERVED_17[12];
  uint32_t TESTER3;                                /**< Value of OTP Bank1 Word0 (Tester Information), offset: 0x440 */
  uint8_t RESERVED_18[12];
  uint32_t TESTER4;                                /**< Value of OTP Bank1 Word1 (Tester Information), offset: 0x450 */
  uint8_t RESERVED_19[12];
  uint32_t TESTER5;                                /**< Value of OTP Bank1 Word2 (Tester Information), offset: 0x460 */
  uint8_t RESERVED_20[12];
  uint32_t BOOT_CFG0;                              /**< Value of OTP Bank1 Word3 (Boot Configuration Information), offset: 0x470 */
  uint8_t RESERVED_21[12];
  uint32_t BOOT_CFG1;                              /**< Value of OTP Bank2 Word0 (Boot Configuration Information), offset: 0x480 */
  uint8_t RESERVED_22[12];
  uint32_t BOOT_CFG2;                              /**< Value of OTP Bank2 Word1 (Boot Configuration Information), offset: 0x490 */
  uint8_t RESERVED_23[12];
  uint32_t BOOT_CFG3;                              /**< Value of OTP Bank2 Word2 (Boot Configuration Information), offset: 0x4A0 */
  uint8_t RESERVED_24[12];
  uint32_t BOOT_CFG4;                              /**< Value of OTP Bank2 Word3 (BOOT Configuration Information), offset: 0x4B0 */
  uint8_t RESERVED_25[12];
  uint32_t MEM_TRIM0;                              /**< Value of OTP Bank3 Word0 (Memory Related Information), offset: 0x4C0 */
  uint8_t RESERVED_26[12];
  uint32_t MEM_TRIM1;                              /**< Value of OTP Bank3 Word1 (Memory Related Information), offset: 0x4D0 */
  uint8_t RESERVED_27[12];
  uint32_t ANA0;                                   /**< Value of OTP Bank3 Word2 (Analog Information), offset: 0x4E0 */
  uint8_t RESERVED_28[12];
  uint32_t ANA1;                                   /**< Value of OTP Bank3 Word3 (Analog Info.), offset: 0x4F0 */
  uint8_t RESERVED_29[12];
  uint32_t OTPMK0;                                 /**< Shadow Register for OTP Bank4 Word0 (OTPMK Key), offset: 0x500 */
  uint8_t RESERVED_30[12];
  uint32_t OTPMK1;                                 /**< Shadow Register for OTP Bank4 Word1 (OTPMK Key), offset: 0x510 */
  uint8_t RESERVED_31[12];
  uint32_t OTPMK2;                                 /**< Shadow Register for OTP Bank4 Word2 (OTPMK Key), offset: 0x520 */
  uint8_t RESERVED_32[12];
  uint32_t OTPMK3;                                 /**< Shadow Register for OTP Bank4 Word3 (OTPMK Key), offset: 0x530 */
  uint8_t RESERVED_33[12];
  uint32_t OTPMK4;                                 /**< Shadow Register for OTP Bank5 Word0 (OTPMK Key), offset: 0x540 */
  uint8_t RESERVED_34[12];
  uint32_t OTPMK5;                                 /**< Shadow Register for OTP Bank5 Word1 (OTPMK Key), offset: 0x550 */
  uint8_t RESERVED_35[12];
  uint32_t OTPMK6;                                 /**< Shadow Register for OTP Bank5 Word2 (OTPMK Key), offset: 0x560 */
  uint8_t RESERVED_36[12];
  uint32_t OTPMK7;                                 /**< Shadow Register for OTP Bank5 Word3 (OTPMK Key), offset: 0x570 */
  uint8_t RESERVED_37[12];
  uint32_t SRK0;                                   /**< Shadow Register for OTP Bank6 Word0 (SRK Hash), offset: 0x580 */
  uint8_t RESERVED_38[12];
  uint32_t SRK1;                                   /**< Shadow Register for OTP Bank6 Word1 (SRK Hash), offset: 0x590 */
  uint8_t RESERVED_39[12];
  uint32_t SRK2;                                   /**< Shadow Register for OTP Bank6 Word2 (SRK Hash), offset: 0x5A0 */
  uint8_t RESERVED_40[12];
  uint32_t SRK3;                                   /**< Shadow Register for OTP Bank6 Word3 (SRK Hash), offset: 0x5B0 */
  uint8_t RESERVED_41[12];
  uint32_t SRK4;                                   /**< Shadow Register for OTP Bank7 Word0 (SRK Hash), offset: 0x5C0 */
  uint8_t RESERVED_42[12];
  uint32_t SRK5;                                   /**< Shadow Register for OTP Bank7 Word1 (SRK Hash), offset: 0x5D0 */
  uint8_t RESERVED_43[12];
  uint32_t SRK6;                                   /**< Shadow Register for OTP Bank7 Word2 (SRK Hash), offset: 0x5E0 */
  uint8_t RESERVED_44[12];
  uint32_t SRK7;                                   /**< Shadow Register for OTP Bank7 Word3 (SRK Hash), offset: 0x5F0 */
  uint8_t RESERVED_45[12];
  uint32_t SJC_RESP0;                              /**< Value of OTP Bank8 Word0 (Secure JTAG Response Field), offset: 0x600 */
  uint8_t RESERVED_46[12];
  uint32_t SJC_RESP1;                              /**< Value of OTP Bank8 Word1 (Secure JTAG Response Field), offset: 0x610 */
  uint8_t RESERVED_47[12];
  uint32_t USB_ID;                                 /**< Value of OTP Bank8 Word2 (USB ID info), offset: 0x620 */
  uint8_t RESERVED_48[12];
  uint32_t FIELD_RETURN;                           /**< Value of OTP Bank8 Word3 (Field Return), offset: 0x630 */
  uint8_t RESERVED_49[12];
  uint32_t MAC_ADDR0;                              /**< Value of OTP Bank9 Word0 (MAC Address), offset: 0x640 */
  uint8_t RESERVED_50[12];
  uint32_t MAC_ADDR1;                              /**< Value of OTP Bank9 Word1 (MAC Address), offset: 0x650 */
  uint8_t RESERVED_51[12];
  uint32_t MAC_ADDR2;                              /**< Value of OTP Bank9 Word2 (MAC Address), offset: 0x660 */
  uint8_t RESERVED_52[12];
  uint32_t SRK_REVOKE;                             /**< Value of OTP Bank9 Word3 (SRK Revoke), offset: 0x670 */
  uint8_t RESERVED_53[12];
  uint32_t MAU_KEY0;                               /**< Shadow Register for OTP Bank10 Word0 (MAU Key), offset: 0x680 */
  uint8_t RESERVED_54[12];
  uint32_t MAU_KEY1;                               /**< Shadow Register for OTP Bank10 Word1 (MAU Key), offset: 0x690 */
  uint8_t RESERVED_55[12];
  uint32_t MAU_KEY2;                               /**< Shadow Register for OTP Bank10 Word2 (MAU Key), offset: 0x6A0 */
  uint8_t RESERVED_56[12];
  uint32_t MAU_KEY3;                               /**< Shadow Register for OTP Bank10 Word3 (MAU Key), offset: 0x6B0 */
  uint8_t RESERVED_57[12];
  uint32_t MAU_KEY4;                               /**< Shadow Register for OTP Bank11 Word0 (MAU Key), offset: 0x6C0 */
  uint8_t RESERVED_58[12];
  uint32_t MAU_KEY5;                               /**< Shadow Register for OTP Bank11 Word1 (MAU Key), offset: 0x6D0 */
  uint8_t RESERVED_59[12];
  uint32_t MAU_KEY6;                               /**< Shadow Register for OTP Bank11 Word2 (MAU Key), offset: 0x6E0 */
  uint8_t RESERVED_60[12];
  uint32_t MAU_KEY7;                               /**< Shadow Register for OTP Bank11 Word3 (MAU Key), offset: 0x6F0 */
  uint8_t RESERVED_61[140];
  uint32_t GP10;                                   /**< Value of OTP Bank14 Word0, offset: 0x780 */
  uint8_t RESERVED_62[12];
  uint32_t GP11;                                   /**< Value of OTP Bank14 Word1, offset: 0x790 */
  uint8_t RESERVED_63[12];
  uint32_t GP20;                                   /**< Value of OTP Bank14 Word2, offset: 0x7A0 */
  uint8_t RESERVED_64[12];
  uint32_t GP21;                                   /**< Value of OTP Bank14 Word3, offset: 0x7B0 */
  uint8_t RESERVED_65[12];
  uint32_t CRC_GP10;                               /**< Value of OTP Bank15 Word0 (CRC Key), offset: 0x7C0 */
  uint8_t RESERVED_66[12];
  uint32_t CRC_GP11;                               /**< Value of OTP Bank15 Word1 (CRC Key), offset: 0x7D0 */
  uint8_t RESERVED_67[12];
  uint32_t CRC_GP20;                               /**< Value of OTP Bank15 Word2 (CRC Key), offset: 0x7E0 */
  uint8_t RESERVED_68[12];
  uint32_t CRC_GP21;                               /**< Value of OTP Bank15 Word3 (CRC Key), offset: 0x7F0 */
} volatile *OCOTP_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- OCOTP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup OCOTP_Register_Accessor_Macros OCOTP - Register accessor macros
 * @{
 */


/* OCOTP - Register accessors */
#define OCOTP_CTRL_REG(base)                     ((base)->CTRL)
#define OCOTP_CTRL_SET_REG(base)                 ((base)->CTRL_SET)
#define OCOTP_CTRL_CLR_REG(base)                 ((base)->CTRL_CLR)
#define OCOTP_CTRL_TOG_REG(base)                 ((base)->CTRL_TOG)
#define OCOTP_TIMING_REG(base)                   ((base)->TIMING)
#define OCOTP_DATA0_REG(base)                    ((base)->DATA0)
#define OCOTP_DATA1_REG(base)                    ((base)->DATA1)
#define OCOTP_DATA2_REG(base)                    ((base)->DATA2)
#define OCOTP_DATA3_REG(base)                    ((base)->DATA3)
#define OCOTP_READ_CTRL_REG(base)                ((base)->READ_CTRL)
#define OCOTP_READ_FUSE_DATA0_REG(base)          ((base)->READ_FUSE_DATA0)
#define OCOTP_READ_FUSE_DATA1_REG(base)          ((base)->READ_FUSE_DATA1)
#define OCOTP_READ_FUSE_DATA2_REG(base)          ((base)->READ_FUSE_DATA2)
#define OCOTP_READ_FUSE_DATA3_REG(base)          ((base)->READ_FUSE_DATA3)
#define OCOTP_SW_STICKY_REG(base)                ((base)->SW_STICKY)
#define OCOTP_SCS_REG(base)                      ((base)->SCS)
#define OCOTP_SCS_SET_REG(base)                  ((base)->SCS_SET)
#define OCOTP_SCS_CLR_REG(base)                  ((base)->SCS_CLR)
#define OCOTP_SCS_TOG_REG(base)                  ((base)->SCS_TOG)
#define OCOTP_CRC_ADDR_REG(base)                 ((base)->CRC_ADDR)
#define OCOTP_CRC_VALUE_REG(base)                ((base)->CRC_VALUE)
#define OCOTP_VERSION_REG(base)                  ((base)->VERSION)
#define OCOTP_LOCK_REG(base)                     ((base)->LOCK)
#define OCOTP_TESTER0_REG(base)                  ((base)->TESTER0)
#define OCOTP_TESTER1_REG(base)                  ((base)->TESTER1)
#define OCOTP_TESTER2_REG(base)                  ((base)->TESTER2)
#define OCOTP_TESTER3_REG(base)                  ((base)->TESTER3)
#define OCOTP_TESTER4_REG(base)                  ((base)->TESTER4)
#define OCOTP_TESTER5_REG(base)                  ((base)->TESTER5)
#define OCOTP_BOOT_CFG0_REG(base)                ((base)->BOOT_CFG0)
#define OCOTP_BOOT_CFG1_REG(base)                ((base)->BOOT_CFG1)
#define OCOTP_BOOT_CFG2_REG(base)                ((base)->BOOT_CFG2)
#define OCOTP_BOOT_CFG3_REG(base)                ((base)->BOOT_CFG3)
#define OCOTP_BOOT_CFG4_REG(base)                ((base)->BOOT_CFG4)
#define OCOTP_MEM_TRIM0_REG(base)                ((base)->MEM_TRIM0)
#define OCOTP_MEM_TRIM1_REG(base)                ((base)->MEM_TRIM1)
#define OCOTP_ANA0_REG(base)                     ((base)->ANA0)
#define OCOTP_ANA1_REG(base)                     ((base)->ANA1)
#define OCOTP_OTPMK0_REG(base)                   ((base)->OTPMK0)
#define OCOTP_OTPMK1_REG(base)                   ((base)->OTPMK1)
#define OCOTP_OTPMK2_REG(base)                   ((base)->OTPMK2)
#define OCOTP_OTPMK3_REG(base)                   ((base)->OTPMK3)
#define OCOTP_OTPMK4_REG(base)                   ((base)->OTPMK4)
#define OCOTP_OTPMK5_REG(base)                   ((base)->OTPMK5)
#define OCOTP_OTPMK6_REG(base)                   ((base)->OTPMK6)
#define OCOTP_OTPMK7_REG(base)                   ((base)->OTPMK7)
#define OCOTP_SRK0_REG(base)                     ((base)->SRK0)
#define OCOTP_SRK1_REG(base)                     ((base)->SRK1)
#define OCOTP_SRK2_REG(base)                     ((base)->SRK2)
#define OCOTP_SRK3_REG(base)                     ((base)->SRK3)
#define OCOTP_SRK4_REG(base)                     ((base)->SRK4)
#define OCOTP_SRK5_REG(base)                     ((base)->SRK5)
#define OCOTP_SRK6_REG(base)                     ((base)->SRK6)
#define OCOTP_SRK7_REG(base)                     ((base)->SRK7)
#define OCOTP_SJC_RESP0_REG(base)                ((base)->SJC_RESP0)
#define OCOTP_SJC_RESP1_REG(base)                ((base)->SJC_RESP1)
#define OCOTP_USB_ID_REG(base)                   ((base)->USB_ID)
#define OCOTP_FIELD_RETURN_REG(base)             ((base)->FIELD_RETURN)
#define OCOTP_MAC_ADDR0_REG(base)                ((base)->MAC_ADDR0)
#define OCOTP_MAC_ADDR1_REG(base)                ((base)->MAC_ADDR1)
#define OCOTP_MAC_ADDR2_REG(base)                ((base)->MAC_ADDR2)
#define OCOTP_SRK_REVOKE_REG(base)               ((base)->SRK_REVOKE)
#define OCOTP_MAU_KEY0_REG(base)                 ((base)->MAU_KEY0)
#define OCOTP_MAU_KEY1_REG(base)                 ((base)->MAU_KEY1)
#define OCOTP_MAU_KEY2_REG(base)                 ((base)->MAU_KEY2)
#define OCOTP_MAU_KEY3_REG(base)                 ((base)->MAU_KEY3)
#define OCOTP_MAU_KEY4_REG(base)                 ((base)->MAU_KEY4)
#define OCOTP_MAU_KEY5_REG(base)                 ((base)->MAU_KEY5)
#define OCOTP_MAU_KEY6_REG(base)                 ((base)->MAU_KEY6)
#define OCOTP_MAU_KEY7_REG(base)                 ((base)->MAU_KEY7)
#define OCOTP_GP10_REG(base)                     ((base)->GP10)
#define OCOTP_GP11_REG(base)                     ((base)->GP11)
#define OCOTP_GP20_REG(base)                     ((base)->GP20)
#define OCOTP_GP21_REG(base)                     ((base)->GP21)
#define OCOTP_CRC_GP10_REG(base)                 ((base)->CRC_GP10)
#define OCOTP_CRC_GP11_REG(base)                 ((base)->CRC_GP11)
#define OCOTP_CRC_GP20_REG(base)                 ((base)->CRC_GP20)
#define OCOTP_CRC_GP21_REG(base)                 ((base)->CRC_GP21)

/*!
 * @}
 */ /* end of group OCOTP_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- OCOTP Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup OCOTP_Register_Masks OCOTP Register Masks
 * @{
 */

/*! @name CTRL - OTP Controller Control Register */
#define OCOTP_CTRL_ADDR_MASK                     (0xFU)
#define OCOTP_CTRL_ADDR_SHIFT                    (0U)
#define OCOTP_CTRL_ADDR(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_ADDR_SHIFT)) & OCOTP_CTRL_ADDR_MASK)
#define OCOTP_CTRL_RSVD0_MASK                    (0xF0U)
#define OCOTP_CTRL_RSVD0_SHIFT                   (4U)
#define OCOTP_CTRL_RSVD0(x)                      (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_RSVD0_SHIFT)) & OCOTP_CTRL_RSVD0_MASK)
#define OCOTP_CTRL_BUSY_MASK                     (0x100U)
#define OCOTP_CTRL_BUSY_SHIFT                    (8U)
#define OCOTP_CTRL_ERROR_MASK                    (0x200U)
#define OCOTP_CTRL_ERROR_SHIFT                   (9U)
#define OCOTP_CTRL_RELOAD_SHADOWS_MASK           (0x400U)
#define OCOTP_CTRL_RELOAD_SHADOWS_SHIFT          (10U)
#define OCOTP_CTRL_CRC_TEST_MASK                 (0x800U)
#define OCOTP_CTRL_CRC_TEST_SHIFT                (11U)
#define OCOTP_CTRL_CRC_FAIL_MASK                 (0x1000U)
#define OCOTP_CTRL_CRC_FAIL_SHIFT                (12U)
#define OCOTP_CTRL_RSVD1_MASK                    (0xE000U)
#define OCOTP_CTRL_RSVD1_SHIFT                   (13U)
#define OCOTP_CTRL_RSVD1(x)                      (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_RSVD1_SHIFT)) & OCOTP_CTRL_RSVD1_MASK)
#define OCOTP_CTRL_WR_UNLOCK_MASK                (0xFFFF0000U)
#define OCOTP_CTRL_WR_UNLOCK_SHIFT               (16U)
#define OCOTP_CTRL_WR_UNLOCK(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_WR_UNLOCK_SHIFT)) & OCOTP_CTRL_WR_UNLOCK_MASK)

/*! @name CTRL_SET - OTP Controller Control Register */
#define OCOTP_CTRL_SET_ADDR_MASK                 (0xFU)
#define OCOTP_CTRL_SET_ADDR_SHIFT                (0U)
#define OCOTP_CTRL_SET_ADDR(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_SET_ADDR_SHIFT)) & OCOTP_CTRL_SET_ADDR_MASK)
#define OCOTP_CTRL_SET_RSVD0_MASK                (0xF0U)
#define OCOTP_CTRL_SET_RSVD0_SHIFT               (4U)
#define OCOTP_CTRL_SET_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_SET_RSVD0_SHIFT)) & OCOTP_CTRL_SET_RSVD0_MASK)
#define OCOTP_CTRL_SET_BUSY_MASK                 (0x100U)
#define OCOTP_CTRL_SET_BUSY_SHIFT                (8U)
#define OCOTP_CTRL_SET_ERROR_MASK                (0x200U)
#define OCOTP_CTRL_SET_ERROR_SHIFT               (9U)
#define OCOTP_CTRL_SET_RELOAD_SHADOWS_MASK       (0x400U)
#define OCOTP_CTRL_SET_RELOAD_SHADOWS_SHIFT      (10U)
#define OCOTP_CTRL_SET_CRC_TEST_MASK             (0x800U)
#define OCOTP_CTRL_SET_CRC_TEST_SHIFT            (11U)
#define OCOTP_CTRL_SET_CRC_FAIL_MASK             (0x1000U)
#define OCOTP_CTRL_SET_CRC_FAIL_SHIFT            (12U)
#define OCOTP_CTRL_SET_RSVD1_MASK                (0xE000U)
#define OCOTP_CTRL_SET_RSVD1_SHIFT               (13U)
#define OCOTP_CTRL_SET_RSVD1(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_SET_RSVD1_SHIFT)) & OCOTP_CTRL_SET_RSVD1_MASK)
#define OCOTP_CTRL_SET_WR_UNLOCK_MASK            (0xFFFF0000U)
#define OCOTP_CTRL_SET_WR_UNLOCK_SHIFT           (16U)
#define OCOTP_CTRL_SET_WR_UNLOCK(x)              (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_SET_WR_UNLOCK_SHIFT)) & OCOTP_CTRL_SET_WR_UNLOCK_MASK)

/*! @name CTRL_CLR - OTP Controller Control Register */
#define OCOTP_CTRL_CLR_ADDR_MASK                 (0xFU)
#define OCOTP_CTRL_CLR_ADDR_SHIFT                (0U)
#define OCOTP_CTRL_CLR_ADDR(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_CLR_ADDR_SHIFT)) & OCOTP_CTRL_CLR_ADDR_MASK)
#define OCOTP_CTRL_CLR_RSVD0_MASK                (0xF0U)
#define OCOTP_CTRL_CLR_RSVD0_SHIFT               (4U)
#define OCOTP_CTRL_CLR_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_CLR_RSVD0_SHIFT)) & OCOTP_CTRL_CLR_RSVD0_MASK)
#define OCOTP_CTRL_CLR_BUSY_MASK                 (0x100U)
#define OCOTP_CTRL_CLR_BUSY_SHIFT                (8U)
#define OCOTP_CTRL_CLR_ERROR_MASK                (0x200U)
#define OCOTP_CTRL_CLR_ERROR_SHIFT               (9U)
#define OCOTP_CTRL_CLR_RELOAD_SHADOWS_MASK       (0x400U)
#define OCOTP_CTRL_CLR_RELOAD_SHADOWS_SHIFT      (10U)
#define OCOTP_CTRL_CLR_CRC_TEST_MASK             (0x800U)
#define OCOTP_CTRL_CLR_CRC_TEST_SHIFT            (11U)
#define OCOTP_CTRL_CLR_CRC_FAIL_MASK             (0x1000U)
#define OCOTP_CTRL_CLR_CRC_FAIL_SHIFT            (12U)
#define OCOTP_CTRL_CLR_RSVD1_MASK                (0xE000U)
#define OCOTP_CTRL_CLR_RSVD1_SHIFT               (13U)
#define OCOTP_CTRL_CLR_RSVD1(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_CLR_RSVD1_SHIFT)) & OCOTP_CTRL_CLR_RSVD1_MASK)
#define OCOTP_CTRL_CLR_WR_UNLOCK_MASK            (0xFFFF0000U)
#define OCOTP_CTRL_CLR_WR_UNLOCK_SHIFT           (16U)
#define OCOTP_CTRL_CLR_WR_UNLOCK(x)              (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_CLR_WR_UNLOCK_SHIFT)) & OCOTP_CTRL_CLR_WR_UNLOCK_MASK)

/*! @name CTRL_TOG - OTP Controller Control Register */
#define OCOTP_CTRL_TOG_ADDR_MASK                 (0xFU)
#define OCOTP_CTRL_TOG_ADDR_SHIFT                (0U)
#define OCOTP_CTRL_TOG_ADDR(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_TOG_ADDR_SHIFT)) & OCOTP_CTRL_TOG_ADDR_MASK)
#define OCOTP_CTRL_TOG_RSVD0_MASK                (0xF0U)
#define OCOTP_CTRL_TOG_RSVD0_SHIFT               (4U)
#define OCOTP_CTRL_TOG_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_TOG_RSVD0_SHIFT)) & OCOTP_CTRL_TOG_RSVD0_MASK)
#define OCOTP_CTRL_TOG_BUSY_MASK                 (0x100U)
#define OCOTP_CTRL_TOG_BUSY_SHIFT                (8U)
#define OCOTP_CTRL_TOG_ERROR_MASK                (0x200U)
#define OCOTP_CTRL_TOG_ERROR_SHIFT               (9U)
#define OCOTP_CTRL_TOG_RELOAD_SHADOWS_MASK       (0x400U)
#define OCOTP_CTRL_TOG_RELOAD_SHADOWS_SHIFT      (10U)
#define OCOTP_CTRL_TOG_CRC_TEST_MASK             (0x800U)
#define OCOTP_CTRL_TOG_CRC_TEST_SHIFT            (11U)
#define OCOTP_CTRL_TOG_CRC_FAIL_MASK             (0x1000U)
#define OCOTP_CTRL_TOG_CRC_FAIL_SHIFT            (12U)
#define OCOTP_CTRL_TOG_RSVD1_MASK                (0xE000U)
#define OCOTP_CTRL_TOG_RSVD1_SHIFT               (13U)
#define OCOTP_CTRL_TOG_RSVD1(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_TOG_RSVD1_SHIFT)) & OCOTP_CTRL_TOG_RSVD1_MASK)
#define OCOTP_CTRL_TOG_WR_UNLOCK_MASK            (0xFFFF0000U)
#define OCOTP_CTRL_TOG_WR_UNLOCK_SHIFT           (16U)
#define OCOTP_CTRL_TOG_WR_UNLOCK(x)              (((uint32_t)(((uint32_t)(x)) << OCOTP_CTRL_TOG_WR_UNLOCK_SHIFT)) & OCOTP_CTRL_TOG_WR_UNLOCK_MASK)

/*! @name TIMING - OTP Controller Timing Register */
#define OCOTP_TIMING_PROG_MASK                   (0xFFFU)
#define OCOTP_TIMING_PROG_SHIFT                  (0U)
#define OCOTP_TIMING_PROG(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_TIMING_PROG_SHIFT)) & OCOTP_TIMING_PROG_MASK)
#define OCOTP_TIMING_FSOURCE_MASK                (0xFF000U)
#define OCOTP_TIMING_FSOURCE_SHIFT               (12U)
#define OCOTP_TIMING_FSOURCE(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_TIMING_FSOURCE_SHIFT)) & OCOTP_TIMING_FSOURCE_MASK)
#define OCOTP_TIMING_RSRVD0_MASK                 (0xFFF00000U)
#define OCOTP_TIMING_RSRVD0_SHIFT                (20U)
#define OCOTP_TIMING_RSRVD0(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_TIMING_RSRVD0_SHIFT)) & OCOTP_TIMING_RSRVD0_MASK)

/*! @name DATA0 - OTP Controller Write Data Register */
#define OCOTP_DATA0_DATA0_MASK                   (0xFFFFFFFFU)
#define OCOTP_DATA0_DATA0_SHIFT                  (0U)
#define OCOTP_DATA0_DATA0(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_DATA0_DATA0_SHIFT)) & OCOTP_DATA0_DATA0_MASK)

/*! @name DATA1 - OTP Controller Write Data Register */
#define OCOTP_DATA1_DATA1_MASK                   (0xFFFFFFFFU)
#define OCOTP_DATA1_DATA1_SHIFT                  (0U)
#define OCOTP_DATA1_DATA1(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_DATA1_DATA1_SHIFT)) & OCOTP_DATA1_DATA1_MASK)

/*! @name DATA2 - OTP Controller Write Data Register */
#define OCOTP_DATA2_DATA2_MASK                   (0xFFFFFFFFU)
#define OCOTP_DATA2_DATA2_SHIFT                  (0U)
#define OCOTP_DATA2_DATA2(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_DATA2_DATA2_SHIFT)) & OCOTP_DATA2_DATA2_MASK)

/*! @name DATA3 - OTP Controller Write Data Register */
#define OCOTP_DATA3_DATA3_MASK                   (0xFFFFFFFFU)
#define OCOTP_DATA3_DATA3_SHIFT                  (0U)
#define OCOTP_DATA3_DATA3(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_DATA3_DATA3_SHIFT)) & OCOTP_DATA3_DATA3_MASK)

/*! @name READ_CTRL - OTP Controller Write Data Register */
#define OCOTP_READ_CTRL_READ_FUSE_MASK           (0x1U)
#define OCOTP_READ_CTRL_READ_FUSE_SHIFT          (0U)
#define OCOTP_READ_CTRL_RSVD0_MASK               (0xFFFFFFFEU)
#define OCOTP_READ_CTRL_RSVD0_SHIFT              (1U)
#define OCOTP_READ_CTRL_RSVD0(x)                 (((uint32_t)(((uint32_t)(x)) << OCOTP_READ_CTRL_RSVD0_SHIFT)) & OCOTP_READ_CTRL_RSVD0_MASK)

/*! @name READ_FUSE_DATA0 - OTP Controller Read Data Register */
#define OCOTP_READ_FUSE_DATA0_DATA0_MASK         (0xFFFFFFFFU)
#define OCOTP_READ_FUSE_DATA0_DATA0_SHIFT        (0U)
#define OCOTP_READ_FUSE_DATA0_DATA0(x)           (((uint32_t)(((uint32_t)(x)) << OCOTP_READ_FUSE_DATA0_DATA0_SHIFT)) & OCOTP_READ_FUSE_DATA0_DATA0_MASK)

/*! @name READ_FUSE_DATA1 - OTP Controller Read Data Register */
#define OCOTP_READ_FUSE_DATA1_DATA1_MASK         (0xFFFFFFFFU)
#define OCOTP_READ_FUSE_DATA1_DATA1_SHIFT        (0U)
#define OCOTP_READ_FUSE_DATA1_DATA1(x)           (((uint32_t)(((uint32_t)(x)) << OCOTP_READ_FUSE_DATA1_DATA1_SHIFT)) & OCOTP_READ_FUSE_DATA1_DATA1_MASK)

/*! @name READ_FUSE_DATA2 - OTP Controller Read Data Register */
#define OCOTP_READ_FUSE_DATA2_DATA2_MASK         (0xFFFFFFFFU)
#define OCOTP_READ_FUSE_DATA2_DATA2_SHIFT        (0U)
#define OCOTP_READ_FUSE_DATA2_DATA2(x)           (((uint32_t)(((uint32_t)(x)) << OCOTP_READ_FUSE_DATA2_DATA2_SHIFT)) & OCOTP_READ_FUSE_DATA2_DATA2_MASK)

/*! @name READ_FUSE_DATA3 - OTP Controller Read Data Register */
#define OCOTP_READ_FUSE_DATA3_DATA3_MASK         (0xFFFFFFFFU)
#define OCOTP_READ_FUSE_DATA3_DATA3_SHIFT        (0U)
#define OCOTP_READ_FUSE_DATA3_DATA3(x)           (((uint32_t)(((uint32_t)(x)) << OCOTP_READ_FUSE_DATA3_DATA3_SHIFT)) & OCOTP_READ_FUSE_DATA3_DATA3_MASK)

/*! @name SW_STICKY - Sticky bit Register */
#define OCOTP_SW_STICKY_RSVD0_MASK               (0x1U)
#define OCOTP_SW_STICKY_RSVD0_SHIFT              (0U)
#define OCOTP_SW_STICKY_SRK_REVOKE_LOCK_MASK     (0x2U)
#define OCOTP_SW_STICKY_SRK_REVOKE_LOCK_SHIFT    (1U)
#define OCOTP_SW_STICKY_FIELD_RETURN_LOCK_MASK   (0x4U)
#define OCOTP_SW_STICKY_FIELD_RETURN_LOCK_SHIFT  (2U)
#define OCOTP_SW_STICKY_RSVD1_MASK               (0xFFFFFFF8U)
#define OCOTP_SW_STICKY_RSVD1_SHIFT              (3U)
#define OCOTP_SW_STICKY_RSVD1(x)                 (((uint32_t)(((uint32_t)(x)) << OCOTP_SW_STICKY_RSVD1_SHIFT)) & OCOTP_SW_STICKY_RSVD1_MASK)

/*! @name SCS - Software Controllable Signals Register */
#define OCOTP_SCS_HAB_JDE_MASK                   (0x1U)
#define OCOTP_SCS_HAB_JDE_SHIFT                  (0U)
#define OCOTP_SCS_SPARE_MASK                     (0x7FFFFFFEU)
#define OCOTP_SCS_SPARE_SHIFT                    (1U)
#define OCOTP_SCS_SPARE(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SCS_SPARE_SHIFT)) & OCOTP_SCS_SPARE_MASK)
#define OCOTP_SCS_LOCK_MASK                      (0x80000000U)
#define OCOTP_SCS_LOCK_SHIFT                     (31U)

/*! @name SCS_SET - Software Controllable Signals Register */
#define OCOTP_SCS_SET_HAB_JDE_MASK               (0x1U)
#define OCOTP_SCS_SET_HAB_JDE_SHIFT              (0U)
#define OCOTP_SCS_SET_SPARE_MASK                 (0x7FFFFFFEU)
#define OCOTP_SCS_SET_SPARE_SHIFT                (1U)
#define OCOTP_SCS_SET_SPARE(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_SCS_SET_SPARE_SHIFT)) & OCOTP_SCS_SET_SPARE_MASK)
#define OCOTP_SCS_SET_LOCK_MASK                  (0x80000000U)
#define OCOTP_SCS_SET_LOCK_SHIFT                 (31U)

/*! @name SCS_CLR - Software Controllable Signals Register */
#define OCOTP_SCS_CLR_HAB_JDE_MASK               (0x1U)
#define OCOTP_SCS_CLR_HAB_JDE_SHIFT              (0U)
#define OCOTP_SCS_CLR_SPARE_MASK                 (0x7FFFFFFEU)
#define OCOTP_SCS_CLR_SPARE_SHIFT                (1U)
#define OCOTP_SCS_CLR_SPARE(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_SCS_CLR_SPARE_SHIFT)) & OCOTP_SCS_CLR_SPARE_MASK)
#define OCOTP_SCS_CLR_LOCK_MASK                  (0x80000000U)
#define OCOTP_SCS_CLR_LOCK_SHIFT                 (31U)

/*! @name SCS_TOG - Software Controllable Signals Register */
#define OCOTP_SCS_TOG_HAB_JDE_MASK               (0x1U)
#define OCOTP_SCS_TOG_HAB_JDE_SHIFT              (0U)
#define OCOTP_SCS_TOG_SPARE_MASK                 (0x7FFFFFFEU)
#define OCOTP_SCS_TOG_SPARE_SHIFT                (1U)
#define OCOTP_SCS_TOG_SPARE(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_SCS_TOG_SPARE_SHIFT)) & OCOTP_SCS_TOG_SPARE_MASK)
#define OCOTP_SCS_TOG_LOCK_MASK                  (0x80000000U)
#define OCOTP_SCS_TOG_LOCK_SHIFT                 (31U)

/*! @name CRC_ADDR - OTP Controller CRC test address */
#define OCOTP_CRC_ADDR_DATA_START_ADDR_MASK      (0xFFU)
#define OCOTP_CRC_ADDR_DATA_START_ADDR_SHIFT     (0U)
#define OCOTP_CRC_ADDR_DATA_START_ADDR(x)        (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_ADDR_DATA_START_ADDR_SHIFT)) & OCOTP_CRC_ADDR_DATA_START_ADDR_MASK)
#define OCOTP_CRC_ADDR_DATA_END_ADDR_MASK        (0xFF00U)
#define OCOTP_CRC_ADDR_DATA_END_ADDR_SHIFT       (8U)
#define OCOTP_CRC_ADDR_DATA_END_ADDR(x)          (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_ADDR_DATA_END_ADDR_SHIFT)) & OCOTP_CRC_ADDR_DATA_END_ADDR_MASK)
#define OCOTP_CRC_ADDR_CRC_ADDR_MASK             (0x30000U)
#define OCOTP_CRC_ADDR_CRC_ADDR_SHIFT            (16U)
#define OCOTP_CRC_ADDR_CRC_ADDR(x)               (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_ADDR_CRC_ADDR_SHIFT)) & OCOTP_CRC_ADDR_CRC_ADDR_MASK)
#define OCOTP_CRC_ADDR_RSVD0_MASK                (0xFFFC0000U)
#define OCOTP_CRC_ADDR_RSVD0_SHIFT               (18U)
#define OCOTP_CRC_ADDR_RSVD0(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_ADDR_RSVD0_SHIFT)) & OCOTP_CRC_ADDR_RSVD0_MASK)

/*! @name CRC_VALUE - OTP Controller CRC Value Register */
#define OCOTP_CRC_VALUE_DATA_MASK                (0xFFFFFFFFU)
#define OCOTP_CRC_VALUE_DATA_SHIFT               (0U)
#define OCOTP_CRC_VALUE_DATA(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_VALUE_DATA_SHIFT)) & OCOTP_CRC_VALUE_DATA_MASK)

/*! @name VERSION - OTP Controller Version Register */
#define OCOTP_VERSION_STEP_MASK                  (0xFFFFU)
#define OCOTP_VERSION_STEP_SHIFT                 (0U)
#define OCOTP_VERSION_STEP(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_VERSION_STEP_SHIFT)) & OCOTP_VERSION_STEP_MASK)
#define OCOTP_VERSION_MINOR_MASK                 (0xFF0000U)
#define OCOTP_VERSION_MINOR_SHIFT                (16U)
#define OCOTP_VERSION_MINOR(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_VERSION_MINOR_SHIFT)) & OCOTP_VERSION_MINOR_MASK)
#define OCOTP_VERSION_MAJOR_MASK                 (0xFF000000U)
#define OCOTP_VERSION_MAJOR_SHIFT                (24U)
#define OCOTP_VERSION_MAJOR(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_VERSION_MAJOR_SHIFT)) & OCOTP_VERSION_MAJOR_MASK)

/*! @name LOCK - Value of OTP Bank0 Word0 (Lock controls) */
#define OCOTP_LOCK_TESTER_MASK                   (0x3U)
#define OCOTP_LOCK_TESTER_SHIFT                  (0U)
#define OCOTP_LOCK_TESTER(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_TESTER_SHIFT)) & OCOTP_LOCK_TESTER_MASK)
#define OCOTP_LOCK_BOOT_CFG_MASK                 (0xCU)
#define OCOTP_LOCK_BOOT_CFG_SHIFT                (2U)
#define OCOTP_LOCK_BOOT_CFG(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_BOOT_CFG_SHIFT)) & OCOTP_LOCK_BOOT_CFG_MASK)
#define OCOTP_LOCK_MEM_TRIM_MASK                 (0x30U)
#define OCOTP_LOCK_MEM_TRIM_SHIFT                (4U)
#define OCOTP_LOCK_MEM_TRIM(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_MEM_TRIM_SHIFT)) & OCOTP_LOCK_MEM_TRIM_MASK)
#define OCOTP_LOCK_ANALOG_MASK                   (0xC0U)
#define OCOTP_LOCK_ANALOG_SHIFT                  (6U)
#define OCOTP_LOCK_ANALOG(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_ANALOG_SHIFT)) & OCOTP_LOCK_ANALOG_MASK)
#define OCOTP_LOCK_OTPMK_MASK                    (0x100U)
#define OCOTP_LOCK_OTPMK_SHIFT                   (8U)
#define OCOTP_LOCK_SRK_MASK                      (0x200U)
#define OCOTP_LOCK_SRK_SHIFT                     (9U)
#define OCOTP_LOCK_SJC_RESP_MASK                 (0x400U)
#define OCOTP_LOCK_SJC_RESP_SHIFT                (10U)
#define OCOTP_LOCK_RSVD0_MASK                    (0x800U)
#define OCOTP_LOCK_RSVD0_SHIFT                   (11U)
#define OCOTP_LOCK_USB_ID_MASK                   (0x3000U)
#define OCOTP_LOCK_USB_ID_SHIFT                  (12U)
#define OCOTP_LOCK_USB_ID(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_USB_ID_SHIFT)) & OCOTP_LOCK_USB_ID_MASK)
#define OCOTP_LOCK_MAC_ADDR_MASK                 (0xC000U)
#define OCOTP_LOCK_MAC_ADDR_SHIFT                (14U)
#define OCOTP_LOCK_MAC_ADDR(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_MAC_ADDR_SHIFT)) & OCOTP_LOCK_MAC_ADDR_MASK)
#define OCOTP_LOCK_MAU_KEY_MASK                  (0x10000U)
#define OCOTP_LOCK_MAU_KEY_SHIFT                 (16U)
#define OCOTP_LOCK_ROM_PATCH_MASK                (0x20000U)
#define OCOTP_LOCK_ROM_PATCH_SHIFT               (17U)
#define OCOTP_LOCK_RSVD1_MASK                    (0xC0000U)
#define OCOTP_LOCK_RSVD1_SHIFT                   (18U)
#define OCOTP_LOCK_RSVD1(x)                      (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_RSVD1_SHIFT)) & OCOTP_LOCK_RSVD1_MASK)
#define OCOTP_LOCK_GP1_MASK                      (0x300000U)
#define OCOTP_LOCK_GP1_SHIFT                     (20U)
#define OCOTP_LOCK_GP1(x)                        (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_GP1_SHIFT)) & OCOTP_LOCK_GP1_MASK)
#define OCOTP_LOCK_GP2_MASK                      (0xC00000U)
#define OCOTP_LOCK_GP2_SHIFT                     (22U)
#define OCOTP_LOCK_GP2(x)                        (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_GP2_SHIFT)) & OCOTP_LOCK_GP2_MASK)
#define OCOTP_LOCK_RSVD2_MASK                    (0xF000000U)
#define OCOTP_LOCK_RSVD2_SHIFT                   (24U)
#define OCOTP_LOCK_RSVD2(x)                      (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_RSVD2_SHIFT)) & OCOTP_LOCK_RSVD2_MASK)
#define OCOTP_LOCK_CRC_GP1_MASK                  (0x30000000U)
#define OCOTP_LOCK_CRC_GP1_SHIFT                 (28U)
#define OCOTP_LOCK_CRC_GP1(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_CRC_GP1_SHIFT)) & OCOTP_LOCK_CRC_GP1_MASK)
#define OCOTP_LOCK_CRC_GP2_MASK                  (0xC0000000U)
#define OCOTP_LOCK_CRC_GP2_SHIFT                 (30U)
#define OCOTP_LOCK_CRC_GP2(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_LOCK_CRC_GP2_SHIFT)) & OCOTP_LOCK_CRC_GP2_MASK)

/*! @name TESTER0 - Value of OTP Bank0 Word1 (Tester Information) */
#define OCOTP_TESTER0_BITS_MASK                  (0xFFFFFFFFU)
#define OCOTP_TESTER0_BITS_SHIFT                 (0U)
#define OCOTP_TESTER0_BITS(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_TESTER0_BITS_SHIFT)) & OCOTP_TESTER0_BITS_MASK)

/*! @name TESTER1 - Value of OTP Bank0 Word2 (Tester Information) */
#define OCOTP_TESTER1_BITS_MASK                  (0xFFFFFFFFU)
#define OCOTP_TESTER1_BITS_SHIFT                 (0U)
#define OCOTP_TESTER1_BITS(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_TESTER1_BITS_SHIFT)) & OCOTP_TESTER1_BITS_MASK)

/*! @name TESTER2 - Value of OTP Bank0 Word3 (Tester Information) */
#define OCOTP_TESTER2_BITS_MASK                  (0xFFFFFFFFU)
#define OCOTP_TESTER2_BITS_SHIFT                 (0U)
#define OCOTP_TESTER2_BITS(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_TESTER2_BITS_SHIFT)) & OCOTP_TESTER2_BITS_MASK)

/*! @name TESTER3 - Value of OTP Bank1 Word0 (Tester Information) */
#define OCOTP_TESTER3_BITS_MASK                  (0xFFFFFFFFU)
#define OCOTP_TESTER3_BITS_SHIFT                 (0U)
#define OCOTP_TESTER3_BITS(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_TESTER3_BITS_SHIFT)) & OCOTP_TESTER3_BITS_MASK)

/*! @name TESTER4 - Value of OTP Bank1 Word1 (Tester Information) */
#define OCOTP_TESTER4_BITS_MASK                  (0xFFFFFFFFU)
#define OCOTP_TESTER4_BITS_SHIFT                 (0U)
#define OCOTP_TESTER4_BITS(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_TESTER4_BITS_SHIFT)) & OCOTP_TESTER4_BITS_MASK)

/*! @name TESTER5 - Value of OTP Bank1 Word2 (Tester Information) */
#define OCOTP_TESTER5_BITS_MASK                  (0xFFFFFFFFU)
#define OCOTP_TESTER5_BITS_SHIFT                 (0U)
#define OCOTP_TESTER5_BITS(x)                    (((uint32_t)(((uint32_t)(x)) << OCOTP_TESTER5_BITS_SHIFT)) & OCOTP_TESTER5_BITS_MASK)

/*! @name BOOT_CFG0 - Value of OTP Bank1 Word3 (Boot Configuration Information) */
#define OCOTP_BOOT_CFG0_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_BOOT_CFG0_BITS_SHIFT               (0U)
#define OCOTP_BOOT_CFG0_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_BOOT_CFG0_BITS_SHIFT)) & OCOTP_BOOT_CFG0_BITS_MASK)

/*! @name BOOT_CFG1 - Value of OTP Bank2 Word0 (Boot Configuration Information) */
#define OCOTP_BOOT_CFG1_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_BOOT_CFG1_BITS_SHIFT               (0U)
#define OCOTP_BOOT_CFG1_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_BOOT_CFG1_BITS_SHIFT)) & OCOTP_BOOT_CFG1_BITS_MASK)

/*! @name BOOT_CFG2 - Value of OTP Bank2 Word1 (Boot Configuration Information) */
#define OCOTP_BOOT_CFG2_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_BOOT_CFG2_BITS_SHIFT               (0U)
#define OCOTP_BOOT_CFG2_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_BOOT_CFG2_BITS_SHIFT)) & OCOTP_BOOT_CFG2_BITS_MASK)

/*! @name BOOT_CFG3 - Value of OTP Bank2 Word2 (Boot Configuration Information) */
#define OCOTP_BOOT_CFG3_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_BOOT_CFG3_BITS_SHIFT               (0U)
#define OCOTP_BOOT_CFG3_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_BOOT_CFG3_BITS_SHIFT)) & OCOTP_BOOT_CFG3_BITS_MASK)

/*! @name BOOT_CFG4 - Value of OTP Bank2 Word3 (BOOT Configuration Information) */
#define OCOTP_BOOT_CFG4_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_BOOT_CFG4_BITS_SHIFT               (0U)
#define OCOTP_BOOT_CFG4_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_BOOT_CFG4_BITS_SHIFT)) & OCOTP_BOOT_CFG4_BITS_MASK)

/*! @name MEM_TRIM0 - Value of OTP Bank3 Word0 (Memory Related Information) */
#define OCOTP_MEM_TRIM0_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_MEM_TRIM0_BITS_SHIFT               (0U)
#define OCOTP_MEM_TRIM0_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_MEM_TRIM0_BITS_SHIFT)) & OCOTP_MEM_TRIM0_BITS_MASK)

/*! @name MEM_TRIM1 - Value of OTP Bank3 Word1 (Memory Related Information) */
#define OCOTP_MEM_TRIM1_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_MEM_TRIM1_BITS_SHIFT               (0U)
#define OCOTP_MEM_TRIM1_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_MEM_TRIM1_BITS_SHIFT)) & OCOTP_MEM_TRIM1_BITS_MASK)

/*! @name ANA0 - Value of OTP Bank3 Word2 (Analog Information) */
#define OCOTP_ANA0_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_ANA0_BITS_SHIFT                    (0U)
#define OCOTP_ANA0_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_ANA0_BITS_SHIFT)) & OCOTP_ANA0_BITS_MASK)

/*! @name ANA1 - Value of OTP Bank3 Word3 (Analog Info.) */
#define OCOTP_ANA1_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_ANA1_BITS_SHIFT                    (0U)
#define OCOTP_ANA1_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_ANA1_BITS_SHIFT)) & OCOTP_ANA1_BITS_MASK)

/*! @name OTPMK0 - Shadow Register for OTP Bank4 Word0 (OTPMK Key) */
#define OCOTP_OTPMK0_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_OTPMK0_BITS_SHIFT                  (0U)
#define OCOTP_OTPMK0_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_OTPMK0_BITS_SHIFT)) & OCOTP_OTPMK0_BITS_MASK)

/*! @name OTPMK1 - Shadow Register for OTP Bank4 Word1 (OTPMK Key) */
#define OCOTP_OTPMK1_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_OTPMK1_BITS_SHIFT                  (0U)
#define OCOTP_OTPMK1_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_OTPMK1_BITS_SHIFT)) & OCOTP_OTPMK1_BITS_MASK)

/*! @name OTPMK2 - Shadow Register for OTP Bank4 Word2 (OTPMK Key) */
#define OCOTP_OTPMK2_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_OTPMK2_BITS_SHIFT                  (0U)
#define OCOTP_OTPMK2_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_OTPMK2_BITS_SHIFT)) & OCOTP_OTPMK2_BITS_MASK)

/*! @name OTPMK3 - Shadow Register for OTP Bank4 Word3 (OTPMK Key) */
#define OCOTP_OTPMK3_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_OTPMK3_BITS_SHIFT                  (0U)
#define OCOTP_OTPMK3_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_OTPMK3_BITS_SHIFT)) & OCOTP_OTPMK3_BITS_MASK)

/*! @name OTPMK4 - Shadow Register for OTP Bank5 Word0 (OTPMK Key) */
#define OCOTP_OTPMK4_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_OTPMK4_BITS_SHIFT                  (0U)
#define OCOTP_OTPMK4_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_OTPMK4_BITS_SHIFT)) & OCOTP_OTPMK4_BITS_MASK)

/*! @name OTPMK5 - Shadow Register for OTP Bank5 Word1 (OTPMK Key) */
#define OCOTP_OTPMK5_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_OTPMK5_BITS_SHIFT                  (0U)
#define OCOTP_OTPMK5_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_OTPMK5_BITS_SHIFT)) & OCOTP_OTPMK5_BITS_MASK)

/*! @name OTPMK6 - Shadow Register for OTP Bank5 Word2 (OTPMK Key) */
#define OCOTP_OTPMK6_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_OTPMK6_BITS_SHIFT                  (0U)
#define OCOTP_OTPMK6_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_OTPMK6_BITS_SHIFT)) & OCOTP_OTPMK6_BITS_MASK)

/*! @name OTPMK7 - Shadow Register for OTP Bank5 Word3 (OTPMK Key) */
#define OCOTP_OTPMK7_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_OTPMK7_BITS_SHIFT                  (0U)
#define OCOTP_OTPMK7_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_OTPMK7_BITS_SHIFT)) & OCOTP_OTPMK7_BITS_MASK)

/*! @name SRK0 - Shadow Register for OTP Bank6 Word0 (SRK Hash) */
#define OCOTP_SRK0_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_SRK0_BITS_SHIFT                    (0U)
#define OCOTP_SRK0_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK0_BITS_SHIFT)) & OCOTP_SRK0_BITS_MASK)

/*! @name SRK1 - Shadow Register for OTP Bank6 Word1 (SRK Hash) */
#define OCOTP_SRK1_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_SRK1_BITS_SHIFT                    (0U)
#define OCOTP_SRK1_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK1_BITS_SHIFT)) & OCOTP_SRK1_BITS_MASK)

/*! @name SRK2 - Shadow Register for OTP Bank6 Word2 (SRK Hash) */
#define OCOTP_SRK2_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_SRK2_BITS_SHIFT                    (0U)
#define OCOTP_SRK2_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK2_BITS_SHIFT)) & OCOTP_SRK2_BITS_MASK)

/*! @name SRK3 - Shadow Register for OTP Bank6 Word3 (SRK Hash) */
#define OCOTP_SRK3_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_SRK3_BITS_SHIFT                    (0U)
#define OCOTP_SRK3_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK3_BITS_SHIFT)) & OCOTP_SRK3_BITS_MASK)

/*! @name SRK4 - Shadow Register for OTP Bank7 Word0 (SRK Hash) */
#define OCOTP_SRK4_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_SRK4_BITS_SHIFT                    (0U)
#define OCOTP_SRK4_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK4_BITS_SHIFT)) & OCOTP_SRK4_BITS_MASK)

/*! @name SRK5 - Shadow Register for OTP Bank7 Word1 (SRK Hash) */
#define OCOTP_SRK5_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_SRK5_BITS_SHIFT                    (0U)
#define OCOTP_SRK5_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK5_BITS_SHIFT)) & OCOTP_SRK5_BITS_MASK)

/*! @name SRK6 - Shadow Register for OTP Bank7 Word2 (SRK Hash) */
#define OCOTP_SRK6_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_SRK6_BITS_SHIFT                    (0U)
#define OCOTP_SRK6_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK6_BITS_SHIFT)) & OCOTP_SRK6_BITS_MASK)

/*! @name SRK7 - Shadow Register for OTP Bank7 Word3 (SRK Hash) */
#define OCOTP_SRK7_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_SRK7_BITS_SHIFT                    (0U)
#define OCOTP_SRK7_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK7_BITS_SHIFT)) & OCOTP_SRK7_BITS_MASK)

/*! @name SJC_RESP0 - Value of OTP Bank8 Word0 (Secure JTAG Response Field) */
#define OCOTP_SJC_RESP0_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_SJC_RESP0_BITS_SHIFT               (0U)
#define OCOTP_SJC_RESP0_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_SJC_RESP0_BITS_SHIFT)) & OCOTP_SJC_RESP0_BITS_MASK)

/*! @name SJC_RESP1 - Value of OTP Bank8 Word1 (Secure JTAG Response Field) */
#define OCOTP_SJC_RESP1_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_SJC_RESP1_BITS_SHIFT               (0U)
#define OCOTP_SJC_RESP1_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_SJC_RESP1_BITS_SHIFT)) & OCOTP_SJC_RESP1_BITS_MASK)

/*! @name USB_ID - Value of OTP Bank8 Word2 (USB ID info) */
#define OCOTP_USB_ID_BITS_MASK                   (0xFFFFFFFFU)
#define OCOTP_USB_ID_BITS_SHIFT                  (0U)
#define OCOTP_USB_ID_BITS(x)                     (((uint32_t)(((uint32_t)(x)) << OCOTP_USB_ID_BITS_SHIFT)) & OCOTP_USB_ID_BITS_MASK)

/*! @name FIELD_RETURN - Value of OTP Bank8 Word3 (Field Return) */
#define OCOTP_FIELD_RETURN_BITS_MASK             (0xFFFFFFFFU)
#define OCOTP_FIELD_RETURN_BITS_SHIFT            (0U)
#define OCOTP_FIELD_RETURN_BITS(x)               (((uint32_t)(((uint32_t)(x)) << OCOTP_FIELD_RETURN_BITS_SHIFT)) & OCOTP_FIELD_RETURN_BITS_MASK)

/*! @name MAC_ADDR0 - Value of OTP Bank9 Word0 (MAC Address) */
#define OCOTP_MAC_ADDR0_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_MAC_ADDR0_BITS_SHIFT               (0U)
#define OCOTP_MAC_ADDR0_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_MAC_ADDR0_BITS_SHIFT)) & OCOTP_MAC_ADDR0_BITS_MASK)

/*! @name MAC_ADDR1 - Value of OTP Bank9 Word1 (MAC Address) */
#define OCOTP_MAC_ADDR1_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_MAC_ADDR1_BITS_SHIFT               (0U)
#define OCOTP_MAC_ADDR1_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_MAC_ADDR1_BITS_SHIFT)) & OCOTP_MAC_ADDR1_BITS_MASK)

/*! @name MAC_ADDR2 - Value of OTP Bank9 Word2 (MAC Address) */
#define OCOTP_MAC_ADDR2_BITS_MASK                (0xFFFFFFFFU)
#define OCOTP_MAC_ADDR2_BITS_SHIFT               (0U)
#define OCOTP_MAC_ADDR2_BITS(x)                  (((uint32_t)(((uint32_t)(x)) << OCOTP_MAC_ADDR2_BITS_SHIFT)) & OCOTP_MAC_ADDR2_BITS_MASK)

/*! @name SRK_REVOKE - Value of OTP Bank9 Word3 (SRK Revoke) */
#define OCOTP_SRK_REVOKE_BITS_MASK               (0xFFFFFFFFU)
#define OCOTP_SRK_REVOKE_BITS_SHIFT              (0U)
#define OCOTP_SRK_REVOKE_BITS(x)                 (((uint32_t)(((uint32_t)(x)) << OCOTP_SRK_REVOKE_BITS_SHIFT)) & OCOTP_SRK_REVOKE_BITS_MASK)

/*! @name MAU_KEY0 - Shadow Register for OTP Bank10 Word0 (MAU Key) */
#define OCOTP_MAU_KEY0_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_MAU_KEY0_BITS_SHIFT                (0U)
#define OCOTP_MAU_KEY0_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_MAU_KEY0_BITS_SHIFT)) & OCOTP_MAU_KEY0_BITS_MASK)

/*! @name MAU_KEY1 - Shadow Register for OTP Bank10 Word1 (MAU Key) */
#define OCOTP_MAU_KEY1_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_MAU_KEY1_BITS_SHIFT                (0U)
#define OCOTP_MAU_KEY1_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_MAU_KEY1_BITS_SHIFT)) & OCOTP_MAU_KEY1_BITS_MASK)

/*! @name MAU_KEY2 - Shadow Register for OTP Bank10 Word2 (MAU Key) */
#define OCOTP_MAU_KEY2_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_MAU_KEY2_BITS_SHIFT                (0U)
#define OCOTP_MAU_KEY2_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_MAU_KEY2_BITS_SHIFT)) & OCOTP_MAU_KEY2_BITS_MASK)

/*! @name MAU_KEY3 - Shadow Register for OTP Bank10 Word3 (MAU Key) */
#define OCOTP_MAU_KEY3_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_MAU_KEY3_BITS_SHIFT                (0U)
#define OCOTP_MAU_KEY3_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_MAU_KEY3_BITS_SHIFT)) & OCOTP_MAU_KEY3_BITS_MASK)

/*! @name MAU_KEY4 - Shadow Register for OTP Bank11 Word0 (MAU Key) */
#define OCOTP_MAU_KEY4_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_MAU_KEY4_BITS_SHIFT                (0U)
#define OCOTP_MAU_KEY4_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_MAU_KEY4_BITS_SHIFT)) & OCOTP_MAU_KEY4_BITS_MASK)

/*! @name MAU_KEY5 - Shadow Register for OTP Bank11 Word1 (MAU Key) */
#define OCOTP_MAU_KEY5_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_MAU_KEY5_BITS_SHIFT                (0U)
#define OCOTP_MAU_KEY5_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_MAU_KEY5_BITS_SHIFT)) & OCOTP_MAU_KEY5_BITS_MASK)

/*! @name MAU_KEY6 - Shadow Register for OTP Bank11 Word2 (MAU Key) */
#define OCOTP_MAU_KEY6_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_MAU_KEY6_BITS_SHIFT                (0U)
#define OCOTP_MAU_KEY6_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_MAU_KEY6_BITS_SHIFT)) & OCOTP_MAU_KEY6_BITS_MASK)

/*! @name MAU_KEY7 - Shadow Register for OTP Bank11 Word3 (MAU Key) */
#define OCOTP_MAU_KEY7_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_MAU_KEY7_BITS_SHIFT                (0U)
#define OCOTP_MAU_KEY7_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_MAU_KEY7_BITS_SHIFT)) & OCOTP_MAU_KEY7_BITS_MASK)

/*! @name GP10 - Value of OTP Bank14 Word0 */
#define OCOTP_GP10_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_GP10_BITS_SHIFT                    (0U)
#define OCOTP_GP10_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_GP10_BITS_SHIFT)) & OCOTP_GP10_BITS_MASK)

/*! @name GP11 - Value of OTP Bank14 Word1 */
#define OCOTP_GP11_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_GP11_BITS_SHIFT                    (0U)
#define OCOTP_GP11_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_GP11_BITS_SHIFT)) & OCOTP_GP11_BITS_MASK)

/*! @name GP20 - Value of OTP Bank14 Word2 */
#define OCOTP_GP20_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_GP20_BITS_SHIFT                    (0U)
#define OCOTP_GP20_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_GP20_BITS_SHIFT)) & OCOTP_GP20_BITS_MASK)

/*! @name GP21 - Value of OTP Bank14 Word3 */
#define OCOTP_GP21_BITS_MASK                     (0xFFFFFFFFU)
#define OCOTP_GP21_BITS_SHIFT                    (0U)
#define OCOTP_GP21_BITS(x)                       (((uint32_t)(((uint32_t)(x)) << OCOTP_GP21_BITS_SHIFT)) & OCOTP_GP21_BITS_MASK)

/*! @name CRC_GP10 - Value of OTP Bank15 Word0 (CRC Key) */
#define OCOTP_CRC_GP10_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_CRC_GP10_BITS_SHIFT                (0U)
#define OCOTP_CRC_GP10_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_GP10_BITS_SHIFT)) & OCOTP_CRC_GP10_BITS_MASK)

/*! @name CRC_GP11 - Value of OTP Bank15 Word1 (CRC Key) */
#define OCOTP_CRC_GP11_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_CRC_GP11_BITS_SHIFT                (0U)
#define OCOTP_CRC_GP11_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_GP11_BITS_SHIFT)) & OCOTP_CRC_GP11_BITS_MASK)

/*! @name CRC_GP20 - Value of OTP Bank15 Word2 (CRC Key) */
#define OCOTP_CRC_GP20_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_CRC_GP20_BITS_SHIFT                (0U)
#define OCOTP_CRC_GP20_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_GP20_BITS_SHIFT)) & OCOTP_CRC_GP20_BITS_MASK)

/*! @name CRC_GP21 - Value of OTP Bank15 Word3 (CRC Key) */
#define OCOTP_CRC_GP21_BITS_MASK                 (0xFFFFFFFFU)
#define OCOTP_CRC_GP21_BITS_SHIFT                (0U)
#define OCOTP_CRC_GP21_BITS(x)                   (((uint32_t)(((uint32_t)(x)) << OCOTP_CRC_GP21_BITS_SHIFT)) & OCOTP_CRC_GP21_BITS_MASK)


/*!
 * @}
 */ /* end of group OCOTP_Register_Masks */


/* OCOTP - Peripheral instance base addresses */
/** Peripheral OCOTP base pointer */
#define OCOTP_BASE_PTR                           ((OCOTP_MemMapPtr)0x30350000u)
/** Array initializer of OCOTP peripheral base pointers */
#define OCOTP_BASE_PTRS                          { OCOTP_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- OCOTP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup OCOTP_Register_Accessor_Macros OCOTP - Register accessor macros
 * @{
 */


/* OCOTP - Register instance definitions */
/* OCOTP */
#define OCOTP_CTRL                               OCOTP_CTRL_REG(OCOTP_BASE_PTR)
#define OCOTP_CTRL_SET                           OCOTP_CTRL_SET_REG(OCOTP_BASE_PTR)
#define OCOTP_CTRL_CLR                           OCOTP_CTRL_CLR_REG(OCOTP_BASE_PTR)
#define OCOTP_CTRL_TOG                           OCOTP_CTRL_TOG_REG(OCOTP_BASE_PTR)
#define OCOTP_TIMING                             OCOTP_TIMING_REG(OCOTP_BASE_PTR)
#define OCOTP_DATA0                              OCOTP_DATA0_REG(OCOTP_BASE_PTR)
#define OCOTP_DATA1                              OCOTP_DATA1_REG(OCOTP_BASE_PTR)
#define OCOTP_DATA2                              OCOTP_DATA2_REG(OCOTP_BASE_PTR)
#define OCOTP_DATA3                              OCOTP_DATA3_REG(OCOTP_BASE_PTR)
#define OCOTP_READ_CTRL                          OCOTP_READ_CTRL_REG(OCOTP_BASE_PTR)
#define OCOTP_READ_FUSE_DATA0                    OCOTP_READ_FUSE_DATA0_REG(OCOTP_BASE_PTR)
#define OCOTP_READ_FUSE_DATA1                    OCOTP_READ_FUSE_DATA1_REG(OCOTP_BASE_PTR)
#define OCOTP_READ_FUSE_DATA2                    OCOTP_READ_FUSE_DATA2_REG(OCOTP_BASE_PTR)
#define OCOTP_READ_FUSE_DATA3                    OCOTP_READ_FUSE_DATA3_REG(OCOTP_BASE_PTR)
#define OCOTP_SW_STICKY                          OCOTP_SW_STICKY_REG(OCOTP_BASE_PTR)
#define OCOTP_SCS                                OCOTP_SCS_REG(OCOTP_BASE_PTR)
#define OCOTP_SCS_SET                            OCOTP_SCS_SET_REG(OCOTP_BASE_PTR)
#define OCOTP_SCS_CLR                            OCOTP_SCS_CLR_REG(OCOTP_BASE_PTR)
#define OCOTP_SCS_TOG                            OCOTP_SCS_TOG_REG(OCOTP_BASE_PTR)
#define OCOTP_CRC_ADDR                           OCOTP_CRC_ADDR_REG(OCOTP_BASE_PTR)
#define OCOTP_CRC_VALUE                          OCOTP_CRC_VALUE_REG(OCOTP_BASE_PTR)
#define OCOTP_VERSION                            OCOTP_VERSION_REG(OCOTP_BASE_PTR)
#define OCOTP_LOCK                               OCOTP_LOCK_REG(OCOTP_BASE_PTR)
#define OCOTP_TESTER0                            OCOTP_TESTER0_REG(OCOTP_BASE_PTR)
#define OCOTP_TESTER1                            OCOTP_TESTER1_REG(OCOTP_BASE_PTR)
#define OCOTP_TESTER2                            OCOTP_TESTER2_REG(OCOTP_BASE_PTR)
#define OCOTP_TESTER3                            OCOTP_TESTER3_REG(OCOTP_BASE_PTR)
#define OCOTP_TESTER4                            OCOTP_TESTER4_REG(OCOTP_BASE_PTR)
#define OCOTP_TESTER5                            OCOTP_TESTER5_REG(OCOTP_BASE_PTR)
#define OCOTP_BOOT_CFG0                          OCOTP_BOOT_CFG0_REG(OCOTP_BASE_PTR)
#define OCOTP_BOOT_CFG1                          OCOTP_BOOT_CFG1_REG(OCOTP_BASE_PTR)
#define OCOTP_BOOT_CFG2                          OCOTP_BOOT_CFG2_REG(OCOTP_BASE_PTR)
#define OCOTP_BOOT_CFG3                          OCOTP_BOOT_CFG3_REG(OCOTP_BASE_PTR)
#define OCOTP_BOOT_CFG4                          OCOTP_BOOT_CFG4_REG(OCOTP_BASE_PTR)
#define OCOTP_MEM_TRIM0                          OCOTP_MEM_TRIM0_REG(OCOTP_BASE_PTR)
#define OCOTP_MEM_TRIM1                          OCOTP_MEM_TRIM1_REG(OCOTP_BASE_PTR)
#define OCOTP_ANA0                               OCOTP_ANA0_REG(OCOTP_BASE_PTR)
#define OCOTP_ANA1                               OCOTP_ANA1_REG(OCOTP_BASE_PTR)
#define OCOTP_OTPMK0                             OCOTP_OTPMK0_REG(OCOTP_BASE_PTR)
#define OCOTP_OTPMK1                             OCOTP_OTPMK1_REG(OCOTP_BASE_PTR)
#define OCOTP_OTPMK2                             OCOTP_OTPMK2_REG(OCOTP_BASE_PTR)
#define OCOTP_OTPMK3                             OCOTP_OTPMK3_REG(OCOTP_BASE_PTR)
#define OCOTP_OTPMK4                             OCOTP_OTPMK4_REG(OCOTP_BASE_PTR)
#define OCOTP_OTPMK5                             OCOTP_OTPMK5_REG(OCOTP_BASE_PTR)
#define OCOTP_OTPMK6                             OCOTP_OTPMK6_REG(OCOTP_BASE_PTR)
#define OCOTP_OTPMK7                             OCOTP_OTPMK7_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK0                               OCOTP_SRK0_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK1                               OCOTP_SRK1_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK2                               OCOTP_SRK2_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK3                               OCOTP_SRK3_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK4                               OCOTP_SRK4_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK5                               OCOTP_SRK5_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK6                               OCOTP_SRK6_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK7                               OCOTP_SRK7_REG(OCOTP_BASE_PTR)
#define OCOTP_SJC_RESP0                          OCOTP_SJC_RESP0_REG(OCOTP_BASE_PTR)
#define OCOTP_SJC_RESP1                          OCOTP_SJC_RESP1_REG(OCOTP_BASE_PTR)
#define OCOTP_USB_ID                             OCOTP_USB_ID_REG(OCOTP_BASE_PTR)
#define OCOTP_FIELD_RETURN                       OCOTP_FIELD_RETURN_REG(OCOTP_BASE_PTR)
#define OCOTP_MAC_ADDR0                          OCOTP_MAC_ADDR0_REG(OCOTP_BASE_PTR)
#define OCOTP_MAC_ADDR1                          OCOTP_MAC_ADDR1_REG(OCOTP_BASE_PTR)
#define OCOTP_MAC_ADDR2                          OCOTP_MAC_ADDR2_REG(OCOTP_BASE_PTR)
#define OCOTP_SRK_REVOKE                         OCOTP_SRK_REVOKE_REG(OCOTP_BASE_PTR)
#define OCOTP_MAU_KEY0                           OCOTP_MAU_KEY0_REG(OCOTP_BASE_PTR)
#define OCOTP_MAU_KEY1                           OCOTP_MAU_KEY1_REG(OCOTP_BASE_PTR)
#define OCOTP_MAU_KEY2                           OCOTP_MAU_KEY2_REG(OCOTP_BASE_PTR)
#define OCOTP_MAU_KEY3                           OCOTP_MAU_KEY3_REG(OCOTP_BASE_PTR)
#define OCOTP_MAU_KEY4                           OCOTP_MAU_KEY4_REG(OCOTP_BASE_PTR)
#define OCOTP_MAU_KEY5                           OCOTP_MAU_KEY5_REG(OCOTP_BASE_PTR)
#define OCOTP_MAU_KEY6                           OCOTP_MAU_KEY6_REG(OCOTP_BASE_PTR)
#define OCOTP_MAU_KEY7                           OCOTP_MAU_KEY7_REG(OCOTP_BASE_PTR)
#define OCOTP_GP10                               OCOTP_GP10_REG(OCOTP_BASE_PTR)
#define OCOTP_GP11                               OCOTP_GP11_REG(OCOTP_BASE_PTR)
#define OCOTP_GP20                               OCOTP_GP20_REG(OCOTP_BASE_PTR)
#define OCOTP_GP21                               OCOTP_GP21_REG(OCOTP_BASE_PTR)
#define OCOTP_CRC_GP10                           OCOTP_CRC_GP10_REG(OCOTP_BASE_PTR)
#define OCOTP_CRC_GP11                           OCOTP_CRC_GP11_REG(OCOTP_BASE_PTR)
#define OCOTP_CRC_GP20                           OCOTP_CRC_GP20_REG(OCOTP_BASE_PTR)
#define OCOTP_CRC_GP21                           OCOTP_CRC_GP21_REG(OCOTP_BASE_PTR)

/*!
 * @}
 */ /* end of group OCOTP_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group OCOTP_Peripheral */


/* ----------------------------------------------------------------------------
   -- PCIE_PHY_CMN
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PCIE_PHY_CMN_Peripheral PCIE_PHY_CMN
 * @{
 */

/** PCIE_PHY_CMN - Peripheral register structure */
typedef struct PCIE_PHY_CMN_MemMap {
  uint8_t RESERVED_0[4];
  uint32_t REG01;                                  /**< Impedance Calibration Register, offset: 0x4 */
  uint32_t REG02;                                  /**< , offset: 0x8 */
  uint8_t RESERVED_1[6];
  uint32_t REG03;                                  /**< , offset: 0x12 */
  uint32_t REG04;                                  /**< , offset: 0x16 */
  uint8_t RESERVED_2[6];
  uint32_t REG05;                                  /**< , offset: 0x20 */
  uint32_t REG06;                                  /**< , offset: 0x24 */
  uint32_t REG07;                                  /**< , offset: 0x28 */
  uint32_t REG0B;                                  /**< , offset: 0x2C */
  uint8_t RESERVED_3[2];
  uint32_t REG08;                                  /**< , offset: 0x32 */
  uint32_t REG09;                                  /**< , offset: 0x36 */
  uint8_t RESERVED_4[6];
  uint32_t REG11;                                  /**< , offset: 0x40 */
  uint8_t RESERVED_5[28];
  uint32_t REG15;                                  /**< , offset: 0x60 */
  uint32_t REG16;                                  /**< , offset: 0x64 */
  uint32_t REG17;                                  /**< , offset: 0x68 */
  uint8_t RESERVED_6[6];
  uint32_t REG18;                                  /**< , offset: 0x72 */
  uint32_t REG19;                                  /**< , offset: 0x76 */
  uint8_t RESERVED_7[6];
  uint32_t REG1A;                                  /**< , offset: 0x80 */
} volatile *PCIE_PHY_CMN_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- PCIE_PHY_CMN - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PCIE_PHY_CMN_Register_Accessor_Macros PCIE_PHY_CMN - Register accessor macros
 * @{
 */


/* PCIE_PHY_CMN - Register accessors */
#define PCIE_PHY_CMN_REG01_REG(base)             ((base)->REG01)
#define PCIE_PHY_CMN_REG02_REG(base)             ((base)->REG02)
#define PCIE_PHY_CMN_REG03_REG(base)             ((base)->REG03)
#define PCIE_PHY_CMN_REG04_REG(base)             ((base)->REG04)
#define PCIE_PHY_CMN_REG05_REG(base)             ((base)->REG05)
#define PCIE_PHY_CMN_REG06_REG(base)             ((base)->REG06)
#define PCIE_PHY_CMN_REG07_REG(base)             ((base)->REG07)
#define PCIE_PHY_CMN_REG0B_REG(base)             ((base)->REG0B)
#define PCIE_PHY_CMN_REG08_REG(base)             ((base)->REG08)
#define PCIE_PHY_CMN_REG09_REG(base)             ((base)->REG09)
#define PCIE_PHY_CMN_REG11_REG(base)             ((base)->REG11)
#define PCIE_PHY_CMN_REG15_REG(base)             ((base)->REG15)
#define PCIE_PHY_CMN_REG16_REG(base)             ((base)->REG16)
#define PCIE_PHY_CMN_REG17_REG(base)             ((base)->REG17)
#define PCIE_PHY_CMN_REG18_REG(base)             ((base)->REG18)
#define PCIE_PHY_CMN_REG19_REG(base)             ((base)->REG19)
#define PCIE_PHY_CMN_REG1A_REG(base)             ((base)->REG1A)

/*!
 * @}
 */ /* end of group PCIE_PHY_CMN_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- PCIE_PHY_CMN Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PCIE_PHY_CMN_Register_Masks PCIE_PHY_CMN Register Masks
 * @{
 */

/*! @name REG01 - Impedance Calibration Register */
#define PCIE_PHY_CMN_REG01_TCODE_MASK            (0xFU)
#define PCIE_PHY_CMN_REG01_TCODE_SHIFT           (0U)
#define PCIE_PHY_CMN_REG01_TCODE(x)              (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG01_TCODE_SHIFT)) & PCIE_PHY_CMN_REG01_TCODE_MASK)
#define PCIE_PHY_CMN_REG01_RCODE_MASK            (0xF0U)
#define PCIE_PHY_CMN_REG01_RCODE_SHIFT           (4U)
#define PCIE_PHY_CMN_REG01_RCODE(x)              (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG01_RCODE_SHIFT)) & PCIE_PHY_CMN_REG01_RCODE_MASK)

/*! @name REG02 -  */
#define PCIE_PHY_CMN_REG02_FORCE_MASK            (0x1U)
#define PCIE_PHY_CMN_REG02_FORCE_SHIFT           (0U)
#define PCIE_PHY_CMN_REG02_PDIV_MASK             (0xF0U)
#define PCIE_PHY_CMN_REG02_PDIV_SHIFT            (4U)
#define PCIE_PHY_CMN_REG02_PDIV(x)               (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG02_PDIV_SHIFT)) & PCIE_PHY_CMN_REG02_PDIV_MASK)

/*! @name REG03 -  */
#define PCIE_PHY_CMN_REG03_CTRL_CP_MASK          (0xFU)
#define PCIE_PHY_CMN_REG03_CTRL_CP_SHIFT         (0U)
#define PCIE_PHY_CMN_REG03_CTRL_CP(x)            (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG03_CTRL_CP_SHIFT)) & PCIE_PHY_CMN_REG03_CTRL_CP_MASK)

/*! @name REG04 -  */
#define PCIE_PHY_CMN_REG04_CTRL_C_MASK           (0xEU)
#define PCIE_PHY_CMN_REG04_CTRL_C_SHIFT          (1U)
#define PCIE_PHY_CMN_REG04_CTRL_C(x)             (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG04_CTRL_C_SHIFT)) & PCIE_PHY_CMN_REG04_CTRL_C_MASK)
#define PCIE_PHY_CMN_REG04_CTRL_R_MASK           (0xF0U)
#define PCIE_PHY_CMN_REG04_CTRL_R_SHIFT          (4U)
#define PCIE_PHY_CMN_REG04_CTRL_R(x)             (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG04_CTRL_R_SHIFT)) & PCIE_PHY_CMN_REG04_CTRL_R_MASK)

/*! @name REG05 -  */
#define PCIE_PHY_CMN_REG05_DCC_FB_EN_MASK        (0x40U)
#define PCIE_PHY_CMN_REG05_DCC_FB_EN_SHIFT       (6U)
#define PCIE_PHY_CMN_REG05_CKFB_MON_EN_MASK      (0x80U)
#define PCIE_PHY_CMN_REG05_CKFB_MON_EN_SHIFT     (7U)

/*! @name REG06 -  */
#define PCIE_PHY_CMN_REG06_SD_DIV_MASK           (0x7U)
#define PCIE_PHY_CMN_REG06_SD_DIV_SHIFT          (0U)
#define PCIE_PHY_CMN_REG06_SD_DIV(x)             (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG06_SD_DIV_SHIFT)) & PCIE_PHY_CMN_REG06_SD_DIV_MASK)
#define PCIE_PHY_CMN_REG06_CK100M_EN_MASK        (0x10U)
#define PCIE_PHY_CMN_REG06_CK100M_EN_SHIFT       (4U)
#define PCIE_PHY_CMN_REG06_MDIV_HS_MASK          (0x80U)
#define PCIE_PHY_CMN_REG06_MDIV_HS_SHIFT         (7U)

/*! @name REG07 -  */
#define PCIE_PHY_CMN_REG07_MDIV_MS_MASK          (0xFFU)
#define PCIE_PHY_CMN_REG07_MDIV_MS_SHIFT         (0U)
#define PCIE_PHY_CMN_REG07_MDIV_MS(x)            (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG07_MDIV_MS_SHIFT)) & PCIE_PHY_CMN_REG07_MDIV_MS_MASK)

/*! @name REG0B -  */
#define PCIE_PHY_CMN_REG0B_SSC_MASK              (0x7FU)
#define PCIE_PHY_CMN_REG0B_SSC_SHIFT             (0U)
#define PCIE_PHY_CMN_REG0B_SSC(x)                (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG0B_SSC_SHIFT)) & PCIE_PHY_CMN_REG0B_SSC_MASK)

/*! @name REG08 -  */
#define PCIE_PHY_CMN_REG08_PI_EN_MASK            (0x1U)
#define PCIE_PHY_CMN_REG08_PI_EN_SHIFT           (0U)
#define PCIE_PHY_CMN_REG08_PI_STR_MASK           (0x1EU)
#define PCIE_PHY_CMN_REG08_PI_STR_SHIFT          (1U)
#define PCIE_PHY_CMN_REG08_PI_STR(x)             (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG08_PI_STR_SHIFT)) & PCIE_PHY_CMN_REG08_PI_STR_MASK)

/*! @name REG09 -  */
#define PCIE_PHY_CMN_REG09_SSC_CNTL_MASK         (0x60U)
#define PCIE_PHY_CMN_REG09_SSC_CNTL_SHIFT        (5U)
#define PCIE_PHY_CMN_REG09_SSC_CNTL(x)           (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG09_SSC_CNTL_SHIFT)) & PCIE_PHY_CMN_REG09_SSC_CNTL_MASK)

/*! @name REG11 -  */
#define PCIE_PHY_CMN_REG11_PREF_MASK             (0xFFU)
#define PCIE_PHY_CMN_REG11_PREF_SHIFT            (0U)
#define PCIE_PHY_CMN_REG11_PREF(x)               (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG11_PREF_SHIFT)) & PCIE_PHY_CMN_REG11_PREF_MASK)

/*! @name REG15 -  */
#define PCIE_PHY_CMN_REG15_MON_EN_MASK           (0x10U)
#define PCIE_PHY_CMN_REG15_MON_EN_SHIFT          (4U)
#define PCIE_PHY_CMN_REG15_PD_SCMN_MASK          (0x60U)
#define PCIE_PHY_CMN_REG15_PD_SCMN_SHIFT         (5U)
#define PCIE_PHY_CMN_REG15_PD_SCMN(x)            (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG15_PD_SCMN_SHIFT)) & PCIE_PHY_CMN_REG15_PD_SCMN_MASK)
#define PCIE_PHY_CMN_REG15_PHY_CMNPD_EN_MASK     (0x80U)
#define PCIE_PHY_CMN_REG15_PHY_CMNPD_EN_SHIFT    (7U)

/*! @name REG16 -  */
#define PCIE_PHY_CMN_REG16_PHY_SSC_EN_MASK       (0xCU)
#define PCIE_PHY_CMN_REG16_PHY_SSC_EN_SHIFT      (2U)
#define PCIE_PHY_CMN_REG16_PHY_SSC_EN(x)         (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG16_PHY_SSC_EN_SHIFT)) & PCIE_PHY_CMN_REG16_PHY_SSC_EN_MASK)

/*! @name REG17 -  */
#define PCIE_PHY_CMN_REG17_RDIV_MASK             (0xFU)
#define PCIE_PHY_CMN_REG17_RDIV_SHIFT            (0U)
#define PCIE_PHY_CMN_REG17_RDIV(x)               (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG17_RDIV_SHIFT)) & PCIE_PHY_CMN_REG17_RDIV_MASK)
#define PCIE_PHY_CMN_REG17_RDIV_EN_MASK          (0x10U)
#define PCIE_PHY_CMN_REG17_RDIV_EN_SHIFT         (4U)
#define PCIE_PHY_CMN_REG17_TG_CODE_EN_MASK       (0x80U)
#define PCIE_PHY_CMN_REG17_TG_CODE_EN_SHIFT      (7U)

/*! @name REG18 -  */
#define PCIE_PHY_CMN_REG18_TG_CODE_MASK          (0xFFU)
#define PCIE_PHY_CMN_REG18_TG_CODE_SHIFT         (0U)
#define PCIE_PHY_CMN_REG18_TG_CODE(x)            (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG18_TG_CODE_SHIFT)) & PCIE_PHY_CMN_REG18_TG_CODE_MASK)

/*! @name REG19 -  */
#define PCIE_PHY_CMN_REG19_TOL_MASK              (0x7U)
#define PCIE_PHY_CMN_REG19_TOL_SHIFT             (0U)
#define PCIE_PHY_CMN_REG19_TOL(x)                (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG19_TOL_SHIFT)) & PCIE_PHY_CMN_REG19_TOL_MASK)
#define PCIE_PHY_CMN_REG19_PD_CMN_MASK           (0x8U)
#define PCIE_PHY_CMN_REG19_PD_CMN_SHIFT          (3U)
#define PCIE_PHY_CMN_REG19_RTOL_MASK             (0xF0U)
#define PCIE_PHY_CMN_REG19_RTOL_SHIFT            (4U)
#define PCIE_PHY_CMN_REG19_RTOL(x)               (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG19_RTOL_SHIFT)) & PCIE_PHY_CMN_REG19_RTOL_MASK)

/*! @name REG1A -  */
#define PCIE_PHY_CMN_REG1A_CMNRST_MASK           (0xFFU)
#define PCIE_PHY_CMN_REG1A_CMNRST_SHIFT          (0U)
#define PCIE_PHY_CMN_REG1A_CMNRST(x)             (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_CMN_REG1A_CMNRST_SHIFT)) & PCIE_PHY_CMN_REG1A_CMNRST_MASK)


/*!
 * @}
 */ /* end of group PCIE_PHY_CMN_Register_Masks */


/* PCIE_PHY_CMN - Peripheral instance base addresses */
/** Peripheral PCIE_PHY_CMN base pointer */
#define PCIE_PHY_CMN_BASE_PTR                    ((PCIE_PHY_CMN_MemMapPtr)0x306D0000u)
/** Array initializer of PCIE_PHY_CMN peripheral base pointers */
#define PCIE_PHY_CMN_BASE_PTRS                   { PCIE_PHY_CMN_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- PCIE_PHY_CMN - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PCIE_PHY_CMN_Register_Accessor_Macros PCIE_PHY_CMN - Register accessor macros
 * @{
 */


/* PCIE_PHY_CMN - Register instance definitions */
/* PCIE_PHY_CMN */
#define PCIE_PHY_CMN_REG01                       PCIE_PHY_CMN_REG01_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG02                       PCIE_PHY_CMN_REG02_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG03                       PCIE_PHY_CMN_REG03_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG04                       PCIE_PHY_CMN_REG04_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG05                       PCIE_PHY_CMN_REG05_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG06                       PCIE_PHY_CMN_REG06_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG07                       PCIE_PHY_CMN_REG07_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG0B                       PCIE_PHY_CMN_REG0B_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG08                       PCIE_PHY_CMN_REG08_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG09                       PCIE_PHY_CMN_REG09_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG11                       PCIE_PHY_CMN_REG11_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG15                       PCIE_PHY_CMN_REG15_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG16                       PCIE_PHY_CMN_REG16_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG17                       PCIE_PHY_CMN_REG17_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG18                       PCIE_PHY_CMN_REG18_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG19                       PCIE_PHY_CMN_REG19_REG(PCIE_PHY_CMN_BASE_PTR)
#define PCIE_PHY_CMN_REG1A                       PCIE_PHY_CMN_REG1A_REG(PCIE_PHY_CMN_BASE_PTR)

/*!
 * @}
 */ /* end of group PCIE_PHY_CMN_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group PCIE_PHY_CMN_Peripheral */


/* ----------------------------------------------------------------------------
   -- PCIE_PHY_TRSV
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PCIE_PHY_TRSV_Peripheral PCIE_PHY_TRSV
 * @{
 */

/** PCIE_PHY_TRSV - Peripheral register structure */
typedef struct PCIE_PHY_TRSV_MemMap {
  uint8_t RESERVED_0[4];
  uint32_t REG21;                                  /**< , offset: 0x4 */
  uint32_t REG22;                                  /**< , offset: 0x8 */
  uint8_t RESERVED_1[10];
  uint32_t REG24;                                  /**< , offset: 0x16 */
  uint8_t RESERVED_2[18];
  uint32_t REG2B;                                  /**< , offset: 0x2C */
  uint8_t RESERVED_3[56];
  uint32_t REG3A;                                  /**< , offset: 0x68 */
  uint8_t RESERVED_4[12];
  uint32_t REG3E;                                  /**< , offset: 0x78 */
  uint8_t RESERVED_5[4];
  uint32_t REG25;                                  /**< , offset: 0x80 */
  uint32_t REG26;                                  /**< , offset: 0x84 */
  uint8_t RESERVED_6[14];
  uint32_t REG29;                                  /**< , offset: 0x96 */
  uint8_t RESERVED_7[10];
  uint32_t REG31;                                  /**< , offset: 0xA4 */
  uint8_t RESERVED_8[10];
  uint32_t REG33;                                  /**< , offset: 0xB2 */
  uint8_t RESERVED_9[14];
  uint32_t REG36;                                  /**< , offset: 0xC4 */
  uint32_t REG37;                                  /**< , offset: 0xC8 */
  uint8_t RESERVED_10[6];
  uint32_t REG38;                                  /**< , offset: 0xD2 */
  uint32_t REG39;                                  /**< , offset: 0xD6 */
  uint8_t RESERVED_11[6];
  uint32_t REG40;                                  /**< , offset: 0xE0 */
  uint8_t RESERVED_12[4];
  uint32_t REG42;                                  /**< , offset: 0xE8 */
} volatile *PCIE_PHY_TRSV_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- PCIE_PHY_TRSV - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PCIE_PHY_TRSV_Register_Accessor_Macros PCIE_PHY_TRSV - Register accessor macros
 * @{
 */


/* PCIE_PHY_TRSV - Register accessors */
#define PCIE_PHY_TRSV_REG21_REG(base)            ((base)->REG21)
#define PCIE_PHY_TRSV_REG22_REG(base)            ((base)->REG22)
#define PCIE_PHY_TRSV_REG24_REG(base)            ((base)->REG24)
#define PCIE_PHY_TRSV_REG2B_REG(base)            ((base)->REG2B)
#define PCIE_PHY_TRSV_REG3A_REG(base)            ((base)->REG3A)
#define PCIE_PHY_TRSV_REG3E_REG(base)            ((base)->REG3E)
#define PCIE_PHY_TRSV_REG25_REG(base)            ((base)->REG25)
#define PCIE_PHY_TRSV_REG26_REG(base)            ((base)->REG26)
#define PCIE_PHY_TRSV_REG29_REG(base)            ((base)->REG29)
#define PCIE_PHY_TRSV_REG31_REG(base)            ((base)->REG31)
#define PCIE_PHY_TRSV_REG33_REG(base)            ((base)->REG33)
#define PCIE_PHY_TRSV_REG36_REG(base)            ((base)->REG36)
#define PCIE_PHY_TRSV_REG37_REG(base)            ((base)->REG37)
#define PCIE_PHY_TRSV_REG38_REG(base)            ((base)->REG38)
#define PCIE_PHY_TRSV_REG39_REG(base)            ((base)->REG39)
#define PCIE_PHY_TRSV_REG40_REG(base)            ((base)->REG40)
#define PCIE_PHY_TRSV_REG42_REG(base)            ((base)->REG42)

/*!
 * @}
 */ /* end of group PCIE_PHY_TRSV_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- PCIE_PHY_TRSV Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PCIE_PHY_TRSV_Register_Masks PCIE_PHY_TRSV Register Masks
 * @{
 */

/*! @name REG21 -  */
#define PCIE_PHY_TRSV_REG21_EMP_LVL_MASK         (0x1FU)
#define PCIE_PHY_TRSV_REG21_EMP_LVL_SHIFT        (0U)
#define PCIE_PHY_TRSV_REG21_EMP_LVL(x)           (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG21_EMP_LVL_SHIFT)) & PCIE_PHY_TRSV_REG21_EMP_LVL_MASK)
#define PCIE_PHY_TRSV_REG21_DRVR_PDH_MASK        (0x80U)
#define PCIE_PHY_TRSV_REG21_DRVR_PDH_SHIFT       (7U)

/*! @name REG22 -  */
#define PCIE_PHY_TRSV_REG22_DRV_LVL_MASK         (0x3FU)
#define PCIE_PHY_TRSV_REG22_DRV_LVL_SHIFT        (0U)
#define PCIE_PHY_TRSV_REG22_DRV_LVL(x)           (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG22_DRV_LVL_SHIFT)) & PCIE_PHY_TRSV_REG22_DRV_LVL_MASK)

/*! @name REG24 -  */
#define PCIE_PHY_TRSV_REG24_RX_EQ_SEL_MASK       (0x8U)
#define PCIE_PHY_TRSV_REG24_RX_EQ_SEL_SHIFT      (3U)
#define PCIE_PHY_TRSV_REG24_RX_SS_MASK           (0x30U)
#define PCIE_PHY_TRSV_REG24_RX_SS_SHIFT          (4U)
#define PCIE_PHY_TRSV_REG24_RX_SS(x)             (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG24_RX_SS_SHIFT)) & PCIE_PHY_TRSV_REG24_RX_SS_MASK)
#define PCIE_PHY_TRSV_REG24_RX_EQS_MASK          (0x40U)
#define PCIE_PHY_TRSV_REG24_RX_EQS_SHIFT         (6U)
#define PCIE_PHY_TRSV_REG24_RX_SS_PD_MASK        (0x80U)
#define PCIE_PHY_TRSV_REG24_RX_SS_PD_SHIFT       (7U)

/*! @name REG2B -  */
#define PCIE_PHY_TRSV_REG2B_RXCDR_MASK           (0xFU)
#define PCIE_PHY_TRSV_REG2B_RXCDR_SHIFT          (0U)
#define PCIE_PHY_TRSV_REG2B_RXCDR(x)             (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG2B_RXCDR_SHIFT)) & PCIE_PHY_TRSV_REG2B_RXCDR_MASK)

/*! @name REG3A -  */
#define PCIE_PHY_TRSV_REG3A_TDIMODE_MASK         (0x1U)
#define PCIE_PHY_TRSV_REG3A_TDIMODE_SHIFT        (0U)
#define PCIE_PHY_TRSV_REG3A_RDIMODE_MASK         (0x2U)
#define PCIE_PHY_TRSV_REG3A_RDIMODE_SHIFT        (1U)
#define PCIE_PHY_TRSV_REG3A_COMDET_EN_MASK       (0x8U)
#define PCIE_PHY_TRSV_REG3A_COMDET_EN_SHIFT      (3U)

/*! @name REG3E -  */
#define PCIE_PHY_TRSV_REG3E_DET_CNT_MASK         (0xFU)
#define PCIE_PHY_TRSV_REG3E_DET_CNT_SHIFT        (0U)
#define PCIE_PHY_TRSV_REG3E_DET_CNT(x)           (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG3E_DET_CNT_SHIFT)) & PCIE_PHY_TRSV_REG3E_DET_CNT_MASK)

/*! @name REG25 -  */
#define PCIE_PHY_TRSV_REG25_RXEQS_MASK           (0x7U)
#define PCIE_PHY_TRSV_REG25_RXEQS_SHIFT          (0U)
#define PCIE_PHY_TRSV_REG25_RXEQS(x)             (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG25_RXEQS_SHIFT)) & PCIE_PHY_TRSV_REG25_RXEQS_MASK)
#define PCIE_PHY_TRSV_REG25_RXEQ_MASK            (0xF0U)
#define PCIE_PHY_TRSV_REG25_RXEQ_SHIFT           (4U)
#define PCIE_PHY_TRSV_REG25_RXEQ(x)              (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG25_RXEQ_SHIFT)) & PCIE_PHY_TRSV_REG25_RXEQ_MASK)

/*! @name REG26 -  */
#define PCIE_PHY_TRSV_REG26_SQTH_MASK            (0x70U)
#define PCIE_PHY_TRSV_REG26_SQTH_SHIFT           (4U)
#define PCIE_PHY_TRSV_REG26_SQTH(x)              (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG26_SQTH_SHIFT)) & PCIE_PHY_TRSV_REG26_SQTH_MASK)

/*! @name REG29 -  */
#define PCIE_PHY_TRSV_REG29_BIAS_MASK            (0xFFU)
#define PCIE_PHY_TRSV_REG29_BIAS_SHIFT           (0U)
#define PCIE_PHY_TRSV_REG29_BIAS(x)              (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG29_BIAS_SHIFT)) & PCIE_PHY_TRSV_REG29_BIAS_MASK)

/*! @name REG31 -  */
#define PCIE_PHY_TRSV_REG31_PD_TSV_MASK          (0x80U)
#define PCIE_PHY_TRSV_REG31_PD_TSV_SHIFT         (7U)

/*! @name REG36 -  */
#define PCIE_PHY_TRSV_REG36_SR_LVL_MASK          (0x7U)
#define PCIE_PHY_TRSV_REG36_SR_LVL_SHIFT         (0U)
#define PCIE_PHY_TRSV_REG36_SR_LVL(x)            (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG36_SR_LVL_SHIFT)) & PCIE_PHY_TRSV_REG36_SR_LVL_MASK)
#define PCIE_PHY_TRSV_REG36_TX_SWING_MASK        (0x8U)
#define PCIE_PHY_TRSV_REG36_TX_SWING_SHIFT       (3U)
#define PCIE_PHY_TRSV_REG36_DRVR_CNT_MASK        (0x30U)
#define PCIE_PHY_TRSV_REG36_DRVR_CNT_SHIFT       (4U)
#define PCIE_PHY_TRSV_REG36_DRVR_CNT(x)          (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG36_DRVR_CNT_SHIFT)) & PCIE_PHY_TRSV_REG36_DRVR_CNT_MASK)

/*! @name REG38 -  */
#define PCIE_PHY_TRSV_REG38_ADD_ALIGN_MASK       (0x8U)
#define PCIE_PHY_TRSV_REG38_ADD_ALIGN_SHIFT      (3U)
#define PCIE_PHY_TRSV_REG38_RX_INV_MASK          (0x10U)
#define PCIE_PHY_TRSV_REG38_RX_INV_SHIFT         (4U)
#define PCIE_PHY_TRSV_REG38_TX_INV_MASK          (0x20U)
#define PCIE_PHY_TRSV_REG38_TX_INV_SHIFT         (5U)

/*! @name REG39 -  */
#define PCIE_PHY_TRSV_REG39_TD_ORD_MASK          (0x30U)
#define PCIE_PHY_TRSV_REG39_TD_ORD_SHIFT         (4U)
#define PCIE_PHY_TRSV_REG39_TD_ORD(x)            (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG39_TD_ORD_SHIFT)) & PCIE_PHY_TRSV_REG39_TD_ORD_MASK)
#define PCIE_PHY_TRSV_REG39_RD_ORD_MASK          (0xC0U)
#define PCIE_PHY_TRSV_REG39_RD_ORD_SHIFT         (6U)
#define PCIE_PHY_TRSV_REG39_RD_ORD(x)            (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG39_RD_ORD_SHIFT)) & PCIE_PHY_TRSV_REG39_RD_ORD_MASK)

/*! @name REG40 -  */
#define PCIE_PHY_TRSV_REG40_PD_TRAS_MASK         (0x7CU)
#define PCIE_PHY_TRSV_REG40_PD_TRAS_SHIFT        (2U)
#define PCIE_PHY_TRSV_REG40_PD_TRAS(x)           (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG40_PD_TRAS_SHIFT)) & PCIE_PHY_TRSV_REG40_PD_TRAS_MASK)
#define PCIE_PHY_TRSV_REG40_PHY_TRSV_EN_MASK     (0x80U)
#define PCIE_PHY_TRSV_REG40_PHY_TRSV_EN_SHIFT    (7U)

/*! @name REG42 -  */
#define PCIE_PHY_TRSV_REG42_TRSVRST_MASK         (0xFFU)
#define PCIE_PHY_TRSV_REG42_TRSVRST_SHIFT        (0U)
#define PCIE_PHY_TRSV_REG42_TRSVRST(x)           (((uint32_t)(((uint32_t)(x)) << PCIE_PHY_TRSV_REG42_TRSVRST_SHIFT)) & PCIE_PHY_TRSV_REG42_TRSVRST_MASK)


/*!
 * @}
 */ /* end of group PCIE_PHY_TRSV_Register_Masks */


/* PCIE_PHY_TRSV - Peripheral instance base addresses */
/** Peripheral PCIE_PHY_TRSV base pointer */
#define PCIE_PHY_TRSV_BASE_PTR                   ((PCIE_PHY_TRSV_MemMapPtr)0x306D0080u)
/** Array initializer of PCIE_PHY_TRSV peripheral base pointers */
#define PCIE_PHY_TRSV_BASE_PTRS                  { PCIE_PHY_TRSV_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- PCIE_PHY_TRSV - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PCIE_PHY_TRSV_Register_Accessor_Macros PCIE_PHY_TRSV - Register accessor macros
 * @{
 */


/* PCIE_PHY_TRSV - Register instance definitions */
/* PCIE_PHY_TRSV */
#define PCIE_PHY_TRSV_REG21                      PCIE_PHY_TRSV_REG21_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG22                      PCIE_PHY_TRSV_REG22_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG24                      PCIE_PHY_TRSV_REG24_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG2B                      PCIE_PHY_TRSV_REG2B_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG3A                      PCIE_PHY_TRSV_REG3A_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG3E                      PCIE_PHY_TRSV_REG3E_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG25                      PCIE_PHY_TRSV_REG25_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG26                      PCIE_PHY_TRSV_REG26_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG29                      PCIE_PHY_TRSV_REG29_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG31                      PCIE_PHY_TRSV_REG31_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG33                      PCIE_PHY_TRSV_REG33_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG36                      PCIE_PHY_TRSV_REG36_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG37                      PCIE_PHY_TRSV_REG37_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG38                      PCIE_PHY_TRSV_REG38_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG39                      PCIE_PHY_TRSV_REG39_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG40                      PCIE_PHY_TRSV_REG40_REG(PCIE_PHY_TRSV_BASE_PTR)
#define PCIE_PHY_TRSV_REG42                      PCIE_PHY_TRSV_REG42_REG(PCIE_PHY_TRSV_BASE_PTR)

/*!
 * @}
 */ /* end of group PCIE_PHY_TRSV_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group PCIE_PHY_TRSV_Peripheral */


/* ----------------------------------------------------------------------------
   -- PMU
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PMU_Peripheral PMU
 * @{
 */

/** PMU - Peripheral register structure */
typedef struct PMU_MemMap {
  uint32_t REG_1P0A;                               /**< Anadig 1.0V A Regulator Control Register, offset: 0x0 */
  uint32_t REG_1P0A_SET;                           /**< Anadig 1.0V A Regulator Control Register, offset: 0x4 */
  uint32_t REG_1P0A_CLR;                           /**< Anadig 1.0V A Regulator Control Register, offset: 0x8 */
  uint32_t REG_1P0A_TOG;                           /**< Anadig 1.0V A Regulator Control Register, offset: 0xC */
  uint32_t REG_1P0D;                               /**< Anadig 1.0V D Regulator Control Register, offset: 0x10 */
  uint32_t REG_1P0D_SET;                           /**< Anadig 1.0V D Regulator Control Register, offset: 0x14 */
  uint32_t REG_1P0D_CLR;                           /**< Anadig 1.0V D Regulator Control Register, offset: 0x18 */
  uint32_t REG_1P0D_TOG;                           /**< Anadig 1.0V D Regulator Control Register, offset: 0x1C */
  uint32_t REG_HSIC_1P2;                           /**< Anadig 1.2V HSIC Regulator Control Register, offset: 0x20 */
  uint32_t REG_HSIC_1P2_SET;                       /**< Anadig 1.2V HSIC Regulator Control Register, offset: 0x24 */
  uint32_t REG_HSIC_1P2_CLR;                       /**< Anadig 1.2V HSIC Regulator Control Register, offset: 0x28 */
  uint32_t REG_HSIC_1P2_TOG;                       /**< Anadig 1.2V HSIC Regulator Control Register, offset: 0x2C */
  uint32_t REG_LPSR_1P0;                           /**< Anadig 1.0V Low Power State Retention Regulator Control Register, offset: 0x30 */
  uint32_t REG_LPSR_1P0_SET;                       /**< Anadig 1.0V Low Power State Retention Regulator Control Register, offset: 0x34 */
  uint32_t REG_LPSR_1P0_CLR;                       /**< Anadig 1.0V Low Power State Retention Regulator Control Register, offset: 0x38 */
  uint32_t REG_LPSR_1P0_TOG;                       /**< Anadig 1.0V Low Power State Retention Regulator Control Register, offset: 0x3C */
  uint8_t RESERVED_0[48];
  uint32_t REF;                                    /**< Anadig Reference Analog Control and Status Register, offset: 0x70 */
  uint32_t REF_SET;                                /**< Anadig Reference Analog Control and Status Register, offset: 0x74 */
  uint32_t REF_CLR;                                /**< Anadig Reference Analog Control and Status Register, offset: 0x78 */
  uint32_t REF_TOG;                                /**< Anadig Reference Analog Control and Status Register, offset: 0x7C */
  uint8_t RESERVED_1[176];
  uint32_t LOWPWR_CTRL;                            /**< Anadig Low Power Control Register, offset: 0x130 */
  uint32_t LOWPWR_CTRL_SET;                        /**< Anadig Low Power Control Register, offset: 0x134 */
  uint32_t LOWPWR_CTRL_CLR;                        /**< Anadig Low Power Control Register, offset: 0x138 */
  uint32_t LOWPWR_CTRL_TOG;                        /**< Anadig Low Power Control Register, offset: 0x13C */
} volatile *PMU_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- PMU - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PMU_Register_Accessor_Macros PMU - Register accessor macros
 * @{
 */


/* PMU - Register accessors */
#define PMU_REG_1P0A_REG(base)                   ((base)->REG_1P0A)
#define PMU_REG_1P0A_SET_REG(base)               ((base)->REG_1P0A_SET)
#define PMU_REG_1P0A_CLR_REG(base)               ((base)->REG_1P0A_CLR)
#define PMU_REG_1P0A_TOG_REG(base)               ((base)->REG_1P0A_TOG)
#define PMU_REG_1P0D_REG(base)                   ((base)->REG_1P0D)
#define PMU_REG_1P0D_SET_REG(base)               ((base)->REG_1P0D_SET)
#define PMU_REG_1P0D_CLR_REG(base)               ((base)->REG_1P0D_CLR)
#define PMU_REG_1P0D_TOG_REG(base)               ((base)->REG_1P0D_TOG)
#define PMU_REG_HSIC_1P2_REG(base)               ((base)->REG_HSIC_1P2)
#define PMU_REG_HSIC_1P2_SET_REG(base)           ((base)->REG_HSIC_1P2_SET)
#define PMU_REG_HSIC_1P2_CLR_REG(base)           ((base)->REG_HSIC_1P2_CLR)
#define PMU_REG_HSIC_1P2_TOG_REG(base)           ((base)->REG_HSIC_1P2_TOG)
#define PMU_REG_LPSR_1P0_REG(base)               ((base)->REG_LPSR_1P0)
#define PMU_REG_LPSR_1P0_SET_REG(base)           ((base)->REG_LPSR_1P0_SET)
#define PMU_REG_LPSR_1P0_CLR_REG(base)           ((base)->REG_LPSR_1P0_CLR)
#define PMU_REG_LPSR_1P0_TOG_REG(base)           ((base)->REG_LPSR_1P0_TOG)
#define PMU_REF_REG(base)                        ((base)->REF)
#define PMU_REF_SET_REG(base)                    ((base)->REF_SET)
#define PMU_REF_CLR_REG(base)                    ((base)->REF_CLR)
#define PMU_REF_TOG_REG(base)                    ((base)->REF_TOG)
#define PMU_LOWPWR_CTRL_REG(base)                ((base)->LOWPWR_CTRL)
#define PMU_LOWPWR_CTRL_SET_REG(base)            ((base)->LOWPWR_CTRL_SET)
#define PMU_LOWPWR_CTRL_CLR_REG(base)            ((base)->LOWPWR_CTRL_CLR)
#define PMU_LOWPWR_CTRL_TOG_REG(base)            ((base)->LOWPWR_CTRL_TOG)

/*!
 * @}
 */ /* end of group PMU_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- PMU Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PMU_Register_Masks PMU Register Masks
 * @{
 */

/*! @name REG_1P0A - Anadig 1.0V A Regulator Control Register */
#define PMU_REG_1P0A_ENABLE_LINREG_MASK          (0x1U)
#define PMU_REG_1P0A_ENABLE_LINREG_SHIFT         (0U)
#define PMU_REG_1P0A_ENABLE_BO_MASK              (0x2U)
#define PMU_REG_1P0A_ENABLE_BO_SHIFT             (1U)
#define PMU_REG_1P0A_ENABLE_ILIMIT_MASK          (0x4U)
#define PMU_REG_1P0A_ENABLE_ILIMIT_SHIFT         (2U)
#define PMU_REG_1P0A_ENABLE_PULLDOWN_MASK        (0x8U)
#define PMU_REG_1P0A_ENABLE_PULLDOWN_SHIFT       (3U)
#define PMU_REG_1P0A_BO_OFFSET_MASK              (0x70U)
#define PMU_REG_1P0A_BO_OFFSET_SHIFT             (4U)
#define PMU_REG_1P0A_BO_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_BO_OFFSET_SHIFT)) & PMU_REG_1P0A_BO_OFFSET_MASK)
#define PMU_REG_1P0A_ENABLE_PWRUPLOAD_MASK       (0x80U)
#define PMU_REG_1P0A_ENABLE_PWRUPLOAD_SHIFT      (7U)
#define PMU_REG_1P0A_OUTPUT_TRG_MASK             (0x1F00U)
#define PMU_REG_1P0A_OUTPUT_TRG_SHIFT            (8U)
#define PMU_REG_1P0A_OUTPUT_TRG(x)               (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_OUTPUT_TRG_SHIFT)) & PMU_REG_1P0A_OUTPUT_TRG_MASK)
#define PMU_REG_1P0A_RSVD0_MASK                  (0xE000U)
#define PMU_REG_1P0A_RSVD0_SHIFT                 (13U)
#define PMU_REG_1P0A_RSVD0(x)                    (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_RSVD0_SHIFT)) & PMU_REG_1P0A_RSVD0_MASK)
#define PMU_REG_1P0A_BO_MASK                     (0x10000U)
#define PMU_REG_1P0A_BO_SHIFT                    (16U)
#define PMU_REG_1P0A_OK_MASK                     (0x20000U)
#define PMU_REG_1P0A_OK_SHIFT                    (17U)
#define PMU_REG_1P0A_ENABLE_WEAK_LINREG_MASK     (0x40000U)
#define PMU_REG_1P0A_ENABLE_WEAK_LINREG_SHIFT    (18U)
#define PMU_REG_1P0A_SELREF_WEAK_LINREG_MASK     (0x80000U)
#define PMU_REG_1P0A_SELREF_WEAK_LINREG_SHIFT    (19U)
#define PMU_REG_1P0A_REG_TEST_MASK               (0xF00000U)
#define PMU_REG_1P0A_REG_TEST_SHIFT              (20U)
#define PMU_REG_1P0A_REG_TEST(x)                 (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_REG_TEST_SHIFT)) & PMU_REG_1P0A_REG_TEST_MASK)
#define PMU_REG_1P0A_RSVD1_MASK                  (0xFF000000U)
#define PMU_REG_1P0A_RSVD1_SHIFT                 (24U)
#define PMU_REG_1P0A_RSVD1(x)                    (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_RSVD1_SHIFT)) & PMU_REG_1P0A_RSVD1_MASK)

/*! @name REG_1P0A_SET - Anadig 1.0V A Regulator Control Register */
#define PMU_REG_1P0A_SET_ENABLE_LINREG_MASK      (0x1U)
#define PMU_REG_1P0A_SET_ENABLE_LINREG_SHIFT     (0U)
#define PMU_REG_1P0A_SET_ENABLE_BO_MASK          (0x2U)
#define PMU_REG_1P0A_SET_ENABLE_BO_SHIFT         (1U)
#define PMU_REG_1P0A_SET_ENABLE_ILIMIT_MASK      (0x4U)
#define PMU_REG_1P0A_SET_ENABLE_ILIMIT_SHIFT     (2U)
#define PMU_REG_1P0A_SET_ENABLE_PULLDOWN_MASK    (0x8U)
#define PMU_REG_1P0A_SET_ENABLE_PULLDOWN_SHIFT   (3U)
#define PMU_REG_1P0A_SET_BO_OFFSET_MASK          (0x70U)
#define PMU_REG_1P0A_SET_BO_OFFSET_SHIFT         (4U)
#define PMU_REG_1P0A_SET_BO_OFFSET(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_SET_BO_OFFSET_SHIFT)) & PMU_REG_1P0A_SET_BO_OFFSET_MASK)
#define PMU_REG_1P0A_SET_ENABLE_PWRUPLOAD_MASK   (0x80U)
#define PMU_REG_1P0A_SET_ENABLE_PWRUPLOAD_SHIFT  (7U)
#define PMU_REG_1P0A_SET_OUTPUT_TRG_MASK         (0x1F00U)
#define PMU_REG_1P0A_SET_OUTPUT_TRG_SHIFT        (8U)
#define PMU_REG_1P0A_SET_OUTPUT_TRG(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_SET_OUTPUT_TRG_SHIFT)) & PMU_REG_1P0A_SET_OUTPUT_TRG_MASK)
#define PMU_REG_1P0A_SET_RSVD0_MASK              (0xE000U)
#define PMU_REG_1P0A_SET_RSVD0_SHIFT             (13U)
#define PMU_REG_1P0A_SET_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_SET_RSVD0_SHIFT)) & PMU_REG_1P0A_SET_RSVD0_MASK)
#define PMU_REG_1P0A_SET_BO_MASK                 (0x10000U)
#define PMU_REG_1P0A_SET_BO_SHIFT                (16U)
#define PMU_REG_1P0A_SET_OK_MASK                 (0x20000U)
#define PMU_REG_1P0A_SET_OK_SHIFT                (17U)
#define PMU_REG_1P0A_SET_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_1P0A_SET_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_1P0A_SET_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_1P0A_SET_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_1P0A_SET_REG_TEST_MASK           (0xF00000U)
#define PMU_REG_1P0A_SET_REG_TEST_SHIFT          (20U)
#define PMU_REG_1P0A_SET_REG_TEST(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_SET_REG_TEST_SHIFT)) & PMU_REG_1P0A_SET_REG_TEST_MASK)
#define PMU_REG_1P0A_SET_RSVD1_MASK              (0xFF000000U)
#define PMU_REG_1P0A_SET_RSVD1_SHIFT             (24U)
#define PMU_REG_1P0A_SET_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_SET_RSVD1_SHIFT)) & PMU_REG_1P0A_SET_RSVD1_MASK)

/*! @name REG_1P0A_CLR - Anadig 1.0V A Regulator Control Register */
#define PMU_REG_1P0A_CLR_ENABLE_LINREG_MASK      (0x1U)
#define PMU_REG_1P0A_CLR_ENABLE_LINREG_SHIFT     (0U)
#define PMU_REG_1P0A_CLR_ENABLE_BO_MASK          (0x2U)
#define PMU_REG_1P0A_CLR_ENABLE_BO_SHIFT         (1U)
#define PMU_REG_1P0A_CLR_ENABLE_ILIMIT_MASK      (0x4U)
#define PMU_REG_1P0A_CLR_ENABLE_ILIMIT_SHIFT     (2U)
#define PMU_REG_1P0A_CLR_ENABLE_PULLDOWN_MASK    (0x8U)
#define PMU_REG_1P0A_CLR_ENABLE_PULLDOWN_SHIFT   (3U)
#define PMU_REG_1P0A_CLR_BO_OFFSET_MASK          (0x70U)
#define PMU_REG_1P0A_CLR_BO_OFFSET_SHIFT         (4U)
#define PMU_REG_1P0A_CLR_BO_OFFSET(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_CLR_BO_OFFSET_SHIFT)) & PMU_REG_1P0A_CLR_BO_OFFSET_MASK)
#define PMU_REG_1P0A_CLR_ENABLE_PWRUPLOAD_MASK   (0x80U)
#define PMU_REG_1P0A_CLR_ENABLE_PWRUPLOAD_SHIFT  (7U)
#define PMU_REG_1P0A_CLR_OUTPUT_TRG_MASK         (0x1F00U)
#define PMU_REG_1P0A_CLR_OUTPUT_TRG_SHIFT        (8U)
#define PMU_REG_1P0A_CLR_OUTPUT_TRG(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_CLR_OUTPUT_TRG_SHIFT)) & PMU_REG_1P0A_CLR_OUTPUT_TRG_MASK)
#define PMU_REG_1P0A_CLR_RSVD0_MASK              (0xE000U)
#define PMU_REG_1P0A_CLR_RSVD0_SHIFT             (13U)
#define PMU_REG_1P0A_CLR_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_CLR_RSVD0_SHIFT)) & PMU_REG_1P0A_CLR_RSVD0_MASK)
#define PMU_REG_1P0A_CLR_BO_MASK                 (0x10000U)
#define PMU_REG_1P0A_CLR_BO_SHIFT                (16U)
#define PMU_REG_1P0A_CLR_OK_MASK                 (0x20000U)
#define PMU_REG_1P0A_CLR_OK_SHIFT                (17U)
#define PMU_REG_1P0A_CLR_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_1P0A_CLR_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_1P0A_CLR_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_1P0A_CLR_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_1P0A_CLR_REG_TEST_MASK           (0xF00000U)
#define PMU_REG_1P0A_CLR_REG_TEST_SHIFT          (20U)
#define PMU_REG_1P0A_CLR_REG_TEST(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_CLR_REG_TEST_SHIFT)) & PMU_REG_1P0A_CLR_REG_TEST_MASK)
#define PMU_REG_1P0A_CLR_RSVD1_MASK              (0xFF000000U)
#define PMU_REG_1P0A_CLR_RSVD1_SHIFT             (24U)
#define PMU_REG_1P0A_CLR_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_CLR_RSVD1_SHIFT)) & PMU_REG_1P0A_CLR_RSVD1_MASK)

/*! @name REG_1P0A_TOG - Anadig 1.0V A Regulator Control Register */
#define PMU_REG_1P0A_TOG_ENABLE_LINREG_MASK      (0x1U)
#define PMU_REG_1P0A_TOG_ENABLE_LINREG_SHIFT     (0U)
#define PMU_REG_1P0A_TOG_ENABLE_BO_MASK          (0x2U)
#define PMU_REG_1P0A_TOG_ENABLE_BO_SHIFT         (1U)
#define PMU_REG_1P0A_TOG_ENABLE_ILIMIT_MASK      (0x4U)
#define PMU_REG_1P0A_TOG_ENABLE_ILIMIT_SHIFT     (2U)
#define PMU_REG_1P0A_TOG_ENABLE_PULLDOWN_MASK    (0x8U)
#define PMU_REG_1P0A_TOG_ENABLE_PULLDOWN_SHIFT   (3U)
#define PMU_REG_1P0A_TOG_BO_OFFSET_MASK          (0x70U)
#define PMU_REG_1P0A_TOG_BO_OFFSET_SHIFT         (4U)
#define PMU_REG_1P0A_TOG_BO_OFFSET(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_TOG_BO_OFFSET_SHIFT)) & PMU_REG_1P0A_TOG_BO_OFFSET_MASK)
#define PMU_REG_1P0A_TOG_ENABLE_PWRUPLOAD_MASK   (0x80U)
#define PMU_REG_1P0A_TOG_ENABLE_PWRUPLOAD_SHIFT  (7U)
#define PMU_REG_1P0A_TOG_OUTPUT_TRG_MASK         (0x1F00U)
#define PMU_REG_1P0A_TOG_OUTPUT_TRG_SHIFT        (8U)
#define PMU_REG_1P0A_TOG_OUTPUT_TRG(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_TOG_OUTPUT_TRG_SHIFT)) & PMU_REG_1P0A_TOG_OUTPUT_TRG_MASK)
#define PMU_REG_1P0A_TOG_RSVD0_MASK              (0xE000U)
#define PMU_REG_1P0A_TOG_RSVD0_SHIFT             (13U)
#define PMU_REG_1P0A_TOG_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_TOG_RSVD0_SHIFT)) & PMU_REG_1P0A_TOG_RSVD0_MASK)
#define PMU_REG_1P0A_TOG_BO_MASK                 (0x10000U)
#define PMU_REG_1P0A_TOG_BO_SHIFT                (16U)
#define PMU_REG_1P0A_TOG_OK_MASK                 (0x20000U)
#define PMU_REG_1P0A_TOG_OK_SHIFT                (17U)
#define PMU_REG_1P0A_TOG_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_1P0A_TOG_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_1P0A_TOG_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_1P0A_TOG_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_1P0A_TOG_REG_TEST_MASK           (0xF00000U)
#define PMU_REG_1P0A_TOG_REG_TEST_SHIFT          (20U)
#define PMU_REG_1P0A_TOG_REG_TEST(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_TOG_REG_TEST_SHIFT)) & PMU_REG_1P0A_TOG_REG_TEST_MASK)
#define PMU_REG_1P0A_TOG_RSVD1_MASK              (0xFF000000U)
#define PMU_REG_1P0A_TOG_RSVD1_SHIFT             (24U)
#define PMU_REG_1P0A_TOG_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0A_TOG_RSVD1_SHIFT)) & PMU_REG_1P0A_TOG_RSVD1_MASK)

/*! @name REG_1P0D - Anadig 1.0V D Regulator Control Register */
#define PMU_REG_1P0D_ENABLE_LINREG_MASK          (0x1U)
#define PMU_REG_1P0D_ENABLE_LINREG_SHIFT         (0U)
#define PMU_REG_1P0D_ENABLE_BO_MASK              (0x2U)
#define PMU_REG_1P0D_ENABLE_BO_SHIFT             (1U)
#define PMU_REG_1P0D_ENABLE_ILIMIT_MASK          (0x4U)
#define PMU_REG_1P0D_ENABLE_ILIMIT_SHIFT         (2U)
#define PMU_REG_1P0D_ENABLE_PULLDOWN_MASK        (0x8U)
#define PMU_REG_1P0D_ENABLE_PULLDOWN_SHIFT       (3U)
#define PMU_REG_1P0D_BO_OFFSET_MASK              (0x70U)
#define PMU_REG_1P0D_BO_OFFSET_SHIFT             (4U)
#define PMU_REG_1P0D_BO_OFFSET(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_BO_OFFSET_SHIFT)) & PMU_REG_1P0D_BO_OFFSET_MASK)
#define PMU_REG_1P0D_ENABLE_PWRUPLOAD_MASK       (0x80U)
#define PMU_REG_1P0D_ENABLE_PWRUPLOAD_SHIFT      (7U)
#define PMU_REG_1P0D_OUTPUT_TRG_MASK             (0x1F00U)
#define PMU_REG_1P0D_OUTPUT_TRG_SHIFT            (8U)
#define PMU_REG_1P0D_OUTPUT_TRG(x)               (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_OUTPUT_TRG_SHIFT)) & PMU_REG_1P0D_OUTPUT_TRG_MASK)
#define PMU_REG_1P0D_RSVD0_MASK                  (0xE000U)
#define PMU_REG_1P0D_RSVD0_SHIFT                 (13U)
#define PMU_REG_1P0D_RSVD0(x)                    (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_RSVD0_SHIFT)) & PMU_REG_1P0D_RSVD0_MASK)
#define PMU_REG_1P0D_BO_MASK                     (0x10000U)
#define PMU_REG_1P0D_BO_SHIFT                    (16U)
#define PMU_REG_1P0D_OK_MASK                     (0x20000U)
#define PMU_REG_1P0D_OK_SHIFT                    (17U)
#define PMU_REG_1P0D_ENABLE_WEAK_LINREG_MASK     (0x40000U)
#define PMU_REG_1P0D_ENABLE_WEAK_LINREG_SHIFT    (18U)
#define PMU_REG_1P0D_SELREF_WEAK_LINREG_MASK     (0x80000U)
#define PMU_REG_1P0D_SELREF_WEAK_LINREG_SHIFT    (19U)
#define PMU_REG_1P0D_REG_TEST_MASK               (0xF00000U)
#define PMU_REG_1P0D_REG_TEST_SHIFT              (20U)
#define PMU_REG_1P0D_REG_TEST(x)                 (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_REG_TEST_SHIFT)) & PMU_REG_1P0D_REG_TEST_MASK)
#define PMU_REG_1P0D_RSVD1_MASK                  (0x7F000000U)
#define PMU_REG_1P0D_RSVD1_SHIFT                 (24U)
#define PMU_REG_1P0D_RSVD1(x)                    (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_RSVD1_SHIFT)) & PMU_REG_1P0D_RSVD1_MASK)
#define PMU_REG_1P0D_OVERRIDE_MASK               (0x80000000U)
#define PMU_REG_1P0D_OVERRIDE_SHIFT              (31U)

/*! @name REG_1P0D_SET - Anadig 1.0V D Regulator Control Register */
#define PMU_REG_1P0D_SET_ENABLE_LINREG_MASK      (0x1U)
#define PMU_REG_1P0D_SET_ENABLE_LINREG_SHIFT     (0U)
#define PMU_REG_1P0D_SET_ENABLE_BO_MASK          (0x2U)
#define PMU_REG_1P0D_SET_ENABLE_BO_SHIFT         (1U)
#define PMU_REG_1P0D_SET_ENABLE_ILIMIT_MASK      (0x4U)
#define PMU_REG_1P0D_SET_ENABLE_ILIMIT_SHIFT     (2U)
#define PMU_REG_1P0D_SET_ENABLE_PULLDOWN_MASK    (0x8U)
#define PMU_REG_1P0D_SET_ENABLE_PULLDOWN_SHIFT   (3U)
#define PMU_REG_1P0D_SET_BO_OFFSET_MASK          (0x70U)
#define PMU_REG_1P0D_SET_BO_OFFSET_SHIFT         (4U)
#define PMU_REG_1P0D_SET_BO_OFFSET(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_SET_BO_OFFSET_SHIFT)) & PMU_REG_1P0D_SET_BO_OFFSET_MASK)
#define PMU_REG_1P0D_SET_ENABLE_PWRUPLOAD_MASK   (0x80U)
#define PMU_REG_1P0D_SET_ENABLE_PWRUPLOAD_SHIFT  (7U)
#define PMU_REG_1P0D_SET_OUTPUT_TRG_MASK         (0x1F00U)
#define PMU_REG_1P0D_SET_OUTPUT_TRG_SHIFT        (8U)
#define PMU_REG_1P0D_SET_OUTPUT_TRG(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_SET_OUTPUT_TRG_SHIFT)) & PMU_REG_1P0D_SET_OUTPUT_TRG_MASK)
#define PMU_REG_1P0D_SET_RSVD0_MASK              (0xE000U)
#define PMU_REG_1P0D_SET_RSVD0_SHIFT             (13U)
#define PMU_REG_1P0D_SET_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_SET_RSVD0_SHIFT)) & PMU_REG_1P0D_SET_RSVD0_MASK)
#define PMU_REG_1P0D_SET_BO_MASK                 (0x10000U)
#define PMU_REG_1P0D_SET_BO_SHIFT                (16U)
#define PMU_REG_1P0D_SET_OK_MASK                 (0x20000U)
#define PMU_REG_1P0D_SET_OK_SHIFT                (17U)
#define PMU_REG_1P0D_SET_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_1P0D_SET_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_1P0D_SET_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_1P0D_SET_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_1P0D_SET_REG_TEST_MASK           (0xF00000U)
#define PMU_REG_1P0D_SET_REG_TEST_SHIFT          (20U)
#define PMU_REG_1P0D_SET_REG_TEST(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_SET_REG_TEST_SHIFT)) & PMU_REG_1P0D_SET_REG_TEST_MASK)
#define PMU_REG_1P0D_SET_RSVD1_MASK              (0x7F000000U)
#define PMU_REG_1P0D_SET_RSVD1_SHIFT             (24U)
#define PMU_REG_1P0D_SET_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_SET_RSVD1_SHIFT)) & PMU_REG_1P0D_SET_RSVD1_MASK)
#define PMU_REG_1P0D_SET_OVERRIDE_MASK           (0x80000000U)
#define PMU_REG_1P0D_SET_OVERRIDE_SHIFT          (31U)

/*! @name REG_1P0D_CLR - Anadig 1.0V D Regulator Control Register */
#define PMU_REG_1P0D_CLR_ENABLE_LINREG_MASK      (0x1U)
#define PMU_REG_1P0D_CLR_ENABLE_LINREG_SHIFT     (0U)
#define PMU_REG_1P0D_CLR_ENABLE_BO_MASK          (0x2U)
#define PMU_REG_1P0D_CLR_ENABLE_BO_SHIFT         (1U)
#define PMU_REG_1P0D_CLR_ENABLE_ILIMIT_MASK      (0x4U)
#define PMU_REG_1P0D_CLR_ENABLE_ILIMIT_SHIFT     (2U)
#define PMU_REG_1P0D_CLR_ENABLE_PULLDOWN_MASK    (0x8U)
#define PMU_REG_1P0D_CLR_ENABLE_PULLDOWN_SHIFT   (3U)
#define PMU_REG_1P0D_CLR_BO_OFFSET_MASK          (0x70U)
#define PMU_REG_1P0D_CLR_BO_OFFSET_SHIFT         (4U)
#define PMU_REG_1P0D_CLR_BO_OFFSET(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_CLR_BO_OFFSET_SHIFT)) & PMU_REG_1P0D_CLR_BO_OFFSET_MASK)
#define PMU_REG_1P0D_CLR_ENABLE_PWRUPLOAD_MASK   (0x80U)
#define PMU_REG_1P0D_CLR_ENABLE_PWRUPLOAD_SHIFT  (7U)
#define PMU_REG_1P0D_CLR_OUTPUT_TRG_MASK         (0x1F00U)
#define PMU_REG_1P0D_CLR_OUTPUT_TRG_SHIFT        (8U)
#define PMU_REG_1P0D_CLR_OUTPUT_TRG(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_CLR_OUTPUT_TRG_SHIFT)) & PMU_REG_1P0D_CLR_OUTPUT_TRG_MASK)
#define PMU_REG_1P0D_CLR_RSVD0_MASK              (0xE000U)
#define PMU_REG_1P0D_CLR_RSVD0_SHIFT             (13U)
#define PMU_REG_1P0D_CLR_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_CLR_RSVD0_SHIFT)) & PMU_REG_1P0D_CLR_RSVD0_MASK)
#define PMU_REG_1P0D_CLR_BO_MASK                 (0x10000U)
#define PMU_REG_1P0D_CLR_BO_SHIFT                (16U)
#define PMU_REG_1P0D_CLR_OK_MASK                 (0x20000U)
#define PMU_REG_1P0D_CLR_OK_SHIFT                (17U)
#define PMU_REG_1P0D_CLR_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_1P0D_CLR_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_1P0D_CLR_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_1P0D_CLR_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_1P0D_CLR_REG_TEST_MASK           (0xF00000U)
#define PMU_REG_1P0D_CLR_REG_TEST_SHIFT          (20U)
#define PMU_REG_1P0D_CLR_REG_TEST(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_CLR_REG_TEST_SHIFT)) & PMU_REG_1P0D_CLR_REG_TEST_MASK)
#define PMU_REG_1P0D_CLR_RSVD1_MASK              (0x7F000000U)
#define PMU_REG_1P0D_CLR_RSVD1_SHIFT             (24U)
#define PMU_REG_1P0D_CLR_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_CLR_RSVD1_SHIFT)) & PMU_REG_1P0D_CLR_RSVD1_MASK)
#define PMU_REG_1P0D_CLR_OVERRIDE_MASK           (0x80000000U)
#define PMU_REG_1P0D_CLR_OVERRIDE_SHIFT          (31U)

/*! @name REG_1P0D_TOG - Anadig 1.0V D Regulator Control Register */
#define PMU_REG_1P0D_TOG_ENABLE_LINREG_MASK      (0x1U)
#define PMU_REG_1P0D_TOG_ENABLE_LINREG_SHIFT     (0U)
#define PMU_REG_1P0D_TOG_ENABLE_BO_MASK          (0x2U)
#define PMU_REG_1P0D_TOG_ENABLE_BO_SHIFT         (1U)
#define PMU_REG_1P0D_TOG_ENABLE_ILIMIT_MASK      (0x4U)
#define PMU_REG_1P0D_TOG_ENABLE_ILIMIT_SHIFT     (2U)
#define PMU_REG_1P0D_TOG_ENABLE_PULLDOWN_MASK    (0x8U)
#define PMU_REG_1P0D_TOG_ENABLE_PULLDOWN_SHIFT   (3U)
#define PMU_REG_1P0D_TOG_BO_OFFSET_MASK          (0x70U)
#define PMU_REG_1P0D_TOG_BO_OFFSET_SHIFT         (4U)
#define PMU_REG_1P0D_TOG_BO_OFFSET(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_TOG_BO_OFFSET_SHIFT)) & PMU_REG_1P0D_TOG_BO_OFFSET_MASK)
#define PMU_REG_1P0D_TOG_ENABLE_PWRUPLOAD_MASK   (0x80U)
#define PMU_REG_1P0D_TOG_ENABLE_PWRUPLOAD_SHIFT  (7U)
#define PMU_REG_1P0D_TOG_OUTPUT_TRG_MASK         (0x1F00U)
#define PMU_REG_1P0D_TOG_OUTPUT_TRG_SHIFT        (8U)
#define PMU_REG_1P0D_TOG_OUTPUT_TRG(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_TOG_OUTPUT_TRG_SHIFT)) & PMU_REG_1P0D_TOG_OUTPUT_TRG_MASK)
#define PMU_REG_1P0D_TOG_RSVD0_MASK              (0xE000U)
#define PMU_REG_1P0D_TOG_RSVD0_SHIFT             (13U)
#define PMU_REG_1P0D_TOG_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_TOG_RSVD0_SHIFT)) & PMU_REG_1P0D_TOG_RSVD0_MASK)
#define PMU_REG_1P0D_TOG_BO_MASK                 (0x10000U)
#define PMU_REG_1P0D_TOG_BO_SHIFT                (16U)
#define PMU_REG_1P0D_TOG_OK_MASK                 (0x20000U)
#define PMU_REG_1P0D_TOG_OK_SHIFT                (17U)
#define PMU_REG_1P0D_TOG_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_1P0D_TOG_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_1P0D_TOG_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_1P0D_TOG_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_1P0D_TOG_REG_TEST_MASK           (0xF00000U)
#define PMU_REG_1P0D_TOG_REG_TEST_SHIFT          (20U)
#define PMU_REG_1P0D_TOG_REG_TEST(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_TOG_REG_TEST_SHIFT)) & PMU_REG_1P0D_TOG_REG_TEST_MASK)
#define PMU_REG_1P0D_TOG_RSVD1_MASK              (0x7F000000U)
#define PMU_REG_1P0D_TOG_RSVD1_SHIFT             (24U)
#define PMU_REG_1P0D_TOG_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_1P0D_TOG_RSVD1_SHIFT)) & PMU_REG_1P0D_TOG_RSVD1_MASK)
#define PMU_REG_1P0D_TOG_OVERRIDE_MASK           (0x80000000U)
#define PMU_REG_1P0D_TOG_OVERRIDE_SHIFT          (31U)

/*! @name REG_HSIC_1P2 - Anadig 1.2V HSIC Regulator Control Register */
#define PMU_REG_HSIC_1P2_ENABLE_LINREG_MASK      (0x1U)
#define PMU_REG_HSIC_1P2_ENABLE_LINREG_SHIFT     (0U)
#define PMU_REG_HSIC_1P2_ENABLE_BO_MASK          (0x2U)
#define PMU_REG_HSIC_1P2_ENABLE_BO_SHIFT         (1U)
#define PMU_REG_HSIC_1P2_ENABLE_ILIMIT_MASK      (0x4U)
#define PMU_REG_HSIC_1P2_ENABLE_ILIMIT_SHIFT     (2U)
#define PMU_REG_HSIC_1P2_ENABLE_PULLDOWN_MASK    (0x8U)
#define PMU_REG_HSIC_1P2_ENABLE_PULLDOWN_SHIFT   (3U)
#define PMU_REG_HSIC_1P2_BO_OFFSET_MASK          (0x70U)
#define PMU_REG_HSIC_1P2_BO_OFFSET_SHIFT         (4U)
#define PMU_REG_HSIC_1P2_BO_OFFSET(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_BO_OFFSET_SHIFT)) & PMU_REG_HSIC_1P2_BO_OFFSET_MASK)
#define PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD_MASK   (0x80U)
#define PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD_SHIFT  (7U)
#define PMU_REG_HSIC_1P2_OUTPUT_TRG_MASK         (0x1F00U)
#define PMU_REG_HSIC_1P2_OUTPUT_TRG_SHIFT        (8U)
#define PMU_REG_HSIC_1P2_OUTPUT_TRG(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_OUTPUT_TRG_SHIFT)) & PMU_REG_HSIC_1P2_OUTPUT_TRG_MASK)
#define PMU_REG_HSIC_1P2_RSVD0_MASK              (0xE000U)
#define PMU_REG_HSIC_1P2_RSVD0_SHIFT             (13U)
#define PMU_REG_HSIC_1P2_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_RSVD0_SHIFT)) & PMU_REG_HSIC_1P2_RSVD0_MASK)
#define PMU_REG_HSIC_1P2_BO_MASK                 (0x10000U)
#define PMU_REG_HSIC_1P2_BO_SHIFT                (16U)
#define PMU_REG_HSIC_1P2_OK_MASK                 (0x20000U)
#define PMU_REG_HSIC_1P2_OK_SHIFT                (17U)
#define PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_HSIC_1P2_REG_TEST_MASK           (0xF00000U)
#define PMU_REG_HSIC_1P2_REG_TEST_SHIFT          (20U)
#define PMU_REG_HSIC_1P2_REG_TEST(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_REG_TEST_SHIFT)) & PMU_REG_HSIC_1P2_REG_TEST_MASK)
#define PMU_REG_HSIC_1P2_RSVD1_MASK              (0x7F000000U)
#define PMU_REG_HSIC_1P2_RSVD1_SHIFT             (24U)
#define PMU_REG_HSIC_1P2_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_RSVD1_SHIFT)) & PMU_REG_HSIC_1P2_RSVD1_MASK)
#define PMU_REG_HSIC_1P2_OVERRIDE_MASK           (0x80000000U)
#define PMU_REG_HSIC_1P2_OVERRIDE_SHIFT          (31U)

/*! @name REG_HSIC_1P2_SET - Anadig 1.2V HSIC Regulator Control Register */
#define PMU_REG_HSIC_1P2_SET_ENABLE_LINREG_MASK  (0x1U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_LINREG_SHIFT (0U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_BO_MASK      (0x2U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_BO_SHIFT     (1U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_ILIMIT_MASK  (0x4U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_ILIMIT_SHIFT (2U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_PULLDOWN_MASK (0x8U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_PULLDOWN_SHIFT (3U)
#define PMU_REG_HSIC_1P2_SET_BO_OFFSET_MASK      (0x70U)
#define PMU_REG_HSIC_1P2_SET_BO_OFFSET_SHIFT     (4U)
#define PMU_REG_HSIC_1P2_SET_BO_OFFSET(x)        (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_SET_BO_OFFSET_SHIFT)) & PMU_REG_HSIC_1P2_SET_BO_OFFSET_MASK)
#define PMU_REG_HSIC_1P2_SET_ENABLE_PWRUPLOAD_MASK (0x80U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_PWRUPLOAD_SHIFT (7U)
#define PMU_REG_HSIC_1P2_SET_OUTPUT_TRG_MASK     (0x1F00U)
#define PMU_REG_HSIC_1P2_SET_OUTPUT_TRG_SHIFT    (8U)
#define PMU_REG_HSIC_1P2_SET_OUTPUT_TRG(x)       (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_SET_OUTPUT_TRG_SHIFT)) & PMU_REG_HSIC_1P2_SET_OUTPUT_TRG_MASK)
#define PMU_REG_HSIC_1P2_SET_RSVD0_MASK          (0xE000U)
#define PMU_REG_HSIC_1P2_SET_RSVD0_SHIFT         (13U)
#define PMU_REG_HSIC_1P2_SET_RSVD0(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_SET_RSVD0_SHIFT)) & PMU_REG_HSIC_1P2_SET_RSVD0_MASK)
#define PMU_REG_HSIC_1P2_SET_BO_MASK             (0x10000U)
#define PMU_REG_HSIC_1P2_SET_BO_SHIFT            (16U)
#define PMU_REG_HSIC_1P2_SET_OK_MASK             (0x20000U)
#define PMU_REG_HSIC_1P2_SET_OK_SHIFT            (17U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_HSIC_1P2_SET_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_HSIC_1P2_SET_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_HSIC_1P2_SET_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_HSIC_1P2_SET_REG_TEST_MASK       (0xF00000U)
#define PMU_REG_HSIC_1P2_SET_REG_TEST_SHIFT      (20U)
#define PMU_REG_HSIC_1P2_SET_REG_TEST(x)         (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_SET_REG_TEST_SHIFT)) & PMU_REG_HSIC_1P2_SET_REG_TEST_MASK)
#define PMU_REG_HSIC_1P2_SET_RSVD1_MASK          (0x7F000000U)
#define PMU_REG_HSIC_1P2_SET_RSVD1_SHIFT         (24U)
#define PMU_REG_HSIC_1P2_SET_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_SET_RSVD1_SHIFT)) & PMU_REG_HSIC_1P2_SET_RSVD1_MASK)
#define PMU_REG_HSIC_1P2_SET_OVERRIDE_MASK       (0x80000000U)
#define PMU_REG_HSIC_1P2_SET_OVERRIDE_SHIFT      (31U)

/*! @name REG_HSIC_1P2_CLR - Anadig 1.2V HSIC Regulator Control Register */
#define PMU_REG_HSIC_1P2_CLR_ENABLE_LINREG_MASK  (0x1U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_LINREG_SHIFT (0U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_BO_MASK      (0x2U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_BO_SHIFT     (1U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_ILIMIT_MASK  (0x4U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_ILIMIT_SHIFT (2U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_PULLDOWN_MASK (0x8U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_PULLDOWN_SHIFT (3U)
#define PMU_REG_HSIC_1P2_CLR_BO_OFFSET_MASK      (0x70U)
#define PMU_REG_HSIC_1P2_CLR_BO_OFFSET_SHIFT     (4U)
#define PMU_REG_HSIC_1P2_CLR_BO_OFFSET(x)        (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_CLR_BO_OFFSET_SHIFT)) & PMU_REG_HSIC_1P2_CLR_BO_OFFSET_MASK)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_PWRUPLOAD_MASK (0x80U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_PWRUPLOAD_SHIFT (7U)
#define PMU_REG_HSIC_1P2_CLR_OUTPUT_TRG_MASK     (0x1F00U)
#define PMU_REG_HSIC_1P2_CLR_OUTPUT_TRG_SHIFT    (8U)
#define PMU_REG_HSIC_1P2_CLR_OUTPUT_TRG(x)       (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_CLR_OUTPUT_TRG_SHIFT)) & PMU_REG_HSIC_1P2_CLR_OUTPUT_TRG_MASK)
#define PMU_REG_HSIC_1P2_CLR_RSVD0_MASK          (0xE000U)
#define PMU_REG_HSIC_1P2_CLR_RSVD0_SHIFT         (13U)
#define PMU_REG_HSIC_1P2_CLR_RSVD0(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_CLR_RSVD0_SHIFT)) & PMU_REG_HSIC_1P2_CLR_RSVD0_MASK)
#define PMU_REG_HSIC_1P2_CLR_BO_MASK             (0x10000U)
#define PMU_REG_HSIC_1P2_CLR_BO_SHIFT            (16U)
#define PMU_REG_HSIC_1P2_CLR_OK_MASK             (0x20000U)
#define PMU_REG_HSIC_1P2_CLR_OK_SHIFT            (17U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_HSIC_1P2_CLR_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_HSIC_1P2_CLR_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_HSIC_1P2_CLR_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_HSIC_1P2_CLR_REG_TEST_MASK       (0xF00000U)
#define PMU_REG_HSIC_1P2_CLR_REG_TEST_SHIFT      (20U)
#define PMU_REG_HSIC_1P2_CLR_REG_TEST(x)         (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_CLR_REG_TEST_SHIFT)) & PMU_REG_HSIC_1P2_CLR_REG_TEST_MASK)
#define PMU_REG_HSIC_1P2_CLR_RSVD1_MASK          (0x7F000000U)
#define PMU_REG_HSIC_1P2_CLR_RSVD1_SHIFT         (24U)
#define PMU_REG_HSIC_1P2_CLR_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_CLR_RSVD1_SHIFT)) & PMU_REG_HSIC_1P2_CLR_RSVD1_MASK)
#define PMU_REG_HSIC_1P2_CLR_OVERRIDE_MASK       (0x80000000U)
#define PMU_REG_HSIC_1P2_CLR_OVERRIDE_SHIFT      (31U)

/*! @name REG_HSIC_1P2_TOG - Anadig 1.2V HSIC Regulator Control Register */
#define PMU_REG_HSIC_1P2_TOG_ENABLE_LINREG_MASK  (0x1U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_LINREG_SHIFT (0U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_BO_MASK      (0x2U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_BO_SHIFT     (1U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_ILIMIT_MASK  (0x4U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_ILIMIT_SHIFT (2U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_PULLDOWN_MASK (0x8U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_PULLDOWN_SHIFT (3U)
#define PMU_REG_HSIC_1P2_TOG_BO_OFFSET_MASK      (0x70U)
#define PMU_REG_HSIC_1P2_TOG_BO_OFFSET_SHIFT     (4U)
#define PMU_REG_HSIC_1P2_TOG_BO_OFFSET(x)        (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_TOG_BO_OFFSET_SHIFT)) & PMU_REG_HSIC_1P2_TOG_BO_OFFSET_MASK)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_PWRUPLOAD_MASK (0x80U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_PWRUPLOAD_SHIFT (7U)
#define PMU_REG_HSIC_1P2_TOG_OUTPUT_TRG_MASK     (0x1F00U)
#define PMU_REG_HSIC_1P2_TOG_OUTPUT_TRG_SHIFT    (8U)
#define PMU_REG_HSIC_1P2_TOG_OUTPUT_TRG(x)       (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_TOG_OUTPUT_TRG_SHIFT)) & PMU_REG_HSIC_1P2_TOG_OUTPUT_TRG_MASK)
#define PMU_REG_HSIC_1P2_TOG_RSVD0_MASK          (0xE000U)
#define PMU_REG_HSIC_1P2_TOG_RSVD0_SHIFT         (13U)
#define PMU_REG_HSIC_1P2_TOG_RSVD0(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_TOG_RSVD0_SHIFT)) & PMU_REG_HSIC_1P2_TOG_RSVD0_MASK)
#define PMU_REG_HSIC_1P2_TOG_BO_MASK             (0x10000U)
#define PMU_REG_HSIC_1P2_TOG_BO_SHIFT            (16U)
#define PMU_REG_HSIC_1P2_TOG_OK_MASK             (0x20000U)
#define PMU_REG_HSIC_1P2_TOG_OK_SHIFT            (17U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_HSIC_1P2_TOG_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_HSIC_1P2_TOG_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_HSIC_1P2_TOG_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_HSIC_1P2_TOG_REG_TEST_MASK       (0xF00000U)
#define PMU_REG_HSIC_1P2_TOG_REG_TEST_SHIFT      (20U)
#define PMU_REG_HSIC_1P2_TOG_REG_TEST(x)         (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_TOG_REG_TEST_SHIFT)) & PMU_REG_HSIC_1P2_TOG_REG_TEST_MASK)
#define PMU_REG_HSIC_1P2_TOG_RSVD1_MASK          (0x7F000000U)
#define PMU_REG_HSIC_1P2_TOG_RSVD1_SHIFT         (24U)
#define PMU_REG_HSIC_1P2_TOG_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_HSIC_1P2_TOG_RSVD1_SHIFT)) & PMU_REG_HSIC_1P2_TOG_RSVD1_MASK)
#define PMU_REG_HSIC_1P2_TOG_OVERRIDE_MASK       (0x80000000U)
#define PMU_REG_HSIC_1P2_TOG_OVERRIDE_SHIFT      (31U)

/*! @name REG_LPSR_1P0 - Anadig 1.0V Low Power State Retention Regulator Control Register */
#define PMU_REG_LPSR_1P0_ENABLE_LINREG_MASK      (0x1U)
#define PMU_REG_LPSR_1P0_ENABLE_LINREG_SHIFT     (0U)
#define PMU_REG_LPSR_1P0_ENABLE_BO_MASK          (0x2U)
#define PMU_REG_LPSR_1P0_ENABLE_BO_SHIFT         (1U)
#define PMU_REG_LPSR_1P0_ENABLE_ILIMIT_MASK      (0x4U)
#define PMU_REG_LPSR_1P0_ENABLE_ILIMIT_SHIFT     (2U)
#define PMU_REG_LPSR_1P0_ENABLE_PULLDOWN_MASK    (0x8U)
#define PMU_REG_LPSR_1P0_ENABLE_PULLDOWN_SHIFT   (3U)
#define PMU_REG_LPSR_1P0_BO_OFFSET_MASK          (0x70U)
#define PMU_REG_LPSR_1P0_BO_OFFSET_SHIFT         (4U)
#define PMU_REG_LPSR_1P0_BO_OFFSET(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_BO_OFFSET_SHIFT)) & PMU_REG_LPSR_1P0_BO_OFFSET_MASK)
#define PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD_MASK   (0x80U)
#define PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD_SHIFT  (7U)
#define PMU_REG_LPSR_1P0_OUTPUT_TRG_MASK         (0x1F00U)
#define PMU_REG_LPSR_1P0_OUTPUT_TRG_SHIFT        (8U)
#define PMU_REG_LPSR_1P0_OUTPUT_TRG(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_OUTPUT_TRG_SHIFT)) & PMU_REG_LPSR_1P0_OUTPUT_TRG_MASK)
#define PMU_REG_LPSR_1P0_RSVD0_MASK              (0xE000U)
#define PMU_REG_LPSR_1P0_RSVD0_SHIFT             (13U)
#define PMU_REG_LPSR_1P0_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_RSVD0_SHIFT)) & PMU_REG_LPSR_1P0_RSVD0_MASK)
#define PMU_REG_LPSR_1P0_BO_MASK                 (0x10000U)
#define PMU_REG_LPSR_1P0_BO_SHIFT                (16U)
#define PMU_REG_LPSR_1P0_OK_MASK                 (0x20000U)
#define PMU_REG_LPSR_1P0_OK_SHIFT                (17U)
#define PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_LPSR_1P0_REG_TEST_MASK           (0xF00000U)
#define PMU_REG_LPSR_1P0_REG_TEST_SHIFT          (20U)
#define PMU_REG_LPSR_1P0_REG_TEST(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_REG_TEST_SHIFT)) & PMU_REG_LPSR_1P0_REG_TEST_MASK)
#define PMU_REG_LPSR_1P0_RSVD1_MASK              (0xFF000000U)
#define PMU_REG_LPSR_1P0_RSVD1_SHIFT             (24U)
#define PMU_REG_LPSR_1P0_RSVD1(x)                (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_RSVD1_SHIFT)) & PMU_REG_LPSR_1P0_RSVD1_MASK)

/*! @name REG_LPSR_1P0_SET - Anadig 1.0V Low Power State Retention Regulator Control Register */
#define PMU_REG_LPSR_1P0_SET_ENABLE_LINREG_MASK  (0x1U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_LINREG_SHIFT (0U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_BO_MASK      (0x2U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_BO_SHIFT     (1U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_ILIMIT_MASK  (0x4U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_ILIMIT_SHIFT (2U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_PULLDOWN_MASK (0x8U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_PULLDOWN_SHIFT (3U)
#define PMU_REG_LPSR_1P0_SET_BO_OFFSET_MASK      (0x70U)
#define PMU_REG_LPSR_1P0_SET_BO_OFFSET_SHIFT     (4U)
#define PMU_REG_LPSR_1P0_SET_BO_OFFSET(x)        (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_SET_BO_OFFSET_SHIFT)) & PMU_REG_LPSR_1P0_SET_BO_OFFSET_MASK)
#define PMU_REG_LPSR_1P0_SET_ENABLE_PWRUPLOAD_MASK (0x80U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_PWRUPLOAD_SHIFT (7U)
#define PMU_REG_LPSR_1P0_SET_OUTPUT_TRG_MASK     (0x1F00U)
#define PMU_REG_LPSR_1P0_SET_OUTPUT_TRG_SHIFT    (8U)
#define PMU_REG_LPSR_1P0_SET_OUTPUT_TRG(x)       (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_SET_OUTPUT_TRG_SHIFT)) & PMU_REG_LPSR_1P0_SET_OUTPUT_TRG_MASK)
#define PMU_REG_LPSR_1P0_SET_RSVD0_MASK          (0xE000U)
#define PMU_REG_LPSR_1P0_SET_RSVD0_SHIFT         (13U)
#define PMU_REG_LPSR_1P0_SET_RSVD0(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_SET_RSVD0_SHIFT)) & PMU_REG_LPSR_1P0_SET_RSVD0_MASK)
#define PMU_REG_LPSR_1P0_SET_BO_MASK             (0x10000U)
#define PMU_REG_LPSR_1P0_SET_BO_SHIFT            (16U)
#define PMU_REG_LPSR_1P0_SET_OK_MASK             (0x20000U)
#define PMU_REG_LPSR_1P0_SET_OK_SHIFT            (17U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_LPSR_1P0_SET_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_LPSR_1P0_SET_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_LPSR_1P0_SET_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_LPSR_1P0_SET_REG_TEST_MASK       (0xF00000U)
#define PMU_REG_LPSR_1P0_SET_REG_TEST_SHIFT      (20U)
#define PMU_REG_LPSR_1P0_SET_REG_TEST(x)         (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_SET_REG_TEST_SHIFT)) & PMU_REG_LPSR_1P0_SET_REG_TEST_MASK)
#define PMU_REG_LPSR_1P0_SET_RSVD1_MASK          (0xFF000000U)
#define PMU_REG_LPSR_1P0_SET_RSVD1_SHIFT         (24U)
#define PMU_REG_LPSR_1P0_SET_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_SET_RSVD1_SHIFT)) & PMU_REG_LPSR_1P0_SET_RSVD1_MASK)

/*! @name REG_LPSR_1P0_CLR - Anadig 1.0V Low Power State Retention Regulator Control Register */
#define PMU_REG_LPSR_1P0_CLR_ENABLE_LINREG_MASK  (0x1U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_LINREG_SHIFT (0U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_BO_MASK      (0x2U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_BO_SHIFT     (1U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_ILIMIT_MASK  (0x4U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_ILIMIT_SHIFT (2U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_PULLDOWN_MASK (0x8U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_PULLDOWN_SHIFT (3U)
#define PMU_REG_LPSR_1P0_CLR_BO_OFFSET_MASK      (0x70U)
#define PMU_REG_LPSR_1P0_CLR_BO_OFFSET_SHIFT     (4U)
#define PMU_REG_LPSR_1P0_CLR_BO_OFFSET(x)        (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_CLR_BO_OFFSET_SHIFT)) & PMU_REG_LPSR_1P0_CLR_BO_OFFSET_MASK)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_PWRUPLOAD_MASK (0x80U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_PWRUPLOAD_SHIFT (7U)
#define PMU_REG_LPSR_1P0_CLR_OUTPUT_TRG_MASK     (0x1F00U)
#define PMU_REG_LPSR_1P0_CLR_OUTPUT_TRG_SHIFT    (8U)
#define PMU_REG_LPSR_1P0_CLR_OUTPUT_TRG(x)       (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_CLR_OUTPUT_TRG_SHIFT)) & PMU_REG_LPSR_1P0_CLR_OUTPUT_TRG_MASK)
#define PMU_REG_LPSR_1P0_CLR_RSVD0_MASK          (0xE000U)
#define PMU_REG_LPSR_1P0_CLR_RSVD0_SHIFT         (13U)
#define PMU_REG_LPSR_1P0_CLR_RSVD0(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_CLR_RSVD0_SHIFT)) & PMU_REG_LPSR_1P0_CLR_RSVD0_MASK)
#define PMU_REG_LPSR_1P0_CLR_BO_MASK             (0x10000U)
#define PMU_REG_LPSR_1P0_CLR_BO_SHIFT            (16U)
#define PMU_REG_LPSR_1P0_CLR_OK_MASK             (0x20000U)
#define PMU_REG_LPSR_1P0_CLR_OK_SHIFT            (17U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_LPSR_1P0_CLR_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_LPSR_1P0_CLR_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_LPSR_1P0_CLR_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_LPSR_1P0_CLR_REG_TEST_MASK       (0xF00000U)
#define PMU_REG_LPSR_1P0_CLR_REG_TEST_SHIFT      (20U)
#define PMU_REG_LPSR_1P0_CLR_REG_TEST(x)         (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_CLR_REG_TEST_SHIFT)) & PMU_REG_LPSR_1P0_CLR_REG_TEST_MASK)
#define PMU_REG_LPSR_1P0_CLR_RSVD1_MASK          (0xFF000000U)
#define PMU_REG_LPSR_1P0_CLR_RSVD1_SHIFT         (24U)
#define PMU_REG_LPSR_1P0_CLR_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_CLR_RSVD1_SHIFT)) & PMU_REG_LPSR_1P0_CLR_RSVD1_MASK)

/*! @name REG_LPSR_1P0_TOG - Anadig 1.0V Low Power State Retention Regulator Control Register */
#define PMU_REG_LPSR_1P0_TOG_ENABLE_LINREG_MASK  (0x1U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_LINREG_SHIFT (0U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_BO_MASK      (0x2U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_BO_SHIFT     (1U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_ILIMIT_MASK  (0x4U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_ILIMIT_SHIFT (2U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_PULLDOWN_MASK (0x8U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_PULLDOWN_SHIFT (3U)
#define PMU_REG_LPSR_1P0_TOG_BO_OFFSET_MASK      (0x70U)
#define PMU_REG_LPSR_1P0_TOG_BO_OFFSET_SHIFT     (4U)
#define PMU_REG_LPSR_1P0_TOG_BO_OFFSET(x)        (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_TOG_BO_OFFSET_SHIFT)) & PMU_REG_LPSR_1P0_TOG_BO_OFFSET_MASK)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_PWRUPLOAD_MASK (0x80U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_PWRUPLOAD_SHIFT (7U)
#define PMU_REG_LPSR_1P0_TOG_OUTPUT_TRG_MASK     (0x1F00U)
#define PMU_REG_LPSR_1P0_TOG_OUTPUT_TRG_SHIFT    (8U)
#define PMU_REG_LPSR_1P0_TOG_OUTPUT_TRG(x)       (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_TOG_OUTPUT_TRG_SHIFT)) & PMU_REG_LPSR_1P0_TOG_OUTPUT_TRG_MASK)
#define PMU_REG_LPSR_1P0_TOG_RSVD0_MASK          (0xE000U)
#define PMU_REG_LPSR_1P0_TOG_RSVD0_SHIFT         (13U)
#define PMU_REG_LPSR_1P0_TOG_RSVD0(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_TOG_RSVD0_SHIFT)) & PMU_REG_LPSR_1P0_TOG_RSVD0_MASK)
#define PMU_REG_LPSR_1P0_TOG_BO_MASK             (0x10000U)
#define PMU_REG_LPSR_1P0_TOG_BO_SHIFT            (16U)
#define PMU_REG_LPSR_1P0_TOG_OK_MASK             (0x20000U)
#define PMU_REG_LPSR_1P0_TOG_OK_SHIFT            (17U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_WEAK_LINREG_MASK (0x40000U)
#define PMU_REG_LPSR_1P0_TOG_ENABLE_WEAK_LINREG_SHIFT (18U)
#define PMU_REG_LPSR_1P0_TOG_SELREF_WEAK_LINREG_MASK (0x80000U)
#define PMU_REG_LPSR_1P0_TOG_SELREF_WEAK_LINREG_SHIFT (19U)
#define PMU_REG_LPSR_1P0_TOG_REG_TEST_MASK       (0xF00000U)
#define PMU_REG_LPSR_1P0_TOG_REG_TEST_SHIFT      (20U)
#define PMU_REG_LPSR_1P0_TOG_REG_TEST(x)         (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_TOG_REG_TEST_SHIFT)) & PMU_REG_LPSR_1P0_TOG_REG_TEST_MASK)
#define PMU_REG_LPSR_1P0_TOG_RSVD1_MASK          (0xFF000000U)
#define PMU_REG_LPSR_1P0_TOG_RSVD1_SHIFT         (24U)
#define PMU_REG_LPSR_1P0_TOG_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << PMU_REG_LPSR_1P0_TOG_RSVD1_SHIFT)) & PMU_REG_LPSR_1P0_TOG_RSVD1_MASK)

/*! @name REF - Anadig Reference Analog Control and Status Register */
#define PMU_REF_REFTOP_PWD_MASK                  (0x1U)
#define PMU_REF_REFTOP_PWD_SHIFT                 (0U)
#define PMU_REF_REFTOP_PWDVBGUP_MASK             (0x2U)
#define PMU_REF_REFTOP_PWDVBGUP_SHIFT            (1U)
#define PMU_REF_REFTOP_LOWPOWER_MASK             (0x4U)
#define PMU_REF_REFTOP_LOWPOWER_SHIFT            (2U)
#define PMU_REF_REFTOP_SELFBIASOFF_MASK          (0x8U)
#define PMU_REF_REFTOP_SELFBIASOFF_SHIFT         (3U)
#define PMU_REF_REFTOP_VBGADJ_MASK               (0x70U)
#define PMU_REF_REFTOP_VBGADJ_SHIFT              (4U)
#define PMU_REF_REFTOP_VBGADJ(x)                 (((uint32_t)(((uint32_t)(x)) << PMU_REF_REFTOP_VBGADJ_SHIFT)) & PMU_REF_REFTOP_VBGADJ_MASK)
#define PMU_REF_REFTOP_VBGUP_MASK                (0x80U)
#define PMU_REF_REFTOP_VBGUP_SHIFT               (7U)
#define PMU_REF_REFTOP_BIAS_TST_MASK             (0x300U)
#define PMU_REF_REFTOP_BIAS_TST_SHIFT            (8U)
#define PMU_REF_REFTOP_BIAS_TST(x)               (((uint32_t)(((uint32_t)(x)) << PMU_REF_REFTOP_BIAS_TST_SHIFT)) & PMU_REF_REFTOP_BIAS_TST_MASK)
#define PMU_REF_LPBG_SEL_MASK                    (0x400U)
#define PMU_REF_LPBG_SEL_SHIFT                   (10U)
#define PMU_REF_LPBG_TEST_MASK                   (0x800U)
#define PMU_REF_LPBG_TEST_SHIFT                  (11U)
#define PMU_REF_REFTOP_IBIAS_OFF_MASK            (0x1000U)
#define PMU_REF_REFTOP_IBIAS_OFF_SHIFT           (12U)
#define PMU_REF_REFTOP_LINREGREF_EN_MASK         (0x2000U)
#define PMU_REF_REFTOP_LINREGREF_EN_SHIFT        (13U)
#define PMU_REF_RSVD1_MASK                       (0xFFFFC000U)
#define PMU_REF_RSVD1_SHIFT                      (14U)
#define PMU_REF_RSVD1(x)                         (((uint32_t)(((uint32_t)(x)) << PMU_REF_RSVD1_SHIFT)) & PMU_REF_RSVD1_MASK)

/*! @name REF_SET - Anadig Reference Analog Control and Status Register */
#define PMU_REF_SET_REFTOP_PWD_MASK              (0x1U)
#define PMU_REF_SET_REFTOP_PWD_SHIFT             (0U)
#define PMU_REF_SET_REFTOP_PWDVBGUP_MASK         (0x2U)
#define PMU_REF_SET_REFTOP_PWDVBGUP_SHIFT        (1U)
#define PMU_REF_SET_REFTOP_LOWPOWER_MASK         (0x4U)
#define PMU_REF_SET_REFTOP_LOWPOWER_SHIFT        (2U)
#define PMU_REF_SET_REFTOP_SELFBIASOFF_MASK      (0x8U)
#define PMU_REF_SET_REFTOP_SELFBIASOFF_SHIFT     (3U)
#define PMU_REF_SET_REFTOP_VBGADJ_MASK           (0x70U)
#define PMU_REF_SET_REFTOP_VBGADJ_SHIFT          (4U)
#define PMU_REF_SET_REFTOP_VBGADJ(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REF_SET_REFTOP_VBGADJ_SHIFT)) & PMU_REF_SET_REFTOP_VBGADJ_MASK)
#define PMU_REF_SET_REFTOP_VBGUP_MASK            (0x80U)
#define PMU_REF_SET_REFTOP_VBGUP_SHIFT           (7U)
#define PMU_REF_SET_REFTOP_BIAS_TST_MASK         (0x300U)
#define PMU_REF_SET_REFTOP_BIAS_TST_SHIFT        (8U)
#define PMU_REF_SET_REFTOP_BIAS_TST(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REF_SET_REFTOP_BIAS_TST_SHIFT)) & PMU_REF_SET_REFTOP_BIAS_TST_MASK)
#define PMU_REF_SET_LPBG_SEL_MASK                (0x400U)
#define PMU_REF_SET_LPBG_SEL_SHIFT               (10U)
#define PMU_REF_SET_LPBG_TEST_MASK               (0x800U)
#define PMU_REF_SET_LPBG_TEST_SHIFT              (11U)
#define PMU_REF_SET_REFTOP_IBIAS_OFF_MASK        (0x1000U)
#define PMU_REF_SET_REFTOP_IBIAS_OFF_SHIFT       (12U)
#define PMU_REF_SET_REFTOP_LINREGREF_EN_MASK     (0x2000U)
#define PMU_REF_SET_REFTOP_LINREGREF_EN_SHIFT    (13U)
#define PMU_REF_SET_RSVD1_MASK                   (0xFFFFC000U)
#define PMU_REF_SET_RSVD1_SHIFT                  (14U)
#define PMU_REF_SET_RSVD1(x)                     (((uint32_t)(((uint32_t)(x)) << PMU_REF_SET_RSVD1_SHIFT)) & PMU_REF_SET_RSVD1_MASK)

/*! @name REF_CLR - Anadig Reference Analog Control and Status Register */
#define PMU_REF_CLR_REFTOP_PWD_MASK              (0x1U)
#define PMU_REF_CLR_REFTOP_PWD_SHIFT             (0U)
#define PMU_REF_CLR_REFTOP_PWDVBGUP_MASK         (0x2U)
#define PMU_REF_CLR_REFTOP_PWDVBGUP_SHIFT        (1U)
#define PMU_REF_CLR_REFTOP_LOWPOWER_MASK         (0x4U)
#define PMU_REF_CLR_REFTOP_LOWPOWER_SHIFT        (2U)
#define PMU_REF_CLR_REFTOP_SELFBIASOFF_MASK      (0x8U)
#define PMU_REF_CLR_REFTOP_SELFBIASOFF_SHIFT     (3U)
#define PMU_REF_CLR_REFTOP_VBGADJ_MASK           (0x70U)
#define PMU_REF_CLR_REFTOP_VBGADJ_SHIFT          (4U)
#define PMU_REF_CLR_REFTOP_VBGADJ(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REF_CLR_REFTOP_VBGADJ_SHIFT)) & PMU_REF_CLR_REFTOP_VBGADJ_MASK)
#define PMU_REF_CLR_REFTOP_VBGUP_MASK            (0x80U)
#define PMU_REF_CLR_REFTOP_VBGUP_SHIFT           (7U)
#define PMU_REF_CLR_REFTOP_BIAS_TST_MASK         (0x300U)
#define PMU_REF_CLR_REFTOP_BIAS_TST_SHIFT        (8U)
#define PMU_REF_CLR_REFTOP_BIAS_TST(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REF_CLR_REFTOP_BIAS_TST_SHIFT)) & PMU_REF_CLR_REFTOP_BIAS_TST_MASK)
#define PMU_REF_CLR_LPBG_SEL_MASK                (0x400U)
#define PMU_REF_CLR_LPBG_SEL_SHIFT               (10U)
#define PMU_REF_CLR_LPBG_TEST_MASK               (0x800U)
#define PMU_REF_CLR_LPBG_TEST_SHIFT              (11U)
#define PMU_REF_CLR_REFTOP_IBIAS_OFF_MASK        (0x1000U)
#define PMU_REF_CLR_REFTOP_IBIAS_OFF_SHIFT       (12U)
#define PMU_REF_CLR_REFTOP_LINREGREF_EN_MASK     (0x2000U)
#define PMU_REF_CLR_REFTOP_LINREGREF_EN_SHIFT    (13U)
#define PMU_REF_CLR_RSVD1_MASK                   (0xFFFFC000U)
#define PMU_REF_CLR_RSVD1_SHIFT                  (14U)
#define PMU_REF_CLR_RSVD1(x)                     (((uint32_t)(((uint32_t)(x)) << PMU_REF_CLR_RSVD1_SHIFT)) & PMU_REF_CLR_RSVD1_MASK)

/*! @name REF_TOG - Anadig Reference Analog Control and Status Register */
#define PMU_REF_TOG_REFTOP_PWD_MASK              (0x1U)
#define PMU_REF_TOG_REFTOP_PWD_SHIFT             (0U)
#define PMU_REF_TOG_REFTOP_PWDVBGUP_MASK         (0x2U)
#define PMU_REF_TOG_REFTOP_PWDVBGUP_SHIFT        (1U)
#define PMU_REF_TOG_REFTOP_LOWPOWER_MASK         (0x4U)
#define PMU_REF_TOG_REFTOP_LOWPOWER_SHIFT        (2U)
#define PMU_REF_TOG_REFTOP_SELFBIASOFF_MASK      (0x8U)
#define PMU_REF_TOG_REFTOP_SELFBIASOFF_SHIFT     (3U)
#define PMU_REF_TOG_REFTOP_VBGADJ_MASK           (0x70U)
#define PMU_REF_TOG_REFTOP_VBGADJ_SHIFT          (4U)
#define PMU_REF_TOG_REFTOP_VBGADJ(x)             (((uint32_t)(((uint32_t)(x)) << PMU_REF_TOG_REFTOP_VBGADJ_SHIFT)) & PMU_REF_TOG_REFTOP_VBGADJ_MASK)
#define PMU_REF_TOG_REFTOP_VBGUP_MASK            (0x80U)
#define PMU_REF_TOG_REFTOP_VBGUP_SHIFT           (7U)
#define PMU_REF_TOG_REFTOP_BIAS_TST_MASK         (0x300U)
#define PMU_REF_TOG_REFTOP_BIAS_TST_SHIFT        (8U)
#define PMU_REF_TOG_REFTOP_BIAS_TST(x)           (((uint32_t)(((uint32_t)(x)) << PMU_REF_TOG_REFTOP_BIAS_TST_SHIFT)) & PMU_REF_TOG_REFTOP_BIAS_TST_MASK)
#define PMU_REF_TOG_LPBG_SEL_MASK                (0x400U)
#define PMU_REF_TOG_LPBG_SEL_SHIFT               (10U)
#define PMU_REF_TOG_LPBG_TEST_MASK               (0x800U)
#define PMU_REF_TOG_LPBG_TEST_SHIFT              (11U)
#define PMU_REF_TOG_REFTOP_IBIAS_OFF_MASK        (0x1000U)
#define PMU_REF_TOG_REFTOP_IBIAS_OFF_SHIFT       (12U)
#define PMU_REF_TOG_REFTOP_LINREGREF_EN_MASK     (0x2000U)
#define PMU_REF_TOG_REFTOP_LINREGREF_EN_SHIFT    (13U)
#define PMU_REF_TOG_RSVD1_MASK                   (0xFFFFC000U)
#define PMU_REF_TOG_RSVD1_SHIFT                  (14U)
#define PMU_REF_TOG_RSVD1(x)                     (((uint32_t)(((uint32_t)(x)) << PMU_REF_TOG_RSVD1_SHIFT)) & PMU_REF_TOG_RSVD1_MASK)

/*! @name LOWPWR_CTRL - Anadig Low Power Control Register */
#define PMU_LOWPWR_CTRL_STOP_MODE_CONFIG_MASK    (0x3U)
#define PMU_LOWPWR_CTRL_STOP_MODE_CONFIG_SHIFT   (0U)
#define PMU_LOWPWR_CTRL_STOP_MODE_CONFIG(x)      (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_STOP_MODE_CONFIG_SHIFT)) & PMU_LOWPWR_CTRL_STOP_MODE_CONFIG_MASK)
#define PMU_LOWPWR_CTRL_RSVD0_MASK               (0xFCU)
#define PMU_LOWPWR_CTRL_RSVD0_SHIFT              (2U)
#define PMU_LOWPWR_CTRL_RSVD0(x)                 (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_RSVD0_SHIFT)) & PMU_LOWPWR_CTRL_RSVD0_MASK)
#define PMU_LOWPWR_CTRL_L1_PWRGATE_MASK          (0x100U)
#define PMU_LOWPWR_CTRL_L1_PWRGATE_SHIFT         (8U)
#define PMU_LOWPWR_CTRL_L2_PWRGATE_MASK          (0x200U)
#define PMU_LOWPWR_CTRL_L2_PWRGATE_SHIFT         (9U)
#define PMU_LOWPWR_CTRL_CPU_PWRGATE_MASK         (0x400U)
#define PMU_LOWPWR_CTRL_CPU_PWRGATE_SHIFT        (10U)
#define PMU_LOWPWR_CTRL_DISPLAY_PWRGATE_MASK     (0x800U)
#define PMU_LOWPWR_CTRL_DISPLAY_PWRGATE_SHIFT    (11U)
#define PMU_LOWPWR_CTRL_MIX_PWRGATE_MASK         (0x1000U)
#define PMU_LOWPWR_CTRL_MIX_PWRGATE_SHIFT        (12U)
#define PMU_LOWPWR_CTRL_GPU_PWRGATE_MASK         (0x2000U)
#define PMU_LOWPWR_CTRL_GPU_PWRGATE_SHIFT        (13U)
#define PMU_LOWPWR_CTRL_CONTROL0_MASK            (0xFFC000U)
#define PMU_LOWPWR_CTRL_CONTROL0_SHIFT           (14U)
#define PMU_LOWPWR_CTRL_CONTROL0(x)              (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_CONTROL0_SHIFT)) & PMU_LOWPWR_CTRL_CONTROL0_MASK)
#define PMU_LOWPWR_CTRL_CONTROL1_MASK            (0xFF000000U)
#define PMU_LOWPWR_CTRL_CONTROL1_SHIFT           (24U)
#define PMU_LOWPWR_CTRL_CONTROL1(x)              (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_CONTROL1_SHIFT)) & PMU_LOWPWR_CTRL_CONTROL1_MASK)

/*! @name LOWPWR_CTRL_SET - Anadig Low Power Control Register */
#define PMU_LOWPWR_CTRL_SET_STOP_MODE_CONFIG_MASK (0x3U)
#define PMU_LOWPWR_CTRL_SET_STOP_MODE_CONFIG_SHIFT (0U)
#define PMU_LOWPWR_CTRL_SET_STOP_MODE_CONFIG(x)  (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_SET_STOP_MODE_CONFIG_SHIFT)) & PMU_LOWPWR_CTRL_SET_STOP_MODE_CONFIG_MASK)
#define PMU_LOWPWR_CTRL_SET_RSVD0_MASK           (0xFCU)
#define PMU_LOWPWR_CTRL_SET_RSVD0_SHIFT          (2U)
#define PMU_LOWPWR_CTRL_SET_RSVD0(x)             (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_SET_RSVD0_SHIFT)) & PMU_LOWPWR_CTRL_SET_RSVD0_MASK)
#define PMU_LOWPWR_CTRL_SET_L1_PWRGATE_MASK      (0x100U)
#define PMU_LOWPWR_CTRL_SET_L1_PWRGATE_SHIFT     (8U)
#define PMU_LOWPWR_CTRL_SET_L2_PWRGATE_MASK      (0x200U)
#define PMU_LOWPWR_CTRL_SET_L2_PWRGATE_SHIFT     (9U)
#define PMU_LOWPWR_CTRL_SET_CPU_PWRGATE_MASK     (0x400U)
#define PMU_LOWPWR_CTRL_SET_CPU_PWRGATE_SHIFT    (10U)
#define PMU_LOWPWR_CTRL_SET_DISPLAY_PWRGATE_MASK (0x800U)
#define PMU_LOWPWR_CTRL_SET_DISPLAY_PWRGATE_SHIFT (11U)
#define PMU_LOWPWR_CTRL_SET_MIX_PWRGATE_MASK     (0x1000U)
#define PMU_LOWPWR_CTRL_SET_MIX_PWRGATE_SHIFT    (12U)
#define PMU_LOWPWR_CTRL_SET_GPU_PWRGATE_MASK     (0x2000U)
#define PMU_LOWPWR_CTRL_SET_GPU_PWRGATE_SHIFT    (13U)
#define PMU_LOWPWR_CTRL_SET_CONTROL0_MASK        (0xFFC000U)
#define PMU_LOWPWR_CTRL_SET_CONTROL0_SHIFT       (14U)
#define PMU_LOWPWR_CTRL_SET_CONTROL0(x)          (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_SET_CONTROL0_SHIFT)) & PMU_LOWPWR_CTRL_SET_CONTROL0_MASK)
#define PMU_LOWPWR_CTRL_SET_CONTROL1_MASK        (0xFF000000U)
#define PMU_LOWPWR_CTRL_SET_CONTROL1_SHIFT       (24U)
#define PMU_LOWPWR_CTRL_SET_CONTROL1(x)          (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_SET_CONTROL1_SHIFT)) & PMU_LOWPWR_CTRL_SET_CONTROL1_MASK)

/*! @name LOWPWR_CTRL_CLR - Anadig Low Power Control Register */
#define PMU_LOWPWR_CTRL_CLR_STOP_MODE_CONFIG_MASK (0x3U)
#define PMU_LOWPWR_CTRL_CLR_STOP_MODE_CONFIG_SHIFT (0U)
#define PMU_LOWPWR_CTRL_CLR_STOP_MODE_CONFIG(x)  (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_CLR_STOP_MODE_CONFIG_SHIFT)) & PMU_LOWPWR_CTRL_CLR_STOP_MODE_CONFIG_MASK)
#define PMU_LOWPWR_CTRL_CLR_RSVD0_MASK           (0xFCU)
#define PMU_LOWPWR_CTRL_CLR_RSVD0_SHIFT          (2U)
#define PMU_LOWPWR_CTRL_CLR_RSVD0(x)             (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_CLR_RSVD0_SHIFT)) & PMU_LOWPWR_CTRL_CLR_RSVD0_MASK)
#define PMU_LOWPWR_CTRL_CLR_L1_PWRGATE_MASK      (0x100U)
#define PMU_LOWPWR_CTRL_CLR_L1_PWRGATE_SHIFT     (8U)
#define PMU_LOWPWR_CTRL_CLR_L2_PWRGATE_MASK      (0x200U)
#define PMU_LOWPWR_CTRL_CLR_L2_PWRGATE_SHIFT     (9U)
#define PMU_LOWPWR_CTRL_CLR_CPU_PWRGATE_MASK     (0x400U)
#define PMU_LOWPWR_CTRL_CLR_CPU_PWRGATE_SHIFT    (10U)
#define PMU_LOWPWR_CTRL_CLR_DISPLAY_PWRGATE_MASK (0x800U)
#define PMU_LOWPWR_CTRL_CLR_DISPLAY_PWRGATE_SHIFT (11U)
#define PMU_LOWPWR_CTRL_CLR_MIX_PWRGATE_MASK     (0x1000U)
#define PMU_LOWPWR_CTRL_CLR_MIX_PWRGATE_SHIFT    (12U)
#define PMU_LOWPWR_CTRL_CLR_GPU_PWRGATE_MASK     (0x2000U)
#define PMU_LOWPWR_CTRL_CLR_GPU_PWRGATE_SHIFT    (13U)
#define PMU_LOWPWR_CTRL_CLR_CONTROL0_MASK        (0xFFC000U)
#define PMU_LOWPWR_CTRL_CLR_CONTROL0_SHIFT       (14U)
#define PMU_LOWPWR_CTRL_CLR_CONTROL0(x)          (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_CLR_CONTROL0_SHIFT)) & PMU_LOWPWR_CTRL_CLR_CONTROL0_MASK)
#define PMU_LOWPWR_CTRL_CLR_CONTROL1_MASK        (0xFF000000U)
#define PMU_LOWPWR_CTRL_CLR_CONTROL1_SHIFT       (24U)
#define PMU_LOWPWR_CTRL_CLR_CONTROL1(x)          (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_CLR_CONTROL1_SHIFT)) & PMU_LOWPWR_CTRL_CLR_CONTROL1_MASK)

/*! @name LOWPWR_CTRL_TOG - Anadig Low Power Control Register */
#define PMU_LOWPWR_CTRL_TOG_STOP_MODE_CONFIG_MASK (0x3U)
#define PMU_LOWPWR_CTRL_TOG_STOP_MODE_CONFIG_SHIFT (0U)
#define PMU_LOWPWR_CTRL_TOG_STOP_MODE_CONFIG(x)  (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_TOG_STOP_MODE_CONFIG_SHIFT)) & PMU_LOWPWR_CTRL_TOG_STOP_MODE_CONFIG_MASK)
#define PMU_LOWPWR_CTRL_TOG_RSVD0_MASK           (0xFCU)
#define PMU_LOWPWR_CTRL_TOG_RSVD0_SHIFT          (2U)
#define PMU_LOWPWR_CTRL_TOG_RSVD0(x)             (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_TOG_RSVD0_SHIFT)) & PMU_LOWPWR_CTRL_TOG_RSVD0_MASK)
#define PMU_LOWPWR_CTRL_TOG_L1_PWRGATE_MASK      (0x100U)
#define PMU_LOWPWR_CTRL_TOG_L1_PWRGATE_SHIFT     (8U)
#define PMU_LOWPWR_CTRL_TOG_L2_PWRGATE_MASK      (0x200U)
#define PMU_LOWPWR_CTRL_TOG_L2_PWRGATE_SHIFT     (9U)
#define PMU_LOWPWR_CTRL_TOG_CPU_PWRGATE_MASK     (0x400U)
#define PMU_LOWPWR_CTRL_TOG_CPU_PWRGATE_SHIFT    (10U)
#define PMU_LOWPWR_CTRL_TOG_DISPLAY_PWRGATE_MASK (0x800U)
#define PMU_LOWPWR_CTRL_TOG_DISPLAY_PWRGATE_SHIFT (11U)
#define PMU_LOWPWR_CTRL_TOG_MIX_PWRGATE_MASK     (0x1000U)
#define PMU_LOWPWR_CTRL_TOG_MIX_PWRGATE_SHIFT    (12U)
#define PMU_LOWPWR_CTRL_TOG_GPU_PWRGATE_MASK     (0x2000U)
#define PMU_LOWPWR_CTRL_TOG_GPU_PWRGATE_SHIFT    (13U)
#define PMU_LOWPWR_CTRL_TOG_CONTROL0_MASK        (0xFFC000U)
#define PMU_LOWPWR_CTRL_TOG_CONTROL0_SHIFT       (14U)
#define PMU_LOWPWR_CTRL_TOG_CONTROL0(x)          (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_TOG_CONTROL0_SHIFT)) & PMU_LOWPWR_CTRL_TOG_CONTROL0_MASK)
#define PMU_LOWPWR_CTRL_TOG_CONTROL1_MASK        (0xFF000000U)
#define PMU_LOWPWR_CTRL_TOG_CONTROL1_SHIFT       (24U)
#define PMU_LOWPWR_CTRL_TOG_CONTROL1(x)          (((uint32_t)(((uint32_t)(x)) << PMU_LOWPWR_CTRL_TOG_CONTROL1_SHIFT)) & PMU_LOWPWR_CTRL_TOG_CONTROL1_MASK)


/*!
 * @}
 */ /* end of group PMU_Register_Masks */


/* PMU - Peripheral instance base addresses */
/** Peripheral PMU base pointer */
#define PMU_BASE_PTR                             ((PMU_MemMapPtr)0x30360200u)
/** Array initializer of PMU peripheral base pointers */
#define PMU_BASE_PTRS                            { PMU_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- PMU - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PMU_Register_Accessor_Macros PMU - Register accessor macros
 * @{
 */


/* PMU - Register instance definitions */
/* PMU */
#define PMU_REG_1P0A                             PMU_REG_1P0A_REG(PMU_BASE_PTR)
#define PMU_REG_1P0A_SET                         PMU_REG_1P0A_SET_REG(PMU_BASE_PTR)
#define PMU_REG_1P0A_CLR                         PMU_REG_1P0A_CLR_REG(PMU_BASE_PTR)
#define PMU_REG_1P0A_TOG                         PMU_REG_1P0A_TOG_REG(PMU_BASE_PTR)
#define PMU_REG_1P0D                             PMU_REG_1P0D_REG(PMU_BASE_PTR)
#define PMU_REG_1P0D_SET                         PMU_REG_1P0D_SET_REG(PMU_BASE_PTR)
#define PMU_REG_1P0D_CLR                         PMU_REG_1P0D_CLR_REG(PMU_BASE_PTR)
#define PMU_REG_1P0D_TOG                         PMU_REG_1P0D_TOG_REG(PMU_BASE_PTR)
#define PMU_REG_HSIC_1P2                         PMU_REG_HSIC_1P2_REG(PMU_BASE_PTR)
#define PMU_REG_HSIC_1P2_SET                     PMU_REG_HSIC_1P2_SET_REG(PMU_BASE_PTR)
#define PMU_REG_HSIC_1P2_CLR                     PMU_REG_HSIC_1P2_CLR_REG(PMU_BASE_PTR)
#define PMU_REG_HSIC_1P2_TOG                     PMU_REG_HSIC_1P2_TOG_REG(PMU_BASE_PTR)
#define PMU_REG_LPSR_1P0                         PMU_REG_LPSR_1P0_REG(PMU_BASE_PTR)
#define PMU_REG_LPSR_1P0_SET                     PMU_REG_LPSR_1P0_SET_REG(PMU_BASE_PTR)
#define PMU_REG_LPSR_1P0_CLR                     PMU_REG_LPSR_1P0_CLR_REG(PMU_BASE_PTR)
#define PMU_REG_LPSR_1P0_TOG                     PMU_REG_LPSR_1P0_TOG_REG(PMU_BASE_PTR)
#define PMU_REF                                  PMU_REF_REG(PMU_BASE_PTR)
#define PMU_REF_SET                              PMU_REF_SET_REG(PMU_BASE_PTR)
#define PMU_REF_CLR                              PMU_REF_CLR_REG(PMU_BASE_PTR)
#define PMU_REF_TOG                              PMU_REF_TOG_REG(PMU_BASE_PTR)
#define PMU_LOWPWR_CTRL                          PMU_LOWPWR_CTRL_REG(PMU_BASE_PTR)
#define PMU_LOWPWR_CTRL_SET                      PMU_LOWPWR_CTRL_SET_REG(PMU_BASE_PTR)
#define PMU_LOWPWR_CTRL_CLR                      PMU_LOWPWR_CTRL_CLR_REG(PMU_BASE_PTR)
#define PMU_LOWPWR_CTRL_TOG                      PMU_LOWPWR_CTRL_TOG_REG(PMU_BASE_PTR)

/*!
 * @}
 */ /* end of group PMU_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group PMU_Peripheral */


/* ----------------------------------------------------------------------------
   -- PWM
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PWM_Peripheral PWM
 * @{
 */

/** PWM - Peripheral register structure */
typedef struct PWM_MemMap {
  uint32_t PWMCR;                                  /**< PWM Control Register, offset: 0x0 */
  uint32_t PWMSR;                                  /**< PWM Status Register, offset: 0x4 */
  uint32_t PWMIR;                                  /**< PWM Interrupt Register, offset: 0x8 */
  uint32_t PWMSAR;                                 /**< PWM Sample Register, offset: 0xC */
  uint32_t PWMPR;                                  /**< PWM Period Register, offset: 0x10 */
  uint32_t PWMCNR;                                 /**< PWM Counter Register, offset: 0x14 */
} volatile *PWM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- PWM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PWM_Register_Accessor_Macros PWM - Register accessor macros
 * @{
 */


/* PWM - Register accessors */
#define PWM_PWMCR_REG(base)                      ((base)->PWMCR)
#define PWM_PWMSR_REG(base)                      ((base)->PWMSR)
#define PWM_PWMIR_REG(base)                      ((base)->PWMIR)
#define PWM_PWMSAR_REG(base)                     ((base)->PWMSAR)
#define PWM_PWMPR_REG(base)                      ((base)->PWMPR)
#define PWM_PWMCNR_REG(base)                     ((base)->PWMCNR)

/*!
 * @}
 */ /* end of group PWM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- PWM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PWM_Register_Masks PWM Register Masks
 * @{
 */

/*! @name PWMCR - PWM Control Register */
#define PWM_PWMCR_EN_MASK                        (0x1U)
#define PWM_PWMCR_EN_SHIFT                       (0U)
#define PWM_PWMCR_REPEAT_MASK                    (0x6U)
#define PWM_PWMCR_REPEAT_SHIFT                   (1U)
#define PWM_PWMCR_REPEAT(x)                      (((uint32_t)(((uint32_t)(x)) << PWM_PWMCR_REPEAT_SHIFT)) & PWM_PWMCR_REPEAT_MASK)
#define PWM_PWMCR_SWR_MASK                       (0x8U)
#define PWM_PWMCR_SWR_SHIFT                      (3U)
#define PWM_PWMCR_PRESCALER_MASK                 (0xFFF0U)
#define PWM_PWMCR_PRESCALER_SHIFT                (4U)
#define PWM_PWMCR_PRESCALER(x)                   (((uint32_t)(((uint32_t)(x)) << PWM_PWMCR_PRESCALER_SHIFT)) & PWM_PWMCR_PRESCALER_MASK)
#define PWM_PWMCR_CLKSRC_MASK                    (0x30000U)
#define PWM_PWMCR_CLKSRC_SHIFT                   (16U)
#define PWM_PWMCR_CLKSRC(x)                      (((uint32_t)(((uint32_t)(x)) << PWM_PWMCR_CLKSRC_SHIFT)) & PWM_PWMCR_CLKSRC_MASK)
#define PWM_PWMCR_POUTC_MASK                     (0xC0000U)
#define PWM_PWMCR_POUTC_SHIFT                    (18U)
#define PWM_PWMCR_POUTC(x)                       (((uint32_t)(((uint32_t)(x)) << PWM_PWMCR_POUTC_SHIFT)) & PWM_PWMCR_POUTC_MASK)
#define PWM_PWMCR_HCTR_MASK                      (0x100000U)
#define PWM_PWMCR_HCTR_SHIFT                     (20U)
#define PWM_PWMCR_BCTR_MASK                      (0x200000U)
#define PWM_PWMCR_BCTR_SHIFT                     (21U)
#define PWM_PWMCR_DBGEN_MASK                     (0x400000U)
#define PWM_PWMCR_DBGEN_SHIFT                    (22U)
#define PWM_PWMCR_WAITEN_MASK                    (0x800000U)
#define PWM_PWMCR_WAITEN_SHIFT                   (23U)
#define PWM_PWMCR_DOZEN_MASK                     (0x1000000U)
#define PWM_PWMCR_DOZEN_SHIFT                    (24U)
#define PWM_PWMCR_STOPEN_MASK                    (0x2000000U)
#define PWM_PWMCR_STOPEN_SHIFT                   (25U)
#define PWM_PWMCR_FWM_MASK                       (0xC000000U)
#define PWM_PWMCR_FWM_SHIFT                      (26U)
#define PWM_PWMCR_FWM(x)                         (((uint32_t)(((uint32_t)(x)) << PWM_PWMCR_FWM_SHIFT)) & PWM_PWMCR_FWM_MASK)

/*! @name PWMSR - PWM Status Register */
#define PWM_PWMSR_FIFOAV_MASK                    (0x7U)
#define PWM_PWMSR_FIFOAV_SHIFT                   (0U)
#define PWM_PWMSR_FIFOAV(x)                      (((uint32_t)(((uint32_t)(x)) << PWM_PWMSR_FIFOAV_SHIFT)) & PWM_PWMSR_FIFOAV_MASK)
#define PWM_PWMSR_FE_MASK                        (0x8U)
#define PWM_PWMSR_FE_SHIFT                       (3U)
#define PWM_PWMSR_ROV_MASK                       (0x10U)
#define PWM_PWMSR_ROV_SHIFT                      (4U)
#define PWM_PWMSR_CMP_MASK                       (0x20U)
#define PWM_PWMSR_CMP_SHIFT                      (5U)
#define PWM_PWMSR_FWE_MASK                       (0x40U)
#define PWM_PWMSR_FWE_SHIFT                      (6U)

/*! @name PWMIR - PWM Interrupt Register */
#define PWM_PWMIR_FIE_MASK                       (0x1U)
#define PWM_PWMIR_FIE_SHIFT                      (0U)
#define PWM_PWMIR_RIE_MASK                       (0x2U)
#define PWM_PWMIR_RIE_SHIFT                      (1U)
#define PWM_PWMIR_CIE_MASK                       (0x4U)
#define PWM_PWMIR_CIE_SHIFT                      (2U)

/*! @name PWMSAR - PWM Sample Register */
#define PWM_PWMSAR_SAMPLE_MASK                   (0xFFFFU)
#define PWM_PWMSAR_SAMPLE_SHIFT                  (0U)
#define PWM_PWMSAR_SAMPLE(x)                     (((uint32_t)(((uint32_t)(x)) << PWM_PWMSAR_SAMPLE_SHIFT)) & PWM_PWMSAR_SAMPLE_MASK)

/*! @name PWMPR - PWM Period Register */
#define PWM_PWMPR_PERIOD_MASK                    (0xFFFFU)
#define PWM_PWMPR_PERIOD_SHIFT                   (0U)
#define PWM_PWMPR_PERIOD(x)                      (((uint32_t)(((uint32_t)(x)) << PWM_PWMPR_PERIOD_SHIFT)) & PWM_PWMPR_PERIOD_MASK)

/*! @name PWMCNR - PWM Counter Register */
#define PWM_PWMCNR_COUNT_MASK                    (0xFFFFU)
#define PWM_PWMCNR_COUNT_SHIFT                   (0U)
#define PWM_PWMCNR_COUNT(x)                      (((uint32_t)(((uint32_t)(x)) << PWM_PWMCNR_COUNT_SHIFT)) & PWM_PWMCNR_COUNT_MASK)


/*!
 * @}
 */ /* end of group PWM_Register_Masks */


/* PWM - Peripheral instance base addresses */
/** Peripheral PWM1 base pointer */
#define PWM1_BASE_PTR                            ((PWM_MemMapPtr)0x30660000u)
/** Peripheral PWM2 base pointer */
#define PWM2_BASE_PTR                            ((PWM_MemMapPtr)0x30670000u)
/** Peripheral PWM3 base pointer */
#define PWM3_BASE_PTR                            ((PWM_MemMapPtr)0x30680000u)
/** Peripheral PWM4 base pointer */
#define PWM4_BASE_PTR                            ((PWM_MemMapPtr)0x30690000u)
/** Array initializer of PWM peripheral base pointers */
#define PWM_BASE_PTRS                            { PWM1_BASE_PTR, PWM2_BASE_PTR, PWM3_BASE_PTR, PWM4_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- PWM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PWM_Register_Accessor_Macros PWM - Register accessor macros
 * @{
 */


/* PWM - Register instance definitions */
/* PWM1 */
#define PWM1_PWMCR                               PWM_PWMCR_REG(PWM1_BASE_PTR)
#define PWM1_PWMSR                               PWM_PWMSR_REG(PWM1_BASE_PTR)
#define PWM1_PWMIR                               PWM_PWMIR_REG(PWM1_BASE_PTR)
#define PWM1_PWMSAR                              PWM_PWMSAR_REG(PWM1_BASE_PTR)
#define PWM1_PWMPR                               PWM_PWMPR_REG(PWM1_BASE_PTR)
#define PWM1_PWMCNR                              PWM_PWMCNR_REG(PWM1_BASE_PTR)
/* PWM2 */
#define PWM2_PWMCR                               PWM_PWMCR_REG(PWM2_BASE_PTR)
#define PWM2_PWMSR                               PWM_PWMSR_REG(PWM2_BASE_PTR)
#define PWM2_PWMIR                               PWM_PWMIR_REG(PWM2_BASE_PTR)
#define PWM2_PWMSAR                              PWM_PWMSAR_REG(PWM2_BASE_PTR)
#define PWM2_PWMPR                               PWM_PWMPR_REG(PWM2_BASE_PTR)
#define PWM2_PWMCNR                              PWM_PWMCNR_REG(PWM2_BASE_PTR)
/* PWM3 */
#define PWM3_PWMCR                               PWM_PWMCR_REG(PWM3_BASE_PTR)
#define PWM3_PWMSR                               PWM_PWMSR_REG(PWM3_BASE_PTR)
#define PWM3_PWMIR                               PWM_PWMIR_REG(PWM3_BASE_PTR)
#define PWM3_PWMSAR                              PWM_PWMSAR_REG(PWM3_BASE_PTR)
#define PWM3_PWMPR                               PWM_PWMPR_REG(PWM3_BASE_PTR)
#define PWM3_PWMCNR                              PWM_PWMCNR_REG(PWM3_BASE_PTR)
/* PWM4 */
#define PWM4_PWMCR                               PWM_PWMCR_REG(PWM4_BASE_PTR)
#define PWM4_PWMSR                               PWM_PWMSR_REG(PWM4_BASE_PTR)
#define PWM4_PWMIR                               PWM_PWMIR_REG(PWM4_BASE_PTR)
#define PWM4_PWMSAR                              PWM_PWMSAR_REG(PWM4_BASE_PTR)
#define PWM4_PWMPR                               PWM_PWMPR_REG(PWM4_BASE_PTR)
#define PWM4_PWMCNR                              PWM_PWMCNR_REG(PWM4_BASE_PTR)

/*!
 * @}
 */ /* end of group PWM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group PWM_Peripheral */


/* ----------------------------------------------------------------------------
   -- PXP
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PXP_Peripheral PXP
 * @{
 */

/** PXP - Peripheral register structure */
typedef struct PXP_MemMap {
  uint32_t HW_PXP_CTRL;                            /**< Control Register 0, offset: 0x0 */
  uint8_t RESERVED_0[12];
  uint32_t HW_PXP_STAT;                            /**< Status Register, offset: 0x10 */
  uint8_t RESERVED_1[12];
  uint32_t HW_PXP_OUT_CTRL;                        /**< Output Buffer Control Register, offset: 0x20 */
  uint8_t RESERVED_2[12];
  uint32_t HW_PXP_OUT_BUF;                         /**< Output Frame Buffer Pointer, offset: 0x30 */
  uint8_t RESERVED_3[12];
  uint32_t HW_PXP_OUT_BUF2;                        /**< Output Frame Buffer Pointer #2, offset: 0x40 */
  uint8_t RESERVED_4[12];
  uint32_t HW_PXP_OUT_PITCH;                       /**< Output Buffer Pitch, offset: 0x50 */
  uint8_t RESERVED_5[12];
  uint32_t HW_PXP_OUT_LRC;                         /**< Output Surface Lower Right Coordinate, offset: 0x60 */
  uint8_t RESERVED_6[12];
  uint32_t HW_PXP_OUT_PS_ULC;                      /**< Processed Surface Upper Left Coordinate, offset: 0x70 */
  uint8_t RESERVED_7[12];
  uint32_t HW_PXP_OUT_PS_LRC;                      /**< Processed Surface Lower Right Coordinate, offset: 0x80 */
  uint8_t RESERVED_8[12];
  uint32_t HW_PXP_OUT_AS_ULC;                      /**< Alpha Surface Upper Left Coordinate, offset: 0x90 */
  uint8_t RESERVED_9[12];
  uint32_t HW_PXP_OUT_AS_LRC;                      /**< Alpha Surface Lower Right Coordinate, offset: 0xA0 */
  uint8_t RESERVED_10[12];
  uint32_t HW_PXP_PS_CTRL;                         /**< Processed Surface (PS) Control Register, offset: 0xB0 */
  uint8_t RESERVED_11[12];
  uint32_t HW_PXP_PS_BUF;                          /**< PS Input Buffer Address, offset: 0xC0 */
  uint8_t RESERVED_12[12];
  uint32_t HW_PXP_PS_UBUF;                         /**< PS U/Cb or 2 Plane UV Input Buffer Address, offset: 0xD0 */
  uint8_t RESERVED_13[12];
  uint32_t HW_PXP_PS_VBUF;                         /**< PS V/Cr Input Buffer Address, offset: 0xE0 */
  uint8_t RESERVED_14[12];
  uint32_t HW_PXP_PS_PITCH;                        /**< Processed Surface Pitch, offset: 0xF0 */
  uint8_t RESERVED_15[12];
  uint32_t HW_PXP_PS_BACKGROUND_0;                 /**< PS Background Color, offset: 0x100 */
  uint8_t RESERVED_16[12];
  uint32_t HW_PXP_PS_SCALE;                        /**< PS Scale Factor Register, offset: 0x110 */
  uint8_t RESERVED_17[12];
  uint32_t HW_PXP_PS_OFFSET;                       /**< PS Scale Offset Register, offset: 0x120 */
  uint8_t RESERVED_18[12];
  uint32_t HW_PXP_PS_CLRKEYLOW_0;                  /**< PS Color Key Low, offset: 0x130 */
  uint8_t RESERVED_19[12];
  uint32_t HW_PXP_PS_CLRKEYHIGH_0;                 /**< PS Color Key High, offset: 0x140 */
  uint8_t RESERVED_20[12];
  uint32_t HW_PXP_AS_CTRL;                         /**< Alpha Surface Control, offset: 0x150 */
  uint8_t RESERVED_21[12];
  uint32_t HW_PXP_AS_BUF;                          /**< Alpha Surface Buffer Pointer, offset: 0x160 */
  uint8_t RESERVED_22[12];
  uint32_t HW_PXP_AS_PITCH;                        /**< Alpha Surface Pitch, offset: 0x170 */
  uint8_t RESERVED_23[12];
  uint32_t HW_PXP_AS_CLRKEYLOW_0;                  /**< Overlay Color Key Low, offset: 0x180 */
  uint8_t RESERVED_24[12];
  uint32_t HW_PXP_AS_CLRKEYHIGH_0;                 /**< Overlay Color Key High, offset: 0x190 */
  uint8_t RESERVED_25[12];
  uint32_t HW_PXP_CSC1_COEF0;                      /**< Color Space Conversion Coefficient Register 0, offset: 0x1A0 */
  uint8_t RESERVED_26[12];
  uint32_t HW_PXP_CSC1_COEF1;                      /**< Color Space Conversion Coefficient Register 1, offset: 0x1B0 */
  uint8_t RESERVED_27[12];
  uint32_t HW_PXP_CSC1_COEF2;                      /**< Color Space Conversion Coefficient Register 2, offset: 0x1C0 */
  uint8_t RESERVED_28[12];
  uint32_t HW_PXP_CSC2_CTRL;                       /**< Color Space Conversion Control Register., offset: 0x1D0 */
  uint8_t RESERVED_29[12];
  uint32_t HW_PXP_CSC2_COEF0;                      /**< Color Space Conversion Coefficient Register 0, offset: 0x1E0 */
  uint8_t RESERVED_30[12];
  uint32_t HW_PXP_CSC2_COEF1;                      /**< Color Space Conversion Coefficient Register 1, offset: 0x1F0 */
  uint8_t RESERVED_31[12];
  uint32_t HW_PXP_CSC2_COEF2;                      /**< Color Space Conversion Coefficient Register 2, offset: 0x200 */
  uint8_t RESERVED_32[12];
  uint32_t HW_PXP_CSC2_COEF3;                      /**< Color Space Conversion Coefficient Register 3, offset: 0x210 */
  uint8_t RESERVED_33[12];
  uint32_t HW_PXP_CSC2_COEF4;                      /**< Color Space Conversion Coefficient Register 4, offset: 0x220 */
  uint8_t RESERVED_34[12];
  uint32_t HW_PXP_CSC2_COEF5;                      /**< Color Space Conversion Coefficient Register 5, offset: 0x230 */
  uint8_t RESERVED_35[12];
  uint32_t HW_PXP_LUT_CTRL;                        /**< Lookup Table Control Register., offset: 0x240 */
  uint8_t RESERVED_36[12];
  uint32_t HW_PXP_LUT_ADDR;                        /**< Lookup Table Control Register., offset: 0x250 */
  uint8_t RESERVED_37[12];
  uint32_t HW_PXP_LUT_DATA;                        /**< Lookup Table Data Register., offset: 0x260 */
  uint8_t RESERVED_38[12];
  uint32_t HW_PXP_LUT_EXTMEM;                      /**< Lookup Table External Memory Address Register., offset: 0x270 */
  uint8_t RESERVED_39[12];
  uint32_t HW_PXP_CFA;                             /**< Color Filter Array Register., offset: 0x280 */
  uint8_t RESERVED_40[12];
  uint32_t HW_PXP_ALPHA_A_CTRL;                    /**< PXP Alpha Engine A Control Register., offset: 0x290 */
  uint8_t RESERVED_41[12];
  uint32_t HW_PXP_ALPHA_B_CTRL;                    /**< PXP Alpha Engine B Control Register., offset: 0x2A0 */
  uint8_t RESERVED_42[12];
  uint32_t HW_PXP_ALPHA_B_CTRL_1;                  /**< , offset: 0x2B0 */
  uint8_t RESERVED_43[12];
  uint32_t HW_PXP_PS_BACKGROUND_1;                 /**< PS Background Color 1, offset: 0x2C0 */
  uint8_t RESERVED_44[12];
  uint32_t HW_PXP_PS_CLRKEYLOW_1;                  /**< PS Color Key Low 1, offset: 0x2D0 */
  uint8_t RESERVED_45[12];
  uint32_t HW_PXP_PS_CLRKEYHIGH_1;                 /**< PS Color Key High 1, offset: 0x2E0 */
  uint8_t RESERVED_46[12];
  uint32_t HW_PXP_AS_CLRKEYLOW_1;                  /**< Overlay Color Key Low, offset: 0x2F0 */
  uint8_t RESERVED_47[12];
  uint32_t HW_PXP_AS_CLRKEYHIGH_1;                 /**< Overlay Color Key High, offset: 0x300 */
  uint8_t RESERVED_48[12];
  uint32_t HW_PXP_CTRL2;                           /**< Control Register 2, offset: 0x310 */
  uint8_t RESERVED_49[12];
  uint32_t HW_PXP_POWER_REG0;                      /**< PXP Power Control Register., offset: 0x320 */
  uint8_t RESERVED_50[12];
  uint32_t HW_PXP_POWER_REG1;                      /**< PXP Power Control Register 1., offset: 0x330 */
  uint8_t RESERVED_51[28];
  uint32_t HW_PXP_DATA_PATH_CTRL1;                 /**< , offset: 0x350 */
  uint8_t RESERVED_52[12];
  uint32_t HW_PXP_INIT_MEM_CTRL;                   /**< Initialize memory buffer control Register, offset: 0x360 */
  uint8_t RESERVED_53[12];
  uint32_t HW_PXP_INIT_MEM_DATA;                   /**< Write data Register, offset: 0x370 */
  uint8_t RESERVED_54[12];
  uint32_t HW_PXP_INIT_MEM_DATA_HIGH;              /**< Write data Register, offset: 0x380 */
  uint8_t RESERVED_55[12];
  uint32_t HW_PXP_IRQ_MASK;                        /**< PXP IRQ Mask Register, offset: 0x390 */
  uint8_t RESERVED_56[12];
  uint32_t HW_PXP_IRQ;                             /**< PXP Interrupt Register, offset: 0x3A0 */
  uint8_t RESERVED_57[92];
  uint32_t HW_PXP_NEXT;                            /**< Next Frame Pointer, offset: 0x400 */
  uint8_t RESERVED_58[76];
  uint32_t HW_PXP_INPUT_FETCH_CTRL_CH0;            /**< Pre-fetch engine Control Channel 0 Register, offset: 0x450 */
  uint8_t RESERVED_59[12];
  uint32_t HW_PXP_INPUT_FETCH_CTRL_CH1;            /**< Pre-fetch engine Control Channel 1 Register, offset: 0x460 */
  uint8_t RESERVED_60[12];
  uint32_t HW_PXP_INPUT_FETCH_STATUS_CH0;          /**< Pre-fetch engine status Channel 0 Register, offset: 0x470 */
  uint8_t RESERVED_61[12];
  uint32_t HW_PXP_INPUT_FETCH_STATUS_CH1;          /**< Store engine status Channel 1 Register, offset: 0x480 */
  uint8_t RESERVED_62[12];
  uint32_t HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0; /**< , offset: 0x490 */
  uint8_t RESERVED_63[12];
  uint32_t HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0; /**< , offset: 0x4A0 */
  uint8_t RESERVED_64[12];
  uint32_t HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1; /**< , offset: 0x4B0 */
  uint8_t RESERVED_65[12];
  uint32_t HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1; /**< , offset: 0x4C0 */
  uint8_t RESERVED_66[12];
  uint32_t HW_PXP_INPUT_FETCH_SIZE_CH0;            /**< , offset: 0x4D0 */
  uint8_t RESERVED_67[12];
  uint32_t HW_PXP_INPUT_FETCH_SIZE_CH1;            /**< , offset: 0x4E0 */
  uint8_t RESERVED_68[12];
  uint32_t HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0; /**< , offset: 0x4F0 */
  uint8_t RESERVED_69[12];
  uint32_t HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1; /**< , offset: 0x500 */
  uint8_t RESERVED_70[12];
  uint32_t HW_PXP_INPUT_FETCH_PITCH;               /**< , offset: 0x510 */
  uint8_t RESERVED_71[12];
  uint32_t HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0;      /**< , offset: 0x520 */
  uint8_t RESERVED_72[12];
  uint32_t HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1;      /**< , offset: 0x530 */
  uint8_t RESERVED_73[12];
  uint32_t HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0;    /**< , offset: 0x540 */
  uint8_t RESERVED_74[12];
  uint32_t HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1;    /**< , offset: 0x550 */
  uint8_t RESERVED_75[12];
  uint32_t HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0;     /**< , offset: 0x560 */
  uint8_t RESERVED_76[12];
  uint32_t HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1;     /**< , offset: 0x570 */
  uint8_t RESERVED_77[12];
  uint32_t HW_PXP_INPUT_FETCH_ADDR_0_CH0;          /**< , offset: 0x580 */
  uint8_t RESERVED_78[12];
  uint32_t HW_PXP_INPUT_FETCH_ADDR_1_CH0;          /**< , offset: 0x590 */
  uint8_t RESERVED_79[12];
  uint32_t HW_PXP_INPUT_FETCH_ADDR_0_CH1;          /**< , offset: 0x5A0 */
  uint8_t RESERVED_80[12];
  uint32_t HW_PXP_INPUT_FETCH_ADDR_1_CH1;          /**< , offset: 0x5B0 */
  uint8_t RESERVED_81[12];
  uint32_t HW_PXP_INPUT_STORE_CTRL_CH0;            /**< Store engine Control Channel 0 Register, offset: 0x5C0 */
  uint8_t RESERVED_82[12];
  uint32_t HW_PXP_INPUT_STORE_CTRL_CH1;            /**< Store engine Control Channel 1 Register, offset: 0x5D0 */
  uint8_t RESERVED_83[12];
  uint32_t HW_PXP_INPUT_STORE_STATUS_CH0;          /**< Store engine status Channel 0 Register, offset: 0x5E0 */
  uint8_t RESERVED_84[12];
  uint32_t HW_PXP_INPUT_STORE_STATUS_CH1;          /**< Store engine status Channel 1 Register, offset: 0x5F0 */
  uint8_t RESERVED_85[12];
  uint32_t HW_PXP_INPUT_STORE_SIZE_CH0;            /**< , offset: 0x600 */
  uint8_t RESERVED_86[12];
  uint32_t HW_PXP_INPUT_STORE_SIZE_CH1;            /**< , offset: 0x610 */
  uint8_t RESERVED_87[12];
  uint32_t HW_PXP_INPUT_STORE_PITCH;               /**< , offset: 0x620 */
  uint8_t RESERVED_88[12];
  uint32_t HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0;      /**< , offset: 0x630 */
  uint8_t RESERVED_89[12];
  uint32_t HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1;      /**< , offset: 0x640 */
  uint8_t RESERVED_90[76];
  uint32_t HW_PXP_INPUT_STORE_ADDR_0_CH0;          /**< , offset: 0x690 */
  uint8_t RESERVED_91[12];
  uint32_t HW_PXP_INPUT_STORE_ADDR_1_CH0;          /**< , offset: 0x6A0 */
  uint8_t RESERVED_92[12];
  uint32_t HW_PXP_INPUT_STORE_FILL_DATA_CH0;       /**< , offset: 0x6B0 */
  uint8_t RESERVED_93[12];
  uint32_t HW_PXP_INPUT_STORE_ADDR_0_CH1;          /**< , offset: 0x6C0 */
  uint8_t RESERVED_94[12];
  uint32_t HW_PXP_INPUT_STORE_ADDR_1_CH1;          /**< , offset: 0x6D0 */
  uint8_t RESERVED_95[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK0_H_CH0;       /**< , offset: 0x6E0 */
  uint8_t RESERVED_96[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK0_L_CH0;       /**< , offset: 0x6F0 */
  uint8_t RESERVED_97[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK1_H_CH0;       /**< , offset: 0x700 */
  uint8_t RESERVED_98[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK1_L_CH0;       /**< , offset: 0x710 */
  uint8_t RESERVED_99[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK2_H_CH0;       /**< , offset: 0x720 */
  uint8_t RESERVED_100[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK2_L_CH0;       /**< , offset: 0x730 */
  uint8_t RESERVED_101[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK3_H_CH0;       /**< , offset: 0x740 */
  uint8_t RESERVED_102[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK3_L_CH0;       /**< , offset: 0x750 */
  uint8_t RESERVED_103[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK4_H_CH0;       /**< , offset: 0x760 */
  uint8_t RESERVED_104[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK4_L_CH0;       /**< , offset: 0x770 */
  uint8_t RESERVED_105[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK5_H_CH0;       /**< , offset: 0x780 */
  uint8_t RESERVED_106[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK5_L_CH0;       /**< , offset: 0x790 */
  uint8_t RESERVED_107[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK6_H_CH0;       /**< , offset: 0x7A0 */
  uint8_t RESERVED_108[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK6_L_CH0;       /**< , offset: 0x7B0 */
  uint8_t RESERVED_109[12];
  uint32_t HW_PXP_INPUT_STORE_D_MASK7_H_CH0;       /**< , offset: 0x7C0 */
  uint8_t RESERVED_110[28];
  uint32_t HW_PXP_INPUT_STORE_D_MASK7_L_CH0;       /**< , offset: 0x7E0 */
  uint8_t RESERVED_111[12];
  uint32_t HW_PXP_INPUT_STORE_D_SHIFT_L_CH0;       /**< , offset: 0x7F0 */
  uint8_t RESERVED_112[12];
  uint32_t HW_PXP_INPUT_STORE_D_SHIFT_H_CH0;       /**< , offset: 0x800 */
  uint8_t RESERVED_113[12];
  uint32_t HW_PXP_INPUT_STORE_F_SHIFT_L_CH0;       /**< , offset: 0x810 */
  uint8_t RESERVED_114[12];
  uint32_t HW_PXP_INPUT_STORE_F_SHIFT_H_CH0;       /**< , offset: 0x820 */
  uint8_t RESERVED_115[12];
  uint32_t HW_PXP_INPUT_STORE_F_MASK_L_CH0;        /**< , offset: 0x830 */
  uint8_t RESERVED_116[12];
  uint32_t HW_PXP_INPUT_STORE_F_MASK_H_CH0;        /**< , offset: 0x840 */
  uint8_t RESERVED_117[12];
  uint32_t HW_PXP_DITHER_FETCH_CTRL_CH0;           /**< Pre-fetch engine Control Channel 0 Register, offset: 0x850 */
  uint8_t RESERVED_118[12];
  uint32_t HW_PXP_DITHER_FETCH_CTRL_CH1;           /**< Pre-fetch engine Control Channel 1 Register, offset: 0x860 */
  uint8_t RESERVED_119[12];
  uint32_t HW_PXP_DITHER_FETCH_STATUS_CH0;         /**< Pre-fetch engine status Channel 0 Register, offset: 0x870 */
  uint8_t RESERVED_120[12];
  uint32_t HW_PXP_DITHER_FETCH_STATUS_CH1;         /**< Store engine status Channel 1 Register, offset: 0x880 */
  uint8_t RESERVED_121[12];
  uint32_t HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0; /**< , offset: 0x890 */
  uint8_t RESERVED_122[12];
  uint32_t HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0; /**< , offset: 0x8A0 */
  uint8_t RESERVED_123[12];
  uint32_t HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1; /**< , offset: 0x8B0 */
  uint8_t RESERVED_124[12];
  uint32_t HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1; /**< , offset: 0x8C0 */
  uint8_t RESERVED_125[12];
  uint32_t HW_PXP_DITHER_FETCH_SIZE_CH0;           /**< , offset: 0x8D0 */
  uint8_t RESERVED_126[12];
  uint32_t HW_PXP_DITHER_FETCH_SIZE_CH1;           /**< , offset: 0x8E0 */
  uint8_t RESERVED_127[12];
  uint32_t HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0; /**< , offset: 0x8F0 */
  uint8_t RESERVED_128[12];
  uint32_t HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1; /**< , offset: 0x900 */
  uint8_t RESERVED_129[12];
  uint32_t HW_PXP_DITHER_FETCH_PITCH;              /**< , offset: 0x910 */
  uint8_t RESERVED_130[12];
  uint32_t HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0;     /**< , offset: 0x920 */
  uint8_t RESERVED_131[12];
  uint32_t HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1;     /**< , offset: 0x930 */
  uint8_t RESERVED_132[12];
  uint32_t HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0;   /**< , offset: 0x940 */
  uint8_t RESERVED_133[12];
  uint32_t HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1;   /**< , offset: 0x950 */
  uint8_t RESERVED_134[12];
  uint32_t HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0;    /**< , offset: 0x960 */
  uint8_t RESERVED_135[12];
  uint32_t HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1;    /**< , offset: 0x970 */
  uint8_t RESERVED_136[12];
  uint32_t HW_PXP_DITHER_FETCH_ADDR_0_CH0;         /**< , offset: 0x980 */
  uint8_t RESERVED_137[12];
  uint32_t HW_PXP_DITHER_FETCH_ADDR_1_CH0;         /**< , offset: 0x990 */
  uint8_t RESERVED_138[12];
  uint32_t HW_PXP_DITHER_FETCH_ADDR_0_CH1;         /**< , offset: 0x9A0 */
  uint8_t RESERVED_139[12];
  uint32_t HW_PXP_DITHER_FETCH_ADDR_1_CH1;         /**< , offset: 0x9B0 */
  uint8_t RESERVED_140[12];
  uint32_t HW_PXP_DITHER_STORE_CTRL_CH0;           /**< Store engine Control Channel 0 Register, offset: 0x9C0 */
  uint8_t RESERVED_141[12];
  uint32_t HW_PXP_DITHER_STORE_CTRL_CH1;           /**< Store engine Control Channel 1 Register, offset: 0x9D0 */
  uint8_t RESERVED_142[12];
  uint32_t HW_PXP_DITHER_STORE_STATUS_CH0;         /**< Store engine status Channel 0 Register, offset: 0x9E0 */
  uint8_t RESERVED_143[12];
  uint32_t HW_PXP_DITHER_STORE_STATUS_CH1;         /**< Store engine status Channel 1 Register, offset: 0x9F0 */
  uint8_t RESERVED_144[12];
  uint32_t HW_PXP_DITHER_STORE_SIZE_CH0;           /**< , offset: 0xA00 */
  uint8_t RESERVED_145[12];
  uint32_t HW_PXP_DITHER_STORE_SIZE_CH1;           /**< , offset: 0xA10 */
  uint8_t RESERVED_146[12];
  uint32_t HW_PXP_DITHER_STORE_PITCH;              /**< , offset: 0xA20 */
  uint8_t RESERVED_147[12];
  uint32_t HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0;     /**< , offset: 0xA30 */
  uint8_t RESERVED_148[12];
  uint32_t HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1;     /**< , offset: 0xA40 */
  uint8_t RESERVED_149[76];
  uint32_t HW_PXP_DITHER_STORE_ADDR_0_CH0;         /**< , offset: 0xA90 */
  uint8_t RESERVED_150[12];
  uint32_t HW_PXP_DITHER_STORE_ADDR_1_CH0;         /**< , offset: 0xAA0 */
  uint8_t RESERVED_151[12];
  uint32_t HW_PXP_DITHER_STORE_FILL_DATA_CH0;      /**< , offset: 0xAB0 */
  uint8_t RESERVED_152[12];
  uint32_t HW_PXP_DITHER_STORE_ADDR_0_CH1;         /**< , offset: 0xAC0 */
  uint8_t RESERVED_153[12];
  uint32_t HW_PXP_DITHER_STORE_ADDR_1_CH1;         /**< , offset: 0xAD0 */
  uint8_t RESERVED_154[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK0_H_CH0;      /**< , offset: 0xAE0 */
  uint8_t RESERVED_155[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK0_L_CH0;      /**< , offset: 0xAF0 */
  uint8_t RESERVED_156[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK1_H_CH0;      /**< , offset: 0xB00 */
  uint8_t RESERVED_157[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK1_L_CH0;      /**< , offset: 0xB10 */
  uint8_t RESERVED_158[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK2_H_CH0;      /**< , offset: 0xB20 */
  uint8_t RESERVED_159[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK2_L_CH0;      /**< , offset: 0xB30 */
  uint8_t RESERVED_160[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK3_H_CH0;      /**< , offset: 0xB40 */
  uint8_t RESERVED_161[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK3_L_CH0;      /**< , offset: 0xB50 */
  uint8_t RESERVED_162[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK4_H_CH0;      /**< , offset: 0xB60 */
  uint8_t RESERVED_163[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK4_L_CH0;      /**< , offset: 0xB70 */
  uint8_t RESERVED_164[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK5_H_CH0;      /**< , offset: 0xB80 */
  uint8_t RESERVED_165[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK5_L_CH0;      /**< , offset: 0xB90 */
  uint8_t RESERVED_166[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK6_H_CH0;      /**< , offset: 0xBA0 */
  uint8_t RESERVED_167[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK6_L_CH0;      /**< , offset: 0xBB0 */
  uint8_t RESERVED_168[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK7_H_CH0;      /**< , offset: 0xBC0 */
  uint8_t RESERVED_169[12];
  uint32_t HW_PXP_DITHER_STORE_D_MASK7_L_CH0;      /**< , offset: 0xBD0 */
  uint8_t RESERVED_170[12];
  uint32_t HW_PXP_DITHER_STORE_D_SHIFT_L_CH0;      /**< , offset: 0xBE0 */
  uint8_t RESERVED_171[12];
  uint32_t HW_PXP_DITHER_STORE_D_SHIFT_H_CH0;      /**< , offset: 0xBF0 */
  uint8_t RESERVED_172[12];
  uint32_t HW_PXP_DITHER_STORE_F_SHIFT_L_CH0;      /**< , offset: 0xC00 */
  uint8_t RESERVED_173[12];
  uint32_t HW_PXP_DITHER_STORE_F_SHIFT_H_CH0;      /**< , offset: 0xC10 */
  uint8_t RESERVED_174[12];
  uint32_t HW_PXP_DITHER_STORE_F_MASK_L_CH0;       /**< , offset: 0xC20 */
  uint8_t RESERVED_175[12];
  uint32_t HW_PXP_DITHER_STORE_F_MASK_H_CH0;       /**< , offset: 0xC30 */
  uint8_t RESERVED_176[2620];
  uint32_t HW_PXP_DITHER_CTRL;                     /**< Dither Control Register 0, offset: 0x1670 */
  uint8_t RESERVED_177[12];
  uint32_t HW_PXP_DITHER_FINAL_LUT_DATA0;          /**< Final stage lookup value Register, offset: 0x1680 */
  uint8_t RESERVED_178[12];
  uint32_t HW_PXP_DITHER_FINAL_LUT_DATA1;          /**< Final stage lookup value Register, offset: 0x1690 */
  uint8_t RESERVED_179[12];
  uint32_t HW_PXP_DITHER_FINAL_LUT_DATA2;          /**< Final stage lookup value Register, offset: 0x16A0 */
  uint8_t RESERVED_180[12];
  uint32_t HW_PXP_DITHER_FINAL_LUT_DATA3;          /**< Final stage lookup value Register, offset: 0x16B0 */
  uint8_t RESERVED_181[4940];
  uint32_t HW_PXP_HIST_A_CTRL;                     /**< Histogram Control Register., offset: 0x2A00 */
  uint8_t RESERVED_182[12];
  uint32_t HW_PXP_HIST_A_MASK;                     /**< Histogram Pixel Mask Register., offset: 0x2A10 */
  uint8_t RESERVED_183[12];
  uint32_t HW_PXP_HIST_A_BUF_SIZE;                 /**< Histogram Pixel Buffer Size Register., offset: 0x2A20 */
  uint8_t RESERVED_184[12];
  uint32_t HW_PXP_HIST_A_TOTAL_PIXEL;              /**< Total Number of Pixels Used by Histogram Engine., offset: 0x2A30 */
  uint8_t RESERVED_185[12];
  uint32_t HW_PXP_HIST_A_ACTIVE_AREA_X;            /**< The X Coordinate Offset for Active Area., offset: 0x2A40 */
  uint8_t RESERVED_186[12];
  uint32_t HW_PXP_HIST_A_ACTIVE_AREA_Y;            /**< The Y Coordinate Offset for Active Area., offset: 0x2A50 */
  uint8_t RESERVED_187[12];
  uint32_t HW_PXP_HIST_A_RAW_STAT0;                /**< Histogram Result Based on RAW Pixel Value., offset: 0x2A60 */
  uint8_t RESERVED_188[12];
  uint32_t HW_PXP_HIST_A_RAW_STAT1;                /**< Histogram Result Based on RAW Pixel Value., offset: 0x2A70 */
  uint8_t RESERVED_189[12];
  uint32_t HW_PXP_HIST_B_CTRL;                     /**< Histogram Control Register., offset: 0x2A80 */
  uint8_t RESERVED_190[12];
  uint32_t HW_PXP_HIST_B_MASK;                     /**< Histogram Pixel Mask Register., offset: 0x2A90 */
  uint8_t RESERVED_191[12];
  uint32_t HW_PXP_HIST_B_BUF_SIZE;                 /**< Histogram Pixel Buffer Size Register., offset: 0x2AA0 */
  uint8_t RESERVED_192[12];
  uint32_t HW_PXP_HIST_B_TOTAL_PIXEL;              /**< Total Number of Pixels Used by Histogram Engine., offset: 0x2AB0 */
  uint8_t RESERVED_193[12];
  uint32_t HW_PXP_HIST_B_ACTIVE_AREA_X;            /**< The X Coordinate Offset for Active Area., offset: 0x2AC0 */
  uint8_t RESERVED_194[12];
  uint32_t HW_PXP_HIST_B_ACTIVE_AREA_Y;            /**< The Y Coordinate Offset for Active Area., offset: 0x2AD0 */
  uint8_t RESERVED_195[12];
  uint32_t HW_PXP_HIST_B_RAW_STAT0;                /**< Histogram Result Based on RAW Pixel Value., offset: 0x2AE0 */
  uint8_t RESERVED_196[12];
  uint32_t HW_PXP_HIST_B_RAW_STAT1;                /**< Histogram Result Based on RAW Pixel Value., offset: 0x2AF0 */
  uint8_t RESERVED_197[12];
  uint32_t HW_PXP_HIST2_PARAM;                     /**< 2-level Histogram Parameter Register., offset: 0x2B00 */
  uint8_t RESERVED_198[12];
  uint32_t HW_PXP_HIST4_PARAM;                     /**< 4-level Histogram Parameter Register., offset: 0x2B10 */
  uint8_t RESERVED_199[12];
  uint32_t HW_PXP_HIST8_PARAM0;                    /**< 8-level Histogram Parameter 0 Register., offset: 0x2B20 */
  uint8_t RESERVED_200[12];
  uint32_t HW_PXP_HIST8_PARAM1;                    /**< 8-level Histogram Parameter 1 Register., offset: 0x2B30 */
  uint8_t RESERVED_201[12];
  uint32_t HW_PXP_HIST16_PARAM0;                   /**< 16-level Histogram Parameter 0 Register., offset: 0x2B40 */
  uint8_t RESERVED_202[12];
  uint32_t HW_PXP_HIST16_PARAM1;                   /**< 16-level Histogram Parameter 1 Register., offset: 0x2B50 */
  uint8_t RESERVED_203[12];
  uint32_t HW_PXP_HIST16_PARAM2;                   /**< 16-level Histogram Parameter 2 Register., offset: 0x2B60 */
  uint8_t RESERVED_204[12];
  uint32_t HW_PXP_HIST16_PARAM3;                   /**< 16-level Histogram Parameter 3 Register., offset: 0x2B70 */
  uint8_t RESERVED_205[12];
  uint32_t HW_PXP_HIST32_PARAM0;                   /**< 32-level Histogram Parameter 0 Register., offset: 0x2B80 */
  uint8_t RESERVED_206[12];
  uint32_t HW_PXP_HIST32_PARAM1;                   /**< 32-level Histogram Parameter 1 Register., offset: 0x2B90 */
  uint8_t RESERVED_207[12];
  uint32_t HW_PXP_HIST32_PARAM2;                   /**< 32-level Histogram Parameter 2 Register., offset: 0x2BA0 */
  uint8_t RESERVED_208[12];
  uint32_t HW_PXP_HIST32_PARAM3;                   /**< 32-level Histogram Parameter 3 Register., offset: 0x2BB0 */
  uint8_t RESERVED_209[12];
  uint32_t HW_PXP_HIST32_PARAM4;                   /**< 32-level Histogram Parameter 0 Register., offset: 0x2BC0 */
  uint8_t RESERVED_210[12];
  uint32_t HW_PXP_HIST32_PARAM5;                   /**< 32-level Histogram Parameter 1 Register., offset: 0x2BD0 */
  uint8_t RESERVED_211[12];
  uint32_t HW_PXP_HIST32_PARAM6;                   /**< 32-level Histogram Parameter 2 Register., offset: 0x2BE0 */
  uint8_t RESERVED_212[12];
  uint32_t HW_PXP_HIST32_PARAM7;                   /**< 32-level Histogram Parameter 3 Register., offset: 0x2BF0 */
  uint8_t RESERVED_213[12];
  uint32_t HW_PXP_COMP_CTRL;                       /**< , offset: 0x2C00 */
  uint8_t RESERVED_214[12];
  uint32_t HW_PXP_COMP_FORMAT0;                    /**< , offset: 0x2C10 */
  uint8_t RESERVED_215[12];
  uint32_t HW_PXP_COMP_FORMAT1;                    /**< , offset: 0x2C20 */
  uint8_t RESERVED_216[12];
  uint32_t HW_PXP_COMP_FORMAT2;                    /**< , offset: 0x2C30 */
  uint8_t RESERVED_217[12];
  uint32_t HW_PXP_COMP_MASK0;                      /**< , offset: 0x2C40 */
  uint8_t RESERVED_218[12];
  uint32_t HW_PXP_COMP_MASK1;                      /**< , offset: 0x2C50 */
  uint8_t RESERVED_219[12];
  uint32_t HW_PXP_COMP_BUFFER_SIZE;                /**< , offset: 0x2C60 */
  uint8_t RESERVED_220[12];
  uint32_t HW_PXP_COMP_SOURCE;                     /**< , offset: 0x2C70 */
  uint8_t RESERVED_221[12];
  uint32_t HW_PXP_COMP_TARGET;                     /**< , offset: 0x2C80 */
  uint8_t RESERVED_222[12];
  uint32_t HW_PXP_COMP_BUFFER_A;                   /**< , offset: 0x2C90 */
  uint8_t RESERVED_223[12];
  uint32_t HW_PXP_COMP_BUFFER_B;                   /**< , offset: 0x2CA0 */
  uint8_t RESERVED_224[12];
  uint32_t HW_PXP_COMP_BUFFER_C;                   /**< , offset: 0x2CB0 */
  uint8_t RESERVED_225[12];
  uint32_t HW_PXP_COMP_BUFFER_D;                   /**< , offset: 0x2CC0 */
  uint8_t RESERVED_226[12];
  uint32_t HW_PXP_COMP_DEBUG;                      /**< , offset: 0x2CD0 */
  uint8_t RESERVED_227[12];
  uint32_t HW_PXP_BUS_MUX;                         /**< , offset: 0x2CE0 */
  uint8_t RESERVED_228[12];
  uint32_t HW_PXP_HANDSHAKE_READY_MUX0;            /**< , offset: 0x2CF0 */
  uint8_t RESERVED_229[12];
  uint32_t HW_PXP_HANDSHAKE_READY_MUX1;            /**< , offset: 0x2D00 */
  uint8_t RESERVED_230[12];
  uint32_t HW_PXP_HANDSHAKE_DONE_MUX0;             /**< , offset: 0x2D10 */
  uint8_t RESERVED_231[12];
  uint32_t HW_PXP_HANDSHAKE_DONE_MUX1;             /**< , offset: 0x2D20 */
  uint8_t RESERVED_232[12];
  uint32_t HW_PXP_HANDSHAKE_CPU_FETCH;             /**< , offset: 0x2D30 */
  uint8_t RESERVED_233[12];
  uint32_t HW_PXP_HANDSHAKE_CPU_STORE;             /**< , offset: 0x2D40 */
} volatile *PXP_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- PXP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PXP_Register_Accessor_Macros PXP - Register accessor macros
 * @{
 */


/* PXP - Register accessors */
#define PXP_HW_PXP_CTRL_REG(base)                ((base)->HW_PXP_CTRL)
#define PXP_HW_PXP_STAT_REG(base)                ((base)->HW_PXP_STAT)
#define PXP_HW_PXP_OUT_CTRL_REG(base)            ((base)->HW_PXP_OUT_CTRL)
#define PXP_HW_PXP_OUT_BUF_REG(base)             ((base)->HW_PXP_OUT_BUF)
#define PXP_HW_PXP_OUT_BUF2_REG(base)            ((base)->HW_PXP_OUT_BUF2)
#define PXP_HW_PXP_OUT_PITCH_REG(base)           ((base)->HW_PXP_OUT_PITCH)
#define PXP_HW_PXP_OUT_LRC_REG(base)             ((base)->HW_PXP_OUT_LRC)
#define PXP_HW_PXP_OUT_PS_ULC_REG(base)          ((base)->HW_PXP_OUT_PS_ULC)
#define PXP_HW_PXP_OUT_PS_LRC_REG(base)          ((base)->HW_PXP_OUT_PS_LRC)
#define PXP_HW_PXP_OUT_AS_ULC_REG(base)          ((base)->HW_PXP_OUT_AS_ULC)
#define PXP_HW_PXP_OUT_AS_LRC_REG(base)          ((base)->HW_PXP_OUT_AS_LRC)
#define PXP_HW_PXP_PS_CTRL_REG(base)             ((base)->HW_PXP_PS_CTRL)
#define PXP_HW_PXP_PS_BUF_REG(base)              ((base)->HW_PXP_PS_BUF)
#define PXP_HW_PXP_PS_UBUF_REG(base)             ((base)->HW_PXP_PS_UBUF)
#define PXP_HW_PXP_PS_VBUF_REG(base)             ((base)->HW_PXP_PS_VBUF)
#define PXP_HW_PXP_PS_PITCH_REG(base)            ((base)->HW_PXP_PS_PITCH)
#define PXP_HW_PXP_PS_BACKGROUND_0_REG(base)     ((base)->HW_PXP_PS_BACKGROUND_0)
#define PXP_HW_PXP_PS_SCALE_REG(base)            ((base)->HW_PXP_PS_SCALE)
#define PXP_HW_PXP_PS_OFFSET_REG(base)           ((base)->HW_PXP_PS_OFFSET)
#define PXP_HW_PXP_PS_CLRKEYLOW_0_REG(base)      ((base)->HW_PXP_PS_CLRKEYLOW_0)
#define PXP_HW_PXP_PS_CLRKEYHIGH_0_REG(base)     ((base)->HW_PXP_PS_CLRKEYHIGH_0)
#define PXP_HW_PXP_AS_CTRL_REG(base)             ((base)->HW_PXP_AS_CTRL)
#define PXP_HW_PXP_AS_BUF_REG(base)              ((base)->HW_PXP_AS_BUF)
#define PXP_HW_PXP_AS_PITCH_REG(base)            ((base)->HW_PXP_AS_PITCH)
#define PXP_HW_PXP_AS_CLRKEYLOW_0_REG(base)      ((base)->HW_PXP_AS_CLRKEYLOW_0)
#define PXP_HW_PXP_AS_CLRKEYHIGH_0_REG(base)     ((base)->HW_PXP_AS_CLRKEYHIGH_0)
#define PXP_HW_PXP_CSC1_COEF0_REG(base)          ((base)->HW_PXP_CSC1_COEF0)
#define PXP_HW_PXP_CSC1_COEF1_REG(base)          ((base)->HW_PXP_CSC1_COEF1)
#define PXP_HW_PXP_CSC1_COEF2_REG(base)          ((base)->HW_PXP_CSC1_COEF2)
#define PXP_HW_PXP_CSC2_CTRL_REG(base)           ((base)->HW_PXP_CSC2_CTRL)
#define PXP_HW_PXP_CSC2_COEF0_REG(base)          ((base)->HW_PXP_CSC2_COEF0)
#define PXP_HW_PXP_CSC2_COEF1_REG(base)          ((base)->HW_PXP_CSC2_COEF1)
#define PXP_HW_PXP_CSC2_COEF2_REG(base)          ((base)->HW_PXP_CSC2_COEF2)
#define PXP_HW_PXP_CSC2_COEF3_REG(base)          ((base)->HW_PXP_CSC2_COEF3)
#define PXP_HW_PXP_CSC2_COEF4_REG(base)          ((base)->HW_PXP_CSC2_COEF4)
#define PXP_HW_PXP_CSC2_COEF5_REG(base)          ((base)->HW_PXP_CSC2_COEF5)
#define PXP_HW_PXP_LUT_CTRL_REG(base)            ((base)->HW_PXP_LUT_CTRL)
#define PXP_HW_PXP_LUT_ADDR_REG(base)            ((base)->HW_PXP_LUT_ADDR)
#define PXP_HW_PXP_LUT_DATA_REG(base)            ((base)->HW_PXP_LUT_DATA)
#define PXP_HW_PXP_LUT_EXTMEM_REG(base)          ((base)->HW_PXP_LUT_EXTMEM)
#define PXP_HW_PXP_CFA_REG(base)                 ((base)->HW_PXP_CFA)
#define PXP_HW_PXP_ALPHA_A_CTRL_REG(base)        ((base)->HW_PXP_ALPHA_A_CTRL)
#define PXP_HW_PXP_ALPHA_B_CTRL_REG(base)        ((base)->HW_PXP_ALPHA_B_CTRL)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_REG(base)      ((base)->HW_PXP_ALPHA_B_CTRL_1)
#define PXP_HW_PXP_PS_BACKGROUND_1_REG(base)     ((base)->HW_PXP_PS_BACKGROUND_1)
#define PXP_HW_PXP_PS_CLRKEYLOW_1_REG(base)      ((base)->HW_PXP_PS_CLRKEYLOW_1)
#define PXP_HW_PXP_PS_CLRKEYHIGH_1_REG(base)     ((base)->HW_PXP_PS_CLRKEYHIGH_1)
#define PXP_HW_PXP_AS_CLRKEYLOW_1_REG(base)      ((base)->HW_PXP_AS_CLRKEYLOW_1)
#define PXP_HW_PXP_AS_CLRKEYHIGH_1_REG(base)     ((base)->HW_PXP_AS_CLRKEYHIGH_1)
#define PXP_HW_PXP_CTRL2_REG(base)               ((base)->HW_PXP_CTRL2)
#define PXP_HW_PXP_POWER_REG0_REG(base)          ((base)->HW_PXP_POWER_REG0)
#define PXP_HW_PXP_POWER_REG1_REG(base)          ((base)->HW_PXP_POWER_REG1)
#define PXP_HW_PXP_DATA_PATH_CTRL1_REG(base)     ((base)->HW_PXP_DATA_PATH_CTRL1)
#define PXP_HW_PXP_INIT_MEM_CTRL_REG(base)       ((base)->HW_PXP_INIT_MEM_CTRL)
#define PXP_HW_PXP_INIT_MEM_DATA_REG(base)       ((base)->HW_PXP_INIT_MEM_DATA)
#define PXP_HW_PXP_INIT_MEM_DATA_HIGH_REG(base)  ((base)->HW_PXP_INIT_MEM_DATA_HIGH)
#define PXP_HW_PXP_IRQ_MASK_REG(base)            ((base)->HW_PXP_IRQ_MASK)
#define PXP_HW_PXP_IRQ_REG(base)                 ((base)->HW_PXP_IRQ)
#define PXP_HW_PXP_NEXT_REG(base)                ((base)->HW_PXP_NEXT)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_CTRL_CH0)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_CTRL_CH1)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_STATUS_CH0)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_STATUS_CH1)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_SIZE_CH0)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_SIZE_CH1)
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0)
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1)
#define PXP_HW_PXP_INPUT_FETCH_PITCH_REG(base)   ((base)->HW_PXP_INPUT_FETCH_PITCH)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_ADDR_0_CH0)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_REG(base) ((base)->HW_PXP_INPUT_FETCH_ADDR_1_CH0)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_ADDR_0_CH1)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_REG(base) ((base)->HW_PXP_INPUT_FETCH_ADDR_1_CH1)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_CTRL_CH0)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_REG(base) ((base)->HW_PXP_INPUT_STORE_CTRL_CH1)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_STATUS_CH0)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH1_REG(base) ((base)->HW_PXP_INPUT_STORE_STATUS_CH1)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_SIZE_CH0)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH1_REG(base) ((base)->HW_PXP_INPUT_STORE_SIZE_CH1)
#define PXP_HW_PXP_INPUT_STORE_PITCH_REG(base)   ((base)->HW_PXP_INPUT_STORE_PITCH)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_REG(base) ((base)->HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1)
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_ADDR_0_CH0)
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_ADDR_1_CH0)
#define PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_FILL_DATA_CH0)
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_REG(base) ((base)->HW_PXP_INPUT_STORE_ADDR_0_CH1)
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_REG(base) ((base)->HW_PXP_INPUT_STORE_ADDR_1_CH1)
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK0_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK0_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK1_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK1_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK2_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK2_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK3_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK3_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK4_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK4_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK5_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK5_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK6_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK6_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK7_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_MASK7_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_SHIFT_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_D_SHIFT_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_F_SHIFT_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_F_SHIFT_H_CH0)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_F_MASK_L_CH0)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_REG(base) ((base)->HW_PXP_INPUT_STORE_F_MASK_H_CH0)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_CTRL_CH0)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_CTRL_CH1)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_STATUS_CH0)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_STATUS_CH1)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_SIZE_CH0)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_SIZE_CH1)
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0)
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1)
#define PXP_HW_PXP_DITHER_FETCH_PITCH_REG(base)  ((base)->HW_PXP_DITHER_FETCH_PITCH)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_ADDR_0_CH0)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_REG(base) ((base)->HW_PXP_DITHER_FETCH_ADDR_1_CH0)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_ADDR_0_CH1)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_REG(base) ((base)->HW_PXP_DITHER_FETCH_ADDR_1_CH1)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_CTRL_CH0)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_REG(base) ((base)->HW_PXP_DITHER_STORE_CTRL_CH1)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_STATUS_CH0)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH1_REG(base) ((base)->HW_PXP_DITHER_STORE_STATUS_CH1)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_SIZE_CH0)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH1_REG(base) ((base)->HW_PXP_DITHER_STORE_SIZE_CH1)
#define PXP_HW_PXP_DITHER_STORE_PITCH_REG(base)  ((base)->HW_PXP_DITHER_STORE_PITCH)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_REG(base) ((base)->HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1)
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_ADDR_0_CH0)
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_ADDR_1_CH0)
#define PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_FILL_DATA_CH0)
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_REG(base) ((base)->HW_PXP_DITHER_STORE_ADDR_0_CH1)
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_REG(base) ((base)->HW_PXP_DITHER_STORE_ADDR_1_CH1)
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK0_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK0_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK1_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK1_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK2_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK2_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK3_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK3_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK4_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK4_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK5_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK5_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK6_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK6_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK7_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_MASK7_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_SHIFT_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_D_SHIFT_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_F_SHIFT_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_F_SHIFT_H_CH0)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_F_MASK_L_CH0)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_REG(base) ((base)->HW_PXP_DITHER_STORE_F_MASK_H_CH0)
#define PXP_HW_PXP_DITHER_CTRL_REG(base)         ((base)->HW_PXP_DITHER_CTRL)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_REG(base) ((base)->HW_PXP_DITHER_FINAL_LUT_DATA0)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_REG(base) ((base)->HW_PXP_DITHER_FINAL_LUT_DATA1)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_REG(base) ((base)->HW_PXP_DITHER_FINAL_LUT_DATA2)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_REG(base) ((base)->HW_PXP_DITHER_FINAL_LUT_DATA3)
#define PXP_HW_PXP_HIST_A_CTRL_REG(base)         ((base)->HW_PXP_HIST_A_CTRL)
#define PXP_HW_PXP_HIST_A_MASK_REG(base)         ((base)->HW_PXP_HIST_A_MASK)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_REG(base)     ((base)->HW_PXP_HIST_A_BUF_SIZE)
#define PXP_HW_PXP_HIST_A_TOTAL_PIXEL_REG(base)  ((base)->HW_PXP_HIST_A_TOTAL_PIXEL)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_REG(base) ((base)->HW_PXP_HIST_A_ACTIVE_AREA_X)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_REG(base) ((base)->HW_PXP_HIST_A_ACTIVE_AREA_Y)
#define PXP_HW_PXP_HIST_A_RAW_STAT0_REG(base)    ((base)->HW_PXP_HIST_A_RAW_STAT0)
#define PXP_HW_PXP_HIST_A_RAW_STAT1_REG(base)    ((base)->HW_PXP_HIST_A_RAW_STAT1)
#define PXP_HW_PXP_HIST_B_CTRL_REG(base)         ((base)->HW_PXP_HIST_B_CTRL)
#define PXP_HW_PXP_HIST_B_MASK_REG(base)         ((base)->HW_PXP_HIST_B_MASK)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_REG(base)     ((base)->HW_PXP_HIST_B_BUF_SIZE)
#define PXP_HW_PXP_HIST_B_TOTAL_PIXEL_REG(base)  ((base)->HW_PXP_HIST_B_TOTAL_PIXEL)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_REG(base) ((base)->HW_PXP_HIST_B_ACTIVE_AREA_X)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_REG(base) ((base)->HW_PXP_HIST_B_ACTIVE_AREA_Y)
#define PXP_HW_PXP_HIST_B_RAW_STAT0_REG(base)    ((base)->HW_PXP_HIST_B_RAW_STAT0)
#define PXP_HW_PXP_HIST_B_RAW_STAT1_REG(base)    ((base)->HW_PXP_HIST_B_RAW_STAT1)
#define PXP_HW_PXP_HIST2_PARAM_REG(base)         ((base)->HW_PXP_HIST2_PARAM)
#define PXP_HW_PXP_HIST4_PARAM_REG(base)         ((base)->HW_PXP_HIST4_PARAM)
#define PXP_HW_PXP_HIST8_PARAM0_REG(base)        ((base)->HW_PXP_HIST8_PARAM0)
#define PXP_HW_PXP_HIST8_PARAM1_REG(base)        ((base)->HW_PXP_HIST8_PARAM1)
#define PXP_HW_PXP_HIST16_PARAM0_REG(base)       ((base)->HW_PXP_HIST16_PARAM0)
#define PXP_HW_PXP_HIST16_PARAM1_REG(base)       ((base)->HW_PXP_HIST16_PARAM1)
#define PXP_HW_PXP_HIST16_PARAM2_REG(base)       ((base)->HW_PXP_HIST16_PARAM2)
#define PXP_HW_PXP_HIST16_PARAM3_REG(base)       ((base)->HW_PXP_HIST16_PARAM3)
#define PXP_HW_PXP_HIST32_PARAM0_REG(base)       ((base)->HW_PXP_HIST32_PARAM0)
#define PXP_HW_PXP_HIST32_PARAM1_REG(base)       ((base)->HW_PXP_HIST32_PARAM1)
#define PXP_HW_PXP_HIST32_PARAM2_REG(base)       ((base)->HW_PXP_HIST32_PARAM2)
#define PXP_HW_PXP_HIST32_PARAM3_REG(base)       ((base)->HW_PXP_HIST32_PARAM3)
#define PXP_HW_PXP_HIST32_PARAM4_REG(base)       ((base)->HW_PXP_HIST32_PARAM4)
#define PXP_HW_PXP_HIST32_PARAM5_REG(base)       ((base)->HW_PXP_HIST32_PARAM5)
#define PXP_HW_PXP_HIST32_PARAM6_REG(base)       ((base)->HW_PXP_HIST32_PARAM6)
#define PXP_HW_PXP_HIST32_PARAM7_REG(base)       ((base)->HW_PXP_HIST32_PARAM7)
#define PXP_HW_PXP_COMP_CTRL_REG(base)           ((base)->HW_PXP_COMP_CTRL)
#define PXP_HW_PXP_COMP_FORMAT0_REG(base)        ((base)->HW_PXP_COMP_FORMAT0)
#define PXP_HW_PXP_COMP_FORMAT1_REG(base)        ((base)->HW_PXP_COMP_FORMAT1)
#define PXP_HW_PXP_COMP_FORMAT2_REG(base)        ((base)->HW_PXP_COMP_FORMAT2)
#define PXP_HW_PXP_COMP_MASK0_REG(base)          ((base)->HW_PXP_COMP_MASK0)
#define PXP_HW_PXP_COMP_MASK1_REG(base)          ((base)->HW_PXP_COMP_MASK1)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_REG(base)    ((base)->HW_PXP_COMP_BUFFER_SIZE)
#define PXP_HW_PXP_COMP_SOURCE_REG(base)         ((base)->HW_PXP_COMP_SOURCE)
#define PXP_HW_PXP_COMP_TARGET_REG(base)         ((base)->HW_PXP_COMP_TARGET)
#define PXP_HW_PXP_COMP_BUFFER_A_REG(base)       ((base)->HW_PXP_COMP_BUFFER_A)
#define PXP_HW_PXP_COMP_BUFFER_B_REG(base)       ((base)->HW_PXP_COMP_BUFFER_B)
#define PXP_HW_PXP_COMP_BUFFER_C_REG(base)       ((base)->HW_PXP_COMP_BUFFER_C)
#define PXP_HW_PXP_COMP_BUFFER_D_REG(base)       ((base)->HW_PXP_COMP_BUFFER_D)
#define PXP_HW_PXP_COMP_DEBUG_REG(base)          ((base)->HW_PXP_COMP_DEBUG)
#define PXP_HW_PXP_BUS_MUX_REG(base)             ((base)->HW_PXP_BUS_MUX)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_REG(base) ((base)->HW_PXP_HANDSHAKE_READY_MUX0)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_REG(base) ((base)->HW_PXP_HANDSHAKE_READY_MUX1)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_REG(base) ((base)->HW_PXP_HANDSHAKE_DONE_MUX0)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_REG(base) ((base)->HW_PXP_HANDSHAKE_DONE_MUX1)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_REG(base) ((base)->HW_PXP_HANDSHAKE_CPU_FETCH)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_REG(base) ((base)->HW_PXP_HANDSHAKE_CPU_STORE)

/*!
 * @}
 */ /* end of group PXP_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- PXP Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PXP_Register_Masks PXP Register Masks
 * @{
 */

/*! @name HW_PXP_CTRL - Control Register 0 */
#define PXP_HW_PXP_CTRL_ENABLE_MASK              (0x1U)
#define PXP_HW_PXP_CTRL_ENABLE_SHIFT             (0U)
#define PXP_HW_PXP_CTRL_IRQ_ENABLE_MASK          (0x2U)
#define PXP_HW_PXP_CTRL_IRQ_ENABLE_SHIFT         (1U)
#define PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE_MASK     (0x4U)
#define PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE_SHIFT    (2U)
#define PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE_MASK  (0x8U)
#define PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE_SHIFT (3U)
#define PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE_MASK (0x10U)
#define PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE_SHIFT (4U)
#define PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP_MASK (0x20U)
#define PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP_SHIFT (5U)
#define PXP_HW_PXP_CTRL_RSVD0_MASK               (0xC0U)
#define PXP_HW_PXP_CTRL_RSVD0_SHIFT              (6U)
#define PXP_HW_PXP_CTRL_RSVD0(x)                 (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_CTRL_ROTATE0_MASK             (0x300U)
#define PXP_HW_PXP_CTRL_ROTATE0_SHIFT            (8U)
#define PXP_HW_PXP_CTRL_ROTATE0(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CTRL_ROTATE0_SHIFT)) & PXP_HW_PXP_CTRL_ROTATE0_MASK)
#define PXP_HW_PXP_CTRL_HFLIP0_MASK              (0x400U)
#define PXP_HW_PXP_CTRL_HFLIP0_SHIFT             (10U)
#define PXP_HW_PXP_CTRL_VFLIP0_MASK              (0x800U)
#define PXP_HW_PXP_CTRL_VFLIP0_SHIFT             (11U)
#define PXP_HW_PXP_CTRL_ROTATE1_MASK             (0x3000U)
#define PXP_HW_PXP_CTRL_ROTATE1_SHIFT            (12U)
#define PXP_HW_PXP_CTRL_ROTATE1(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CTRL_ROTATE1_SHIFT)) & PXP_HW_PXP_CTRL_ROTATE1_MASK)
#define PXP_HW_PXP_CTRL_HFLIP1_MASK              (0x4000U)
#define PXP_HW_PXP_CTRL_HFLIP1_SHIFT             (14U)
#define PXP_HW_PXP_CTRL_VFLIP1_MASK              (0x8000U)
#define PXP_HW_PXP_CTRL_VFLIP1_SHIFT             (15U)
#define PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT_MASK    (0x10000U)
#define PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT_SHIFT   (16U)
#define PXP_HW_PXP_CTRL_ENABLE_DITHER_MASK       (0x20000U)
#define PXP_HW_PXP_CTRL_ENABLE_DITHER_SHIFT      (17U)
#define PXP_HW_PXP_CTRL_ENABLE_WFE_A_MASK        (0x40000U)
#define PXP_HW_PXP_CTRL_ENABLE_WFE_A_SHIFT       (18U)
#define PXP_HW_PXP_CTRL_ENABLE_WFE_B_MASK        (0x80000U)
#define PXP_HW_PXP_CTRL_ENABLE_WFE_B_SHIFT       (19U)
#define PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE_MASK (0x100000U)
#define PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE_SHIFT (20U)
#define PXP_HW_PXP_CTRL_ENABLE_ALPHA_B_MASK      (0x200000U)
#define PXP_HW_PXP_CTRL_ENABLE_ALPHA_B_SHIFT     (21U)
#define PXP_HW_PXP_CTRL_RSVD1_MASK               (0x400000U)
#define PXP_HW_PXP_CTRL_RSVD1_SHIFT              (22U)
#define PXP_HW_PXP_CTRL_BLOCK_SIZE_MASK          (0x800000U)
#define PXP_HW_PXP_CTRL_BLOCK_SIZE_SHIFT         (23U)
#define PXP_HW_PXP_CTRL_ENABLE_CSC2_MASK         (0x1000000U)
#define PXP_HW_PXP_CTRL_ENABLE_CSC2_SHIFT        (24U)
#define PXP_HW_PXP_CTRL_ENABLE_LUT_MASK          (0x2000000U)
#define PXP_HW_PXP_CTRL_ENABLE_LUT_SHIFT         (25U)
#define PXP_HW_PXP_CTRL_ENABLE_ROTATE0_MASK      (0x4000000U)
#define PXP_HW_PXP_CTRL_ENABLE_ROTATE0_SHIFT     (26U)
#define PXP_HW_PXP_CTRL_ENABLE_ROTATE1_MASK      (0x8000000U)
#define PXP_HW_PXP_CTRL_ENABLE_ROTATE1_SHIFT     (27U)
#define PXP_HW_PXP_CTRL_EN_REPEAT_MASK           (0x10000000U)
#define PXP_HW_PXP_CTRL_EN_REPEAT_SHIFT          (28U)
#define PXP_HW_PXP_CTRL_RSVD4_MASK               (0x20000000U)
#define PXP_HW_PXP_CTRL_RSVD4_SHIFT              (29U)
#define PXP_HW_PXP_CTRL_CLKGATE_MASK             (0x40000000U)
#define PXP_HW_PXP_CTRL_CLKGATE_SHIFT            (30U)
#define PXP_HW_PXP_CTRL_SFTRST_MASK              (0x80000000U)
#define PXP_HW_PXP_CTRL_SFTRST_SHIFT             (31U)

/*! @name HW_PXP_STAT - Status Register */
#define PXP_HW_PXP_STAT_IRQ0_MASK                (0x1U)
#define PXP_HW_PXP_STAT_IRQ0_SHIFT               (0U)
#define PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0_MASK   (0x2U)
#define PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0_SHIFT  (1U)
#define PXP_HW_PXP_STAT_AXI_READ_ERROR_0_MASK    (0x4U)
#define PXP_HW_PXP_STAT_AXI_READ_ERROR_0_SHIFT   (2U)
#define PXP_HW_PXP_STAT_NEXT_IRQ_MASK            (0x8U)
#define PXP_HW_PXP_STAT_NEXT_IRQ_SHIFT           (3U)
#define PXP_HW_PXP_STAT_AXI_ERROR_ID_0_MASK      (0xF0U)
#define PXP_HW_PXP_STAT_AXI_ERROR_ID_0_SHIFT     (4U)
#define PXP_HW_PXP_STAT_AXI_ERROR_ID_0(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_STAT_AXI_ERROR_ID_0_SHIFT)) & PXP_HW_PXP_STAT_AXI_ERROR_ID_0_MASK)
#define PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ_MASK (0x100U)
#define PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ_SHIFT (8U)
#define PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1_MASK   (0x200U)
#define PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1_SHIFT  (9U)
#define PXP_HW_PXP_STAT_AXI_READ_ERROR_1_MASK    (0x400U)
#define PXP_HW_PXP_STAT_AXI_READ_ERROR_1_SHIFT   (10U)
#define PXP_HW_PXP_STAT_RSVD2_MASK               (0x800U)
#define PXP_HW_PXP_STAT_RSVD2_SHIFT              (11U)
#define PXP_HW_PXP_STAT_AXI_ERROR_ID_1_MASK      (0xF000U)
#define PXP_HW_PXP_STAT_AXI_ERROR_ID_1_SHIFT     (12U)
#define PXP_HW_PXP_STAT_AXI_ERROR_ID_1(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_STAT_AXI_ERROR_ID_1_SHIFT)) & PXP_HW_PXP_STAT_AXI_ERROR_ID_1_MASK)
#define PXP_HW_PXP_STAT_BLOCKY_MASK              (0xFF0000U)
#define PXP_HW_PXP_STAT_BLOCKY_SHIFT             (16U)
#define PXP_HW_PXP_STAT_BLOCKY(x)                (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_STAT_BLOCKY_SHIFT)) & PXP_HW_PXP_STAT_BLOCKY_MASK)
#define PXP_HW_PXP_STAT_BLOCKX_MASK              (0xFF000000U)
#define PXP_HW_PXP_STAT_BLOCKX_SHIFT             (24U)
#define PXP_HW_PXP_STAT_BLOCKX(x)                (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_STAT_BLOCKX_SHIFT)) & PXP_HW_PXP_STAT_BLOCKX_MASK)

/*! @name HW_PXP_OUT_CTRL - Output Buffer Control Register */
#define PXP_HW_PXP_OUT_CTRL_FORMAT_MASK          (0x1FU)
#define PXP_HW_PXP_OUT_CTRL_FORMAT_SHIFT         (0U)
#define PXP_HW_PXP_OUT_CTRL_FORMAT(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_CTRL_FORMAT_SHIFT)) & PXP_HW_PXP_OUT_CTRL_FORMAT_MASK)
#define PXP_HW_PXP_OUT_CTRL_RSVD0_MASK           (0xE0U)
#define PXP_HW_PXP_OUT_CTRL_RSVD0_SHIFT          (5U)
#define PXP_HW_PXP_OUT_CTRL_RSVD0(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_OUT_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT_MASK (0x300U)
#define PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT_SHIFT (8U)
#define PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT_SHIFT)) & PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT_MASK)
#define PXP_HW_PXP_OUT_CTRL_RSVD1_MASK           (0x7FFC00U)
#define PXP_HW_PXP_OUT_CTRL_RSVD1_SHIFT          (10U)
#define PXP_HW_PXP_OUT_CTRL_RSVD1(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_CTRL_RSVD1_SHIFT)) & PXP_HW_PXP_OUT_CTRL_RSVD1_MASK)
#define PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT_MASK    (0x800000U)
#define PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT_SHIFT   (23U)
#define PXP_HW_PXP_OUT_CTRL_ALPHA_MASK           (0xFF000000U)
#define PXP_HW_PXP_OUT_CTRL_ALPHA_SHIFT          (24U)
#define PXP_HW_PXP_OUT_CTRL_ALPHA(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_CTRL_ALPHA_SHIFT)) & PXP_HW_PXP_OUT_CTRL_ALPHA_MASK)

/*! @name HW_PXP_OUT_BUF - Output Frame Buffer Pointer */
#define PXP_HW_PXP_OUT_BUF_ADDR_MASK             (0xFFFFFFFFU)
#define PXP_HW_PXP_OUT_BUF_ADDR_SHIFT            (0U)
#define PXP_HW_PXP_OUT_BUF_ADDR(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_BUF_ADDR_SHIFT)) & PXP_HW_PXP_OUT_BUF_ADDR_MASK)

/*! @name HW_PXP_OUT_BUF2 - Output Frame Buffer Pointer #2 */
#define PXP_HW_PXP_OUT_BUF2_ADDR_MASK            (0xFFFFFFFFU)
#define PXP_HW_PXP_OUT_BUF2_ADDR_SHIFT           (0U)
#define PXP_HW_PXP_OUT_BUF2_ADDR(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_BUF2_ADDR_SHIFT)) & PXP_HW_PXP_OUT_BUF2_ADDR_MASK)

/*! @name HW_PXP_OUT_PITCH - Output Buffer Pitch */
#define PXP_HW_PXP_OUT_PITCH_PITCH_MASK          (0xFFFFU)
#define PXP_HW_PXP_OUT_PITCH_PITCH_SHIFT         (0U)
#define PXP_HW_PXP_OUT_PITCH_PITCH(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PITCH_PITCH_SHIFT)) & PXP_HW_PXP_OUT_PITCH_PITCH_MASK)
#define PXP_HW_PXP_OUT_PITCH_RSVD_MASK           (0xFFFF0000U)
#define PXP_HW_PXP_OUT_PITCH_RSVD_SHIFT          (16U)
#define PXP_HW_PXP_OUT_PITCH_RSVD(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PITCH_RSVD_SHIFT)) & PXP_HW_PXP_OUT_PITCH_RSVD_MASK)

/*! @name HW_PXP_OUT_LRC - Output Surface Lower Right Coordinate */
#define PXP_HW_PXP_OUT_LRC_Y_MASK                (0x3FFFU)
#define PXP_HW_PXP_OUT_LRC_Y_SHIFT               (0U)
#define PXP_HW_PXP_OUT_LRC_Y(x)                  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_LRC_Y_SHIFT)) & PXP_HW_PXP_OUT_LRC_Y_MASK)
#define PXP_HW_PXP_OUT_LRC_RSVD0_MASK            (0xC000U)
#define PXP_HW_PXP_OUT_LRC_RSVD0_SHIFT           (14U)
#define PXP_HW_PXP_OUT_LRC_RSVD0(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_LRC_RSVD0_SHIFT)) & PXP_HW_PXP_OUT_LRC_RSVD0_MASK)
#define PXP_HW_PXP_OUT_LRC_X_MASK                (0x3FFF0000U)
#define PXP_HW_PXP_OUT_LRC_X_SHIFT               (16U)
#define PXP_HW_PXP_OUT_LRC_X(x)                  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_LRC_X_SHIFT)) & PXP_HW_PXP_OUT_LRC_X_MASK)
#define PXP_HW_PXP_OUT_LRC_RSVD1_MASK            (0xC0000000U)
#define PXP_HW_PXP_OUT_LRC_RSVD1_SHIFT           (30U)
#define PXP_HW_PXP_OUT_LRC_RSVD1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_LRC_RSVD1_SHIFT)) & PXP_HW_PXP_OUT_LRC_RSVD1_MASK)

/*! @name HW_PXP_OUT_PS_ULC - Processed Surface Upper Left Coordinate */
#define PXP_HW_PXP_OUT_PS_ULC_Y_MASK             (0x3FFFU)
#define PXP_HW_PXP_OUT_PS_ULC_Y_SHIFT            (0U)
#define PXP_HW_PXP_OUT_PS_ULC_Y(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PS_ULC_Y_SHIFT)) & PXP_HW_PXP_OUT_PS_ULC_Y_MASK)
#define PXP_HW_PXP_OUT_PS_ULC_RSVD0_MASK         (0xC000U)
#define PXP_HW_PXP_OUT_PS_ULC_RSVD0_SHIFT        (14U)
#define PXP_HW_PXP_OUT_PS_ULC_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PS_ULC_RSVD0_SHIFT)) & PXP_HW_PXP_OUT_PS_ULC_RSVD0_MASK)
#define PXP_HW_PXP_OUT_PS_ULC_X_MASK             (0x3FFF0000U)
#define PXP_HW_PXP_OUT_PS_ULC_X_SHIFT            (16U)
#define PXP_HW_PXP_OUT_PS_ULC_X(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PS_ULC_X_SHIFT)) & PXP_HW_PXP_OUT_PS_ULC_X_MASK)
#define PXP_HW_PXP_OUT_PS_ULC_RSVD1_MASK         (0xC0000000U)
#define PXP_HW_PXP_OUT_PS_ULC_RSVD1_SHIFT        (30U)
#define PXP_HW_PXP_OUT_PS_ULC_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PS_ULC_RSVD1_SHIFT)) & PXP_HW_PXP_OUT_PS_ULC_RSVD1_MASK)

/*! @name HW_PXP_OUT_PS_LRC - Processed Surface Lower Right Coordinate */
#define PXP_HW_PXP_OUT_PS_LRC_Y_MASK             (0x3FFFU)
#define PXP_HW_PXP_OUT_PS_LRC_Y_SHIFT            (0U)
#define PXP_HW_PXP_OUT_PS_LRC_Y(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PS_LRC_Y_SHIFT)) & PXP_HW_PXP_OUT_PS_LRC_Y_MASK)
#define PXP_HW_PXP_OUT_PS_LRC_RSVD0_MASK         (0xC000U)
#define PXP_HW_PXP_OUT_PS_LRC_RSVD0_SHIFT        (14U)
#define PXP_HW_PXP_OUT_PS_LRC_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PS_LRC_RSVD0_SHIFT)) & PXP_HW_PXP_OUT_PS_LRC_RSVD0_MASK)
#define PXP_HW_PXP_OUT_PS_LRC_X_MASK             (0x3FFF0000U)
#define PXP_HW_PXP_OUT_PS_LRC_X_SHIFT            (16U)
#define PXP_HW_PXP_OUT_PS_LRC_X(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PS_LRC_X_SHIFT)) & PXP_HW_PXP_OUT_PS_LRC_X_MASK)
#define PXP_HW_PXP_OUT_PS_LRC_RSVD1_MASK         (0xC0000000U)
#define PXP_HW_PXP_OUT_PS_LRC_RSVD1_SHIFT        (30U)
#define PXP_HW_PXP_OUT_PS_LRC_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_PS_LRC_RSVD1_SHIFT)) & PXP_HW_PXP_OUT_PS_LRC_RSVD1_MASK)

/*! @name HW_PXP_OUT_AS_ULC - Alpha Surface Upper Left Coordinate */
#define PXP_HW_PXP_OUT_AS_ULC_Y_MASK             (0x3FFFU)
#define PXP_HW_PXP_OUT_AS_ULC_Y_SHIFT            (0U)
#define PXP_HW_PXP_OUT_AS_ULC_Y(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_AS_ULC_Y_SHIFT)) & PXP_HW_PXP_OUT_AS_ULC_Y_MASK)
#define PXP_HW_PXP_OUT_AS_ULC_RSVD0_MASK         (0xC000U)
#define PXP_HW_PXP_OUT_AS_ULC_RSVD0_SHIFT        (14U)
#define PXP_HW_PXP_OUT_AS_ULC_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_AS_ULC_RSVD0_SHIFT)) & PXP_HW_PXP_OUT_AS_ULC_RSVD0_MASK)
#define PXP_HW_PXP_OUT_AS_ULC_X_MASK             (0x3FFF0000U)
#define PXP_HW_PXP_OUT_AS_ULC_X_SHIFT            (16U)
#define PXP_HW_PXP_OUT_AS_ULC_X(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_AS_ULC_X_SHIFT)) & PXP_HW_PXP_OUT_AS_ULC_X_MASK)
#define PXP_HW_PXP_OUT_AS_ULC_RSVD1_MASK         (0xC0000000U)
#define PXP_HW_PXP_OUT_AS_ULC_RSVD1_SHIFT        (30U)
#define PXP_HW_PXP_OUT_AS_ULC_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_AS_ULC_RSVD1_SHIFT)) & PXP_HW_PXP_OUT_AS_ULC_RSVD1_MASK)

/*! @name HW_PXP_OUT_AS_LRC - Alpha Surface Lower Right Coordinate */
#define PXP_HW_PXP_OUT_AS_LRC_Y_MASK             (0x3FFFU)
#define PXP_HW_PXP_OUT_AS_LRC_Y_SHIFT            (0U)
#define PXP_HW_PXP_OUT_AS_LRC_Y(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_AS_LRC_Y_SHIFT)) & PXP_HW_PXP_OUT_AS_LRC_Y_MASK)
#define PXP_HW_PXP_OUT_AS_LRC_RSVD0_MASK         (0xC000U)
#define PXP_HW_PXP_OUT_AS_LRC_RSVD0_SHIFT        (14U)
#define PXP_HW_PXP_OUT_AS_LRC_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_AS_LRC_RSVD0_SHIFT)) & PXP_HW_PXP_OUT_AS_LRC_RSVD0_MASK)
#define PXP_HW_PXP_OUT_AS_LRC_X_MASK             (0x3FFF0000U)
#define PXP_HW_PXP_OUT_AS_LRC_X_SHIFT            (16U)
#define PXP_HW_PXP_OUT_AS_LRC_X(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_AS_LRC_X_SHIFT)) & PXP_HW_PXP_OUT_AS_LRC_X_MASK)
#define PXP_HW_PXP_OUT_AS_LRC_RSVD1_MASK         (0xC0000000U)
#define PXP_HW_PXP_OUT_AS_LRC_RSVD1_SHIFT        (30U)
#define PXP_HW_PXP_OUT_AS_LRC_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_OUT_AS_LRC_RSVD1_SHIFT)) & PXP_HW_PXP_OUT_AS_LRC_RSVD1_MASK)

/*! @name HW_PXP_PS_CTRL - Processed Surface (PS) Control Register */
#define PXP_HW_PXP_PS_CTRL_FORMAT_MASK           (0x3FU)
#define PXP_HW_PXP_PS_CTRL_FORMAT_SHIFT          (0U)
#define PXP_HW_PXP_PS_CTRL_FORMAT(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CTRL_FORMAT_SHIFT)) & PXP_HW_PXP_PS_CTRL_FORMAT_MASK)
#define PXP_HW_PXP_PS_CTRL_WB_SWAP_MASK          (0x40U)
#define PXP_HW_PXP_PS_CTRL_WB_SWAP_SHIFT         (6U)
#define PXP_HW_PXP_PS_CTRL_RSVD0_MASK            (0x80U)
#define PXP_HW_PXP_PS_CTRL_RSVD0_SHIFT           (7U)
#define PXP_HW_PXP_PS_CTRL_DECY_MASK             (0x300U)
#define PXP_HW_PXP_PS_CTRL_DECY_SHIFT            (8U)
#define PXP_HW_PXP_PS_CTRL_DECY(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CTRL_DECY_SHIFT)) & PXP_HW_PXP_PS_CTRL_DECY_MASK)
#define PXP_HW_PXP_PS_CTRL_DECX_MASK             (0xC00U)
#define PXP_HW_PXP_PS_CTRL_DECX_SHIFT            (10U)
#define PXP_HW_PXP_PS_CTRL_DECX(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CTRL_DECX_SHIFT)) & PXP_HW_PXP_PS_CTRL_DECX_MASK)
#define PXP_HW_PXP_PS_CTRL_RSVD1_MASK            (0xFFFFF000U)
#define PXP_HW_PXP_PS_CTRL_RSVD1_SHIFT           (12U)
#define PXP_HW_PXP_PS_CTRL_RSVD1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CTRL_RSVD1_SHIFT)) & PXP_HW_PXP_PS_CTRL_RSVD1_MASK)

/*! @name HW_PXP_PS_BUF - PS Input Buffer Address */
#define PXP_HW_PXP_PS_BUF_ADDR_MASK              (0xFFFFFFFFU)
#define PXP_HW_PXP_PS_BUF_ADDR_SHIFT             (0U)
#define PXP_HW_PXP_PS_BUF_ADDR(x)                (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_BUF_ADDR_SHIFT)) & PXP_HW_PXP_PS_BUF_ADDR_MASK)

/*! @name HW_PXP_PS_UBUF - PS U/Cb or 2 Plane UV Input Buffer Address */
#define PXP_HW_PXP_PS_UBUF_ADDR_MASK             (0xFFFFFFFFU)
#define PXP_HW_PXP_PS_UBUF_ADDR_SHIFT            (0U)
#define PXP_HW_PXP_PS_UBUF_ADDR(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_UBUF_ADDR_SHIFT)) & PXP_HW_PXP_PS_UBUF_ADDR_MASK)

/*! @name HW_PXP_PS_VBUF - PS V/Cr Input Buffer Address */
#define PXP_HW_PXP_PS_VBUF_ADDR_MASK             (0xFFFFFFFFU)
#define PXP_HW_PXP_PS_VBUF_ADDR_SHIFT            (0U)
#define PXP_HW_PXP_PS_VBUF_ADDR(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_VBUF_ADDR_SHIFT)) & PXP_HW_PXP_PS_VBUF_ADDR_MASK)

/*! @name HW_PXP_PS_PITCH - Processed Surface Pitch */
#define PXP_HW_PXP_PS_PITCH_PITCH_MASK           (0xFFFFU)
#define PXP_HW_PXP_PS_PITCH_PITCH_SHIFT          (0U)
#define PXP_HW_PXP_PS_PITCH_PITCH(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_PITCH_PITCH_SHIFT)) & PXP_HW_PXP_PS_PITCH_PITCH_MASK)
#define PXP_HW_PXP_PS_PITCH_RSVD_MASK            (0xFFFF0000U)
#define PXP_HW_PXP_PS_PITCH_RSVD_SHIFT           (16U)
#define PXP_HW_PXP_PS_PITCH_RSVD(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_PITCH_RSVD_SHIFT)) & PXP_HW_PXP_PS_PITCH_RSVD_MASK)

/*! @name HW_PXP_PS_BACKGROUND_0 - PS Background Color */
#define PXP_HW_PXP_PS_BACKGROUND_0_COLOR_MASK    (0xFFFFFFU)
#define PXP_HW_PXP_PS_BACKGROUND_0_COLOR_SHIFT   (0U)
#define PXP_HW_PXP_PS_BACKGROUND_0_COLOR(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_BACKGROUND_0_COLOR_SHIFT)) & PXP_HW_PXP_PS_BACKGROUND_0_COLOR_MASK)
#define PXP_HW_PXP_PS_BACKGROUND_0_RSVD_MASK     (0xFF000000U)
#define PXP_HW_PXP_PS_BACKGROUND_0_RSVD_SHIFT    (24U)
#define PXP_HW_PXP_PS_BACKGROUND_0_RSVD(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_BACKGROUND_0_RSVD_SHIFT)) & PXP_HW_PXP_PS_BACKGROUND_0_RSVD_MASK)

/*! @name HW_PXP_PS_SCALE - PS Scale Factor Register */
#define PXP_HW_PXP_PS_SCALE_XSCALE_MASK          (0x7FFFU)
#define PXP_HW_PXP_PS_SCALE_XSCALE_SHIFT         (0U)
#define PXP_HW_PXP_PS_SCALE_XSCALE(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_SCALE_XSCALE_SHIFT)) & PXP_HW_PXP_PS_SCALE_XSCALE_MASK)
#define PXP_HW_PXP_PS_SCALE_RSVD1_MASK           (0x8000U)
#define PXP_HW_PXP_PS_SCALE_RSVD1_SHIFT          (15U)
#define PXP_HW_PXP_PS_SCALE_YSCALE_MASK          (0x7FFF0000U)
#define PXP_HW_PXP_PS_SCALE_YSCALE_SHIFT         (16U)
#define PXP_HW_PXP_PS_SCALE_YSCALE(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_SCALE_YSCALE_SHIFT)) & PXP_HW_PXP_PS_SCALE_YSCALE_MASK)
#define PXP_HW_PXP_PS_SCALE_RSVD2_MASK           (0x80000000U)
#define PXP_HW_PXP_PS_SCALE_RSVD2_SHIFT          (31U)

/*! @name HW_PXP_PS_OFFSET - PS Scale Offset Register */
#define PXP_HW_PXP_PS_OFFSET_XOFFSET_MASK        (0xFFFU)
#define PXP_HW_PXP_PS_OFFSET_XOFFSET_SHIFT       (0U)
#define PXP_HW_PXP_PS_OFFSET_XOFFSET(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_OFFSET_XOFFSET_SHIFT)) & PXP_HW_PXP_PS_OFFSET_XOFFSET_MASK)
#define PXP_HW_PXP_PS_OFFSET_RSVD1_MASK          (0xF000U)
#define PXP_HW_PXP_PS_OFFSET_RSVD1_SHIFT         (12U)
#define PXP_HW_PXP_PS_OFFSET_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_OFFSET_RSVD1_SHIFT)) & PXP_HW_PXP_PS_OFFSET_RSVD1_MASK)
#define PXP_HW_PXP_PS_OFFSET_YOFFSET_MASK        (0xFFF0000U)
#define PXP_HW_PXP_PS_OFFSET_YOFFSET_SHIFT       (16U)
#define PXP_HW_PXP_PS_OFFSET_YOFFSET(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_OFFSET_YOFFSET_SHIFT)) & PXP_HW_PXP_PS_OFFSET_YOFFSET_MASK)
#define PXP_HW_PXP_PS_OFFSET_RSVD2_MASK          (0xF0000000U)
#define PXP_HW_PXP_PS_OFFSET_RSVD2_SHIFT         (28U)
#define PXP_HW_PXP_PS_OFFSET_RSVD2(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_OFFSET_RSVD2_SHIFT)) & PXP_HW_PXP_PS_OFFSET_RSVD2_MASK)

/*! @name HW_PXP_PS_CLRKEYLOW_0 - PS Color Key Low */
#define PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL_MASK     (0xFFFFFFU)
#define PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL_SHIFT    (0U)
#define PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL_SHIFT)) & PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL_MASK)
#define PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1_MASK     (0xFF000000U)
#define PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1_SHIFT    (24U)
#define PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1_SHIFT)) & PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1_MASK)

/*! @name HW_PXP_PS_CLRKEYHIGH_0 - PS Color Key High */
#define PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL_MASK    (0xFFFFFFU)
#define PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL_SHIFT   (0U)
#define PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL_SHIFT)) & PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL_MASK)
#define PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1_MASK    (0xFF000000U)
#define PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1_SHIFT   (24U)
#define PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1_SHIFT)) & PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1_MASK)

/*! @name HW_PXP_AS_CTRL - Alpha Surface Control */
#define PXP_HW_PXP_AS_CTRL_RSVD0_MASK            (0x1U)
#define PXP_HW_PXP_AS_CTRL_RSVD0_SHIFT           (0U)
#define PXP_HW_PXP_AS_CTRL_ALPHA_CTRL_MASK       (0x6U)
#define PXP_HW_PXP_AS_CTRL_ALPHA_CTRL_SHIFT      (1U)
#define PXP_HW_PXP_AS_CTRL_ALPHA_CTRL(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CTRL_ALPHA_CTRL_SHIFT)) & PXP_HW_PXP_AS_CTRL_ALPHA_CTRL_MASK)
#define PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY_MASK  (0x8U)
#define PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY_SHIFT (3U)
#define PXP_HW_PXP_AS_CTRL_FORMAT_MASK           (0xF0U)
#define PXP_HW_PXP_AS_CTRL_FORMAT_SHIFT          (4U)
#define PXP_HW_PXP_AS_CTRL_FORMAT(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CTRL_FORMAT_SHIFT)) & PXP_HW_PXP_AS_CTRL_FORMAT_MASK)
#define PXP_HW_PXP_AS_CTRL_ALPHA_MASK            (0xFF00U)
#define PXP_HW_PXP_AS_CTRL_ALPHA_SHIFT           (8U)
#define PXP_HW_PXP_AS_CTRL_ALPHA(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CTRL_ALPHA_SHIFT)) & PXP_HW_PXP_AS_CTRL_ALPHA_MASK)
#define PXP_HW_PXP_AS_CTRL_ROP_MASK              (0xF0000U)
#define PXP_HW_PXP_AS_CTRL_ROP_SHIFT             (16U)
#define PXP_HW_PXP_AS_CTRL_ROP(x)                (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CTRL_ROP_SHIFT)) & PXP_HW_PXP_AS_CTRL_ROP_MASK)
#define PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT_MASK    (0x100000U)
#define PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT_SHIFT   (20U)
#define PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT_MASK    (0x200000U)
#define PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT_SHIFT   (21U)
#define PXP_HW_PXP_AS_CTRL_RSVD1_MASK            (0xFFC00000U)
#define PXP_HW_PXP_AS_CTRL_RSVD1_SHIFT           (22U)
#define PXP_HW_PXP_AS_CTRL_RSVD1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CTRL_RSVD1_SHIFT)) & PXP_HW_PXP_AS_CTRL_RSVD1_MASK)

/*! @name HW_PXP_AS_BUF - Alpha Surface Buffer Pointer */
#define PXP_HW_PXP_AS_BUF_ADDR_MASK              (0xFFFFFFFFU)
#define PXP_HW_PXP_AS_BUF_ADDR_SHIFT             (0U)
#define PXP_HW_PXP_AS_BUF_ADDR(x)                (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_BUF_ADDR_SHIFT)) & PXP_HW_PXP_AS_BUF_ADDR_MASK)

/*! @name HW_PXP_AS_PITCH - Alpha Surface Pitch */
#define PXP_HW_PXP_AS_PITCH_PITCH_MASK           (0xFFFFU)
#define PXP_HW_PXP_AS_PITCH_PITCH_SHIFT          (0U)
#define PXP_HW_PXP_AS_PITCH_PITCH(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_PITCH_PITCH_SHIFT)) & PXP_HW_PXP_AS_PITCH_PITCH_MASK)
#define PXP_HW_PXP_AS_PITCH_RSVD_MASK            (0xFFFF0000U)
#define PXP_HW_PXP_AS_PITCH_RSVD_SHIFT           (16U)
#define PXP_HW_PXP_AS_PITCH_RSVD(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_PITCH_RSVD_SHIFT)) & PXP_HW_PXP_AS_PITCH_RSVD_MASK)

/*! @name HW_PXP_AS_CLRKEYLOW_0 - Overlay Color Key Low */
#define PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL_MASK     (0xFFFFFFU)
#define PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL_SHIFT    (0U)
#define PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL_SHIFT)) & PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL_MASK)
#define PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1_MASK     (0xFF000000U)
#define PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1_SHIFT    (24U)
#define PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1_SHIFT)) & PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1_MASK)

/*! @name HW_PXP_AS_CLRKEYHIGH_0 - Overlay Color Key High */
#define PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL_MASK    (0xFFFFFFU)
#define PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL_SHIFT   (0U)
#define PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL_SHIFT)) & PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL_MASK)
#define PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1_MASK    (0xFF000000U)
#define PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1_SHIFT   (24U)
#define PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1_SHIFT)) & PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1_MASK)

/*! @name HW_PXP_CSC1_COEF0 - Color Space Conversion Coefficient Register 0 */
#define PXP_HW_PXP_CSC1_COEF0_Y_OFFSET_MASK      (0x1FFU)
#define PXP_HW_PXP_CSC1_COEF0_Y_OFFSET_SHIFT     (0U)
#define PXP_HW_PXP_CSC1_COEF0_Y_OFFSET(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF0_Y_OFFSET_SHIFT)) & PXP_HW_PXP_CSC1_COEF0_Y_OFFSET_MASK)
#define PXP_HW_PXP_CSC1_COEF0_UV_OFFSET_MASK     (0x3FE00U)
#define PXP_HW_PXP_CSC1_COEF0_UV_OFFSET_SHIFT    (9U)
#define PXP_HW_PXP_CSC1_COEF0_UV_OFFSET(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF0_UV_OFFSET_SHIFT)) & PXP_HW_PXP_CSC1_COEF0_UV_OFFSET_MASK)
#define PXP_HW_PXP_CSC1_COEF0_C0_MASK            (0x1FFC0000U)
#define PXP_HW_PXP_CSC1_COEF0_C0_SHIFT           (18U)
#define PXP_HW_PXP_CSC1_COEF0_C0(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF0_C0_SHIFT)) & PXP_HW_PXP_CSC1_COEF0_C0_MASK)
#define PXP_HW_PXP_CSC1_COEF0_RSVD1_MASK         (0x20000000U)
#define PXP_HW_PXP_CSC1_COEF0_RSVD1_SHIFT        (29U)
#define PXP_HW_PXP_CSC1_COEF0_BYPASS_MASK        (0x40000000U)
#define PXP_HW_PXP_CSC1_COEF0_BYPASS_SHIFT       (30U)
#define PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE_MASK    (0x80000000U)
#define PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE_SHIFT   (31U)

/*! @name HW_PXP_CSC1_COEF1 - Color Space Conversion Coefficient Register 1 */
#define PXP_HW_PXP_CSC1_COEF1_C4_MASK            (0x7FFU)
#define PXP_HW_PXP_CSC1_COEF1_C4_SHIFT           (0U)
#define PXP_HW_PXP_CSC1_COEF1_C4(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF1_C4_SHIFT)) & PXP_HW_PXP_CSC1_COEF1_C4_MASK)
#define PXP_HW_PXP_CSC1_COEF1_RSVD0_MASK         (0xF800U)
#define PXP_HW_PXP_CSC1_COEF1_RSVD0_SHIFT        (11U)
#define PXP_HW_PXP_CSC1_COEF1_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF1_RSVD0_SHIFT)) & PXP_HW_PXP_CSC1_COEF1_RSVD0_MASK)
#define PXP_HW_PXP_CSC1_COEF1_C1_MASK            (0x7FF0000U)
#define PXP_HW_PXP_CSC1_COEF1_C1_SHIFT           (16U)
#define PXP_HW_PXP_CSC1_COEF1_C1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF1_C1_SHIFT)) & PXP_HW_PXP_CSC1_COEF1_C1_MASK)
#define PXP_HW_PXP_CSC1_COEF1_RSVD1_MASK         (0xF8000000U)
#define PXP_HW_PXP_CSC1_COEF1_RSVD1_SHIFT        (27U)
#define PXP_HW_PXP_CSC1_COEF1_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF1_RSVD1_SHIFT)) & PXP_HW_PXP_CSC1_COEF1_RSVD1_MASK)

/*! @name HW_PXP_CSC1_COEF2 - Color Space Conversion Coefficient Register 2 */
#define PXP_HW_PXP_CSC1_COEF2_C3_MASK            (0x7FFU)
#define PXP_HW_PXP_CSC1_COEF2_C3_SHIFT           (0U)
#define PXP_HW_PXP_CSC1_COEF2_C3(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF2_C3_SHIFT)) & PXP_HW_PXP_CSC1_COEF2_C3_MASK)
#define PXP_HW_PXP_CSC1_COEF2_RSVD0_MASK         (0xF800U)
#define PXP_HW_PXP_CSC1_COEF2_RSVD0_SHIFT        (11U)
#define PXP_HW_PXP_CSC1_COEF2_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF2_RSVD0_SHIFT)) & PXP_HW_PXP_CSC1_COEF2_RSVD0_MASK)
#define PXP_HW_PXP_CSC1_COEF2_C2_MASK            (0x7FF0000U)
#define PXP_HW_PXP_CSC1_COEF2_C2_SHIFT           (16U)
#define PXP_HW_PXP_CSC1_COEF2_C2(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF2_C2_SHIFT)) & PXP_HW_PXP_CSC1_COEF2_C2_MASK)
#define PXP_HW_PXP_CSC1_COEF2_RSVD1_MASK         (0xF8000000U)
#define PXP_HW_PXP_CSC1_COEF2_RSVD1_SHIFT        (27U)
#define PXP_HW_PXP_CSC1_COEF2_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC1_COEF2_RSVD1_SHIFT)) & PXP_HW_PXP_CSC1_COEF2_RSVD1_MASK)

/*! @name HW_PXP_CSC2_CTRL - Color Space Conversion Control Register. */
#define PXP_HW_PXP_CSC2_CTRL_BYPASS_MASK         (0x1U)
#define PXP_HW_PXP_CSC2_CTRL_BYPASS_SHIFT        (0U)
#define PXP_HW_PXP_CSC2_CTRL_CSC_MODE_MASK       (0x6U)
#define PXP_HW_PXP_CSC2_CTRL_CSC_MODE_SHIFT      (1U)
#define PXP_HW_PXP_CSC2_CTRL_CSC_MODE(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_CTRL_CSC_MODE_SHIFT)) & PXP_HW_PXP_CSC2_CTRL_CSC_MODE_MASK)
#define PXP_HW_PXP_CSC2_CTRL_RSVD_MASK           (0xFFFFFFF8U)
#define PXP_HW_PXP_CSC2_CTRL_RSVD_SHIFT          (3U)
#define PXP_HW_PXP_CSC2_CTRL_RSVD(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_CTRL_RSVD_SHIFT)) & PXP_HW_PXP_CSC2_CTRL_RSVD_MASK)

/*! @name HW_PXP_CSC2_COEF0 - Color Space Conversion Coefficient Register 0 */
#define PXP_HW_PXP_CSC2_COEF0_A1_MASK            (0x7FFU)
#define PXP_HW_PXP_CSC2_COEF0_A1_SHIFT           (0U)
#define PXP_HW_PXP_CSC2_COEF0_A1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF0_A1_SHIFT)) & PXP_HW_PXP_CSC2_COEF0_A1_MASK)
#define PXP_HW_PXP_CSC2_COEF0_RSVD0_MASK         (0xF800U)
#define PXP_HW_PXP_CSC2_COEF0_RSVD0_SHIFT        (11U)
#define PXP_HW_PXP_CSC2_COEF0_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF0_RSVD0_SHIFT)) & PXP_HW_PXP_CSC2_COEF0_RSVD0_MASK)
#define PXP_HW_PXP_CSC2_COEF0_A2_MASK            (0x7FF0000U)
#define PXP_HW_PXP_CSC2_COEF0_A2_SHIFT           (16U)
#define PXP_HW_PXP_CSC2_COEF0_A2(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF0_A2_SHIFT)) & PXP_HW_PXP_CSC2_COEF0_A2_MASK)
#define PXP_HW_PXP_CSC2_COEF0_RSVD1_MASK         (0xF8000000U)
#define PXP_HW_PXP_CSC2_COEF0_RSVD1_SHIFT        (27U)
#define PXP_HW_PXP_CSC2_COEF0_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF0_RSVD1_SHIFT)) & PXP_HW_PXP_CSC2_COEF0_RSVD1_MASK)

/*! @name HW_PXP_CSC2_COEF1 - Color Space Conversion Coefficient Register 1 */
#define PXP_HW_PXP_CSC2_COEF1_A3_MASK            (0x7FFU)
#define PXP_HW_PXP_CSC2_COEF1_A3_SHIFT           (0U)
#define PXP_HW_PXP_CSC2_COEF1_A3(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF1_A3_SHIFT)) & PXP_HW_PXP_CSC2_COEF1_A3_MASK)
#define PXP_HW_PXP_CSC2_COEF1_RSVD0_MASK         (0xF800U)
#define PXP_HW_PXP_CSC2_COEF1_RSVD0_SHIFT        (11U)
#define PXP_HW_PXP_CSC2_COEF1_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF1_RSVD0_SHIFT)) & PXP_HW_PXP_CSC2_COEF1_RSVD0_MASK)
#define PXP_HW_PXP_CSC2_COEF1_B1_MASK            (0x7FF0000U)
#define PXP_HW_PXP_CSC2_COEF1_B1_SHIFT           (16U)
#define PXP_HW_PXP_CSC2_COEF1_B1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF1_B1_SHIFT)) & PXP_HW_PXP_CSC2_COEF1_B1_MASK)
#define PXP_HW_PXP_CSC2_COEF1_RSVD1_MASK         (0xF8000000U)
#define PXP_HW_PXP_CSC2_COEF1_RSVD1_SHIFT        (27U)
#define PXP_HW_PXP_CSC2_COEF1_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF1_RSVD1_SHIFT)) & PXP_HW_PXP_CSC2_COEF1_RSVD1_MASK)

/*! @name HW_PXP_CSC2_COEF2 - Color Space Conversion Coefficient Register 2 */
#define PXP_HW_PXP_CSC2_COEF2_B2_MASK            (0x7FFU)
#define PXP_HW_PXP_CSC2_COEF2_B2_SHIFT           (0U)
#define PXP_HW_PXP_CSC2_COEF2_B2(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF2_B2_SHIFT)) & PXP_HW_PXP_CSC2_COEF2_B2_MASK)
#define PXP_HW_PXP_CSC2_COEF2_RSVD0_MASK         (0xF800U)
#define PXP_HW_PXP_CSC2_COEF2_RSVD0_SHIFT        (11U)
#define PXP_HW_PXP_CSC2_COEF2_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF2_RSVD0_SHIFT)) & PXP_HW_PXP_CSC2_COEF2_RSVD0_MASK)
#define PXP_HW_PXP_CSC2_COEF2_B3_MASK            (0x7FF0000U)
#define PXP_HW_PXP_CSC2_COEF2_B3_SHIFT           (16U)
#define PXP_HW_PXP_CSC2_COEF2_B3(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF2_B3_SHIFT)) & PXP_HW_PXP_CSC2_COEF2_B3_MASK)
#define PXP_HW_PXP_CSC2_COEF2_RSVD1_MASK         (0xF8000000U)
#define PXP_HW_PXP_CSC2_COEF2_RSVD1_SHIFT        (27U)
#define PXP_HW_PXP_CSC2_COEF2_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF2_RSVD1_SHIFT)) & PXP_HW_PXP_CSC2_COEF2_RSVD1_MASK)

/*! @name HW_PXP_CSC2_COEF3 - Color Space Conversion Coefficient Register 3 */
#define PXP_HW_PXP_CSC2_COEF3_C1_MASK            (0x7FFU)
#define PXP_HW_PXP_CSC2_COEF3_C1_SHIFT           (0U)
#define PXP_HW_PXP_CSC2_COEF3_C1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF3_C1_SHIFT)) & PXP_HW_PXP_CSC2_COEF3_C1_MASK)
#define PXP_HW_PXP_CSC2_COEF3_RSVD0_MASK         (0xF800U)
#define PXP_HW_PXP_CSC2_COEF3_RSVD0_SHIFT        (11U)
#define PXP_HW_PXP_CSC2_COEF3_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF3_RSVD0_SHIFT)) & PXP_HW_PXP_CSC2_COEF3_RSVD0_MASK)
#define PXP_HW_PXP_CSC2_COEF3_C2_MASK            (0x7FF0000U)
#define PXP_HW_PXP_CSC2_COEF3_C2_SHIFT           (16U)
#define PXP_HW_PXP_CSC2_COEF3_C2(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF3_C2_SHIFT)) & PXP_HW_PXP_CSC2_COEF3_C2_MASK)
#define PXP_HW_PXP_CSC2_COEF3_RSVD1_MASK         (0xF8000000U)
#define PXP_HW_PXP_CSC2_COEF3_RSVD1_SHIFT        (27U)
#define PXP_HW_PXP_CSC2_COEF3_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF3_RSVD1_SHIFT)) & PXP_HW_PXP_CSC2_COEF3_RSVD1_MASK)

/*! @name HW_PXP_CSC2_COEF4 - Color Space Conversion Coefficient Register 4 */
#define PXP_HW_PXP_CSC2_COEF4_C3_MASK            (0x7FFU)
#define PXP_HW_PXP_CSC2_COEF4_C3_SHIFT           (0U)
#define PXP_HW_PXP_CSC2_COEF4_C3(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF4_C3_SHIFT)) & PXP_HW_PXP_CSC2_COEF4_C3_MASK)
#define PXP_HW_PXP_CSC2_COEF4_RSVD0_MASK         (0xF800U)
#define PXP_HW_PXP_CSC2_COEF4_RSVD0_SHIFT        (11U)
#define PXP_HW_PXP_CSC2_COEF4_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF4_RSVD0_SHIFT)) & PXP_HW_PXP_CSC2_COEF4_RSVD0_MASK)
#define PXP_HW_PXP_CSC2_COEF4_D1_MASK            (0x1FF0000U)
#define PXP_HW_PXP_CSC2_COEF4_D1_SHIFT           (16U)
#define PXP_HW_PXP_CSC2_COEF4_D1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF4_D1_SHIFT)) & PXP_HW_PXP_CSC2_COEF4_D1_MASK)
#define PXP_HW_PXP_CSC2_COEF4_RSVD1_MASK         (0xFE000000U)
#define PXP_HW_PXP_CSC2_COEF4_RSVD1_SHIFT        (25U)
#define PXP_HW_PXP_CSC2_COEF4_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF4_RSVD1_SHIFT)) & PXP_HW_PXP_CSC2_COEF4_RSVD1_MASK)

/*! @name HW_PXP_CSC2_COEF5 - Color Space Conversion Coefficient Register 5 */
#define PXP_HW_PXP_CSC2_COEF5_D2_MASK            (0x1FFU)
#define PXP_HW_PXP_CSC2_COEF5_D2_SHIFT           (0U)
#define PXP_HW_PXP_CSC2_COEF5_D2(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF5_D2_SHIFT)) & PXP_HW_PXP_CSC2_COEF5_D2_MASK)
#define PXP_HW_PXP_CSC2_COEF5_RSVD0_MASK         (0xFE00U)
#define PXP_HW_PXP_CSC2_COEF5_RSVD0_SHIFT        (9U)
#define PXP_HW_PXP_CSC2_COEF5_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF5_RSVD0_SHIFT)) & PXP_HW_PXP_CSC2_COEF5_RSVD0_MASK)
#define PXP_HW_PXP_CSC2_COEF5_D3_MASK            (0x1FF0000U)
#define PXP_HW_PXP_CSC2_COEF5_D3_SHIFT           (16U)
#define PXP_HW_PXP_CSC2_COEF5_D3(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF5_D3_SHIFT)) & PXP_HW_PXP_CSC2_COEF5_D3_MASK)
#define PXP_HW_PXP_CSC2_COEF5_RSVD1_MASK         (0xFE000000U)
#define PXP_HW_PXP_CSC2_COEF5_RSVD1_SHIFT        (25U)
#define PXP_HW_PXP_CSC2_COEF5_RSVD1(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CSC2_COEF5_RSVD1_SHIFT)) & PXP_HW_PXP_CSC2_COEF5_RSVD1_MASK)

/*! @name HW_PXP_LUT_CTRL - Lookup Table Control Register. */
#define PXP_HW_PXP_LUT_CTRL_DMA_START_MASK       (0x1U)
#define PXP_HW_PXP_LUT_CTRL_DMA_START_SHIFT      (0U)
#define PXP_HW_PXP_LUT_CTRL_RSVD0_MASK           (0xFEU)
#define PXP_HW_PXP_LUT_CTRL_RSVD0_SHIFT          (1U)
#define PXP_HW_PXP_LUT_CTRL_RSVD0(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_LUT_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_LUT_CTRL_INVALID_MASK         (0x100U)
#define PXP_HW_PXP_LUT_CTRL_INVALID_SHIFT        (8U)
#define PXP_HW_PXP_LUT_CTRL_LRU_UPD_MASK         (0x200U)
#define PXP_HW_PXP_LUT_CTRL_LRU_UPD_SHIFT        (9U)
#define PXP_HW_PXP_LUT_CTRL_SEL_8KB_MASK         (0x400U)
#define PXP_HW_PXP_LUT_CTRL_SEL_8KB_SHIFT        (10U)
#define PXP_HW_PXP_LUT_CTRL_RSVD1_MASK           (0xF800U)
#define PXP_HW_PXP_LUT_CTRL_RSVD1_SHIFT          (11U)
#define PXP_HW_PXP_LUT_CTRL_RSVD1(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_CTRL_RSVD1_SHIFT)) & PXP_HW_PXP_LUT_CTRL_RSVD1_MASK)
#define PXP_HW_PXP_LUT_CTRL_OUT_MODE_MASK        (0x30000U)
#define PXP_HW_PXP_LUT_CTRL_OUT_MODE_SHIFT       (16U)
#define PXP_HW_PXP_LUT_CTRL_OUT_MODE(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_CTRL_OUT_MODE_SHIFT)) & PXP_HW_PXP_LUT_CTRL_OUT_MODE_MASK)
#define PXP_HW_PXP_LUT_CTRL_RSVD2_MASK           (0xFC0000U)
#define PXP_HW_PXP_LUT_CTRL_RSVD2_SHIFT          (18U)
#define PXP_HW_PXP_LUT_CTRL_RSVD2(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_CTRL_RSVD2_SHIFT)) & PXP_HW_PXP_LUT_CTRL_RSVD2_MASK)
#define PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE_MASK     (0x3000000U)
#define PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE_SHIFT    (24U)
#define PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE_SHIFT)) & PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE_MASK)
#define PXP_HW_PXP_LUT_CTRL_RSVD3_MASK           (0x7C000000U)
#define PXP_HW_PXP_LUT_CTRL_RSVD3_SHIFT          (26U)
#define PXP_HW_PXP_LUT_CTRL_RSVD3(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_CTRL_RSVD3_SHIFT)) & PXP_HW_PXP_LUT_CTRL_RSVD3_MASK)
#define PXP_HW_PXP_LUT_CTRL_BYPASS_MASK          (0x80000000U)
#define PXP_HW_PXP_LUT_CTRL_BYPASS_SHIFT         (31U)

/*! @name HW_PXP_LUT_ADDR - Lookup Table Control Register. */
#define PXP_HW_PXP_LUT_ADDR_ADDR_MASK            (0x3FFFU)
#define PXP_HW_PXP_LUT_ADDR_ADDR_SHIFT           (0U)
#define PXP_HW_PXP_LUT_ADDR_ADDR(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_ADDR_ADDR_SHIFT)) & PXP_HW_PXP_LUT_ADDR_ADDR_MASK)
#define PXP_HW_PXP_LUT_ADDR_RSVD1_MASK           (0xC000U)
#define PXP_HW_PXP_LUT_ADDR_RSVD1_SHIFT          (14U)
#define PXP_HW_PXP_LUT_ADDR_RSVD1(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_ADDR_RSVD1_SHIFT)) & PXP_HW_PXP_LUT_ADDR_RSVD1_MASK)
#define PXP_HW_PXP_LUT_ADDR_NUM_BYTES_MASK       (0x7FFF0000U)
#define PXP_HW_PXP_LUT_ADDR_NUM_BYTES_SHIFT      (16U)
#define PXP_HW_PXP_LUT_ADDR_NUM_BYTES(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_ADDR_NUM_BYTES_SHIFT)) & PXP_HW_PXP_LUT_ADDR_NUM_BYTES_MASK)
#define PXP_HW_PXP_LUT_ADDR_RSVD2_MASK           (0x80000000U)
#define PXP_HW_PXP_LUT_ADDR_RSVD2_SHIFT          (31U)

/*! @name HW_PXP_LUT_DATA - Lookup Table Data Register. */
#define PXP_HW_PXP_LUT_DATA_DATA_MASK            (0xFFFFFFFFU)
#define PXP_HW_PXP_LUT_DATA_DATA_SHIFT           (0U)
#define PXP_HW_PXP_LUT_DATA_DATA(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_DATA_DATA_SHIFT)) & PXP_HW_PXP_LUT_DATA_DATA_MASK)

/*! @name HW_PXP_LUT_EXTMEM - Lookup Table External Memory Address Register. */
#define PXP_HW_PXP_LUT_EXTMEM_ADDR_MASK          (0xFFFFFFFFU)
#define PXP_HW_PXP_LUT_EXTMEM_ADDR_SHIFT         (0U)
#define PXP_HW_PXP_LUT_EXTMEM_ADDR(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_LUT_EXTMEM_ADDR_SHIFT)) & PXP_HW_PXP_LUT_EXTMEM_ADDR_MASK)

/*! @name HW_PXP_CFA - Color Filter Array Register. */
#define PXP_HW_PXP_CFA_DATA_MASK                 (0xFFFFFFFFU)
#define PXP_HW_PXP_CFA_DATA_SHIFT                (0U)
#define PXP_HW_PXP_CFA_DATA(x)                   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CFA_DATA_SHIFT)) & PXP_HW_PXP_CFA_DATA_MASK)

/*! @name HW_PXP_ALPHA_A_CTRL - PXP Alpha Engine A Control Register. */
#define PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE_MASK (0x1U)
#define PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE_SHIFT (0U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE_MASK (0x6U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE_SHIFT (1U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE_SHIFT)) & PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE_MASK)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE_MASK (0x18U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE_SHIFT (3U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE_SHIFT)) & PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE_MASK)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE_MASK (0x20U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE_SHIFT (5U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE_MASK (0x40U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE_SHIFT (6U)
#define PXP_HW_PXP_ALPHA_A_CTRL_RSVD1_MASK       (0x80U)
#define PXP_HW_PXP_ALPHA_A_CTRL_RSVD1_SHIFT      (7U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE_MASK (0x300U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE_SHIFT (8U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE_SHIFT)) & PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE_MASK)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE_MASK (0xC00U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE_SHIFT (10U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE_SHIFT)) & PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE_MASK)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE_MASK (0x1000U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE_SHIFT (12U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE_MASK (0x2000U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE_SHIFT (13U)
#define PXP_HW_PXP_ALPHA_A_CTRL_RSVD0_MASK       (0xC000U)
#define PXP_HW_PXP_ALPHA_A_CTRL_RSVD0_SHIFT      (14U)
#define PXP_HW_PXP_ALPHA_A_CTRL_RSVD0(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_A_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_ALPHA_A_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MASK (0xFF0000U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_SHIFT (16U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_SHIFT)) & PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MASK)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MASK (0xFF000000U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_SHIFT (24U)
#define PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_SHIFT)) & PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MASK)

/*! @name HW_PXP_ALPHA_B_CTRL - PXP Alpha Engine B Control Register. */
#define PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE_MASK (0x1U)
#define PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE_SHIFT (0U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE_MASK (0x6U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE_SHIFT (1U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE_MASK)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE_MASK (0x18U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE_SHIFT (3U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE_MASK)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE_MASK (0x20U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE_SHIFT (5U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE_MASK (0x40U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE_SHIFT (6U)
#define PXP_HW_PXP_ALPHA_B_CTRL_RSVD1_MASK       (0x80U)
#define PXP_HW_PXP_ALPHA_B_CTRL_RSVD1_SHIFT      (7U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE_MASK (0x300U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE_SHIFT (8U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE_MASK)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE_MASK (0xC00U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE_SHIFT (10U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE_MASK)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE_MASK (0x1000U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE_SHIFT (12U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE_MASK (0x2000U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE_SHIFT (13U)
#define PXP_HW_PXP_ALPHA_B_CTRL_RSVD0_MASK       (0xC000U)
#define PXP_HW_PXP_ALPHA_B_CTRL_RSVD0_SHIFT      (14U)
#define PXP_HW_PXP_ALPHA_B_CTRL_RSVD0(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MASK (0xFF0000U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_SHIFT (16U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MASK)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MASK (0xFF000000U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_SHIFT (24U)
#define PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MASK)

/*! @name HW_PXP_ALPHA_B_CTRL_1 -  */
#define PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE_MASK (0x1U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE_SHIFT (0U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE_MASK (0x2U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE_SHIFT (1U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1_MASK     (0xCU)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1_SHIFT    (2U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1_MASK)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_MASK       (0xF0U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_SHIFT      (4U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_ROP(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_MASK)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0_MASK     (0xFFFFFF00U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0_SHIFT    (8U)
#define PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0_SHIFT)) & PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0_MASK)

/*! @name HW_PXP_PS_BACKGROUND_1 - PS Background Color 1 */
#define PXP_HW_PXP_PS_BACKGROUND_1_COLOR_MASK    (0xFFFFFFU)
#define PXP_HW_PXP_PS_BACKGROUND_1_COLOR_SHIFT   (0U)
#define PXP_HW_PXP_PS_BACKGROUND_1_COLOR(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_BACKGROUND_1_COLOR_SHIFT)) & PXP_HW_PXP_PS_BACKGROUND_1_COLOR_MASK)
#define PXP_HW_PXP_PS_BACKGROUND_1_RSVD_MASK     (0xFF000000U)
#define PXP_HW_PXP_PS_BACKGROUND_1_RSVD_SHIFT    (24U)
#define PXP_HW_PXP_PS_BACKGROUND_1_RSVD(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_BACKGROUND_1_RSVD_SHIFT)) & PXP_HW_PXP_PS_BACKGROUND_1_RSVD_MASK)

/*! @name HW_PXP_PS_CLRKEYLOW_1 - PS Color Key Low 1 */
#define PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL_MASK     (0xFFFFFFU)
#define PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL_SHIFT    (0U)
#define PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL_SHIFT)) & PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL_MASK)
#define PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1_MASK     (0xFF000000U)
#define PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1_SHIFT    (24U)
#define PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1_SHIFT)) & PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1_MASK)

/*! @name HW_PXP_PS_CLRKEYHIGH_1 - PS Color Key High 1 */
#define PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL_MASK    (0xFFFFFFU)
#define PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL_SHIFT   (0U)
#define PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL_SHIFT)) & PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL_MASK)
#define PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1_MASK    (0xFF000000U)
#define PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1_SHIFT   (24U)
#define PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1_SHIFT)) & PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1_MASK)

/*! @name HW_PXP_AS_CLRKEYLOW_1 - Overlay Color Key Low */
#define PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL_MASK     (0xFFFFFFU)
#define PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL_SHIFT    (0U)
#define PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL_SHIFT)) & PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL_MASK)
#define PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1_MASK     (0xFF000000U)
#define PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1_SHIFT    (24U)
#define PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1_SHIFT)) & PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1_MASK)

/*! @name HW_PXP_AS_CLRKEYHIGH_1 - Overlay Color Key High */
#define PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL_MASK    (0xFFFFFFU)
#define PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL_SHIFT   (0U)
#define PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL_SHIFT)) & PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL_MASK)
#define PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1_MASK    (0xFF000000U)
#define PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1_SHIFT   (24U)
#define PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1_SHIFT)) & PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1_MASK)

/*! @name HW_PXP_CTRL2 - Control Register 2 */
#define PXP_HW_PXP_CTRL2_ENABLE_MASK             (0x1U)
#define PXP_HW_PXP_CTRL2_ENABLE_SHIFT            (0U)
#define PXP_HW_PXP_CTRL2_RSVD0_MASK              (0xFEU)
#define PXP_HW_PXP_CTRL2_RSVD0_SHIFT             (1U)
#define PXP_HW_PXP_CTRL2_RSVD0(x)                (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CTRL2_RSVD0_SHIFT)) & PXP_HW_PXP_CTRL2_RSVD0_MASK)
#define PXP_HW_PXP_CTRL2_ROTATE0_MASK            (0x300U)
#define PXP_HW_PXP_CTRL2_ROTATE0_SHIFT           (8U)
#define PXP_HW_PXP_CTRL2_ROTATE0(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CTRL2_ROTATE0_SHIFT)) & PXP_HW_PXP_CTRL2_ROTATE0_MASK)
#define PXP_HW_PXP_CTRL2_HFLIP0_MASK             (0x400U)
#define PXP_HW_PXP_CTRL2_HFLIP0_SHIFT            (10U)
#define PXP_HW_PXP_CTRL2_VFLIP0_MASK             (0x800U)
#define PXP_HW_PXP_CTRL2_VFLIP0_SHIFT            (11U)
#define PXP_HW_PXP_CTRL2_ROTATE1_MASK            (0x3000U)
#define PXP_HW_PXP_CTRL2_ROTATE1_SHIFT           (12U)
#define PXP_HW_PXP_CTRL2_ROTATE1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CTRL2_ROTATE1_SHIFT)) & PXP_HW_PXP_CTRL2_ROTATE1_MASK)
#define PXP_HW_PXP_CTRL2_HFLIP1_MASK             (0x4000U)
#define PXP_HW_PXP_CTRL2_HFLIP1_SHIFT            (14U)
#define PXP_HW_PXP_CTRL2_VFLIP1_MASK             (0x8000U)
#define PXP_HW_PXP_CTRL2_VFLIP1_SHIFT            (15U)
#define PXP_HW_PXP_CTRL2_RSVD1_MASK              (0x10000U)
#define PXP_HW_PXP_CTRL2_RSVD1_SHIFT             (16U)
#define PXP_HW_PXP_CTRL2_ENABLE_DITHER_MASK      (0x20000U)
#define PXP_HW_PXP_CTRL2_ENABLE_DITHER_SHIFT     (17U)
#define PXP_HW_PXP_CTRL2_ENABLE_WFE_A_MASK       (0x40000U)
#define PXP_HW_PXP_CTRL2_ENABLE_WFE_A_SHIFT      (18U)
#define PXP_HW_PXP_CTRL2_ENABLE_WFE_B_MASK       (0x80000U)
#define PXP_HW_PXP_CTRL2_ENABLE_WFE_B_SHIFT      (19U)
#define PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE_MASK (0x100000U)
#define PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE_SHIFT (20U)
#define PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B_MASK     (0x200000U)
#define PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B_SHIFT    (21U)
#define PXP_HW_PXP_CTRL2_RSVD2_MASK              (0x400000U)
#define PXP_HW_PXP_CTRL2_RSVD2_SHIFT             (22U)
#define PXP_HW_PXP_CTRL2_BLOCK_SIZE_MASK         (0x800000U)
#define PXP_HW_PXP_CTRL2_BLOCK_SIZE_SHIFT        (23U)
#define PXP_HW_PXP_CTRL2_ENABLE_CSC2_MASK        (0x1000000U)
#define PXP_HW_PXP_CTRL2_ENABLE_CSC2_SHIFT       (24U)
#define PXP_HW_PXP_CTRL2_ENABLE_LUT_MASK         (0x2000000U)
#define PXP_HW_PXP_CTRL2_ENABLE_LUT_SHIFT        (25U)
#define PXP_HW_PXP_CTRL2_ENABLE_ROTATE0_MASK     (0x4000000U)
#define PXP_HW_PXP_CTRL2_ENABLE_ROTATE0_SHIFT    (26U)
#define PXP_HW_PXP_CTRL2_ENABLE_ROTATE1_MASK     (0x8000000U)
#define PXP_HW_PXP_CTRL2_ENABLE_ROTATE1_SHIFT    (27U)
#define PXP_HW_PXP_CTRL2_RSVD3_MASK              (0xF0000000U)
#define PXP_HW_PXP_CTRL2_RSVD3_SHIFT             (28U)
#define PXP_HW_PXP_CTRL2_RSVD3(x)                (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_CTRL2_RSVD3_SHIFT)) & PXP_HW_PXP_CTRL2_RSVD3_MASK)

/*! @name HW_PXP_POWER_REG0 - PXP Power Control Register. */
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0_MASK (0x7U)
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0_SHIFT (0U)
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0_SHIFT)) & PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0_MASK)
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN_MASK (0x38U)
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN_SHIFT (3U)
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN_SHIFT)) & PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN_MASK)
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN_MASK (0x1C0U)
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN_SHIFT (6U)
#define PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN_SHIFT)) & PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN_MASK)
#define PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE_MASK (0xE00U)
#define PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE_SHIFT (9U)
#define PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG0_CTRL_MASK          (0xFFFFF000U)
#define PXP_HW_PXP_POWER_REG0_CTRL_SHIFT         (12U)
#define PXP_HW_PXP_POWER_REG0_CTRL(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG0_CTRL_SHIFT)) & PXP_HW_PXP_POWER_REG0_CTRL_MASK)

/*! @name HW_PXP_POWER_REG1 - PXP Power Control Register 1. */
#define PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE_MASK (0x7U)
#define PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE_SHIFT (0U)
#define PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE_MASK (0x38U)
#define PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE_SHIFT (3U)
#define PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE_MASK (0x1C0U)
#define PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE_SHIFT (6U)
#define PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE_MASK (0xE00U)
#define PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE_SHIFT (9U)
#define PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE_MASK (0x7000U)
#define PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE_SHIFT (12U)
#define PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE_MASK (0x38000U)
#define PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE_SHIFT (15U)
#define PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE_MASK (0x1C0000U)
#define PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE_SHIFT (18U)
#define PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE_MASK (0xE00000U)
#define PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE_SHIFT (21U)
#define PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE_SHIFT)) & PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE_MASK)
#define PXP_HW_PXP_POWER_REG1_RSVD0_MASK         (0xFF000000U)
#define PXP_HW_PXP_POWER_REG1_RSVD0_SHIFT        (24U)
#define PXP_HW_PXP_POWER_REG1_RSVD0(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_POWER_REG1_RSVD0_SHIFT)) & PXP_HW_PXP_POWER_REG1_RSVD0_MASK)

/*! @name HW_PXP_DATA_PATH_CTRL1 -  */
#define PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL_MASK (0x3U)
#define PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL_SHIFT (0U)
#define PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL_SHIFT)) & PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL_MASK)
#define PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL_MASK (0xCU)
#define PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL_SHIFT (2U)
#define PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL_SHIFT)) & PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL_MASK)
#define PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0_MASK    (0xFFFFFFF0U)
#define PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0_SHIFT   (4U)
#define PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0_SHIFT)) & PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0_MASK)

/*! @name HW_PXP_INIT_MEM_CTRL - Initialize memory buffer control Register */
#define PXP_HW_PXP_INIT_MEM_CTRL_ADDR_MASK       (0xFFFFU)
#define PXP_HW_PXP_INIT_MEM_CTRL_ADDR_SHIFT      (0U)
#define PXP_HW_PXP_INIT_MEM_CTRL_ADDR(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INIT_MEM_CTRL_ADDR_SHIFT)) & PXP_HW_PXP_INIT_MEM_CTRL_ADDR_MASK)
#define PXP_HW_PXP_INIT_MEM_CTRL_RSVD0_MASK      (0x7FF0000U)
#define PXP_HW_PXP_INIT_MEM_CTRL_RSVD0_SHIFT     (16U)
#define PXP_HW_PXP_INIT_MEM_CTRL_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INIT_MEM_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_INIT_MEM_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_INIT_MEM_CTRL_SELECT_MASK     (0x78000000U)
#define PXP_HW_PXP_INIT_MEM_CTRL_SELECT_SHIFT    (27U)
#define PXP_HW_PXP_INIT_MEM_CTRL_SELECT(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INIT_MEM_CTRL_SELECT_SHIFT)) & PXP_HW_PXP_INIT_MEM_CTRL_SELECT_MASK)
#define PXP_HW_PXP_INIT_MEM_CTRL_START_MASK      (0x80000000U)
#define PXP_HW_PXP_INIT_MEM_CTRL_START_SHIFT     (31U)

/*! @name HW_PXP_INIT_MEM_DATA - Write data Register */
#define PXP_HW_PXP_INIT_MEM_DATA_DATA_MASK       (0xFFFFFFFFU)
#define PXP_HW_PXP_INIT_MEM_DATA_DATA_SHIFT      (0U)
#define PXP_HW_PXP_INIT_MEM_DATA_DATA(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INIT_MEM_DATA_DATA_SHIFT)) & PXP_HW_PXP_INIT_MEM_DATA_DATA_MASK)

/*! @name HW_PXP_INIT_MEM_DATA_HIGH - Write data Register */
#define PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA_MASK  (0xFFFFFFFFU)
#define PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA_SHIFT (0U)
#define PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA_SHIFT)) & PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA_MASK)

/*! @name HW_PXP_IRQ_MASK - PXP IRQ Mask Register */
#define PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN_MASK (0x1U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN_SHIFT (0U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN_MASK (0x2U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN_SHIFT (1U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN_MASK (0x4U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN_SHIFT (2U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN_MASK (0x8U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN_SHIFT (3U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN_MASK (0x10U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN_SHIFT (4U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN_MASK (0x20U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN_SHIFT (5U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN_MASK (0x40U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN_SHIFT (6U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN_MASK (0x80U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN_SHIFT (7U)
#define PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN_MASK (0x100U)
#define PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN_SHIFT (8U)
#define PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN_MASK (0x200U)
#define PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN_SHIFT (9U)
#define PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN_MASK (0x400U)
#define PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN_SHIFT (10U)
#define PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN_MASK (0x800U)
#define PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN_SHIFT (11U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN_MASK (0x1000U)
#define PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN_SHIFT (12U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN_MASK (0x2000U)
#define PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN_SHIFT (13U)
#define PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN_MASK (0x4000U)
#define PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN_SHIFT (14U)
#define PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN_MASK (0x8000U)
#define PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN_SHIFT (15U)
#define PXP_HW_PXP_IRQ_MASK_RSVD1_MASK           (0x7FFF0000U)
#define PXP_HW_PXP_IRQ_MASK_RSVD1_SHIFT          (16U)
#define PXP_HW_PXP_IRQ_MASK_RSVD1(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_IRQ_MASK_RSVD1_SHIFT)) & PXP_HW_PXP_IRQ_MASK_RSVD1_MASK)
#define PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN_MASK (0x80000000U)
#define PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN_SHIFT (31U)

/*! @name HW_PXP_IRQ - PXP Interrupt Register */
#define PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ_MASK (0x1U)
#define PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ_SHIFT (0U)
#define PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ_MASK (0x2U)
#define PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ_SHIFT (1U)
#define PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ_MASK  (0x4U)
#define PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ_SHIFT (2U)
#define PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ_MASK  (0x8U)
#define PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ_SHIFT (3U)
#define PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ_MASK (0x10U)
#define PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ_SHIFT (4U)
#define PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ_MASK (0x20U)
#define PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ_SHIFT (5U)
#define PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ_MASK (0x40U)
#define PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ_SHIFT (6U)
#define PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ_MASK (0x80U)
#define PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ_SHIFT (7U)
#define PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ_MASK  (0x100U)
#define PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ_SHIFT (8U)
#define PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ_MASK  (0x200U)
#define PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ_SHIFT (9U)
#define PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ_MASK  (0x400U)
#define PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ_SHIFT (10U)
#define PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ_MASK  (0x800U)
#define PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ_SHIFT (11U)
#define PXP_HW_PXP_IRQ_FIRST_STORE_IRQ_MASK      (0x1000U)
#define PXP_HW_PXP_IRQ_FIRST_STORE_IRQ_SHIFT     (12U)
#define PXP_HW_PXP_IRQ_DITHER_STORE_IRQ_MASK     (0x2000U)
#define PXP_HW_PXP_IRQ_DITHER_STORE_IRQ_SHIFT    (13U)
#define PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ_MASK      (0x4000U)
#define PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ_SHIFT     (14U)
#define PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ_MASK      (0x8000U)
#define PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ_SHIFT     (15U)
#define PXP_HW_PXP_IRQ_RSVD1_MASK                (0x7FFF0000U)
#define PXP_HW_PXP_IRQ_RSVD1_SHIFT               (16U)
#define PXP_HW_PXP_IRQ_RSVD1(x)                  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_IRQ_RSVD1_SHIFT)) & PXP_HW_PXP_IRQ_RSVD1_MASK)
#define PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ_MASK    (0x80000000U)
#define PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ_SHIFT   (31U)

/*! @name HW_PXP_NEXT - Next Frame Pointer */
#define PXP_HW_PXP_NEXT_ENABLED_MASK             (0x1U)
#define PXP_HW_PXP_NEXT_ENABLED_SHIFT            (0U)
#define PXP_HW_PXP_NEXT_RSVD_MASK                (0x2U)
#define PXP_HW_PXP_NEXT_RSVD_SHIFT               (1U)
#define PXP_HW_PXP_NEXT_POINTER_MASK             (0xFFFFFFFCU)
#define PXP_HW_PXP_NEXT_POINTER_SHIFT            (2U)
#define PXP_HW_PXP_NEXT_POINTER(x)               (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_NEXT_POINTER_SHIFT)) & PXP_HW_PXP_NEXT_POINTER_MASK)

/*! @name HW_PXP_INPUT_FETCH_CTRL_CH0 - Pre-fetch engine Control Channel 0 Register */
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN_MASK (0x1U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN_MASK (0x2U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN_SHIFT (1U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16_MASK (0x4U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16_SHIFT (2U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN_MASK (0x8U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN_SHIFT (3U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN_MASK (0x10U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN_SHIFT (4U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE_MASK (0x20U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE_SHIFT (5U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4_MASK (0x1C0U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4_SHIFT (6U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP_MASK (0x200U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP_SHIFT (9U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP_MASK (0x400U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP_SHIFT (10U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3_MASK (0x800U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3_SHIFT (11U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE_MASK (0x3000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE_SHIFT (12U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2_MASK (0xC000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2_SHIFT (14U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES_MASK (0x30000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1_MASK (0xFC0000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1_SHIFT (18U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_MASK (0x3000000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_SHIFT (24U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0_MASK (0x7C000000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0_SHIFT (26U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN_MASK (0x80000000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN_SHIFT (31U)

/*! @name HW_PXP_INPUT_FETCH_CTRL_CH1 - Pre-fetch engine Control Channel 1 Register */
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN_MASK (0x1U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN_MASK (0x2U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN_SHIFT (1U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16_MASK (0x4U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16_SHIFT (2U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN_MASK (0x8U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN_SHIFT (3U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN_MASK (0x10U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN_SHIFT (4U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4_MASK (0x1E0U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4_SHIFT (5U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP_MASK (0x200U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP_SHIFT (9U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP_MASK (0x400U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP_SHIFT (10U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3_MASK (0x800U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3_SHIFT (11U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE_MASK (0x3000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE_SHIFT (12U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2_MASK (0xC000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2_SHIFT (14U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES_MASK (0x30000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1_MASK (0xFC0000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1_SHIFT (18U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_MASK (0x3000000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_SHIFT (24U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_MASK)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0_MASK (0xFC000000U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0_SHIFT (26U)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0_MASK)

/*! @name HW_PXP_INPUT_FETCH_STATUS_CH0 - Pre-fetch engine status Channel 0 Register */
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X_MASK)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y_MASK)

/*! @name HW_PXP_INPUT_FETCH_STATUS_CH1 - Store engine status Channel 1 Register */
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X_MASK)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y_MASK)

/*! @name HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X_MASK)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y_MASK)

/*! @name HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X_MASK)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y_MASK)

/*! @name HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X_MASK)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y_MASK)

/*! @name HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X_MASK)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y_MASK)

/*! @name HW_PXP_INPUT_FETCH_SIZE_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT_MASK)

/*! @name HW_PXP_INPUT_FETCH_SIZE_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT_MASK)

/*! @name HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR_MASK)

/*! @name HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR_MASK)

/*! @name HW_PXP_INPUT_FETCH_PITCH -  */
#define PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH_MASK)
#define PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH_MASK)

/*! @name HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_MASK (0x3U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1_MASK (0xFCU)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1_SHIFT (2U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_MASK (0x700U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_SHIFT (8U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN_MASK (0x800U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN_SHIFT (11U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS_MASK (0x1000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS_SHIFT (12U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0_MASK (0xFFFFE000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0_SHIFT (13U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0_MASK)

/*! @name HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_MASK (0x3U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1_MASK (0xFCU)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1_SHIFT (2U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_MASK (0x700U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_SHIFT (8U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN_MASK (0x800U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN_SHIFT (11U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS_MASK (0x1000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS_SHIFT (12U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0_MASK (0xFFFFE000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0_SHIFT (13U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0_MASK)

/*! @name HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0_MASK (0x1FU)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3_MASK (0xE0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3_SHIFT (5U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1_MASK (0x1F00U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1_SHIFT (8U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2_MASK (0xE000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2_SHIFT (13U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2_MASK (0x1F0000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1_MASK (0xE00000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1_SHIFT (21U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3_MASK (0x1F000000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3_SHIFT (24U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0_MASK (0xE0000000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0_SHIFT (29U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0_MASK)

/*! @name HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0_MASK (0x1FU)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3_MASK (0xE0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3_SHIFT (5U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1_MASK (0x1F00U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1_SHIFT (8U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2_MASK (0xE000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2_SHIFT (13U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2_MASK (0x1F0000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1_MASK (0xE00000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1_SHIFT (21U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3_MASK (0x1F000000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3_SHIFT (24U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0_MASK (0xE0000000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0_SHIFT (29U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0_MASK)

/*! @name HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0_MASK (0xFU)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1_MASK (0xF0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1_SHIFT (4U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2_MASK (0xF00U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2_SHIFT (8U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3_MASK (0xF000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3_SHIFT (12U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0_MASK)

/*! @name HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0_MASK (0xFU)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1_MASK (0xF0U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1_SHIFT (4U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2_MASK (0xF00U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2_SHIFT (8U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3_MASK (0xF000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3_SHIFT (12U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3_MASK)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0_SHIFT (16U)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0_MASK)

/*! @name HW_PXP_INPUT_FETCH_ADDR_0_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0_MASK)

/*! @name HW_PXP_INPUT_FETCH_ADDR_1_CH0 -  */
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1_MASK)

/*! @name HW_PXP_INPUT_FETCH_ADDR_0_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0_MASK)

/*! @name HW_PXP_INPUT_FETCH_ADDR_1_CH1 -  */
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1_SHIFT (0U)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1_SHIFT)) & PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1_MASK)

/*! @name HW_PXP_INPUT_STORE_CTRL_CH0 - Store engine Control Channel 0 Register */
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN_MASK (0x1U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN_MASK (0x2U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN_SHIFT (1U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16_MASK (0x4U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16_SHIFT (2U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN_MASK (0x8U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN_SHIFT (3U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN_MASK (0x10U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN_SHIFT (4U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM_MASK (0x60U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM_SHIFT (5U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM_MASK)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3_MASK (0x80U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3_SHIFT (7U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN_MASK (0x100U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN_MASK (0x200U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN_SHIFT (9U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL_MASK (0x400U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL_SHIFT (10U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN_MASK (0x800U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN_SHIFT (11U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2_MASK (0xF000U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2_SHIFT (12U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2_MASK)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES_MASK (0x30000U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES_MASK)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1_MASK (0xFC0000U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1_SHIFT (18U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1_MASK)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL_MASK (0x1000000U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL_SHIFT (24U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0_MASK (0x7E000000U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0_SHIFT (25U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0_MASK)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN_MASK (0x80000000U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN_SHIFT (31U)

/*! @name HW_PXP_INPUT_STORE_CTRL_CH1 - Store engine Control Channel 1 Register */
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN_MASK (0x1U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN_MASK (0x2U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN_SHIFT (1U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16_MASK (0x4U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16_SHIFT (2U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN_MASK (0x8U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN_SHIFT (3U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN_MASK (0x10U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN_SHIFT (4U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM_MASK (0x60U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM_SHIFT (5U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM_MASK)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3_MASK (0x80U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3_SHIFT (7U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN_MASK (0x100U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN_MASK (0x200U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN_SHIFT (9U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL_MASK (0x400U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL_SHIFT (10U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1_MASK (0xF800U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1_SHIFT (11U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1_MASK)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES_MASK (0x30000U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES_MASK)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0_MASK (0xFFFC0000U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0_SHIFT (18U)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0_MASK)

/*! @name HW_PXP_INPUT_STORE_STATUS_CH0 - Store engine status Channel 0 Register */
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X_SHIFT)) & PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X_MASK)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y_SHIFT)) & PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y_MASK)

/*! @name HW_PXP_INPUT_STORE_STATUS_CH1 - Store engine status Channel 1 Register */
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X_SHIFT)) & PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X_MASK)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y_SHIFT)) & PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y_MASK)

/*! @name HW_PXP_INPUT_STORE_SIZE_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH_MASK)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT_MASK)

/*! @name HW_PXP_INPUT_STORE_SIZE_CH1 -  */
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH_MASK)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT_MASK)

/*! @name HW_PXP_INPUT_STORE_PITCH -  */
#define PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH_MASK (0xFFFFU)
#define PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH_SHIFT)) & PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH_MASK)
#define PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH_MASK (0xFFFF0000U)
#define PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH_SHIFT)) & PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH_MASK)

/*! @name HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2_MASK (0x3U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2_MASK)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_MASK (0xCU)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_SHIFT (2U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_MASK)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN_MASK (0x10U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN_SHIFT (4U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN_MASK (0x20U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN_SHIFT (5U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1_MASK (0x40U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1_SHIFT (6U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS_MASK (0x80U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS_SHIFT (7U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0_MASK (0xFFFFFF00U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0_MASK)

/*! @name HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1 -  */
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2_MASK (0x3U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2_MASK)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_MASK (0xCU)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_SHIFT (2U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_MASK)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN_MASK (0x10U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN_SHIFT (4U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN_MASK (0x20U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN_SHIFT (5U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0_MASK (0xFFFFFFC0U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0_SHIFT (6U)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0_MASK)

/*! @name HW_PXP_INPUT_STORE_ADDR_0_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0_MASK)

/*! @name HW_PXP_INPUT_STORE_ADDR_1_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1_SHIFT)) & PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1_MASK)

/*! @name HW_PXP_INPUT_STORE_FILL_DATA_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_ADDR_0_CH1 -  */
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0_MASK)

/*! @name HW_PXP_INPUT_STORE_ADDR_1_CH1 -  */
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1_SHIFT)) & PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK0_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK0_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK1_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK1_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK2_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK2_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK3_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK3_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK4_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK4_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK5_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK5_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK6_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK6_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK7_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_MASK7_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0_MASK)

/*! @name HW_PXP_INPUT_STORE_D_SHIFT_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0_MASK (0x3FU)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0_MASK)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3_MASK (0x40U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3_SHIFT (6U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0_MASK (0x80U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0_SHIFT (7U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1_MASK (0x3F00U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1_MASK)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2_MASK (0x4000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2_SHIFT (14U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1_MASK (0x8000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1_SHIFT (15U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2_MASK (0x3F0000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2_MASK)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1_MASK (0x400000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1_SHIFT (22U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2_MASK (0x800000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2_SHIFT (23U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3_MASK (0x3F000000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3_SHIFT (24U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3_MASK)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0_MASK (0x40000000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0_SHIFT (30U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3_MASK (0x80000000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3_SHIFT (31U)

/*! @name HW_PXP_INPUT_STORE_D_SHIFT_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4_MASK (0x3FU)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4_MASK)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3_MASK (0x40U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3_SHIFT (6U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4_MASK (0x80U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4_SHIFT (7U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5_MASK (0x3F00U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5_MASK)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2_MASK (0x4000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2_SHIFT (14U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5_MASK (0x8000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5_SHIFT (15U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6_MASK (0x3F0000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6_MASK)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1_MASK (0x400000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1_SHIFT (22U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6_MASK (0x800000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6_SHIFT (23U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7_MASK (0x3F000000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7_SHIFT (24U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7_SHIFT)) & PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7_MASK)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0_MASK (0x40000000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0_SHIFT (30U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7_MASK (0x80000000U)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7_SHIFT (31U)

/*! @name HW_PXP_INPUT_STORE_F_SHIFT_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0_MASK (0x3FU)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0_MASK (0x40U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0_SHIFT (6U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3_MASK (0x80U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3_SHIFT (7U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1_MASK (0x3F00U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1_MASK (0x4000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1_SHIFT (14U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2_MASK (0x8000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2_SHIFT (15U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2_MASK (0x3F0000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2_MASK (0x400000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2_SHIFT (22U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1_MASK (0x800000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1_SHIFT (23U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3_MASK (0x3F000000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3_SHIFT (24U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3_MASK (0x40000000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3_SHIFT (30U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0_MASK (0x80000000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0_SHIFT (31U)

/*! @name HW_PXP_INPUT_STORE_F_SHIFT_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4_MASK (0x3FU)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4_MASK (0x40U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4_SHIFT (6U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3_MASK (0x80U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3_SHIFT (7U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5_MASK (0x3F00U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5_MASK (0x4000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5_SHIFT (14U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2_MASK (0x8000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2_SHIFT (15U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6_MASK (0x3F0000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6_MASK (0x400000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6_SHIFT (22U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1_MASK (0x800000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1_SHIFT (23U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7_MASK (0x3F000000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7_SHIFT (24U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7_MASK (0x40000000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7_SHIFT (30U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0_MASK (0x80000000U)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0_SHIFT (31U)

/*! @name HW_PXP_INPUT_STORE_F_MASK_L_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0_MASK (0xFFU)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1_MASK (0xFF00U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2_MASK (0xFF0000U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3_MASK (0xFF000000U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3_SHIFT (24U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3_MASK)

/*! @name HW_PXP_INPUT_STORE_F_MASK_H_CH0 -  */
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4_MASK (0xFFU)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4_SHIFT (0U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5_MASK (0xFF00U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5_SHIFT (8U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6_MASK (0xFF0000U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6_SHIFT (16U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6_MASK)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7_MASK (0xFF000000U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7_SHIFT (24U)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7_SHIFT)) & PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7_MASK)

/*! @name HW_PXP_DITHER_FETCH_CTRL_CH0 - Pre-fetch engine Control Channel 0 Register */
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN_MASK (0x1U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN_MASK (0x2U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN_SHIFT (1U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16_MASK (0x4U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16_SHIFT (2U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN_MASK (0x8U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN_SHIFT (3U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN_MASK (0x10U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN_SHIFT (4U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE_MASK (0x20U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE_SHIFT (5U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4_MASK (0x1C0U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4_SHIFT (6U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP_MASK (0x200U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP_SHIFT (9U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP_MASK (0x400U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP_SHIFT (10U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3_MASK (0x800U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3_SHIFT (11U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE_MASK (0x3000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE_SHIFT (12U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2_MASK (0xC000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2_SHIFT (14U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES_MASK (0x30000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1_MASK (0xFC0000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1_SHIFT (18U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_MASK (0x3000000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_SHIFT (24U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0_MASK (0x7C000000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0_SHIFT (26U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN_MASK (0x80000000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN_SHIFT (31U)

/*! @name HW_PXP_DITHER_FETCH_CTRL_CH1 - Pre-fetch engine Control Channel 1 Register */
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN_MASK (0x1U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN_MASK (0x2U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN_SHIFT (1U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16_MASK (0x4U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16_SHIFT (2U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN_MASK (0x8U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN_SHIFT (3U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN_MASK (0x10U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN_SHIFT (4U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4_MASK (0x1E0U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4_SHIFT (5U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP_MASK (0x200U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP_SHIFT (9U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP_MASK (0x400U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP_SHIFT (10U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3_MASK (0x800U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3_SHIFT (11U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE_MASK (0x3000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE_SHIFT (12U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2_MASK (0xC000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2_SHIFT (14U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES_MASK (0x30000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1_MASK (0xFC0000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1_SHIFT (18U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_MASK (0x3000000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_SHIFT (24U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_MASK)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0_MASK (0xFC000000U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0_SHIFT (26U)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0_MASK)

/*! @name HW_PXP_DITHER_FETCH_STATUS_CH0 - Pre-fetch engine status Channel 0 Register */
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X_MASK)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y_MASK)

/*! @name HW_PXP_DITHER_FETCH_STATUS_CH1 - Store engine status Channel 1 Register */
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X_MASK)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y_MASK)

/*! @name HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X_MASK)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y_MASK)

/*! @name HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X_MASK)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y_MASK)

/*! @name HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X_MASK)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y_MASK)

/*! @name HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X_MASK)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y_MASK)

/*! @name HW_PXP_DITHER_FETCH_SIZE_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT_MASK)

/*! @name HW_PXP_DITHER_FETCH_SIZE_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT_MASK)

/*! @name HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR_MASK)

/*! @name HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR_MASK)

/*! @name HW_PXP_DITHER_FETCH_PITCH -  */
#define PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH_MASK)
#define PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH_MASK)

/*! @name HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_MASK (0x3U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1_MASK (0xFCU)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1_SHIFT (2U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_MASK (0x700U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN_MASK (0x800U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN_SHIFT (11U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS_MASK (0x1000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS_SHIFT (12U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0_MASK (0xFFFFE000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0_SHIFT (13U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0_MASK)

/*! @name HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_MASK (0x3U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1_MASK (0xFCU)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1_SHIFT (2U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_MASK (0x700U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN_MASK (0x800U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN_SHIFT (11U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS_MASK (0x1000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS_SHIFT (12U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0_MASK (0xFFFFE000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0_SHIFT (13U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0_MASK)

/*! @name HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0_MASK (0x1FU)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3_MASK (0xE0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3_SHIFT (5U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1_MASK (0x1F00U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2_MASK (0xE000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2_SHIFT (13U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2_MASK (0x1F0000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1_MASK (0xE00000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1_SHIFT (21U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3_MASK (0x1F000000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3_SHIFT (24U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0_MASK (0xE0000000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0_SHIFT (29U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0_MASK)

/*! @name HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0_MASK (0x1FU)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3_MASK (0xE0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3_SHIFT (5U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1_MASK (0x1F00U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2_MASK (0xE000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2_SHIFT (13U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2_MASK (0x1F0000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1_MASK (0xE00000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1_SHIFT (21U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3_MASK (0x1F000000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3_SHIFT (24U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0_MASK (0xE0000000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0_SHIFT (29U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0_MASK)

/*! @name HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0_MASK (0xFU)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1_MASK (0xF0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1_SHIFT (4U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2_MASK (0xF00U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3_MASK (0xF000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3_SHIFT (12U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0_MASK)

/*! @name HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0_MASK (0xFU)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1_MASK (0xF0U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1_SHIFT (4U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2_MASK (0xF00U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3_MASK (0xF000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3_SHIFT (12U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3_MASK)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0_MASK)

/*! @name HW_PXP_DITHER_FETCH_ADDR_0_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0_MASK)

/*! @name HW_PXP_DITHER_FETCH_ADDR_1_CH0 -  */
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1_MASK)

/*! @name HW_PXP_DITHER_FETCH_ADDR_0_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0_MASK)

/*! @name HW_PXP_DITHER_FETCH_ADDR_1_CH1 -  */
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1_SHIFT)) & PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1_MASK)

/*! @name HW_PXP_DITHER_STORE_CTRL_CH0 - Store engine Control Channel 0 Register */
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN_MASK (0x1U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN_MASK (0x2U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN_SHIFT (1U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16_MASK (0x4U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16_SHIFT (2U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN_MASK (0x8U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN_SHIFT (3U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN_MASK (0x10U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN_SHIFT (4U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM_MASK (0x60U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM_SHIFT (5U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM_MASK)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3_MASK (0x80U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3_SHIFT (7U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN_MASK (0x100U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN_MASK (0x200U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN_SHIFT (9U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL_MASK (0x400U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL_SHIFT (10U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN_MASK (0x800U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN_SHIFT (11U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2_MASK (0xF000U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2_SHIFT (12U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2_MASK)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES_MASK (0x30000U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES_MASK)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1_MASK (0xFC0000U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1_SHIFT (18U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1_MASK)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL_MASK (0x1000000U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL_SHIFT (24U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0_MASK (0x7E000000U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0_SHIFT (25U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0_MASK)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN_MASK (0x80000000U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN_SHIFT (31U)

/*! @name HW_PXP_DITHER_STORE_CTRL_CH1 - Store engine Control Channel 1 Register */
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN_MASK (0x1U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN_MASK (0x2U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN_SHIFT (1U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16_MASK (0x4U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16_SHIFT (2U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN_MASK (0x8U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN_SHIFT (3U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN_MASK (0x10U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN_SHIFT (4U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM_MASK (0x60U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM_SHIFT (5U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM_MASK)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3_MASK (0x80U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3_SHIFT (7U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN_MASK (0x100U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN_MASK (0x200U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN_SHIFT (9U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL_MASK (0x400U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL_SHIFT (10U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1_MASK (0xF800U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1_SHIFT (11U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1_MASK)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES_MASK (0x30000U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES_MASK)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0_MASK (0xFFFC0000U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0_SHIFT (18U)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0_MASK)

/*! @name HW_PXP_DITHER_STORE_STATUS_CH0 - Store engine status Channel 0 Register */
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X_SHIFT)) & PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X_MASK)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y_SHIFT)) & PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y_MASK)

/*! @name HW_PXP_DITHER_STORE_STATUS_CH1 - Store engine status Channel 1 Register */
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X_SHIFT)) & PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X_MASK)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y_SHIFT)) & PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y_MASK)

/*! @name HW_PXP_DITHER_STORE_SIZE_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH_MASK)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT_MASK)

/*! @name HW_PXP_DITHER_STORE_SIZE_CH1 -  */
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH_MASK)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT_MASK)

/*! @name HW_PXP_DITHER_STORE_PITCH -  */
#define PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH_MASK (0xFFFFU)
#define PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH_SHIFT)) & PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH_MASK)
#define PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH_MASK (0xFFFF0000U)
#define PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH_SHIFT)) & PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH_MASK)

/*! @name HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2_MASK (0x3U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2_MASK)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_MASK (0xCU)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_SHIFT (2U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_MASK)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN_MASK (0x10U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN_SHIFT (4U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN_MASK (0x20U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN_SHIFT (5U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1_MASK (0x40U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1_SHIFT (6U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS_MASK (0x80U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS_SHIFT (7U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0_MASK (0xFFFFFF00U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0_MASK)

/*! @name HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1 -  */
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2_MASK (0x3U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2_MASK)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_MASK (0xCU)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_SHIFT (2U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_MASK)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN_MASK (0x10U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN_SHIFT (4U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN_MASK (0x20U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN_SHIFT (5U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0_MASK (0xFFFFFFC0U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0_SHIFT (6U)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0_MASK)

/*! @name HW_PXP_DITHER_STORE_ADDR_0_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0_MASK)

/*! @name HW_PXP_DITHER_STORE_ADDR_1_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1_SHIFT)) & PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1_MASK)

/*! @name HW_PXP_DITHER_STORE_FILL_DATA_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_ADDR_0_CH1 -  */
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0_MASK)

/*! @name HW_PXP_DITHER_STORE_ADDR_1_CH1 -  */
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1_SHIFT)) & PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK0_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK0_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK1_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK1_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK2_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK2_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK3_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK3_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK4_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK4_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK5_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK5_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK6_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK6_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK7_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_MASK7_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0_MASK)

/*! @name HW_PXP_DITHER_STORE_D_SHIFT_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0_MASK (0x3FU)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0_MASK)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3_MASK (0x40U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3_SHIFT (6U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0_MASK (0x80U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0_SHIFT (7U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1_MASK (0x3F00U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1_MASK)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2_MASK (0x4000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2_SHIFT (14U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1_MASK (0x8000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1_SHIFT (15U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2_MASK (0x3F0000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2_MASK)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1_MASK (0x400000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1_SHIFT (22U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2_MASK (0x800000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2_SHIFT (23U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3_MASK (0x3F000000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3_SHIFT (24U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3_MASK)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0_MASK (0x40000000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0_SHIFT (30U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3_MASK (0x80000000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3_SHIFT (31U)

/*! @name HW_PXP_DITHER_STORE_D_SHIFT_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4_MASK (0x3FU)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4_MASK)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3_MASK (0x40U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3_SHIFT (6U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4_MASK (0x80U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4_SHIFT (7U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5_MASK (0x3F00U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5_MASK)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2_MASK (0x4000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2_SHIFT (14U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5_MASK (0x8000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5_SHIFT (15U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6_MASK (0x3F0000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6_MASK)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1_MASK (0x400000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1_SHIFT (22U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6_MASK (0x800000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6_SHIFT (23U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7_MASK (0x3F000000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7_SHIFT (24U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7_SHIFT)) & PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7_MASK)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0_MASK (0x40000000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0_SHIFT (30U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7_MASK (0x80000000U)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7_SHIFT (31U)

/*! @name HW_PXP_DITHER_STORE_F_SHIFT_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0_MASK (0x3FU)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0_MASK (0x40U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0_SHIFT (6U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3_MASK (0x80U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3_SHIFT (7U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1_MASK (0x3F00U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1_MASK (0x4000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1_SHIFT (14U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2_MASK (0x8000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2_SHIFT (15U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2_MASK (0x3F0000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2_MASK (0x400000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2_SHIFT (22U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1_MASK (0x800000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1_SHIFT (23U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3_MASK (0x3F000000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3_SHIFT (24U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3_MASK (0x40000000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3_SHIFT (30U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0_MASK (0x80000000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0_SHIFT (31U)

/*! @name HW_PXP_DITHER_STORE_F_SHIFT_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4_MASK (0x3FU)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4_MASK (0x40U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4_SHIFT (6U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3_MASK (0x80U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3_SHIFT (7U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5_MASK (0x3F00U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5_MASK (0x4000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5_SHIFT (14U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2_MASK (0x8000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2_SHIFT (15U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6_MASK (0x3F0000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6_MASK (0x400000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6_SHIFT (22U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1_MASK (0x800000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1_SHIFT (23U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7_MASK (0x3F000000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7_SHIFT (24U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7_MASK (0x40000000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7_SHIFT (30U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0_MASK (0x80000000U)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0_SHIFT (31U)

/*! @name HW_PXP_DITHER_STORE_F_MASK_L_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0_MASK (0xFFU)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1_MASK (0xFF00U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2_MASK (0xFF0000U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3_MASK (0xFF000000U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3_SHIFT (24U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3_MASK)

/*! @name HW_PXP_DITHER_STORE_F_MASK_H_CH0 -  */
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4_MASK (0xFFU)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4_SHIFT (0U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5_MASK (0xFF00U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5_SHIFT (8U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6_MASK (0xFF0000U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6_SHIFT (16U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6_MASK)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7_MASK (0xFF000000U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7_SHIFT (24U)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7_SHIFT)) & PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7_MASK)

/*! @name HW_PXP_DITHER_CTRL - Dither Control Register 0 */
#define PXP_HW_PXP_DITHER_CTRL_ENABLE0_MASK      (0x1U)
#define PXP_HW_PXP_DITHER_CTRL_ENABLE0_SHIFT     (0U)
#define PXP_HW_PXP_DITHER_CTRL_ENABLE1_MASK      (0x2U)
#define PXP_HW_PXP_DITHER_CTRL_ENABLE1_SHIFT     (1U)
#define PXP_HW_PXP_DITHER_CTRL_ENABLE2_MASK      (0x4U)
#define PXP_HW_PXP_DITHER_CTRL_ENABLE2_SHIFT     (2U)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_MASK (0x38U)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_SHIFT (3U)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_MASK)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_MASK (0x1C0U)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_SHIFT (6U)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_MASK)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_MASK (0xE00U)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_SHIFT (9U)
#define PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_MASK)
#define PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_MASK (0x7000U)
#define PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_SHIFT (12U)
#define PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_MASK)
#define PXP_HW_PXP_DITHER_CTRL_LUT_MODE_MASK     (0x18000U)
#define PXP_HW_PXP_DITHER_CTRL_LUT_MODE_SHIFT    (15U)
#define PXP_HW_PXP_DITHER_CTRL_LUT_MODE(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_LUT_MODE_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_LUT_MODE_MASK)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE_MASK (0x60000U)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE_SHIFT (17U)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE_MASK)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE_MASK (0x180000U)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE_SHIFT (19U)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE_MASK)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE_MASK (0x600000U)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE_SHIFT (21U)
#define PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE_MASK)
#define PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE_MASK (0x800000U)
#define PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE_SHIFT (23U)
#define PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE_MASK (0x1000000U)
#define PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE_SHIFT (24U)
#define PXP_HW_PXP_DITHER_CTRL_RSVD0_MASK        (0x1E000000U)
#define PXP_HW_PXP_DITHER_CTRL_RSVD0_SHIFT       (25U)
#define PXP_HW_PXP_DITHER_CTRL_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_DITHER_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_DITHER_CTRL_BUSY2_MASK        (0x20000000U)
#define PXP_HW_PXP_DITHER_CTRL_BUSY2_SHIFT       (29U)
#define PXP_HW_PXP_DITHER_CTRL_BUSY1_MASK        (0x40000000U)
#define PXP_HW_PXP_DITHER_CTRL_BUSY1_SHIFT       (30U)
#define PXP_HW_PXP_DITHER_CTRL_BUSY0_MASK        (0x80000000U)
#define PXP_HW_PXP_DITHER_CTRL_BUSY0_SHIFT       (31U)

/*! @name HW_PXP_DITHER_FINAL_LUT_DATA0 - Final stage lookup value Register */
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0_MASK (0xFFU)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1_MASK (0xFF00U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2_MASK (0xFF0000U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3_MASK (0xFF000000U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3_SHIFT (24U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3_MASK)

/*! @name HW_PXP_DITHER_FINAL_LUT_DATA1 - Final stage lookup value Register */
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4_MASK (0xFFU)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5_MASK (0xFF00U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6_MASK (0xFF0000U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7_MASK (0xFF000000U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7_SHIFT (24U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7_MASK)

/*! @name HW_PXP_DITHER_FINAL_LUT_DATA2 - Final stage lookup value Register */
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8_MASK (0xFFU)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9_MASK (0xFF00U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10_MASK (0xFF0000U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11_MASK (0xFF000000U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11_SHIFT (24U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11_MASK)

/*! @name HW_PXP_DITHER_FINAL_LUT_DATA3 - Final stage lookup value Register */
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12_MASK (0xFFU)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12_SHIFT (0U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13_MASK (0xFF00U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13_SHIFT (8U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14_MASK (0xFF0000U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14_SHIFT (16U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14_MASK)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15_MASK (0xFF000000U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15_SHIFT (24U)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15_SHIFT)) & PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15_MASK)

/*! @name HW_PXP_HIST_A_CTRL - Histogram Control Register. */
#define PXP_HW_PXP_HIST_A_CTRL_ENABLE_MASK       (0x1U)
#define PXP_HW_PXP_HIST_A_CTRL_ENABLE_SHIFT      (0U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD0_MASK        (0xEU)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD0_SHIFT       (1U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_A_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_HIST_A_CTRL_CLEAR_MASK        (0x10U)
#define PXP_HW_PXP_HIST_A_CTRL_CLEAR_SHIFT       (4U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD1_MASK        (0xE0U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD1_SHIFT       (5U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_CTRL_RSVD1_SHIFT)) & PXP_HW_PXP_HIST_A_CTRL_RSVD1_MASK)
#define PXP_HW_PXP_HIST_A_CTRL_STATUS_MASK       (0x1F00U)
#define PXP_HW_PXP_HIST_A_CTRL_STATUS_SHIFT      (8U)
#define PXP_HW_PXP_HIST_A_CTRL_STATUS(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_CTRL_STATUS_SHIFT)) & PXP_HW_PXP_HIST_A_CTRL_STATUS_MASK)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD2_MASK        (0xE000U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD2_SHIFT       (13U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD2(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_CTRL_RSVD2_SHIFT)) & PXP_HW_PXP_HIST_A_CTRL_RSVD2_MASK)
#define PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET_MASK (0x7F0000U)
#define PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET_SHIFT (16U)
#define PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET_MASK)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD3_MASK        (0x800000U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD3_SHIFT       (23U)
#define PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH_MASK  (0x7000000U)
#define PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH_SHIFT (24U)
#define PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH_SHIFT)) & PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH_MASK)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD4_MASK        (0xF8000000U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD4_SHIFT       (27U)
#define PXP_HW_PXP_HIST_A_CTRL_RSVD4(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_CTRL_RSVD4_SHIFT)) & PXP_HW_PXP_HIST_A_CTRL_RSVD4_MASK)

/*! @name HW_PXP_HIST_A_MASK - Histogram Pixel Mask Register. */
#define PXP_HW_PXP_HIST_A_MASK_MASK_EN_MASK      (0x1U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_EN_SHIFT     (0U)
#define PXP_HW_PXP_HIST_A_MASK_RSVD0_MASK        (0xEU)
#define PXP_HW_PXP_HIST_A_MASK_RSVD0_SHIFT       (1U)
#define PXP_HW_PXP_HIST_A_MASK_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_MASK_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_A_MASK_RSVD0_MASK)
#define PXP_HW_PXP_HIST_A_MASK_MASK_MODE_MASK    (0x30U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_MODE_SHIFT   (4U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_MODE(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_MASK_MASK_MODE_SHIFT)) & PXP_HW_PXP_HIST_A_MASK_MASK_MODE_MASK)
#define PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET_MASK  (0x1FC0U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET_SHIFT (6U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET_MASK)
#define PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH_MASK   (0xE000U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH_SHIFT  (13U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH_SHIFT)) & PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH_MASK)
#define PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0_MASK  (0xFF0000U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0_SHIFT (16U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0_SHIFT)) & PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0_MASK)
#define PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1_MASK  (0xFF000000U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1_SHIFT (24U)
#define PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1_SHIFT)) & PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1_MASK)

/*! @name HW_PXP_HIST_A_BUF_SIZE - Histogram Pixel Buffer Size Register. */
#define PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH_MASK    (0xFFFU)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH_SHIFT   (0U)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH_SHIFT)) & PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH_MASK)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1_MASK    (0xF000U)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1_SHIFT   (12U)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1_SHIFT)) & PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1_MASK)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT_MASK   (0xFFF0000U)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT_SHIFT  (16U)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT_SHIFT)) & PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT_MASK)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0_MASK    (0xF0000000U)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0_SHIFT   (28U)
#define PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0_MASK)

/*! @name HW_PXP_HIST_A_TOTAL_PIXEL - Total Number of Pixels Used by Histogram Engine. */
#define PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL_MASK (0xFFFFFFU)
#define PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL_SHIFT (0U)
#define PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL_SHIFT)) & PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL_MASK)
#define PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0_MASK (0xFF000000U)
#define PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0_SHIFT (24U)
#define PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0_MASK)

/*! @name HW_PXP_HIST_A_ACTIVE_AREA_X - The X Coordinate Offset for Active Area. */
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET_MASK (0xFFFU)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET_SHIFT (0U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET_MASK)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0_MASK (0xF000U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0_SHIFT (12U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0_MASK)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET_MASK (0xFFF0000U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET_SHIFT (16U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET_MASK)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1_MASK (0xF0000000U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1_SHIFT (28U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1_SHIFT)) & PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1_MASK)

/*! @name HW_PXP_HIST_A_ACTIVE_AREA_Y - The Y Coordinate Offset for Active Area. */
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET_MASK (0xFFFU)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET_SHIFT (0U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET_MASK)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0_MASK (0xF000U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0_SHIFT (12U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0_MASK)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET_MASK (0xFFF0000U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET_SHIFT (16U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET_MASK)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1_MASK (0xF0000000U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1_SHIFT (28U)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1_SHIFT)) & PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1_MASK)

/*! @name HW_PXP_HIST_A_RAW_STAT0 - Histogram Result Based on RAW Pixel Value. */
#define PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0_MASK   (0xFFFFFFFFU)
#define PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0_SHIFT  (0U)
#define PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0_SHIFT)) & PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0_MASK)

/*! @name HW_PXP_HIST_A_RAW_STAT1 - Histogram Result Based on RAW Pixel Value. */
#define PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1_MASK   (0xFFFFFFFFU)
#define PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1_SHIFT  (0U)
#define PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1_SHIFT)) & PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1_MASK)

/*! @name HW_PXP_HIST_B_CTRL - Histogram Control Register. */
#define PXP_HW_PXP_HIST_B_CTRL_ENABLE_MASK       (0x1U)
#define PXP_HW_PXP_HIST_B_CTRL_ENABLE_SHIFT      (0U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD0_MASK        (0xEU)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD0_SHIFT       (1U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_B_CTRL_RSVD0_MASK)
#define PXP_HW_PXP_HIST_B_CTRL_CLEAR_MASK        (0x10U)
#define PXP_HW_PXP_HIST_B_CTRL_CLEAR_SHIFT       (4U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD1_MASK        (0xE0U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD1_SHIFT       (5U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_CTRL_RSVD1_SHIFT)) & PXP_HW_PXP_HIST_B_CTRL_RSVD1_MASK)
#define PXP_HW_PXP_HIST_B_CTRL_STATUS_MASK       (0x1F00U)
#define PXP_HW_PXP_HIST_B_CTRL_STATUS_SHIFT      (8U)
#define PXP_HW_PXP_HIST_B_CTRL_STATUS(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_CTRL_STATUS_SHIFT)) & PXP_HW_PXP_HIST_B_CTRL_STATUS_MASK)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD2_MASK        (0xE000U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD2_SHIFT       (13U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD2(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_CTRL_RSVD2_SHIFT)) & PXP_HW_PXP_HIST_B_CTRL_RSVD2_MASK)
#define PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET_MASK (0x7F0000U)
#define PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET_SHIFT (16U)
#define PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET_MASK)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD3_MASK        (0x800000U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD3_SHIFT       (23U)
#define PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH_MASK  (0x7000000U)
#define PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH_SHIFT (24U)
#define PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH_SHIFT)) & PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH_MASK)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD4_MASK        (0xF8000000U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD4_SHIFT       (27U)
#define PXP_HW_PXP_HIST_B_CTRL_RSVD4(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_CTRL_RSVD4_SHIFT)) & PXP_HW_PXP_HIST_B_CTRL_RSVD4_MASK)

/*! @name HW_PXP_HIST_B_MASK - Histogram Pixel Mask Register. */
#define PXP_HW_PXP_HIST_B_MASK_MASK_EN_MASK      (0x1U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_EN_SHIFT     (0U)
#define PXP_HW_PXP_HIST_B_MASK_RSVD0_MASK        (0xEU)
#define PXP_HW_PXP_HIST_B_MASK_RSVD0_SHIFT       (1U)
#define PXP_HW_PXP_HIST_B_MASK_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_MASK_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_B_MASK_RSVD0_MASK)
#define PXP_HW_PXP_HIST_B_MASK_MASK_MODE_MASK    (0x30U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_MODE_SHIFT   (4U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_MODE(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_MASK_MASK_MODE_SHIFT)) & PXP_HW_PXP_HIST_B_MASK_MASK_MODE_MASK)
#define PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET_MASK  (0x1FC0U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET_SHIFT (6U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET_MASK)
#define PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH_MASK   (0xE000U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH_SHIFT  (13U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH_SHIFT)) & PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH_MASK)
#define PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0_MASK  (0xFF0000U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0_SHIFT (16U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0_SHIFT)) & PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0_MASK)
#define PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1_MASK  (0xFF000000U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1_SHIFT (24U)
#define PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1_SHIFT)) & PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1_MASK)

/*! @name HW_PXP_HIST_B_BUF_SIZE - Histogram Pixel Buffer Size Register. */
#define PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH_MASK    (0xFFFU)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH_SHIFT   (0U)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH_SHIFT)) & PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH_MASK)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1_MASK    (0xF000U)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1_SHIFT   (12U)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1_SHIFT)) & PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1_MASK)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT_MASK   (0xFFF0000U)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT_SHIFT  (16U)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT_SHIFT)) & PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT_MASK)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0_MASK    (0xF0000000U)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0_SHIFT   (28U)
#define PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0_MASK)

/*! @name HW_PXP_HIST_B_TOTAL_PIXEL - Total Number of Pixels Used by Histogram Engine. */
#define PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL_MASK (0xFFFFFFU)
#define PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL_SHIFT (0U)
#define PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL_SHIFT)) & PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL_MASK)
#define PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0_MASK (0xFF000000U)
#define PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0_SHIFT (24U)
#define PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0_MASK)

/*! @name HW_PXP_HIST_B_ACTIVE_AREA_X - The X Coordinate Offset for Active Area. */
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET_MASK (0xFFFU)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET_SHIFT (0U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET_MASK)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0_MASK (0xF000U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0_SHIFT (12U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0_MASK)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET_MASK (0xFFF0000U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET_SHIFT (16U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET_MASK)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1_MASK (0xF0000000U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1_SHIFT (28U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1_SHIFT)) & PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1_MASK)

/*! @name HW_PXP_HIST_B_ACTIVE_AREA_Y - The Y Coordinate Offset for Active Area. */
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET_MASK (0xFFFU)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET_SHIFT (0U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET_MASK)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0_MASK (0xF000U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0_SHIFT (12U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0_SHIFT)) & PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0_MASK)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET_MASK (0xFFF0000U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET_SHIFT (16U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET_SHIFT)) & PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET_MASK)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1_MASK (0xF0000000U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1_SHIFT (28U)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1_SHIFT)) & PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1_MASK)

/*! @name HW_PXP_HIST_B_RAW_STAT0 - Histogram Result Based on RAW Pixel Value. */
#define PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0_MASK   (0xFFFFFFFFU)
#define PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0_SHIFT  (0U)
#define PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0_SHIFT)) & PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0_MASK)

/*! @name HW_PXP_HIST_B_RAW_STAT1 - Histogram Result Based on RAW Pixel Value. */
#define PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1_MASK   (0xFFFFFFFFU)
#define PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1_SHIFT  (0U)
#define PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1_SHIFT)) & PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1_MASK)

/*! @name HW_PXP_HIST2_PARAM - 2-level Histogram Parameter Register. */
#define PXP_HW_PXP_HIST2_PARAM_VALUE0_MASK       (0x3FU)
#define PXP_HW_PXP_HIST2_PARAM_VALUE0_SHIFT      (0U)
#define PXP_HW_PXP_HIST2_PARAM_VALUE0(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST2_PARAM_VALUE0_SHIFT)) & PXP_HW_PXP_HIST2_PARAM_VALUE0_MASK)
#define PXP_HW_PXP_HIST2_PARAM_RSVD0_MASK        (0xC0U)
#define PXP_HW_PXP_HIST2_PARAM_RSVD0_SHIFT       (6U)
#define PXP_HW_PXP_HIST2_PARAM_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST2_PARAM_RSVD0_SHIFT)) & PXP_HW_PXP_HIST2_PARAM_RSVD0_MASK)
#define PXP_HW_PXP_HIST2_PARAM_VALUE1_MASK       (0x3F00U)
#define PXP_HW_PXP_HIST2_PARAM_VALUE1_SHIFT      (8U)
#define PXP_HW_PXP_HIST2_PARAM_VALUE1(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST2_PARAM_VALUE1_SHIFT)) & PXP_HW_PXP_HIST2_PARAM_VALUE1_MASK)
#define PXP_HW_PXP_HIST2_PARAM_RSVD1_MASK        (0xC000U)
#define PXP_HW_PXP_HIST2_PARAM_RSVD1_SHIFT       (14U)
#define PXP_HW_PXP_HIST2_PARAM_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST2_PARAM_RSVD1_SHIFT)) & PXP_HW_PXP_HIST2_PARAM_RSVD1_MASK)
#define PXP_HW_PXP_HIST2_PARAM_RSVD_MASK         (0xFFFF0000U)
#define PXP_HW_PXP_HIST2_PARAM_RSVD_SHIFT        (16U)
#define PXP_HW_PXP_HIST2_PARAM_RSVD(x)           (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST2_PARAM_RSVD_SHIFT)) & PXP_HW_PXP_HIST2_PARAM_RSVD_MASK)

/*! @name HW_PXP_HIST4_PARAM - 4-level Histogram Parameter Register. */
#define PXP_HW_PXP_HIST4_PARAM_VALUE0_MASK       (0x3FU)
#define PXP_HW_PXP_HIST4_PARAM_VALUE0_SHIFT      (0U)
#define PXP_HW_PXP_HIST4_PARAM_VALUE0(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST4_PARAM_VALUE0_SHIFT)) & PXP_HW_PXP_HIST4_PARAM_VALUE0_MASK)
#define PXP_HW_PXP_HIST4_PARAM_RSVD0_MASK        (0xC0U)
#define PXP_HW_PXP_HIST4_PARAM_RSVD0_SHIFT       (6U)
#define PXP_HW_PXP_HIST4_PARAM_RSVD0(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST4_PARAM_RSVD0_SHIFT)) & PXP_HW_PXP_HIST4_PARAM_RSVD0_MASK)
#define PXP_HW_PXP_HIST4_PARAM_VALUE1_MASK       (0x3F00U)
#define PXP_HW_PXP_HIST4_PARAM_VALUE1_SHIFT      (8U)
#define PXP_HW_PXP_HIST4_PARAM_VALUE1(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST4_PARAM_VALUE1_SHIFT)) & PXP_HW_PXP_HIST4_PARAM_VALUE1_MASK)
#define PXP_HW_PXP_HIST4_PARAM_RSVD1_MASK        (0xC000U)
#define PXP_HW_PXP_HIST4_PARAM_RSVD1_SHIFT       (14U)
#define PXP_HW_PXP_HIST4_PARAM_RSVD1(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST4_PARAM_RSVD1_SHIFT)) & PXP_HW_PXP_HIST4_PARAM_RSVD1_MASK)
#define PXP_HW_PXP_HIST4_PARAM_VALUE2_MASK       (0x3F0000U)
#define PXP_HW_PXP_HIST4_PARAM_VALUE2_SHIFT      (16U)
#define PXP_HW_PXP_HIST4_PARAM_VALUE2(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST4_PARAM_VALUE2_SHIFT)) & PXP_HW_PXP_HIST4_PARAM_VALUE2_MASK)
#define PXP_HW_PXP_HIST4_PARAM_RSVD2_MASK        (0xC00000U)
#define PXP_HW_PXP_HIST4_PARAM_RSVD2_SHIFT       (22U)
#define PXP_HW_PXP_HIST4_PARAM_RSVD2(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST4_PARAM_RSVD2_SHIFT)) & PXP_HW_PXP_HIST4_PARAM_RSVD2_MASK)
#define PXP_HW_PXP_HIST4_PARAM_VALUE3_MASK       (0x3F000000U)
#define PXP_HW_PXP_HIST4_PARAM_VALUE3_SHIFT      (24U)
#define PXP_HW_PXP_HIST4_PARAM_VALUE3(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST4_PARAM_VALUE3_SHIFT)) & PXP_HW_PXP_HIST4_PARAM_VALUE3_MASK)
#define PXP_HW_PXP_HIST4_PARAM_RSVD3_MASK        (0xC0000000U)
#define PXP_HW_PXP_HIST4_PARAM_RSVD3_SHIFT       (30U)
#define PXP_HW_PXP_HIST4_PARAM_RSVD3(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST4_PARAM_RSVD3_SHIFT)) & PXP_HW_PXP_HIST4_PARAM_RSVD3_MASK)

/*! @name HW_PXP_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register. */
#define PXP_HW_PXP_HIST8_PARAM0_VALUE0_MASK      (0x3FU)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE0_SHIFT     (0U)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE0(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM0_VALUE0_SHIFT)) & PXP_HW_PXP_HIST8_PARAM0_VALUE0_MASK)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD0_MASK       (0xC0U)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD0_SHIFT      (6U)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD0(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM0_RSVD0_SHIFT)) & PXP_HW_PXP_HIST8_PARAM0_RSVD0_MASK)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE1_MASK      (0x3F00U)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE1_SHIFT     (8U)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE1(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM0_VALUE1_SHIFT)) & PXP_HW_PXP_HIST8_PARAM0_VALUE1_MASK)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD1_MASK       (0xC000U)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD1_SHIFT      (14U)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD1(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM0_RSVD1_SHIFT)) & PXP_HW_PXP_HIST8_PARAM0_RSVD1_MASK)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE2_MASK      (0x3F0000U)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE2_SHIFT     (16U)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE2(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM0_VALUE2_SHIFT)) & PXP_HW_PXP_HIST8_PARAM0_VALUE2_MASK)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD2_MASK       (0xC00000U)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD2_SHIFT      (22U)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD2(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM0_RSVD2_SHIFT)) & PXP_HW_PXP_HIST8_PARAM0_RSVD2_MASK)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE3_MASK      (0x3F000000U)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE3_SHIFT     (24U)
#define PXP_HW_PXP_HIST8_PARAM0_VALUE3(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM0_VALUE3_SHIFT)) & PXP_HW_PXP_HIST8_PARAM0_VALUE3_MASK)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD3_MASK       (0xC0000000U)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD3_SHIFT      (30U)
#define PXP_HW_PXP_HIST8_PARAM0_RSVD3(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM0_RSVD3_SHIFT)) & PXP_HW_PXP_HIST8_PARAM0_RSVD3_MASK)

/*! @name HW_PXP_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register. */
#define PXP_HW_PXP_HIST8_PARAM1_VALUE4_MASK      (0x3FU)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE4_SHIFT     (0U)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE4(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM1_VALUE4_SHIFT)) & PXP_HW_PXP_HIST8_PARAM1_VALUE4_MASK)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD4_MASK       (0xC0U)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD4_SHIFT      (6U)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD4(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM1_RSVD4_SHIFT)) & PXP_HW_PXP_HIST8_PARAM1_RSVD4_MASK)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE5_MASK      (0x3F00U)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE5_SHIFT     (8U)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE5(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM1_VALUE5_SHIFT)) & PXP_HW_PXP_HIST8_PARAM1_VALUE5_MASK)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD5_MASK       (0xC000U)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD5_SHIFT      (14U)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD5(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM1_RSVD5_SHIFT)) & PXP_HW_PXP_HIST8_PARAM1_RSVD5_MASK)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE6_MASK      (0x3F0000U)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE6_SHIFT     (16U)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE6(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM1_VALUE6_SHIFT)) & PXP_HW_PXP_HIST8_PARAM1_VALUE6_MASK)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD6_MASK       (0xC00000U)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD6_SHIFT      (22U)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD6(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM1_RSVD6_SHIFT)) & PXP_HW_PXP_HIST8_PARAM1_RSVD6_MASK)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE7_MASK      (0x3F000000U)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE7_SHIFT     (24U)
#define PXP_HW_PXP_HIST8_PARAM1_VALUE7(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM1_VALUE7_SHIFT)) & PXP_HW_PXP_HIST8_PARAM1_VALUE7_MASK)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD7_MASK       (0xC0000000U)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD7_SHIFT      (30U)
#define PXP_HW_PXP_HIST8_PARAM1_RSVD7(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST8_PARAM1_RSVD7_SHIFT)) & PXP_HW_PXP_HIST8_PARAM1_RSVD7_MASK)

/*! @name HW_PXP_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register. */
#define PXP_HW_PXP_HIST16_PARAM0_VALUE0_MASK     (0x3FU)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE0_SHIFT    (0U)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE0(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM0_VALUE0_SHIFT)) & PXP_HW_PXP_HIST16_PARAM0_VALUE0_MASK)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD0_MASK      (0xC0U)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD0_SHIFT     (6U)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM0_RSVD0_SHIFT)) & PXP_HW_PXP_HIST16_PARAM0_RSVD0_MASK)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE1_MASK     (0x3F00U)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE1_SHIFT    (8U)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE1(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM0_VALUE1_SHIFT)) & PXP_HW_PXP_HIST16_PARAM0_VALUE1_MASK)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD1_MASK      (0xC000U)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD1_SHIFT     (14U)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM0_RSVD1_SHIFT)) & PXP_HW_PXP_HIST16_PARAM0_RSVD1_MASK)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE2_MASK     (0x3F0000U)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE2_SHIFT    (16U)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE2(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM0_VALUE2_SHIFT)) & PXP_HW_PXP_HIST16_PARAM0_VALUE2_MASK)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD2_MASK      (0xC00000U)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD2_SHIFT     (22U)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD2(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM0_RSVD2_SHIFT)) & PXP_HW_PXP_HIST16_PARAM0_RSVD2_MASK)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE3_MASK     (0x3F000000U)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE3_SHIFT    (24U)
#define PXP_HW_PXP_HIST16_PARAM0_VALUE3(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM0_VALUE3_SHIFT)) & PXP_HW_PXP_HIST16_PARAM0_VALUE3_MASK)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD3_MASK      (0xC0000000U)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD3_SHIFT     (30U)
#define PXP_HW_PXP_HIST16_PARAM0_RSVD3(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM0_RSVD3_SHIFT)) & PXP_HW_PXP_HIST16_PARAM0_RSVD3_MASK)

/*! @name HW_PXP_HIST16_PARAM1 - 16-level Histogram Parameter 1 Register. */
#define PXP_HW_PXP_HIST16_PARAM1_VALUE4_MASK     (0x3FU)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE4_SHIFT    (0U)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE4(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM1_VALUE4_SHIFT)) & PXP_HW_PXP_HIST16_PARAM1_VALUE4_MASK)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD4_MASK      (0xC0U)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD4_SHIFT     (6U)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD4(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM1_RSVD4_SHIFT)) & PXP_HW_PXP_HIST16_PARAM1_RSVD4_MASK)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE5_MASK     (0x3F00U)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE5_SHIFT    (8U)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE5(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM1_VALUE5_SHIFT)) & PXP_HW_PXP_HIST16_PARAM1_VALUE5_MASK)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD5_MASK      (0xC000U)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD5_SHIFT     (14U)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD5(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM1_RSVD5_SHIFT)) & PXP_HW_PXP_HIST16_PARAM1_RSVD5_MASK)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE6_MASK     (0x3F0000U)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE6_SHIFT    (16U)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE6(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM1_VALUE6_SHIFT)) & PXP_HW_PXP_HIST16_PARAM1_VALUE6_MASK)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD6_MASK      (0xC00000U)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD6_SHIFT     (22U)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD6(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM1_RSVD6_SHIFT)) & PXP_HW_PXP_HIST16_PARAM1_RSVD6_MASK)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE7_MASK     (0x3F000000U)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE7_SHIFT    (24U)
#define PXP_HW_PXP_HIST16_PARAM1_VALUE7(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM1_VALUE7_SHIFT)) & PXP_HW_PXP_HIST16_PARAM1_VALUE7_MASK)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD7_MASK      (0xC0000000U)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD7_SHIFT     (30U)
#define PXP_HW_PXP_HIST16_PARAM1_RSVD7(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM1_RSVD7_SHIFT)) & PXP_HW_PXP_HIST16_PARAM1_RSVD7_MASK)

/*! @name HW_PXP_HIST16_PARAM2 - 16-level Histogram Parameter 2 Register. */
#define PXP_HW_PXP_HIST16_PARAM2_VALUE8_MASK     (0x3FU)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE8_SHIFT    (0U)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE8(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM2_VALUE8_SHIFT)) & PXP_HW_PXP_HIST16_PARAM2_VALUE8_MASK)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD8_MASK      (0xC0U)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD8_SHIFT     (6U)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD8(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM2_RSVD8_SHIFT)) & PXP_HW_PXP_HIST16_PARAM2_RSVD8_MASK)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE9_MASK     (0x3F00U)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE9_SHIFT    (8U)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE9(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM2_VALUE9_SHIFT)) & PXP_HW_PXP_HIST16_PARAM2_VALUE9_MASK)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD9_MASK      (0xC000U)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD9_SHIFT     (14U)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD9(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM2_RSVD9_SHIFT)) & PXP_HW_PXP_HIST16_PARAM2_RSVD9_MASK)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE10_MASK    (0x3F0000U)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE10_SHIFT   (16U)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE10(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM2_VALUE10_SHIFT)) & PXP_HW_PXP_HIST16_PARAM2_VALUE10_MASK)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD10_MASK     (0xC00000U)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD10_SHIFT    (22U)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD10(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM2_RSVD10_SHIFT)) & PXP_HW_PXP_HIST16_PARAM2_RSVD10_MASK)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE11_MASK    (0x3F000000U)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE11_SHIFT   (24U)
#define PXP_HW_PXP_HIST16_PARAM2_VALUE11(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM2_VALUE11_SHIFT)) & PXP_HW_PXP_HIST16_PARAM2_VALUE11_MASK)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD11_MASK     (0xC0000000U)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD11_SHIFT    (30U)
#define PXP_HW_PXP_HIST16_PARAM2_RSVD11(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM2_RSVD11_SHIFT)) & PXP_HW_PXP_HIST16_PARAM2_RSVD11_MASK)

/*! @name HW_PXP_HIST16_PARAM3 - 16-level Histogram Parameter 3 Register. */
#define PXP_HW_PXP_HIST16_PARAM3_VALUE12_MASK    (0x3FU)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE12_SHIFT   (0U)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE12(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM3_VALUE12_SHIFT)) & PXP_HW_PXP_HIST16_PARAM3_VALUE12_MASK)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD12_MASK     (0xC0U)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD12_SHIFT    (6U)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD12(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM3_RSVD12_SHIFT)) & PXP_HW_PXP_HIST16_PARAM3_RSVD12_MASK)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE13_MASK    (0x3F00U)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE13_SHIFT   (8U)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE13(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM3_VALUE13_SHIFT)) & PXP_HW_PXP_HIST16_PARAM3_VALUE13_MASK)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD13_MASK     (0xC000U)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD13_SHIFT    (14U)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD13(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM3_RSVD13_SHIFT)) & PXP_HW_PXP_HIST16_PARAM3_RSVD13_MASK)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE14_MASK    (0x3F0000U)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE14_SHIFT   (16U)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE14(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM3_VALUE14_SHIFT)) & PXP_HW_PXP_HIST16_PARAM3_VALUE14_MASK)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD14_MASK     (0xC00000U)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD14_SHIFT    (22U)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD14(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM3_RSVD14_SHIFT)) & PXP_HW_PXP_HIST16_PARAM3_RSVD14_MASK)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE15_MASK    (0x3F000000U)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE15_SHIFT   (24U)
#define PXP_HW_PXP_HIST16_PARAM3_VALUE15(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM3_VALUE15_SHIFT)) & PXP_HW_PXP_HIST16_PARAM3_VALUE15_MASK)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD15_MASK     (0xC0000000U)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD15_SHIFT    (30U)
#define PXP_HW_PXP_HIST16_PARAM3_RSVD15(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST16_PARAM3_RSVD15_SHIFT)) & PXP_HW_PXP_HIST16_PARAM3_RSVD15_MASK)

/*! @name HW_PXP_HIST32_PARAM0 - 32-level Histogram Parameter 0 Register. */
#define PXP_HW_PXP_HIST32_PARAM0_VALUE0_MASK     (0x3FU)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE0_SHIFT    (0U)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE0(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM0_VALUE0_SHIFT)) & PXP_HW_PXP_HIST32_PARAM0_VALUE0_MASK)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD0_MASK      (0xC0U)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD0_SHIFT     (6U)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM0_RSVD0_SHIFT)) & PXP_HW_PXP_HIST32_PARAM0_RSVD0_MASK)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE1_MASK     (0x3F00U)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE1_SHIFT    (8U)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE1(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM0_VALUE1_SHIFT)) & PXP_HW_PXP_HIST32_PARAM0_VALUE1_MASK)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD1_MASK      (0xC000U)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD1_SHIFT     (14U)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM0_RSVD1_SHIFT)) & PXP_HW_PXP_HIST32_PARAM0_RSVD1_MASK)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE2_MASK     (0x3F0000U)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE2_SHIFT    (16U)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE2(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM0_VALUE2_SHIFT)) & PXP_HW_PXP_HIST32_PARAM0_VALUE2_MASK)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD2_MASK      (0xC00000U)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD2_SHIFT     (22U)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD2(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM0_RSVD2_SHIFT)) & PXP_HW_PXP_HIST32_PARAM0_RSVD2_MASK)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE3_MASK     (0x3F000000U)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE3_SHIFT    (24U)
#define PXP_HW_PXP_HIST32_PARAM0_VALUE3(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM0_VALUE3_SHIFT)) & PXP_HW_PXP_HIST32_PARAM0_VALUE3_MASK)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD3_MASK      (0xC0000000U)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD3_SHIFT     (30U)
#define PXP_HW_PXP_HIST32_PARAM0_RSVD3(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM0_RSVD3_SHIFT)) & PXP_HW_PXP_HIST32_PARAM0_RSVD3_MASK)

/*! @name HW_PXP_HIST32_PARAM1 - 32-level Histogram Parameter 1 Register. */
#define PXP_HW_PXP_HIST32_PARAM1_VALUE4_MASK     (0x3FU)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE4_SHIFT    (0U)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE4(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM1_VALUE4_SHIFT)) & PXP_HW_PXP_HIST32_PARAM1_VALUE4_MASK)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD4_MASK      (0xC0U)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD4_SHIFT     (6U)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD4(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM1_RSVD4_SHIFT)) & PXP_HW_PXP_HIST32_PARAM1_RSVD4_MASK)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE5_MASK     (0x3F00U)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE5_SHIFT    (8U)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE5(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM1_VALUE5_SHIFT)) & PXP_HW_PXP_HIST32_PARAM1_VALUE5_MASK)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD5_MASK      (0xC000U)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD5_SHIFT     (14U)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD5(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM1_RSVD5_SHIFT)) & PXP_HW_PXP_HIST32_PARAM1_RSVD5_MASK)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE6_MASK     (0x3F0000U)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE6_SHIFT    (16U)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE6(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM1_VALUE6_SHIFT)) & PXP_HW_PXP_HIST32_PARAM1_VALUE6_MASK)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD6_MASK      (0xC00000U)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD6_SHIFT     (22U)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD6(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM1_RSVD6_SHIFT)) & PXP_HW_PXP_HIST32_PARAM1_RSVD6_MASK)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE7_MASK     (0x3F000000U)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE7_SHIFT    (24U)
#define PXP_HW_PXP_HIST32_PARAM1_VALUE7(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM1_VALUE7_SHIFT)) & PXP_HW_PXP_HIST32_PARAM1_VALUE7_MASK)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD7_MASK      (0xC0000000U)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD7_SHIFT     (30U)
#define PXP_HW_PXP_HIST32_PARAM1_RSVD7(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM1_RSVD7_SHIFT)) & PXP_HW_PXP_HIST32_PARAM1_RSVD7_MASK)

/*! @name HW_PXP_HIST32_PARAM2 - 32-level Histogram Parameter 2 Register. */
#define PXP_HW_PXP_HIST32_PARAM2_VALUE8_MASK     (0x3FU)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE8_SHIFT    (0U)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE8(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM2_VALUE8_SHIFT)) & PXP_HW_PXP_HIST32_PARAM2_VALUE8_MASK)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD8_MASK      (0xC0U)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD8_SHIFT     (6U)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD8(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM2_RSVD8_SHIFT)) & PXP_HW_PXP_HIST32_PARAM2_RSVD8_MASK)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE9_MASK     (0x3F00U)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE9_SHIFT    (8U)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE9(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM2_VALUE9_SHIFT)) & PXP_HW_PXP_HIST32_PARAM2_VALUE9_MASK)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD9_MASK      (0xC000U)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD9_SHIFT     (14U)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD9(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM2_RSVD9_SHIFT)) & PXP_HW_PXP_HIST32_PARAM2_RSVD9_MASK)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE10_MASK    (0x3F0000U)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE10_SHIFT   (16U)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE10(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM2_VALUE10_SHIFT)) & PXP_HW_PXP_HIST32_PARAM2_VALUE10_MASK)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD10_MASK     (0xC00000U)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD10_SHIFT    (22U)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD10(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM2_RSVD10_SHIFT)) & PXP_HW_PXP_HIST32_PARAM2_RSVD10_MASK)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE11_MASK    (0x3F000000U)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE11_SHIFT   (24U)
#define PXP_HW_PXP_HIST32_PARAM2_VALUE11(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM2_VALUE11_SHIFT)) & PXP_HW_PXP_HIST32_PARAM2_VALUE11_MASK)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD11_MASK     (0xC0000000U)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD11_SHIFT    (30U)
#define PXP_HW_PXP_HIST32_PARAM2_RSVD11(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM2_RSVD11_SHIFT)) & PXP_HW_PXP_HIST32_PARAM2_RSVD11_MASK)

/*! @name HW_PXP_HIST32_PARAM3 - 32-level Histogram Parameter 3 Register. */
#define PXP_HW_PXP_HIST32_PARAM3_VALUE12_MASK    (0x3FU)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE12_SHIFT   (0U)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE12(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM3_VALUE12_SHIFT)) & PXP_HW_PXP_HIST32_PARAM3_VALUE12_MASK)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD12_MASK     (0xC0U)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD12_SHIFT    (6U)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD12(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM3_RSVD12_SHIFT)) & PXP_HW_PXP_HIST32_PARAM3_RSVD12_MASK)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE13_MASK    (0x3F00U)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE13_SHIFT   (8U)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE13(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM3_VALUE13_SHIFT)) & PXP_HW_PXP_HIST32_PARAM3_VALUE13_MASK)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD13_MASK     (0xC000U)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD13_SHIFT    (14U)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD13(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM3_RSVD13_SHIFT)) & PXP_HW_PXP_HIST32_PARAM3_RSVD13_MASK)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE14_MASK    (0x3F0000U)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE14_SHIFT   (16U)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE14(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM3_VALUE14_SHIFT)) & PXP_HW_PXP_HIST32_PARAM3_VALUE14_MASK)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD14_MASK     (0xC00000U)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD14_SHIFT    (22U)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD14(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM3_RSVD14_SHIFT)) & PXP_HW_PXP_HIST32_PARAM3_RSVD14_MASK)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE15_MASK    (0x3F000000U)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE15_SHIFT   (24U)
#define PXP_HW_PXP_HIST32_PARAM3_VALUE15(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM3_VALUE15_SHIFT)) & PXP_HW_PXP_HIST32_PARAM3_VALUE15_MASK)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD15_MASK     (0xC0000000U)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD15_SHIFT    (30U)
#define PXP_HW_PXP_HIST32_PARAM3_RSVD15(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM3_RSVD15_SHIFT)) & PXP_HW_PXP_HIST32_PARAM3_RSVD15_MASK)

/*! @name HW_PXP_HIST32_PARAM4 - 32-level Histogram Parameter 0 Register. */
#define PXP_HW_PXP_HIST32_PARAM4_VALUE16_MASK    (0x3FU)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE16_SHIFT   (0U)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE16(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM4_VALUE16_SHIFT)) & PXP_HW_PXP_HIST32_PARAM4_VALUE16_MASK)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD0_MASK      (0xC0U)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD0_SHIFT     (6U)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD0(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM4_RSVD0_SHIFT)) & PXP_HW_PXP_HIST32_PARAM4_RSVD0_MASK)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE17_MASK    (0x3F00U)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE17_SHIFT   (8U)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE17(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM4_VALUE17_SHIFT)) & PXP_HW_PXP_HIST32_PARAM4_VALUE17_MASK)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD1_MASK      (0xC000U)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD1_SHIFT     (14U)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD1(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM4_RSVD1_SHIFT)) & PXP_HW_PXP_HIST32_PARAM4_RSVD1_MASK)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE18_MASK    (0x3F0000U)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE18_SHIFT   (16U)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE18(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM4_VALUE18_SHIFT)) & PXP_HW_PXP_HIST32_PARAM4_VALUE18_MASK)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD2_MASK      (0xC00000U)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD2_SHIFT     (22U)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD2(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM4_RSVD2_SHIFT)) & PXP_HW_PXP_HIST32_PARAM4_RSVD2_MASK)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE19_MASK    (0x3F000000U)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE19_SHIFT   (24U)
#define PXP_HW_PXP_HIST32_PARAM4_VALUE19(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM4_VALUE19_SHIFT)) & PXP_HW_PXP_HIST32_PARAM4_VALUE19_MASK)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD3_MASK      (0xC0000000U)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD3_SHIFT     (30U)
#define PXP_HW_PXP_HIST32_PARAM4_RSVD3(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM4_RSVD3_SHIFT)) & PXP_HW_PXP_HIST32_PARAM4_RSVD3_MASK)

/*! @name HW_PXP_HIST32_PARAM5 - 32-level Histogram Parameter 1 Register. */
#define PXP_HW_PXP_HIST32_PARAM5_VALUE20_MASK    (0x3FU)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE20_SHIFT   (0U)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE20(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM5_VALUE20_SHIFT)) & PXP_HW_PXP_HIST32_PARAM5_VALUE20_MASK)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD4_MASK      (0xC0U)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD4_SHIFT     (6U)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD4(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM5_RSVD4_SHIFT)) & PXP_HW_PXP_HIST32_PARAM5_RSVD4_MASK)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE21_MASK    (0x3F00U)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE21_SHIFT   (8U)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE21(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM5_VALUE21_SHIFT)) & PXP_HW_PXP_HIST32_PARAM5_VALUE21_MASK)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD5_MASK      (0xC000U)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD5_SHIFT     (14U)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD5(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM5_RSVD5_SHIFT)) & PXP_HW_PXP_HIST32_PARAM5_RSVD5_MASK)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE22_MASK    (0x3F0000U)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE22_SHIFT   (16U)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE22(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM5_VALUE22_SHIFT)) & PXP_HW_PXP_HIST32_PARAM5_VALUE22_MASK)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD6_MASK      (0xC00000U)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD6_SHIFT     (22U)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD6(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM5_RSVD6_SHIFT)) & PXP_HW_PXP_HIST32_PARAM5_RSVD6_MASK)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE23_MASK    (0x3F000000U)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE23_SHIFT   (24U)
#define PXP_HW_PXP_HIST32_PARAM5_VALUE23(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM5_VALUE23_SHIFT)) & PXP_HW_PXP_HIST32_PARAM5_VALUE23_MASK)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD7_MASK      (0xC0000000U)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD7_SHIFT     (30U)
#define PXP_HW_PXP_HIST32_PARAM5_RSVD7(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM5_RSVD7_SHIFT)) & PXP_HW_PXP_HIST32_PARAM5_RSVD7_MASK)

/*! @name HW_PXP_HIST32_PARAM6 - 32-level Histogram Parameter 2 Register. */
#define PXP_HW_PXP_HIST32_PARAM6_VALUE24_MASK    (0x3FU)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE24_SHIFT   (0U)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE24(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM6_VALUE24_SHIFT)) & PXP_HW_PXP_HIST32_PARAM6_VALUE24_MASK)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD8_MASK      (0xC0U)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD8_SHIFT     (6U)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD8(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM6_RSVD8_SHIFT)) & PXP_HW_PXP_HIST32_PARAM6_RSVD8_MASK)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE25_MASK    (0x3F00U)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE25_SHIFT   (8U)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE25(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM6_VALUE25_SHIFT)) & PXP_HW_PXP_HIST32_PARAM6_VALUE25_MASK)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD9_MASK      (0xC000U)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD9_SHIFT     (14U)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD9(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM6_RSVD9_SHIFT)) & PXP_HW_PXP_HIST32_PARAM6_RSVD9_MASK)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE26_MASK    (0x3F0000U)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE26_SHIFT   (16U)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE26(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM6_VALUE26_SHIFT)) & PXP_HW_PXP_HIST32_PARAM6_VALUE26_MASK)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD10_MASK     (0xC00000U)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD10_SHIFT    (22U)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD10(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM6_RSVD10_SHIFT)) & PXP_HW_PXP_HIST32_PARAM6_RSVD10_MASK)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE27_MASK    (0x3F000000U)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE27_SHIFT   (24U)
#define PXP_HW_PXP_HIST32_PARAM6_VALUE27(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM6_VALUE27_SHIFT)) & PXP_HW_PXP_HIST32_PARAM6_VALUE27_MASK)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD11_MASK     (0xC0000000U)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD11_SHIFT    (30U)
#define PXP_HW_PXP_HIST32_PARAM6_RSVD11(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM6_RSVD11_SHIFT)) & PXP_HW_PXP_HIST32_PARAM6_RSVD11_MASK)

/*! @name HW_PXP_HIST32_PARAM7 - 32-level Histogram Parameter 3 Register. */
#define PXP_HW_PXP_HIST32_PARAM7_VALUE28_MASK    (0x3FU)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE28_SHIFT   (0U)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE28(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM7_VALUE28_SHIFT)) & PXP_HW_PXP_HIST32_PARAM7_VALUE28_MASK)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD2_MASK      (0xC0U)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD2_SHIFT     (6U)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD2(x)        (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM7_RSVD2_SHIFT)) & PXP_HW_PXP_HIST32_PARAM7_RSVD2_MASK)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE29_MASK    (0x3F00U)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE29_SHIFT   (8U)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE29(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM7_VALUE29_SHIFT)) & PXP_HW_PXP_HIST32_PARAM7_VALUE29_MASK)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD13_MASK     (0xC000U)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD13_SHIFT    (14U)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD13(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM7_RSVD13_SHIFT)) & PXP_HW_PXP_HIST32_PARAM7_RSVD13_MASK)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE30_MASK    (0x3F0000U)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE30_SHIFT   (16U)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE30(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM7_VALUE30_SHIFT)) & PXP_HW_PXP_HIST32_PARAM7_VALUE30_MASK)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD14_MASK     (0xC00000U)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD14_SHIFT    (22U)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD14(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM7_RSVD14_SHIFT)) & PXP_HW_PXP_HIST32_PARAM7_RSVD14_MASK)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE31_MASK    (0x3F000000U)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE31_SHIFT   (24U)
#define PXP_HW_PXP_HIST32_PARAM7_VALUE31(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM7_VALUE31_SHIFT)) & PXP_HW_PXP_HIST32_PARAM7_VALUE31_MASK)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD15_MASK     (0xC0000000U)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD15_SHIFT    (30U)
#define PXP_HW_PXP_HIST32_PARAM7_RSVD15(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HIST32_PARAM7_RSVD15_SHIFT)) & PXP_HW_PXP_HIST32_PARAM7_RSVD15_MASK)

/*! @name HW_PXP_COMP_CTRL -  */
#define PXP_HW_PXP_COMP_CTRL_START_MASK          (0x1U)
#define PXP_HW_PXP_COMP_CTRL_START_SHIFT         (0U)
#define PXP_HW_PXP_COMP_CTRL_RSVD1_MASK          (0xFEU)
#define PXP_HW_PXP_COMP_CTRL_RSVD1_SHIFT         (1U)
#define PXP_HW_PXP_COMP_CTRL_RSVD1(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_CTRL_RSVD1_SHIFT)) & PXP_HW_PXP_COMP_CTRL_RSVD1_MASK)
#define PXP_HW_PXP_COMP_CTRL_SW_RESET_MASK       (0x100U)
#define PXP_HW_PXP_COMP_CTRL_SW_RESET_SHIFT      (8U)
#define PXP_HW_PXP_COMP_CTRL_RSVD0_MASK          (0xFFFFFE00U)
#define PXP_HW_PXP_COMP_CTRL_RSVD0_SHIFT         (9U)
#define PXP_HW_PXP_COMP_CTRL_RSVD0(x)            (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_CTRL_RSVD0_SHIFT)) & PXP_HW_PXP_COMP_CTRL_RSVD0_MASK)

/*! @name HW_PXP_COMP_FORMAT0 -  */
#define PXP_HW_PXP_COMP_FORMAT0_FLAG_32B_MASK    (0x1U)
#define PXP_HW_PXP_COMP_FORMAT0_FLAG_32B_SHIFT   (0U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD3_MASK       (0xEU)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD3_SHIFT      (1U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD3(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT0_RSVD3_SHIFT)) & PXP_HW_PXP_COMP_FORMAT0_RSVD3_MASK)
#define PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM_MASK   (0x30U)
#define PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM_SHIFT  (4U)
#define PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM_SHIFT)) & PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM_MASK)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD2_MASK       (0xC0U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD2_SHIFT      (6U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD2(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT0_RSVD2_SHIFT)) & PXP_HW_PXP_COMP_FORMAT0_RSVD2_MASK)
#define PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX_MASK  (0x300U)
#define PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX_SHIFT (8U)
#define PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX_SHIFT)) & PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX_MASK)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD1_MASK       (0xFC00U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD1_SHIFT      (10U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD1(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT0_RSVD1_SHIFT)) & PXP_HW_PXP_COMP_FORMAT0_RSVD1_MASK)
#define PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B_MASK (0x3FF0000U)
#define PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B_SHIFT (16U)
#define PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B_SHIFT)) & PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B_MASK)
#define PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE_MASK   (0x4000000U)
#define PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE_SHIFT  (26U)
#define PXP_HW_PXP_COMP_FORMAT0_FIFOFULL_MASK    (0x8000000U)
#define PXP_HW_PXP_COMP_FORMAT0_FIFOFULL_SHIFT   (27U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD0_MASK       (0xF0000000U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD0_SHIFT      (28U)
#define PXP_HW_PXP_COMP_FORMAT0_RSVD0(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT0_RSVD0_SHIFT)) & PXP_HW_PXP_COMP_FORMAT0_RSVD0_MASK)

/*! @name HW_PXP_COMP_FORMAT1 -  */
#define PXP_HW_PXP_COMP_FORMAT1_A_OFFSET_MASK    (0x1FU)
#define PXP_HW_PXP_COMP_FORMAT1_A_OFFSET_SHIFT   (0U)
#define PXP_HW_PXP_COMP_FORMAT1_A_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT1_A_OFFSET_SHIFT)) & PXP_HW_PXP_COMP_FORMAT1_A_OFFSET_MASK)
#define PXP_HW_PXP_COMP_FORMAT1_A_LEN_MASK       (0xE0U)
#define PXP_HW_PXP_COMP_FORMAT1_A_LEN_SHIFT      (5U)
#define PXP_HW_PXP_COMP_FORMAT1_A_LEN(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT1_A_LEN_SHIFT)) & PXP_HW_PXP_COMP_FORMAT1_A_LEN_MASK)
#define PXP_HW_PXP_COMP_FORMAT1_B_OFFSET_MASK    (0x1F00U)
#define PXP_HW_PXP_COMP_FORMAT1_B_OFFSET_SHIFT   (8U)
#define PXP_HW_PXP_COMP_FORMAT1_B_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT1_B_OFFSET_SHIFT)) & PXP_HW_PXP_COMP_FORMAT1_B_OFFSET_MASK)
#define PXP_HW_PXP_COMP_FORMAT1_B_LEN_MASK       (0xE000U)
#define PXP_HW_PXP_COMP_FORMAT1_B_LEN_SHIFT      (13U)
#define PXP_HW_PXP_COMP_FORMAT1_B_LEN(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT1_B_LEN_SHIFT)) & PXP_HW_PXP_COMP_FORMAT1_B_LEN_MASK)
#define PXP_HW_PXP_COMP_FORMAT1_C_OFFSET_MASK    (0x1F0000U)
#define PXP_HW_PXP_COMP_FORMAT1_C_OFFSET_SHIFT   (16U)
#define PXP_HW_PXP_COMP_FORMAT1_C_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT1_C_OFFSET_SHIFT)) & PXP_HW_PXP_COMP_FORMAT1_C_OFFSET_MASK)
#define PXP_HW_PXP_COMP_FORMAT1_C_LEN_MASK       (0xE00000U)
#define PXP_HW_PXP_COMP_FORMAT1_C_LEN_SHIFT      (21U)
#define PXP_HW_PXP_COMP_FORMAT1_C_LEN(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT1_C_LEN_SHIFT)) & PXP_HW_PXP_COMP_FORMAT1_C_LEN_MASK)
#define PXP_HW_PXP_COMP_FORMAT1_D_OFFSET_MASK    (0x1F000000U)
#define PXP_HW_PXP_COMP_FORMAT1_D_OFFSET_SHIFT   (24U)
#define PXP_HW_PXP_COMP_FORMAT1_D_OFFSET(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT1_D_OFFSET_SHIFT)) & PXP_HW_PXP_COMP_FORMAT1_D_OFFSET_MASK)
#define PXP_HW_PXP_COMP_FORMAT1_D_LEN_MASK       (0xE0000000U)
#define PXP_HW_PXP_COMP_FORMAT1_D_LEN_SHIFT      (29U)
#define PXP_HW_PXP_COMP_FORMAT1_D_LEN(x)         (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT1_D_LEN_SHIFT)) & PXP_HW_PXP_COMP_FORMAT1_D_LEN_MASK)

/*! @name HW_PXP_COMP_FORMAT2 -  */
#define PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN_MASK    (0xFU)
#define PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN_SHIFT   (0U)
#define PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN_SHIFT)) & PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN_MASK)
#define PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN_MASK    (0xF0U)
#define PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN_SHIFT   (4U)
#define PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN_SHIFT)) & PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN_MASK)
#define PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN_MASK    (0xF00U)
#define PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN_SHIFT   (8U)
#define PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN_SHIFT)) & PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN_MASK)
#define PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN_MASK    (0xF000U)
#define PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN_SHIFT   (12U)
#define PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN(x)      (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN_SHIFT)) & PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN_MASK)
#define PXP_HW_PXP_COMP_FORMAT2_RSVD_MASK        (0xFFFF0000U)
#define PXP_HW_PXP_COMP_FORMAT2_RSVD_SHIFT       (16U)
#define PXP_HW_PXP_COMP_FORMAT2_RSVD(x)          (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_FORMAT2_RSVD_SHIFT)) & PXP_HW_PXP_COMP_FORMAT2_RSVD_MASK)

/*! @name HW_PXP_COMP_MASK0 -  */
#define PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW_MASK  (0xFFFFFFFFU)
#define PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW_SHIFT (0U)
#define PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW_SHIFT)) & PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW_MASK)

/*! @name HW_PXP_COMP_MASK1 -  */
#define PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH_SHIFT (0U)
#define PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH_SHIFT)) & PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH_MASK)

/*! @name HW_PXP_COMP_BUFFER_SIZE -  */
#define PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH_MASK (0x1FFFU)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH_SHIFT (0U)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH_SHIFT)) & PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH_MASK)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1_MASK   (0xE000U)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1_SHIFT  (13U)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1_SHIFT)) & PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1_MASK)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH_MASK (0x1FFF0000U)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH_SHIFT (16U)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH_SHIFT)) & PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH_MASK)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0_MASK   (0xE0000000U)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0_SHIFT  (29U)
#define PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0_SHIFT)) & PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0_MASK)

/*! @name HW_PXP_COMP_SOURCE -  */
#define PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR_MASK  (0xFFFFFFFFU)
#define PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR_SHIFT (0U)
#define PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR_SHIFT)) & PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR_MASK)

/*! @name HW_PXP_COMP_TARGET -  */
#define PXP_HW_PXP_COMP_TARGET_TARGET_ADDR_MASK  (0xFFFFFFFFU)
#define PXP_HW_PXP_COMP_TARGET_TARGET_ADDR_SHIFT (0U)
#define PXP_HW_PXP_COMP_TARGET_TARGET_ADDR(x)    (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_TARGET_TARGET_ADDR_SHIFT)) & PXP_HW_PXP_COMP_TARGET_TARGET_ADDR_MASK)

/*! @name HW_PXP_COMP_BUFFER_A -  */
#define PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR_SHIFT (0U)
#define PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR_SHIFT)) & PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR_MASK)

/*! @name HW_PXP_COMP_BUFFER_B -  */
#define PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR_SHIFT (0U)
#define PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR_SHIFT)) & PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR_MASK)

/*! @name HW_PXP_COMP_BUFFER_C -  */
#define PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR_SHIFT (0U)
#define PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR_SHIFT)) & PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR_MASK)

/*! @name HW_PXP_COMP_BUFFER_D -  */
#define PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR_MASK (0xFFFFFFFFU)
#define PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR_SHIFT (0U)
#define PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR_SHIFT)) & PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR_MASK)

/*! @name HW_PXP_COMP_DEBUG -  */
#define PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL_MASK     (0xFFU)
#define PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL_SHIFT    (0U)
#define PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL(x)       (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL_SHIFT)) & PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL_MASK)
#define PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE_MASK   (0xFFFFFF00U)
#define PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE_SHIFT  (8U)
#define PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE(x)     (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE_SHIFT)) & PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE_MASK)

/*! @name HW_PXP_BUS_MUX -  */
#define PXP_HW_PXP_BUS_MUX_RD_SEL_MASK           (0xFFU)
#define PXP_HW_PXP_BUS_MUX_RD_SEL_SHIFT          (0U)
#define PXP_HW_PXP_BUS_MUX_RD_SEL(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_BUS_MUX_RD_SEL_SHIFT)) & PXP_HW_PXP_BUS_MUX_RD_SEL_MASK)
#define PXP_HW_PXP_BUS_MUX_RSVD0_MASK            (0xFF00U)
#define PXP_HW_PXP_BUS_MUX_RSVD0_SHIFT           (8U)
#define PXP_HW_PXP_BUS_MUX_RSVD0(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_BUS_MUX_RSVD0_SHIFT)) & PXP_HW_PXP_BUS_MUX_RSVD0_MASK)
#define PXP_HW_PXP_BUS_MUX_WR_SEL_MASK           (0xFF0000U)
#define PXP_HW_PXP_BUS_MUX_WR_SEL_SHIFT          (16U)
#define PXP_HW_PXP_BUS_MUX_WR_SEL(x)             (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_BUS_MUX_WR_SEL_SHIFT)) & PXP_HW_PXP_BUS_MUX_WR_SEL_MASK)
#define PXP_HW_PXP_BUS_MUX_RSVD1_MASK            (0xFF000000U)
#define PXP_HW_PXP_BUS_MUX_RSVD1_SHIFT           (24U)
#define PXP_HW_PXP_BUS_MUX_RSVD1(x)              (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_BUS_MUX_RSVD1_SHIFT)) & PXP_HW_PXP_BUS_MUX_RSVD1_MASK)

/*! @name HW_PXP_HANDSHAKE_READY_MUX0 -  */
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0_MASK (0xFU)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0_SHIFT (0U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1_MASK (0xF0U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1_SHIFT (4U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2_MASK (0xF00U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2_SHIFT (8U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3_MASK (0xF000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3_SHIFT (12U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4_MASK (0xF0000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4_SHIFT (16U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5_MASK (0xF00000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5_SHIFT (20U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6_MASK (0xF000000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6_SHIFT (24U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7_MASK (0xF0000000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7_SHIFT (28U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7_MASK)

/*! @name HW_PXP_HANDSHAKE_READY_MUX1 -  */
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8_MASK (0xFU)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8_SHIFT (0U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9_MASK (0xF0U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9_SHIFT (4U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10_MASK (0xF00U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10_SHIFT (8U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11_MASK (0xF000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11_SHIFT (12U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12_MASK (0xF0000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12_SHIFT (16U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13_MASK (0xF00000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13_SHIFT (20U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14_MASK (0xF000000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14_SHIFT (24U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14_MASK)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15_MASK (0xF0000000U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15_SHIFT (28U)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15_SHIFT)) & PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15_MASK)

/*! @name HW_PXP_HANDSHAKE_DONE_MUX0 -  */
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0_MASK (0xFU)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0_SHIFT (0U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1_MASK (0xF0U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1_SHIFT (4U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2_MASK (0xF00U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2_SHIFT (8U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3_MASK (0xF000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3_SHIFT (12U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4_MASK (0xF0000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4_SHIFT (16U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5_MASK (0xF00000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5_SHIFT (20U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6_MASK (0xF000000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6_SHIFT (24U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7_MASK (0xF0000000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7_SHIFT (28U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7_MASK)

/*! @name HW_PXP_HANDSHAKE_DONE_MUX1 -  */
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8_MASK (0xFU)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8_SHIFT (0U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9_MASK (0xF0U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9_SHIFT (4U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9(x)   (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10_MASK (0xF00U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10_SHIFT (8U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11_MASK (0xF000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11_SHIFT (12U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12_MASK (0xF0000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12_SHIFT (16U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13_MASK (0xF00000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13_SHIFT (20U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14_MASK (0xF000000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14_SHIFT (24U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14_MASK)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15_MASK (0xF0000000U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15_SHIFT (28U)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15_SHIFT)) & PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15_MASK)

/*! @name HW_PXP_HANDSHAKE_CPU_FETCH -  */
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY_MASK (0x1U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY_SHIFT (0U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY_MASK (0x2U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY_SHIFT (1U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE_MASK (0x4U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE_SHIFT (2U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE_MASK (0x8U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE_SHIFT (3U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES_MASK (0x30U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES_SHIFT (4U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES_SHIFT)) & PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES_MASK)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0_MASK (0x7FC0U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0_SHIFT (6U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0_SHIFT)) & PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0_MASK)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN_MASK (0x8000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN_SHIFT (15U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY_MASK (0x10000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY_SHIFT (16U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY_MASK (0x20000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY_SHIFT (17U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE_MASK (0x40000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE_SHIFT (18U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE_MASK (0x80000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE_SHIFT (19U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES_MASK (0x300000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES_SHIFT (20U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES_SHIFT)) & PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES_MASK)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1_MASK (0x7FC00000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1_SHIFT (22U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1_SHIFT)) & PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1_MASK)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN_MASK (0x80000000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN_SHIFT (31U)

/*! @name HW_PXP_HANDSHAKE_CPU_STORE -  */
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY_MASK (0x1U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY_SHIFT (0U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY_MASK (0x2U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY_SHIFT (1U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE_MASK (0x4U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE_SHIFT (2U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE_MASK (0x8U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE_SHIFT (3U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES_MASK (0x30U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES_SHIFT (4U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES_SHIFT)) & PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES_MASK)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0_MASK (0x7FC0U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0_SHIFT (6U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0_SHIFT)) & PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0_MASK)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN_MASK (0x8000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN_SHIFT (15U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY_MASK (0x10000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY_SHIFT (16U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY_MASK (0x20000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY_SHIFT (17U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE_MASK (0x40000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE_SHIFT (18U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE_MASK (0x80000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE_SHIFT (19U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES_MASK (0x300000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES_SHIFT (20U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES(x) (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES_SHIFT)) & PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES_MASK)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1_MASK (0x7FC00000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1_SHIFT (22U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1(x)  (((uint32_t)(((uint32_t)(x)) << PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1_SHIFT)) & PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1_MASK)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN_MASK (0x80000000U)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN_SHIFT (31U)


/*!
 * @}
 */ /* end of group PXP_Register_Masks */


/* PXP - Peripheral instance base addresses */
/** Peripheral PXP base pointer */
#define PXP_BASE_PTR                             ((PXP_MemMapPtr)0x30700000u)
/** Array initializer of PXP peripheral base pointers */
#define PXP_BASE_PTRS                            { PXP_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- PXP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PXP_Register_Accessor_Macros PXP - Register accessor macros
 * @{
 */


/* PXP - Register instance definitions */
/* PXP */
#define PXP_HW_PXP_CTRL                          PXP_HW_PXP_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_STAT                          PXP_HW_PXP_STAT_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_CTRL                      PXP_HW_PXP_OUT_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_BUF                       PXP_HW_PXP_OUT_BUF_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_BUF2                      PXP_HW_PXP_OUT_BUF2_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_PITCH                     PXP_HW_PXP_OUT_PITCH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_LRC                       PXP_HW_PXP_OUT_LRC_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_PS_ULC                    PXP_HW_PXP_OUT_PS_ULC_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_PS_LRC                    PXP_HW_PXP_OUT_PS_LRC_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_AS_ULC                    PXP_HW_PXP_OUT_AS_ULC_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_OUT_AS_LRC                    PXP_HW_PXP_OUT_AS_LRC_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_CTRL                       PXP_HW_PXP_PS_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_BUF                        PXP_HW_PXP_PS_BUF_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_UBUF                       PXP_HW_PXP_PS_UBUF_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_VBUF                       PXP_HW_PXP_PS_VBUF_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_PITCH                      PXP_HW_PXP_PS_PITCH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_BACKGROUND_0               PXP_HW_PXP_PS_BACKGROUND_0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_SCALE                      PXP_HW_PXP_PS_SCALE_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_OFFSET                     PXP_HW_PXP_PS_OFFSET_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_CLRKEYLOW_0                PXP_HW_PXP_PS_CLRKEYLOW_0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_CLRKEYHIGH_0               PXP_HW_PXP_PS_CLRKEYHIGH_0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_AS_CTRL                       PXP_HW_PXP_AS_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_AS_BUF                        PXP_HW_PXP_AS_BUF_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_AS_PITCH                      PXP_HW_PXP_AS_PITCH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_AS_CLRKEYLOW_0                PXP_HW_PXP_AS_CLRKEYLOW_0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_AS_CLRKEYHIGH_0               PXP_HW_PXP_AS_CLRKEYHIGH_0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC1_COEF0                    PXP_HW_PXP_CSC1_COEF0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC1_COEF1                    PXP_HW_PXP_CSC1_COEF1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC1_COEF2                    PXP_HW_PXP_CSC1_COEF2_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC2_CTRL                     PXP_HW_PXP_CSC2_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC2_COEF0                    PXP_HW_PXP_CSC2_COEF0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC2_COEF1                    PXP_HW_PXP_CSC2_COEF1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC2_COEF2                    PXP_HW_PXP_CSC2_COEF2_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC2_COEF3                    PXP_HW_PXP_CSC2_COEF3_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC2_COEF4                    PXP_HW_PXP_CSC2_COEF4_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CSC2_COEF5                    PXP_HW_PXP_CSC2_COEF5_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_LUT_CTRL                      PXP_HW_PXP_LUT_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_LUT_ADDR                      PXP_HW_PXP_LUT_ADDR_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_LUT_DATA                      PXP_HW_PXP_LUT_DATA_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_LUT_EXTMEM                    PXP_HW_PXP_LUT_EXTMEM_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CFA                           PXP_HW_PXP_CFA_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_ALPHA_A_CTRL                  PXP_HW_PXP_ALPHA_A_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_ALPHA_B_CTRL                  PXP_HW_PXP_ALPHA_B_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_ALPHA_B_CTRL_1                PXP_HW_PXP_ALPHA_B_CTRL_1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_BACKGROUND_1               PXP_HW_PXP_PS_BACKGROUND_1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_CLRKEYLOW_1                PXP_HW_PXP_PS_CLRKEYLOW_1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_PS_CLRKEYHIGH_1               PXP_HW_PXP_PS_CLRKEYHIGH_1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_AS_CLRKEYLOW_1                PXP_HW_PXP_AS_CLRKEYLOW_1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_AS_CLRKEYHIGH_1               PXP_HW_PXP_AS_CLRKEYHIGH_1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_CTRL2                         PXP_HW_PXP_CTRL2_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_POWER_REG0                    PXP_HW_PXP_POWER_REG0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_POWER_REG1                    PXP_HW_PXP_POWER_REG1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DATA_PATH_CTRL1               PXP_HW_PXP_DATA_PATH_CTRL1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INIT_MEM_CTRL                 PXP_HW_PXP_INIT_MEM_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INIT_MEM_DATA                 PXP_HW_PXP_INIT_MEM_DATA_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INIT_MEM_DATA_HIGH            PXP_HW_PXP_INIT_MEM_DATA_HIGH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_IRQ_MASK                      PXP_HW_PXP_IRQ_MASK_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_IRQ                           PXP_HW_PXP_IRQ_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_NEXT                          PXP_HW_PXP_NEXT_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH0          PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_CTRL_CH1          PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH0        PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_STATUS_CH1        PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0 PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0 PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1 PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1 PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH0          PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_SIZE_CH1          PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0 PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1 PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_PITCH             PXP_HW_PXP_INPUT_FETCH_PITCH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0    PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1    PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0  PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1  PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0   PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1   PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0        PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0        PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1        PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1        PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH0          PXP_HW_PXP_INPUT_STORE_CTRL_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_CTRL_CH1          PXP_HW_PXP_INPUT_STORE_CTRL_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH0        PXP_HW_PXP_INPUT_STORE_STATUS_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_STATUS_CH1        PXP_HW_PXP_INPUT_STORE_STATUS_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH0          PXP_HW_PXP_INPUT_STORE_SIZE_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_SIZE_CH1          PXP_HW_PXP_INPUT_STORE_SIZE_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_PITCH             PXP_HW_PXP_INPUT_STORE_PITCH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0    PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1    PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0        PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0        PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0     PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1        PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1        PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0     PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0     PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0     PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0     PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0     PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0      PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0      PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH0         PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_CTRL_CH1         PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH0       PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_STATUS_CH1       PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0 PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0 PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1 PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1 PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH0         PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_SIZE_CH1         PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0 PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1 PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_PITCH            PXP_HW_PXP_DITHER_FETCH_PITCH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0   PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1   PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0 PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1 PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0  PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1  PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0       PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0       PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1       PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1       PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH0         PXP_HW_PXP_DITHER_STORE_CTRL_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_CTRL_CH1         PXP_HW_PXP_DITHER_STORE_CTRL_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH0       PXP_HW_PXP_DITHER_STORE_STATUS_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_STATUS_CH1       PXP_HW_PXP_DITHER_STORE_STATUS_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH0         PXP_HW_PXP_DITHER_STORE_SIZE_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_SIZE_CH1         PXP_HW_PXP_DITHER_STORE_SIZE_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_PITCH            PXP_HW_PXP_DITHER_STORE_PITCH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0   PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1   PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0       PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0       PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0    PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1       PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1       PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0    PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0    PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0    PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0    PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0    PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0     PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0     PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_CTRL                   PXP_HW_PXP_DITHER_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA0        PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA1        PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA2        PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_DITHER_FINAL_LUT_DATA3        PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_A_CTRL                   PXP_HW_PXP_HIST_A_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_A_MASK                   PXP_HW_PXP_HIST_A_MASK_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_A_BUF_SIZE               PXP_HW_PXP_HIST_A_BUF_SIZE_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_A_TOTAL_PIXEL            PXP_HW_PXP_HIST_A_TOTAL_PIXEL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_X          PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y          PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_A_RAW_STAT0              PXP_HW_PXP_HIST_A_RAW_STAT0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_A_RAW_STAT1              PXP_HW_PXP_HIST_A_RAW_STAT1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_B_CTRL                   PXP_HW_PXP_HIST_B_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_B_MASK                   PXP_HW_PXP_HIST_B_MASK_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_B_BUF_SIZE               PXP_HW_PXP_HIST_B_BUF_SIZE_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_B_TOTAL_PIXEL            PXP_HW_PXP_HIST_B_TOTAL_PIXEL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_X          PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y          PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_B_RAW_STAT0              PXP_HW_PXP_HIST_B_RAW_STAT0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST_B_RAW_STAT1              PXP_HW_PXP_HIST_B_RAW_STAT1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST2_PARAM                   PXP_HW_PXP_HIST2_PARAM_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST4_PARAM                   PXP_HW_PXP_HIST4_PARAM_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST8_PARAM0                  PXP_HW_PXP_HIST8_PARAM0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST8_PARAM1                  PXP_HW_PXP_HIST8_PARAM1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST16_PARAM0                 PXP_HW_PXP_HIST16_PARAM0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST16_PARAM1                 PXP_HW_PXP_HIST16_PARAM1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST16_PARAM2                 PXP_HW_PXP_HIST16_PARAM2_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST16_PARAM3                 PXP_HW_PXP_HIST16_PARAM3_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST32_PARAM0                 PXP_HW_PXP_HIST32_PARAM0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST32_PARAM1                 PXP_HW_PXP_HIST32_PARAM1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST32_PARAM2                 PXP_HW_PXP_HIST32_PARAM2_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST32_PARAM3                 PXP_HW_PXP_HIST32_PARAM3_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST32_PARAM4                 PXP_HW_PXP_HIST32_PARAM4_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST32_PARAM5                 PXP_HW_PXP_HIST32_PARAM5_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST32_PARAM6                 PXP_HW_PXP_HIST32_PARAM6_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HIST32_PARAM7                 PXP_HW_PXP_HIST32_PARAM7_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_CTRL                     PXP_HW_PXP_COMP_CTRL_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_FORMAT0                  PXP_HW_PXP_COMP_FORMAT0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_FORMAT1                  PXP_HW_PXP_COMP_FORMAT1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_FORMAT2                  PXP_HW_PXP_COMP_FORMAT2_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_MASK0                    PXP_HW_PXP_COMP_MASK0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_MASK1                    PXP_HW_PXP_COMP_MASK1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_BUFFER_SIZE              PXP_HW_PXP_COMP_BUFFER_SIZE_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_SOURCE                   PXP_HW_PXP_COMP_SOURCE_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_TARGET                   PXP_HW_PXP_COMP_TARGET_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_BUFFER_A                 PXP_HW_PXP_COMP_BUFFER_A_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_BUFFER_B                 PXP_HW_PXP_COMP_BUFFER_B_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_BUFFER_C                 PXP_HW_PXP_COMP_BUFFER_C_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_BUFFER_D                 PXP_HW_PXP_COMP_BUFFER_D_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_COMP_DEBUG                    PXP_HW_PXP_COMP_DEBUG_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_BUS_MUX                       PXP_HW_PXP_BUS_MUX_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX0          PXP_HW_PXP_HANDSHAKE_READY_MUX0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HANDSHAKE_READY_MUX1          PXP_HW_PXP_HANDSHAKE_READY_MUX1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX0           PXP_HW_PXP_HANDSHAKE_DONE_MUX0_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HANDSHAKE_DONE_MUX1           PXP_HW_PXP_HANDSHAKE_DONE_MUX1_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HANDSHAKE_CPU_FETCH           PXP_HW_PXP_HANDSHAKE_CPU_FETCH_REG(PXP_BASE_PTR)
#define PXP_HW_PXP_HANDSHAKE_CPU_STORE           PXP_HW_PXP_HANDSHAKE_CPU_STORE_REG(PXP_BASE_PTR)

/*!
 * @}
 */ /* end of group PXP_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group PXP_Peripheral */


/* ----------------------------------------------------------------------------
   -- QuadSPI
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup QuadSPI_Peripheral QuadSPI
 * @{
 */

/** QuadSPI - Peripheral register structure */
typedef struct QuadSPI_MemMap {
  uint32_t MCR;                                    /**< Module Configuration Register, offset: 0x0 */
  uint8_t RESERVED_0[4];
  uint32_t IPCR;                                   /**< IP Configuration Register, offset: 0x8 */
  uint32_t FLSHCR;                                 /**< Flash Configuration Register, offset: 0xC */
  uint32_t BUF0CR;                                 /**< Buffer0 Configuration Register, offset: 0x10 */
  uint32_t BUF1CR;                                 /**< Buffer1 Configuration Register, offset: 0x14 */
  uint32_t BUF2CR;                                 /**< Buffer2 Configuration Register, offset: 0x18 */
  uint32_t BUF3CR;                                 /**< Buffer3 Configuration Register, offset: 0x1C */
  uint32_t BFGENCR;                                /**< Buffer Generic Configuration Register, offset: 0x20 */
  uint8_t RESERVED_1[12];
  uint32_t BUF0IND;                                /**< Buffer0 Top Index Register, offset: 0x30 */
  uint32_t BUF1IND;                                /**< Buffer1 Top Index Register, offset: 0x34 */
  uint32_t BUF2IND;                                /**< Buffer2 Top Index Register, offset: 0x38 */
  uint8_t RESERVED_2[196];
  uint32_t SFAR;                                   /**< Serial Flash Address Register, offset: 0x100 */
  uint8_t RESERVED_3[4];
  uint32_t SMPR;                                   /**< Sampling Register, offset: 0x108 */
  uint32_t RBSR;                                   /**< RX Buffer Status Register, offset: 0x10C */
  uint32_t RBCT;                                   /**< RX Buffer Control Register, offset: 0x110 */
  uint8_t RESERVED_4[60];
  uint32_t TBSR;                                   /**< TX Buffer Status Register, offset: 0x150 */
  uint32_t TBDR;                                   /**< TX Buffer Data Register, offset: 0x154 */
  uint8_t RESERVED_5[4];
  uint32_t SR;                                     /**< Status Register, offset: 0x15C */
  uint32_t FR;                                     /**< Flag Register, offset: 0x160 */
  uint32_t RSER;                                   /**< Interrupt and DMA Request Select and Enable Register, offset: 0x164 */
  uint32_t SPNDST;                                 /**< Sequence Suspend Status Register, offset: 0x168 */
  uint32_t SPTRCLR;                                /**< Sequence Pointer Clear Register, offset: 0x16C */
  uint8_t RESERVED_6[16];
  uint32_t SFA1AD;                                 /**< Serial Flash A1 Top Address, offset: 0x180 */
  uint32_t SFA2AD;                                 /**< Serial Flash A2 Top Address, offset: 0x184 */
  uint32_t SFB1AD;                                 /**< Serial Flash B1Top Address, offset: 0x188 */
  uint32_t SFB2AD;                                 /**< Serial Flash B2Top Address, offset: 0x18C */
  uint8_t RESERVED_7[112];
  uint32_t RBDR[32];                               /**< RX Buffer Data Register, array offset: 0x200, array step: 0x4 */
  uint8_t RESERVED_8[128];
  uint32_t LUTKEY;                                 /**< LUT Key Register, offset: 0x300 */
  uint32_t LCKCR;                                  /**< LUT Lock Configuration Register, offset: 0x304 */
  uint8_t RESERVED_9[8];
  uint32_t LUT[64];                                /**< Look-up Table register, array offset: 0x310, array step: 0x4 */
} volatile *QuadSPI_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- QuadSPI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup QuadSPI_Register_Accessor_Macros QuadSPI - Register accessor macros
 * @{
 */


/* QuadSPI - Register accessors */
#define QuadSPI_MCR_REG(base)                    ((base)->MCR)
#define QuadSPI_IPCR_REG(base)                   ((base)->IPCR)
#define QuadSPI_FLSHCR_REG(base)                 ((base)->FLSHCR)
#define QuadSPI_BUF0CR_REG(base)                 ((base)->BUF0CR)
#define QuadSPI_BUF1CR_REG(base)                 ((base)->BUF1CR)
#define QuadSPI_BUF2CR_REG(base)                 ((base)->BUF2CR)
#define QuadSPI_BUF3CR_REG(base)                 ((base)->BUF3CR)
#define QuadSPI_BFGENCR_REG(base)                ((base)->BFGENCR)
#define QuadSPI_BUF0IND_REG(base)                ((base)->BUF0IND)
#define QuadSPI_BUF1IND_REG(base)                ((base)->BUF1IND)
#define QuadSPI_BUF2IND_REG(base)                ((base)->BUF2IND)
#define QuadSPI_SFAR_REG(base)                   ((base)->SFAR)
#define QuadSPI_SMPR_REG(base)                   ((base)->SMPR)
#define QuadSPI_RBSR_REG(base)                   ((base)->RBSR)
#define QuadSPI_RBCT_REG(base)                   ((base)->RBCT)
#define QuadSPI_TBSR_REG(base)                   ((base)->TBSR)
#define QuadSPI_TBDR_REG(base)                   ((base)->TBDR)
#define QuadSPI_SR_REG(base)                     ((base)->SR)
#define QuadSPI_FR_REG(base)                     ((base)->FR)
#define QuadSPI_RSER_REG(base)                   ((base)->RSER)
#define QuadSPI_SPNDST_REG(base)                 ((base)->SPNDST)
#define QuadSPI_SPTRCLR_REG(base)                ((base)->SPTRCLR)
#define QuadSPI_SFA1AD_REG(base)                 ((base)->SFA1AD)
#define QuadSPI_SFA2AD_REG(base)                 ((base)->SFA2AD)
#define QuadSPI_SFB1AD_REG(base)                 ((base)->SFB1AD)
#define QuadSPI_SFB2AD_REG(base)                 ((base)->SFB2AD)
#define QuadSPI_RBDR_REG(base,index)             ((base)->RBDR[index])
#define QuadSPI_LUTKEY_REG(base)                 ((base)->LUTKEY)
#define QuadSPI_LCKCR_REG(base)                  ((base)->LCKCR)
#define QuadSPI_LUT_REG(base,index)              ((base)->LUT[index])

/*!
 * @}
 */ /* end of group QuadSPI_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- QuadSPI Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup QuadSPI_Register_Masks QuadSPI Register Masks
 * @{
 */

/*! @name MCR - Module Configuration Register */
#define QuadSPI_MCR_SWRSTSD_MASK                 (0x1U)
#define QuadSPI_MCR_SWRSTSD_SHIFT                (0U)
#define QuadSPI_MCR_SWRSTHD_MASK                 (0x2U)
#define QuadSPI_MCR_SWRSTHD_SHIFT                (1U)
#define QuadSPI_MCR_END_CFG_MASK                 (0xCU)
#define QuadSPI_MCR_END_CFG_SHIFT                (2U)
#define QuadSPI_MCR_END_CFG(x)                   (((uint32_t)(((uint32_t)(x)) << QuadSPI_MCR_END_CFG_SHIFT)) & QuadSPI_MCR_END_CFG_MASK)
#define QuadSPI_MCR_DQS_EN_MASK                  (0x40U)
#define QuadSPI_MCR_DQS_EN_SHIFT                 (6U)
#define QuadSPI_MCR_DDR_EN_MASK                  (0x80U)
#define QuadSPI_MCR_DDR_EN_SHIFT                 (7U)
#define QuadSPI_MCR_CLR_RXF_MASK                 (0x400U)
#define QuadSPI_MCR_CLR_RXF_SHIFT                (10U)
#define QuadSPI_MCR_CLR_TXF_MASK                 (0x800U)
#define QuadSPI_MCR_CLR_TXF_SHIFT                (11U)
#define QuadSPI_MCR_MDIS_MASK                    (0x4000U)
#define QuadSPI_MCR_MDIS_SHIFT                   (14U)
#define QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD_MASK   (0x1000000U)
#define QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD_SHIFT  (24U)
#define QuadSPI_MCR_DQS_LOOPBACK_EN_MASK         (0x2000000U)
#define QuadSPI_MCR_DQS_LOOPBACK_EN_SHIFT        (25U)
#define QuadSPI_MCR_DQS_PHASE_EN_MASK            (0x4000000U)
#define QuadSPI_MCR_DQS_PHASE_EN_SHIFT           (26U)

/*! @name IPCR - IP Configuration Register */
#define QuadSPI_IPCR_IDATSZ_MASK                 (0xFFFFU)
#define QuadSPI_IPCR_IDATSZ_SHIFT                (0U)
#define QuadSPI_IPCR_IDATSZ(x)                   (((uint32_t)(((uint32_t)(x)) << QuadSPI_IPCR_IDATSZ_SHIFT)) & QuadSPI_IPCR_IDATSZ_MASK)
#define QuadSPI_IPCR_PAR_EN_MASK                 (0x10000U)
#define QuadSPI_IPCR_PAR_EN_SHIFT                (16U)
#define QuadSPI_IPCR_SEQID_MASK                  (0xF000000U)
#define QuadSPI_IPCR_SEQID_SHIFT                 (24U)
#define QuadSPI_IPCR_SEQID(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_IPCR_SEQID_SHIFT)) & QuadSPI_IPCR_SEQID_MASK)

/*! @name FLSHCR - Flash Configuration Register */
#define QuadSPI_FLSHCR_TCSS_MASK                 (0xFU)
#define QuadSPI_FLSHCR_TCSS_SHIFT                (0U)
#define QuadSPI_FLSHCR_TCSS(x)                   (((uint32_t)(((uint32_t)(x)) << QuadSPI_FLSHCR_TCSS_SHIFT)) & QuadSPI_FLSHCR_TCSS_MASK)
#define QuadSPI_FLSHCR_TCSH_MASK                 (0xF00U)
#define QuadSPI_FLSHCR_TCSH_SHIFT                (8U)
#define QuadSPI_FLSHCR_TCSH(x)                   (((uint32_t)(((uint32_t)(x)) << QuadSPI_FLSHCR_TCSH_SHIFT)) & QuadSPI_FLSHCR_TCSH_MASK)
#define QuadSPI_FLSHCR_TDH_MASK                  (0x30000U)
#define QuadSPI_FLSHCR_TDH_SHIFT                 (16U)
#define QuadSPI_FLSHCR_TDH(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_FLSHCR_TDH_SHIFT)) & QuadSPI_FLSHCR_TDH_MASK)

/*! @name BUF0CR - Buffer0 Configuration Register */
#define QuadSPI_BUF0CR_MSTRID_MASK               (0xFU)
#define QuadSPI_BUF0CR_MSTRID_SHIFT              (0U)
#define QuadSPI_BUF0CR_MSTRID(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF0CR_MSTRID_SHIFT)) & QuadSPI_BUF0CR_MSTRID_MASK)
#define QuadSPI_BUF0CR_ADATSZ_MASK               (0xFF00U)
#define QuadSPI_BUF0CR_ADATSZ_SHIFT              (8U)
#define QuadSPI_BUF0CR_ADATSZ(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF0CR_ADATSZ_SHIFT)) & QuadSPI_BUF0CR_ADATSZ_MASK)
#define QuadSPI_BUF0CR_HP_EN_MASK                (0x80000000U)
#define QuadSPI_BUF0CR_HP_EN_SHIFT               (31U)

/*! @name BUF1CR - Buffer1 Configuration Register */
#define QuadSPI_BUF1CR_MSTRID_MASK               (0xFU)
#define QuadSPI_BUF1CR_MSTRID_SHIFT              (0U)
#define QuadSPI_BUF1CR_MSTRID(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF1CR_MSTRID_SHIFT)) & QuadSPI_BUF1CR_MSTRID_MASK)
#define QuadSPI_BUF1CR_ADATSZ_MASK               (0xFF00U)
#define QuadSPI_BUF1CR_ADATSZ_SHIFT              (8U)
#define QuadSPI_BUF1CR_ADATSZ(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF1CR_ADATSZ_SHIFT)) & QuadSPI_BUF1CR_ADATSZ_MASK)

/*! @name BUF2CR - Buffer2 Configuration Register */
#define QuadSPI_BUF2CR_MSTRID_MASK               (0xFU)
#define QuadSPI_BUF2CR_MSTRID_SHIFT              (0U)
#define QuadSPI_BUF2CR_MSTRID(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF2CR_MSTRID_SHIFT)) & QuadSPI_BUF2CR_MSTRID_MASK)
#define QuadSPI_BUF2CR_ADATSZ_MASK               (0xFF00U)
#define QuadSPI_BUF2CR_ADATSZ_SHIFT              (8U)
#define QuadSPI_BUF2CR_ADATSZ(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF2CR_ADATSZ_SHIFT)) & QuadSPI_BUF2CR_ADATSZ_MASK)

/*! @name BUF3CR - Buffer3 Configuration Register */
#define QuadSPI_BUF3CR_MSTRID_MASK               (0xFU)
#define QuadSPI_BUF3CR_MSTRID_SHIFT              (0U)
#define QuadSPI_BUF3CR_MSTRID(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF3CR_MSTRID_SHIFT)) & QuadSPI_BUF3CR_MSTRID_MASK)
#define QuadSPI_BUF3CR_ADATSZ_MASK               (0xFF00U)
#define QuadSPI_BUF3CR_ADATSZ_SHIFT              (8U)
#define QuadSPI_BUF3CR_ADATSZ(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF3CR_ADATSZ_SHIFT)) & QuadSPI_BUF3CR_ADATSZ_MASK)
#define QuadSPI_BUF3CR_ALLMST_MASK               (0x80000000U)
#define QuadSPI_BUF3CR_ALLMST_SHIFT              (31U)

/*! @name BFGENCR - Buffer Generic Configuration Register */
#define QuadSPI_BFGENCR_SEQID_MASK               (0xF000U)
#define QuadSPI_BFGENCR_SEQID_SHIFT              (12U)
#define QuadSPI_BFGENCR_SEQID(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_BFGENCR_SEQID_SHIFT)) & QuadSPI_BFGENCR_SEQID_MASK)
#define QuadSPI_BFGENCR_PAR_EN_MASK              (0x10000U)
#define QuadSPI_BFGENCR_PAR_EN_SHIFT             (16U)

/*! @name BUF0IND - Buffer0 Top Index Register */
#define QuadSPI_BUF0IND_TPINDX0_MASK             (0xFFFFFFF8U)
#define QuadSPI_BUF0IND_TPINDX0_SHIFT            (3U)
#define QuadSPI_BUF0IND_TPINDX0(x)               (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF0IND_TPINDX0_SHIFT)) & QuadSPI_BUF0IND_TPINDX0_MASK)

/*! @name BUF1IND - Buffer1 Top Index Register */
#define QuadSPI_BUF1IND_TPINDX1_MASK             (0xFFFFFFF8U)
#define QuadSPI_BUF1IND_TPINDX1_SHIFT            (3U)
#define QuadSPI_BUF1IND_TPINDX1(x)               (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF1IND_TPINDX1_SHIFT)) & QuadSPI_BUF1IND_TPINDX1_MASK)

/*! @name BUF2IND - Buffer2 Top Index Register */
#define QuadSPI_BUF2IND_TPINDX2_MASK             (0xFFFFFFF8U)
#define QuadSPI_BUF2IND_TPINDX2_SHIFT            (3U)
#define QuadSPI_BUF2IND_TPINDX2(x)               (((uint32_t)(((uint32_t)(x)) << QuadSPI_BUF2IND_TPINDX2_SHIFT)) & QuadSPI_BUF2IND_TPINDX2_MASK)

/*! @name SFAR - Serial Flash Address Register */
#define QuadSPI_SFAR_SFADR_MASK                  (0xFFFFFFFFU)
#define QuadSPI_SFAR_SFADR_SHIFT                 (0U)
#define QuadSPI_SFAR_SFADR(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_SFAR_SFADR_SHIFT)) & QuadSPI_SFAR_SFADR_MASK)

/*! @name SMPR - Sampling Register */
#define QuadSPI_SMPR_SDRSMP_MASK                 (0x60U)
#define QuadSPI_SMPR_SDRSMP_SHIFT                (5U)
#define QuadSPI_SMPR_SDRSMP(x)                   (((uint32_t)(((uint32_t)(x)) << QuadSPI_SMPR_SDRSMP_SHIFT)) & QuadSPI_SMPR_SDRSMP_MASK)
#define QuadSPI_SMPR_DDRSMP_MASK                 (0x70000U)
#define QuadSPI_SMPR_DDRSMP_SHIFT                (16U)
#define QuadSPI_SMPR_DDRSMP(x)                   (((uint32_t)(((uint32_t)(x)) << QuadSPI_SMPR_DDRSMP_SHIFT)) & QuadSPI_SMPR_DDRSMP_MASK)

/*! @name RBSR - RX Buffer Status Register */
#define QuadSPI_RBSR_RDBFL_MASK                  (0x3F00U)
#define QuadSPI_RBSR_RDBFL_SHIFT                 (8U)
#define QuadSPI_RBSR_RDBFL(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_RBSR_RDBFL_SHIFT)) & QuadSPI_RBSR_RDBFL_MASK)
#define QuadSPI_RBSR_RDCTR_MASK                  (0xFFFF0000U)
#define QuadSPI_RBSR_RDCTR_SHIFT                 (16U)
#define QuadSPI_RBSR_RDCTR(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_RBSR_RDCTR_SHIFT)) & QuadSPI_RBSR_RDCTR_MASK)

/*! @name RBCT - RX Buffer Control Register */
#define QuadSPI_RBCT_WMRK_MASK                   (0x1FU)
#define QuadSPI_RBCT_WMRK_SHIFT                  (0U)
#define QuadSPI_RBCT_WMRK(x)                     (((uint32_t)(((uint32_t)(x)) << QuadSPI_RBCT_WMRK_SHIFT)) & QuadSPI_RBCT_WMRK_MASK)
#define QuadSPI_RBCT_RXBRD_MASK                  (0x100U)
#define QuadSPI_RBCT_RXBRD_SHIFT                 (8U)

/*! @name TBSR - TX Buffer Status Register */
#define QuadSPI_TBSR_TRBFL_MASK                  (0x1F00U)
#define QuadSPI_TBSR_TRBFL_SHIFT                 (8U)
#define QuadSPI_TBSR_TRBFL(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_TBSR_TRBFL_SHIFT)) & QuadSPI_TBSR_TRBFL_MASK)
#define QuadSPI_TBSR_TRCTR_MASK                  (0xFFFF0000U)
#define QuadSPI_TBSR_TRCTR_SHIFT                 (16U)
#define QuadSPI_TBSR_TRCTR(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_TBSR_TRCTR_SHIFT)) & QuadSPI_TBSR_TRCTR_MASK)

/*! @name TBDR - TX Buffer Data Register */
#define QuadSPI_TBDR_TXDATA_MASK                 (0xFFFFFFFFU)
#define QuadSPI_TBDR_TXDATA_SHIFT                (0U)
#define QuadSPI_TBDR_TXDATA(x)                   (((uint32_t)(((uint32_t)(x)) << QuadSPI_TBDR_TXDATA_SHIFT)) & QuadSPI_TBDR_TXDATA_MASK)

/*! @name SR - Status Register */
#define QuadSPI_SR_BUSY_MASK                     (0x1U)
#define QuadSPI_SR_BUSY_SHIFT                    (0U)
#define QuadSPI_SR_IP_ACC_MASK                   (0x2U)
#define QuadSPI_SR_IP_ACC_SHIFT                  (1U)
#define QuadSPI_SR_AHB_ACC_MASK                  (0x4U)
#define QuadSPI_SR_AHB_ACC_SHIFT                 (2U)
#define QuadSPI_SR_AHBGNT_MASK                   (0x20U)
#define QuadSPI_SR_AHBGNT_SHIFT                  (5U)
#define QuadSPI_SR_AHBTRN_MASK                   (0x40U)
#define QuadSPI_SR_AHBTRN_SHIFT                  (6U)
#define QuadSPI_SR_AHB0NE_MASK                   (0x80U)
#define QuadSPI_SR_AHB0NE_SHIFT                  (7U)
#define QuadSPI_SR_AHB1NE_MASK                   (0x100U)
#define QuadSPI_SR_AHB1NE_SHIFT                  (8U)
#define QuadSPI_SR_AHB2NE_MASK                   (0x200U)
#define QuadSPI_SR_AHB2NE_SHIFT                  (9U)
#define QuadSPI_SR_AHB3NE_MASK                   (0x400U)
#define QuadSPI_SR_AHB3NE_SHIFT                  (10U)
#define QuadSPI_SR_AHB0FUL_MASK                  (0x800U)
#define QuadSPI_SR_AHB0FUL_SHIFT                 (11U)
#define QuadSPI_SR_AHB1FUL_MASK                  (0x1000U)
#define QuadSPI_SR_AHB1FUL_SHIFT                 (12U)
#define QuadSPI_SR_AHB2FUL_MASK                  (0x2000U)
#define QuadSPI_SR_AHB2FUL_SHIFT                 (13U)
#define QuadSPI_SR_AHB3FUL_MASK                  (0x4000U)
#define QuadSPI_SR_AHB3FUL_SHIFT                 (14U)
#define QuadSPI_SR_RXWE_MASK                     (0x10000U)
#define QuadSPI_SR_RXWE_SHIFT                    (16U)
#define QuadSPI_SR_RXFULL_MASK                   (0x80000U)
#define QuadSPI_SR_RXFULL_SHIFT                  (19U)
#define QuadSPI_SR_RXDMA_MASK                    (0x800000U)
#define QuadSPI_SR_RXDMA_SHIFT                   (23U)
#define QuadSPI_SR_TXEDA_MASK                    (0x1000000U)
#define QuadSPI_SR_TXEDA_SHIFT                   (24U)
#define QuadSPI_SR_TXFULL_MASK                   (0x8000000U)
#define QuadSPI_SR_TXFULL_SHIFT                  (27U)
#define QuadSPI_SR_DLPSMP_MASK                   (0xE0000000U)
#define QuadSPI_SR_DLPSMP_SHIFT                  (29U)
#define QuadSPI_SR_DLPSMP(x)                     (((uint32_t)(((uint32_t)(x)) << QuadSPI_SR_DLPSMP_SHIFT)) & QuadSPI_SR_DLPSMP_MASK)

/*! @name FR - Flag Register */
#define QuadSPI_FR_TFF_MASK                      (0x1U)
#define QuadSPI_FR_TFF_SHIFT                     (0U)
#define QuadSPI_FR_IPGEF_MASK                    (0x10U)
#define QuadSPI_FR_IPGEF_SHIFT                   (4U)
#define QuadSPI_FR_IPIEF_MASK                    (0x40U)
#define QuadSPI_FR_IPIEF_SHIFT                   (6U)
#define QuadSPI_FR_IPAEF_MASK                    (0x80U)
#define QuadSPI_FR_IPAEF_SHIFT                   (7U)
#define QuadSPI_FR_IUEF_MASK                     (0x800U)
#define QuadSPI_FR_IUEF_SHIFT                    (11U)
#define QuadSPI_FR_ABOF_MASK                     (0x1000U)
#define QuadSPI_FR_ABOF_SHIFT                    (12U)
#define QuadSPI_FR_ABSEF_MASK                    (0x8000U)
#define QuadSPI_FR_ABSEF_SHIFT                   (15U)
#define QuadSPI_FR_RBDF_MASK                     (0x10000U)
#define QuadSPI_FR_RBDF_SHIFT                    (16U)
#define QuadSPI_FR_RBOF_MASK                     (0x20000U)
#define QuadSPI_FR_RBOF_SHIFT                    (17U)
#define QuadSPI_FR_ILLINE_MASK                   (0x800000U)
#define QuadSPI_FR_ILLINE_SHIFT                  (23U)
#define QuadSPI_FR_TBUF_MASK                     (0x4000000U)
#define QuadSPI_FR_TBUF_SHIFT                    (26U)
#define QuadSPI_FR_TBFF_MASK                     (0x8000000U)
#define QuadSPI_FR_TBFF_SHIFT                    (27U)
#define QuadSPI_FR_DLPFF_MASK                    (0x80000000U)
#define QuadSPI_FR_DLPFF_SHIFT                   (31U)

/*! @name RSER - Interrupt and DMA Request Select and Enable Register */
#define QuadSPI_RSER_TFIE_MASK                   (0x1U)
#define QuadSPI_RSER_TFIE_SHIFT                  (0U)
#define QuadSPI_RSER_IPGEIE_MASK                 (0x10U)
#define QuadSPI_RSER_IPGEIE_SHIFT                (4U)
#define QuadSPI_RSER_IPIEIE_MASK                 (0x40U)
#define QuadSPI_RSER_IPIEIE_SHIFT                (6U)
#define QuadSPI_RSER_IPAEIE_MASK                 (0x80U)
#define QuadSPI_RSER_IPAEIE_SHIFT                (7U)
#define QuadSPI_RSER_IUEIE_MASK                  (0x800U)
#define QuadSPI_RSER_IUEIE_SHIFT                 (11U)
#define QuadSPI_RSER_ABOIE_MASK                  (0x1000U)
#define QuadSPI_RSER_ABOIE_SHIFT                 (12U)
#define QuadSPI_RSER_ABSEIE_MASK                 (0x8000U)
#define QuadSPI_RSER_ABSEIE_SHIFT                (15U)
#define QuadSPI_RSER_RBDIE_MASK                  (0x10000U)
#define QuadSPI_RSER_RBDIE_SHIFT                 (16U)
#define QuadSPI_RSER_RBOIE_MASK                  (0x20000U)
#define QuadSPI_RSER_RBOIE_SHIFT                 (17U)
#define QuadSPI_RSER_RBDDE_MASK                  (0x200000U)
#define QuadSPI_RSER_RBDDE_SHIFT                 (21U)
#define QuadSPI_RSER_ILLINIE_MASK                (0x800000U)
#define QuadSPI_RSER_ILLINIE_SHIFT               (23U)
#define QuadSPI_RSER_TBUIE_MASK                  (0x4000000U)
#define QuadSPI_RSER_TBUIE_SHIFT                 (26U)
#define QuadSPI_RSER_TBFIE_MASK                  (0x8000000U)
#define QuadSPI_RSER_TBFIE_SHIFT                 (27U)
#define QuadSPI_RSER_DLPFIE_MASK                 (0x80000000U)
#define QuadSPI_RSER_DLPFIE_SHIFT                (31U)

/*! @name SPNDST - Sequence Suspend Status Register */
#define QuadSPI_SPNDST_SUSPND_MASK               (0x1U)
#define QuadSPI_SPNDST_SUSPND_SHIFT              (0U)
#define QuadSPI_SPNDST_SPDBUF_MASK               (0xC0U)
#define QuadSPI_SPNDST_SPDBUF_SHIFT              (6U)
#define QuadSPI_SPNDST_SPDBUF(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_SPNDST_SPDBUF_SHIFT)) & QuadSPI_SPNDST_SPDBUF_MASK)
#define QuadSPI_SPNDST_DATLFT_MASK               (0xFE00U)
#define QuadSPI_SPNDST_DATLFT_SHIFT              (9U)
#define QuadSPI_SPNDST_DATLFT(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_SPNDST_DATLFT_SHIFT)) & QuadSPI_SPNDST_DATLFT_MASK)

/*! @name SPTRCLR - Sequence Pointer Clear Register */
#define QuadSPI_SPTRCLR_BFPTRC_MASK              (0x1U)
#define QuadSPI_SPTRCLR_BFPTRC_SHIFT             (0U)
#define QuadSPI_SPTRCLR_IPPTRC_MASK              (0x100U)
#define QuadSPI_SPTRCLR_IPPTRC_SHIFT             (8U)

/*! @name SFA1AD - Serial Flash A1 Top Address */
#define QuadSPI_SFA1AD_TPADA1_MASK               (0xFFFFFC00U)
#define QuadSPI_SFA1AD_TPADA1_SHIFT              (10U)
#define QuadSPI_SFA1AD_TPADA1(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_SFA1AD_TPADA1_SHIFT)) & QuadSPI_SFA1AD_TPADA1_MASK)

/*! @name SFA2AD - Serial Flash A2 Top Address */
#define QuadSPI_SFA2AD_TPADA2_MASK               (0xFFFFFC00U)
#define QuadSPI_SFA2AD_TPADA2_SHIFT              (10U)
#define QuadSPI_SFA2AD_TPADA2(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_SFA2AD_TPADA2_SHIFT)) & QuadSPI_SFA2AD_TPADA2_MASK)

/*! @name SFB1AD - Serial Flash B1Top Address */
#define QuadSPI_SFB1AD_TPADB1_MASK               (0xFFFFFC00U)
#define QuadSPI_SFB1AD_TPADB1_SHIFT              (10U)
#define QuadSPI_SFB1AD_TPADB1(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_SFB1AD_TPADB1_SHIFT)) & QuadSPI_SFB1AD_TPADB1_MASK)

/*! @name SFB2AD - Serial Flash B2Top Address */
#define QuadSPI_SFB2AD_TPADB2_MASK               (0xFFFFFC00U)
#define QuadSPI_SFB2AD_TPADB2_SHIFT              (10U)
#define QuadSPI_SFB2AD_TPADB2(x)                 (((uint32_t)(((uint32_t)(x)) << QuadSPI_SFB2AD_TPADB2_SHIFT)) & QuadSPI_SFB2AD_TPADB2_MASK)

/*! @name RBDR - RX Buffer Data Register */
#define QuadSPI_RBDR_RXDATA_MASK                 (0xFFFFFFFFU)
#define QuadSPI_RBDR_RXDATA_SHIFT                (0U)
#define QuadSPI_RBDR_RXDATA(x)                   (((uint32_t)(((uint32_t)(x)) << QuadSPI_RBDR_RXDATA_SHIFT)) & QuadSPI_RBDR_RXDATA_MASK)

/* The count of QuadSPI_RBDR */
#define QuadSPI_RBDR_COUNT                       (32U)

/*! @name LUTKEY - LUT Key Register */
#define QuadSPI_LUTKEY_KEY_MASK                  (0xFFFFFFFFU)
#define QuadSPI_LUTKEY_KEY_SHIFT                 (0U)
#define QuadSPI_LUTKEY_KEY(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_LUTKEY_KEY_SHIFT)) & QuadSPI_LUTKEY_KEY_MASK)

/*! @name LCKCR - LUT Lock Configuration Register */
#define QuadSPI_LCKCR_LOCK_MASK                  (0x1U)
#define QuadSPI_LCKCR_LOCK_SHIFT                 (0U)
#define QuadSPI_LCKCR_UNLOCK_MASK                (0x2U)
#define QuadSPI_LCKCR_UNLOCK_SHIFT               (1U)

/*! @name LUT - Look-up Table register */
#define QuadSPI_LUT_OPRND0_MASK                  (0xFFU)
#define QuadSPI_LUT_OPRND0_SHIFT                 (0U)
#define QuadSPI_LUT_OPRND0(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_LUT_OPRND0_SHIFT)) & QuadSPI_LUT_OPRND0_MASK)
#define QuadSPI_LUT_PAD0_MASK                    (0x300U)
#define QuadSPI_LUT_PAD0_SHIFT                   (8U)
#define QuadSPI_LUT_PAD0(x)                      (((uint32_t)(((uint32_t)(x)) << QuadSPI_LUT_PAD0_SHIFT)) & QuadSPI_LUT_PAD0_MASK)
#define QuadSPI_LUT_INSTR0_MASK                  (0xFC00U)
#define QuadSPI_LUT_INSTR0_SHIFT                 (10U)
#define QuadSPI_LUT_INSTR0(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_LUT_INSTR0_SHIFT)) & QuadSPI_LUT_INSTR0_MASK)
#define QuadSPI_LUT_OPRND1_MASK                  (0xFF0000U)
#define QuadSPI_LUT_OPRND1_SHIFT                 (16U)
#define QuadSPI_LUT_OPRND1(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_LUT_OPRND1_SHIFT)) & QuadSPI_LUT_OPRND1_MASK)
#define QuadSPI_LUT_PAD1_MASK                    (0x3000000U)
#define QuadSPI_LUT_PAD1_SHIFT                   (24U)
#define QuadSPI_LUT_PAD1(x)                      (((uint32_t)(((uint32_t)(x)) << QuadSPI_LUT_PAD1_SHIFT)) & QuadSPI_LUT_PAD1_MASK)
#define QuadSPI_LUT_INSTR1_MASK                  (0xFC000000U)
#define QuadSPI_LUT_INSTR1_SHIFT                 (26U)
#define QuadSPI_LUT_INSTR1(x)                    (((uint32_t)(((uint32_t)(x)) << QuadSPI_LUT_INSTR1_SHIFT)) & QuadSPI_LUT_INSTR1_MASK)

/* The count of QuadSPI_LUT */
#define QuadSPI_LUT_COUNT                        (64U)


/*!
 * @}
 */ /* end of group QuadSPI_Register_Masks */


/* QuadSPI - Peripheral instance base addresses */
/** Peripheral QuadSPI base pointer */
#define QuadSPI_BASE_PTR                         ((QuadSPI_MemMapPtr)0x30BB0000u)
/** Array initializer of QuadSPI peripheral base pointers */
#define QuadSPI_BASE_PTRS                        { QuadSPI_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- QuadSPI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup QuadSPI_Register_Accessor_Macros QuadSPI - Register accessor macros
 * @{
 */


/* QuadSPI - Register instance definitions */
/* QuadSPI */
#define QuadSPI_MCR                              QuadSPI_MCR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_IPCR                             QuadSPI_IPCR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_FLSHCR                           QuadSPI_FLSHCR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_BUF0CR                           QuadSPI_BUF0CR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_BUF1CR                           QuadSPI_BUF1CR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_BUF2CR                           QuadSPI_BUF2CR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_BUF3CR                           QuadSPI_BUF3CR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_BFGENCR                          QuadSPI_BFGENCR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_BUF0IND                          QuadSPI_BUF0IND_REG(QuadSPI_BASE_PTR)
#define QuadSPI_BUF1IND                          QuadSPI_BUF1IND_REG(QuadSPI_BASE_PTR)
#define QuadSPI_BUF2IND                          QuadSPI_BUF2IND_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SFAR                             QuadSPI_SFAR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SMPR                             QuadSPI_SMPR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_RBSR                             QuadSPI_RBSR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_RBCT                             QuadSPI_RBCT_REG(QuadSPI_BASE_PTR)
#define QuadSPI_TBSR                             QuadSPI_TBSR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_TBDR                             QuadSPI_TBDR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SR                               QuadSPI_SR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_FR                               QuadSPI_FR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_RSER                             QuadSPI_RSER_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SPNDST                           QuadSPI_SPNDST_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SPTRCLR                          QuadSPI_SPTRCLR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SFA1AD                           QuadSPI_SFA1AD_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SFA2AD                           QuadSPI_SFA2AD_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SFB1AD                           QuadSPI_SFB1AD_REG(QuadSPI_BASE_PTR)
#define QuadSPI_SFB2AD                           QuadSPI_SFB2AD_REG(QuadSPI_BASE_PTR)
#define QuadSPI_RBDR0                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,0)
#define QuadSPI_RBDR1                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,1)
#define QuadSPI_RBDR2                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,2)
#define QuadSPI_RBDR3                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,3)
#define QuadSPI_RBDR4                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,4)
#define QuadSPI_RBDR5                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,5)
#define QuadSPI_RBDR6                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,6)
#define QuadSPI_RBDR7                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,7)
#define QuadSPI_RBDR8                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,8)
#define QuadSPI_RBDR9                            QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,9)
#define QuadSPI_RBDR10                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,10)
#define QuadSPI_RBDR11                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,11)
#define QuadSPI_RBDR12                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,12)
#define QuadSPI_RBDR13                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,13)
#define QuadSPI_RBDR14                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,14)
#define QuadSPI_RBDR15                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,15)
#define QuadSPI_RBDR16                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,16)
#define QuadSPI_RBDR17                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,17)
#define QuadSPI_RBDR18                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,18)
#define QuadSPI_RBDR19                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,19)
#define QuadSPI_RBDR20                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,20)
#define QuadSPI_RBDR21                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,21)
#define QuadSPI_RBDR22                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,22)
#define QuadSPI_RBDR23                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,23)
#define QuadSPI_RBDR24                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,24)
#define QuadSPI_RBDR25                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,25)
#define QuadSPI_RBDR26                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,26)
#define QuadSPI_RBDR27                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,27)
#define QuadSPI_RBDR28                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,28)
#define QuadSPI_RBDR29                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,29)
#define QuadSPI_RBDR30                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,30)
#define QuadSPI_RBDR31                           QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,31)
#define QuadSPI_LUTKEY                           QuadSPI_LUTKEY_REG(QuadSPI_BASE_PTR)
#define QuadSPI_LCKCR                            QuadSPI_LCKCR_REG(QuadSPI_BASE_PTR)
#define QuadSPI_LUT0                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,0)
#define QuadSPI_LUT1                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,1)
#define QuadSPI_LUT2                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,2)
#define QuadSPI_LUT3                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,3)
#define QuadSPI_LUT4                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,4)
#define QuadSPI_LUT5                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,5)
#define QuadSPI_LUT6                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,6)
#define QuadSPI_LUT7                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,7)
#define QuadSPI_LUT8                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,8)
#define QuadSPI_LUT9                             QuadSPI_LUT_REG(QuadSPI_BASE_PTR,9)
#define QuadSPI_LUT10                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,10)
#define QuadSPI_LUT11                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,11)
#define QuadSPI_LUT12                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,12)
#define QuadSPI_LUT13                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,13)
#define QuadSPI_LUT14                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,14)
#define QuadSPI_LUT15                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,15)
#define QuadSPI_LUT16                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,16)
#define QuadSPI_LUT17                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,17)
#define QuadSPI_LUT18                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,18)
#define QuadSPI_LUT19                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,19)
#define QuadSPI_LUT20                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,20)
#define QuadSPI_LUT21                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,21)
#define QuadSPI_LUT22                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,22)
#define QuadSPI_LUT23                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,23)
#define QuadSPI_LUT24                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,24)
#define QuadSPI_LUT25                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,25)
#define QuadSPI_LUT26                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,26)
#define QuadSPI_LUT27                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,27)
#define QuadSPI_LUT28                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,28)
#define QuadSPI_LUT29                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,29)
#define QuadSPI_LUT30                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,30)
#define QuadSPI_LUT31                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,31)
#define QuadSPI_LUT32                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,32)
#define QuadSPI_LUT33                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,33)
#define QuadSPI_LUT34                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,34)
#define QuadSPI_LUT35                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,35)
#define QuadSPI_LUT36                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,36)
#define QuadSPI_LUT37                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,37)
#define QuadSPI_LUT38                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,38)
#define QuadSPI_LUT39                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,39)
#define QuadSPI_LUT40                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,40)
#define QuadSPI_LUT41                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,41)
#define QuadSPI_LUT42                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,42)
#define QuadSPI_LUT43                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,43)
#define QuadSPI_LUT44                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,44)
#define QuadSPI_LUT45                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,45)
#define QuadSPI_LUT46                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,46)
#define QuadSPI_LUT47                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,47)
#define QuadSPI_LUT48                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,48)
#define QuadSPI_LUT49                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,49)
#define QuadSPI_LUT50                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,50)
#define QuadSPI_LUT51                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,51)
#define QuadSPI_LUT52                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,52)
#define QuadSPI_LUT53                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,53)
#define QuadSPI_LUT54                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,54)
#define QuadSPI_LUT55                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,55)
#define QuadSPI_LUT56                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,56)
#define QuadSPI_LUT57                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,57)
#define QuadSPI_LUT58                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,58)
#define QuadSPI_LUT59                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,59)
#define QuadSPI_LUT60                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,60)
#define QuadSPI_LUT61                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,61)
#define QuadSPI_LUT62                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,62)
#define QuadSPI_LUT63                            QuadSPI_LUT_REG(QuadSPI_BASE_PTR,63)

/* QuadSPI - Register array accessors */
#define QuadSPI_RBDR(index)                      QuadSPI_RBDR_REG(QuadSPI_BASE_PTR,index)
#define QuadSPI_LUT(index)                       QuadSPI_LUT_REG(QuadSPI_BASE_PTR,index)

/*!
 * @}
 */ /* end of group QuadSPI_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group QuadSPI_Peripheral */


/* ----------------------------------------------------------------------------
   -- RDC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RDC_Peripheral RDC
 * @{
 */

/** RDC - Peripheral register structure */
typedef struct RDC_MemMap {
  uint32_t VIR;                                    /**< Version Information, offset: 0x0 */
  uint8_t RESERVED_0[32];
  uint32_t STAT;                                   /**< Status, offset: 0x24 */
  uint32_t INTCTRL;                                /**< Interrupt and Control, offset: 0x28 */
  uint32_t INTSTAT;                                /**< Interrupt Status, offset: 0x2C */
  uint8_t RESERVED_1[464];
  uint32_t MDA[27];                                /**< Master Domain Assignment, array offset: 0x200, array step: 0x4 */
  uint8_t RESERVED_2[404];
  uint32_t PDAP[118];                              /**< Peripheral Domain Access Permissions, array offset: 0x400, array step: 0x4 */
  uint8_t RESERVED_3[552];
  struct {                                         /* offset: 0x800, array step: 0x10 */
    uint32_t MRSA;                                   /**< Memory Region Start Address, array offset: 0x800, array step: 0x10 */
    uint32_t MREA;                                   /**< Memory Region End Address, array offset: 0x804, array step: 0x10 */
    uint32_t MRC;                                    /**< Memory Region Control, array offset: 0x808, array step: 0x10 */
    uint32_t MRVS;                                   /**< Memory Region Violation Status, array offset: 0x80C, array step: 0x10 */
  } MR[52];
} volatile *RDC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- RDC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RDC_Register_Accessor_Macros RDC - Register accessor macros
 * @{
 */


/* RDC - Register accessors */
#define RDC_VIR_REG(base)                        ((base)->VIR)
#define RDC_STAT_REG(base)                       ((base)->STAT)
#define RDC_INTCTRL_REG(base)                    ((base)->INTCTRL)
#define RDC_INTSTAT_REG(base)                    ((base)->INTSTAT)
#define RDC_MDA_REG(base,index)                  ((base)->MDA[index])
#define RDC_PDAP_REG(base,index)                 ((base)->PDAP[index])
#define RDC_MRSA_REG(base,index)                 ((base)->MR[index].MRSA)
#define RDC_MREA_REG(base,index)                 ((base)->MR[index].MREA)
#define RDC_MRC_REG(base,index)                  ((base)->MR[index].MRC)
#define RDC_MRVS_REG(base,index)                 ((base)->MR[index].MRVS)

/*!
 * @}
 */ /* end of group RDC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- RDC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RDC_Register_Masks RDC Register Masks
 * @{
 */

/*! @name VIR - Version Information */
#define RDC_VIR_NDID_MASK                        (0xFU)
#define RDC_VIR_NDID_SHIFT                       (0U)
#define RDC_VIR_NDID(x)                          (((uint32_t)(((uint32_t)(x)) << RDC_VIR_NDID_SHIFT)) & RDC_VIR_NDID_MASK)
#define RDC_VIR_NMSTR_MASK                       (0xFF0U)
#define RDC_VIR_NMSTR_SHIFT                      (4U)
#define RDC_VIR_NMSTR(x)                         (((uint32_t)(((uint32_t)(x)) << RDC_VIR_NMSTR_SHIFT)) & RDC_VIR_NMSTR_MASK)
#define RDC_VIR_NPER_MASK                        (0xFF000U)
#define RDC_VIR_NPER_SHIFT                       (12U)
#define RDC_VIR_NPER(x)                          (((uint32_t)(((uint32_t)(x)) << RDC_VIR_NPER_SHIFT)) & RDC_VIR_NPER_MASK)
#define RDC_VIR_NRGN_MASK                        (0xFF00000U)
#define RDC_VIR_NRGN_SHIFT                       (20U)
#define RDC_VIR_NRGN(x)                          (((uint32_t)(((uint32_t)(x)) << RDC_VIR_NRGN_SHIFT)) & RDC_VIR_NRGN_MASK)

/*! @name STAT - Status */
#define RDC_STAT_DID_MASK                        (0xFU)
#define RDC_STAT_DID_SHIFT                       (0U)
#define RDC_STAT_DID(x)                          (((uint32_t)(((uint32_t)(x)) << RDC_STAT_DID_SHIFT)) & RDC_STAT_DID_MASK)
#define RDC_STAT_PDS_MASK                        (0x100U)
#define RDC_STAT_PDS_SHIFT                       (8U)

/*! @name INTCTRL - Interrupt and Control */
#define RDC_INTCTRL_RCI_EN_MASK                  (0x1U)
#define RDC_INTCTRL_RCI_EN_SHIFT                 (0U)

/*! @name INTSTAT - Interrupt Status */
#define RDC_INTSTAT_INT_MASK                     (0x1U)
#define RDC_INTSTAT_INT_SHIFT                    (0U)

/*! @name MDA - Master Domain Assignment */
#define RDC_MDA_DID_MASK                         (0x3U)
#define RDC_MDA_DID_SHIFT                        (0U)
#define RDC_MDA_DID(x)                           (((uint32_t)(((uint32_t)(x)) << RDC_MDA_DID_SHIFT)) & RDC_MDA_DID_MASK)
#define RDC_MDA_LCK_MASK                         (0x80000000U)
#define RDC_MDA_LCK_SHIFT                        (31U)

/* The count of RDC_MDA */
#define RDC_MDA_COUNT                            (27U)

/*! @name PDAP - Peripheral Domain Access Permissions */
#define RDC_PDAP_D0W_MASK                        (0x1U)
#define RDC_PDAP_D0W_SHIFT                       (0U)
#define RDC_PDAP_D0R_MASK                        (0x2U)
#define RDC_PDAP_D0R_SHIFT                       (1U)
#define RDC_PDAP_D1W_MASK                        (0x4U)
#define RDC_PDAP_D1W_SHIFT                       (2U)
#define RDC_PDAP_D1R_MASK                        (0x8U)
#define RDC_PDAP_D1R_SHIFT                       (3U)
#define RDC_PDAP_D2W_MASK                        (0x10U)
#define RDC_PDAP_D2W_SHIFT                       (4U)
#define RDC_PDAP_D2R_MASK                        (0x20U)
#define RDC_PDAP_D2R_SHIFT                       (5U)
#define RDC_PDAP_D3W_MASK                        (0x40U)
#define RDC_PDAP_D3W_SHIFT                       (6U)
#define RDC_PDAP_D3R_MASK                        (0x80U)
#define RDC_PDAP_D3R_SHIFT                       (7U)
#define RDC_PDAP_SREQ_MASK                       (0x40000000U)
#define RDC_PDAP_SREQ_SHIFT                      (30U)
#define RDC_PDAP_LCK_MASK                        (0x80000000U)
#define RDC_PDAP_LCK_SHIFT                       (31U)

/* The count of RDC_PDAP */
#define RDC_PDAP_COUNT                           (118U)

/*! @name MRSA - Memory Region Start Address */
#define RDC_MRSA_SADR_MASK                       (0xFFFFFF80U)
#define RDC_MRSA_SADR_SHIFT                      (7U)
#define RDC_MRSA_SADR(x)                         (((uint32_t)(((uint32_t)(x)) << RDC_MRSA_SADR_SHIFT)) & RDC_MRSA_SADR_MASK)

/* The count of RDC_MRSA */
#define RDC_MRSA_COUNT                           (52U)

/*! @name MREA - Memory Region End Address */
#define RDC_MREA_EADR_MASK                       (0xFFFFFF80U)
#define RDC_MREA_EADR_SHIFT                      (7U)
#define RDC_MREA_EADR(x)                         (((uint32_t)(((uint32_t)(x)) << RDC_MREA_EADR_SHIFT)) & RDC_MREA_EADR_MASK)

/* The count of RDC_MREA */
#define RDC_MREA_COUNT                           (52U)

/*! @name MRC - Memory Region Control */
#define RDC_MRC_D0W_MASK                         (0x1U)
#define RDC_MRC_D0W_SHIFT                        (0U)
#define RDC_MRC_D0R_MASK                         (0x2U)
#define RDC_MRC_D0R_SHIFT                        (1U)
#define RDC_MRC_D1W_MASK                         (0x4U)
#define RDC_MRC_D1W_SHIFT                        (2U)
#define RDC_MRC_D1R_MASK                         (0x8U)
#define RDC_MRC_D1R_SHIFT                        (3U)
#define RDC_MRC_D2W_MASK                         (0x10U)
#define RDC_MRC_D2W_SHIFT                        (4U)
#define RDC_MRC_D2R_MASK                         (0x20U)
#define RDC_MRC_D2R_SHIFT                        (5U)
#define RDC_MRC_D3W_MASK                         (0x40U)
#define RDC_MRC_D3W_SHIFT                        (6U)
#define RDC_MRC_D3R_MASK                         (0x80U)
#define RDC_MRC_D3R_SHIFT                        (7U)
#define RDC_MRC_ENA_MASK                         (0x40000000U)
#define RDC_MRC_ENA_SHIFT                        (30U)
#define RDC_MRC_LCK_MASK                         (0x80000000U)
#define RDC_MRC_LCK_SHIFT                        (31U)

/* The count of RDC_MRC */
#define RDC_MRC_COUNT                            (52U)

/*! @name MRVS - Memory Region Violation Status */
#define RDC_MRVS_VDID_MASK                       (0x3U)
#define RDC_MRVS_VDID_SHIFT                      (0U)
#define RDC_MRVS_VDID(x)                         (((uint32_t)(((uint32_t)(x)) << RDC_MRVS_VDID_SHIFT)) & RDC_MRVS_VDID_MASK)
#define RDC_MRVS_AD_MASK                         (0x10U)
#define RDC_MRVS_AD_SHIFT                        (4U)
#define RDC_MRVS_VADR_MASK                       (0xFFFFFFE0U)
#define RDC_MRVS_VADR_SHIFT                      (5U)
#define RDC_MRVS_VADR(x)                         (((uint32_t)(((uint32_t)(x)) << RDC_MRVS_VADR_SHIFT)) & RDC_MRVS_VADR_MASK)

/* The count of RDC_MRVS */
#define RDC_MRVS_COUNT                           (52U)


/*!
 * @}
 */ /* end of group RDC_Register_Masks */


/* RDC - Peripheral instance base addresses */
/** Peripheral RDC base pointer */
#define RDC_BASE_PTR                             ((RDC_MemMapPtr)0x303D0000u)
/** Array initializer of RDC peripheral base pointers */
#define RDC_BASE_PTRS                            { RDC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- RDC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RDC_Register_Accessor_Macros RDC - Register accessor macros
 * @{
 */


/* RDC - Register instance definitions */
/* RDC */
#define RDC_VIR                                  RDC_VIR_REG(RDC_BASE_PTR)
#define RDC_STAT                                 RDC_STAT_REG(RDC_BASE_PTR)
#define RDC_INTCTRL                              RDC_INTCTRL_REG(RDC_BASE_PTR)
#define RDC_INTSTAT                              RDC_INTSTAT_REG(RDC_BASE_PTR)
#define RDC_MDA0                                 RDC_MDA_REG(RDC_BASE_PTR,0)
#define RDC_MDA1                                 RDC_MDA_REG(RDC_BASE_PTR,1)
#define RDC_MDA2                                 RDC_MDA_REG(RDC_BASE_PTR,2)
#define RDC_MDA3                                 RDC_MDA_REG(RDC_BASE_PTR,3)
#define RDC_MDA4                                 RDC_MDA_REG(RDC_BASE_PTR,4)
#define RDC_MDA5                                 RDC_MDA_REG(RDC_BASE_PTR,5)
#define RDC_MDA6                                 RDC_MDA_REG(RDC_BASE_PTR,6)
#define RDC_MDA7                                 RDC_MDA_REG(RDC_BASE_PTR,7)
#define RDC_MDA8                                 RDC_MDA_REG(RDC_BASE_PTR,8)
#define RDC_MDA9                                 RDC_MDA_REG(RDC_BASE_PTR,9)
#define RDC_MDA10                                RDC_MDA_REG(RDC_BASE_PTR,10)
#define RDC_MDA11                                RDC_MDA_REG(RDC_BASE_PTR,11)
#define RDC_MDA12                                RDC_MDA_REG(RDC_BASE_PTR,12)
#define RDC_MDA13                                RDC_MDA_REG(RDC_BASE_PTR,13)
#define RDC_MDA14                                RDC_MDA_REG(RDC_BASE_PTR,14)
#define RDC_MDA15                                RDC_MDA_REG(RDC_BASE_PTR,15)
#define RDC_MDA16                                RDC_MDA_REG(RDC_BASE_PTR,16)
#define RDC_MDA17                                RDC_MDA_REG(RDC_BASE_PTR,17)
#define RDC_MDA18                                RDC_MDA_REG(RDC_BASE_PTR,18)
#define RDC_MDA19                                RDC_MDA_REG(RDC_BASE_PTR,19)
#define RDC_MDA20                                RDC_MDA_REG(RDC_BASE_PTR,20)
#define RDC_MDA21                                RDC_MDA_REG(RDC_BASE_PTR,21)
#define RDC_MDA22                                RDC_MDA_REG(RDC_BASE_PTR,22)
#define RDC_MDA23                                RDC_MDA_REG(RDC_BASE_PTR,23)
#define RDC_MDA24                                RDC_MDA_REG(RDC_BASE_PTR,24)
#define RDC_MDA25                                RDC_MDA_REG(RDC_BASE_PTR,25)
#define RDC_MDA26                                RDC_MDA_REG(RDC_BASE_PTR,26)
#define RDC_PDAP0                                RDC_PDAP_REG(RDC_BASE_PTR,0)
#define RDC_PDAP1                                RDC_PDAP_REG(RDC_BASE_PTR,1)
#define RDC_PDAP2                                RDC_PDAP_REG(RDC_BASE_PTR,2)
#define RDC_PDAP3                                RDC_PDAP_REG(RDC_BASE_PTR,3)
#define RDC_PDAP4                                RDC_PDAP_REG(RDC_BASE_PTR,4)
#define RDC_PDAP5                                RDC_PDAP_REG(RDC_BASE_PTR,5)
#define RDC_PDAP6                                RDC_PDAP_REG(RDC_BASE_PTR,6)
#define RDC_PDAP7                                RDC_PDAP_REG(RDC_BASE_PTR,7)
#define RDC_PDAP8                                RDC_PDAP_REG(RDC_BASE_PTR,8)
#define RDC_PDAP9                                RDC_PDAP_REG(RDC_BASE_PTR,9)
#define RDC_PDAP10                               RDC_PDAP_REG(RDC_BASE_PTR,10)
#define RDC_PDAP11                               RDC_PDAP_REG(RDC_BASE_PTR,11)
#define RDC_PDAP12                               RDC_PDAP_REG(RDC_BASE_PTR,12)
#define RDC_PDAP13                               RDC_PDAP_REG(RDC_BASE_PTR,13)
#define RDC_PDAP14                               RDC_PDAP_REG(RDC_BASE_PTR,14)
#define RDC_PDAP15                               RDC_PDAP_REG(RDC_BASE_PTR,15)
#define RDC_PDAP16                               RDC_PDAP_REG(RDC_BASE_PTR,16)
#define RDC_PDAP17                               RDC_PDAP_REG(RDC_BASE_PTR,17)
#define RDC_PDAP18                               RDC_PDAP_REG(RDC_BASE_PTR,18)
#define RDC_PDAP19                               RDC_PDAP_REG(RDC_BASE_PTR,19)
#define RDC_PDAP20                               RDC_PDAP_REG(RDC_BASE_PTR,20)
#define RDC_PDAP21                               RDC_PDAP_REG(RDC_BASE_PTR,21)
#define RDC_PDAP22                               RDC_PDAP_REG(RDC_BASE_PTR,22)
#define RDC_PDAP23                               RDC_PDAP_REG(RDC_BASE_PTR,23)
#define RDC_PDAP24                               RDC_PDAP_REG(RDC_BASE_PTR,24)
#define RDC_PDAP25                               RDC_PDAP_REG(RDC_BASE_PTR,25)
#define RDC_PDAP26                               RDC_PDAP_REG(RDC_BASE_PTR,26)
#define RDC_PDAP27                               RDC_PDAP_REG(RDC_BASE_PTR,27)
#define RDC_PDAP28                               RDC_PDAP_REG(RDC_BASE_PTR,28)
#define RDC_PDAP29                               RDC_PDAP_REG(RDC_BASE_PTR,29)
#define RDC_PDAP30                               RDC_PDAP_REG(RDC_BASE_PTR,30)
#define RDC_PDAP31                               RDC_PDAP_REG(RDC_BASE_PTR,31)
#define RDC_PDAP32                               RDC_PDAP_REG(RDC_BASE_PTR,32)
#define RDC_PDAP33                               RDC_PDAP_REG(RDC_BASE_PTR,33)
#define RDC_PDAP34                               RDC_PDAP_REG(RDC_BASE_PTR,34)
#define RDC_PDAP35                               RDC_PDAP_REG(RDC_BASE_PTR,35)
#define RDC_PDAP36                               RDC_PDAP_REG(RDC_BASE_PTR,36)
#define RDC_PDAP37                               RDC_PDAP_REG(RDC_BASE_PTR,37)
#define RDC_PDAP38                               RDC_PDAP_REG(RDC_BASE_PTR,38)
#define RDC_PDAP39                               RDC_PDAP_REG(RDC_BASE_PTR,39)
#define RDC_PDAP40                               RDC_PDAP_REG(RDC_BASE_PTR,40)
#define RDC_PDAP41                               RDC_PDAP_REG(RDC_BASE_PTR,41)
#define RDC_PDAP42                               RDC_PDAP_REG(RDC_BASE_PTR,42)
#define RDC_PDAP43                               RDC_PDAP_REG(RDC_BASE_PTR,43)
#define RDC_PDAP44                               RDC_PDAP_REG(RDC_BASE_PTR,44)
#define RDC_PDAP45                               RDC_PDAP_REG(RDC_BASE_PTR,45)
#define RDC_PDAP46                               RDC_PDAP_REG(RDC_BASE_PTR,46)
#define RDC_PDAP47                               RDC_PDAP_REG(RDC_BASE_PTR,47)
#define RDC_PDAP48                               RDC_PDAP_REG(RDC_BASE_PTR,48)
#define RDC_PDAP49                               RDC_PDAP_REG(RDC_BASE_PTR,49)
#define RDC_PDAP50                               RDC_PDAP_REG(RDC_BASE_PTR,50)
#define RDC_PDAP51                               RDC_PDAP_REG(RDC_BASE_PTR,51)
#define RDC_PDAP52                               RDC_PDAP_REG(RDC_BASE_PTR,52)
#define RDC_PDAP53                               RDC_PDAP_REG(RDC_BASE_PTR,53)
#define RDC_PDAP54                               RDC_PDAP_REG(RDC_BASE_PTR,54)
#define RDC_PDAP55                               RDC_PDAP_REG(RDC_BASE_PTR,55)
#define RDC_PDAP56                               RDC_PDAP_REG(RDC_BASE_PTR,56)
#define RDC_PDAP57                               RDC_PDAP_REG(RDC_BASE_PTR,57)
#define RDC_PDAP58                               RDC_PDAP_REG(RDC_BASE_PTR,58)
#define RDC_PDAP59                               RDC_PDAP_REG(RDC_BASE_PTR,59)
#define RDC_PDAP60                               RDC_PDAP_REG(RDC_BASE_PTR,60)
#define RDC_PDAP61                               RDC_PDAP_REG(RDC_BASE_PTR,61)
#define RDC_PDAP62                               RDC_PDAP_REG(RDC_BASE_PTR,62)
#define RDC_PDAP63                               RDC_PDAP_REG(RDC_BASE_PTR,63)
#define RDC_PDAP64                               RDC_PDAP_REG(RDC_BASE_PTR,64)
#define RDC_PDAP65                               RDC_PDAP_REG(RDC_BASE_PTR,65)
#define RDC_PDAP66                               RDC_PDAP_REG(RDC_BASE_PTR,66)
#define RDC_PDAP67                               RDC_PDAP_REG(RDC_BASE_PTR,67)
#define RDC_PDAP68                               RDC_PDAP_REG(RDC_BASE_PTR,68)
#define RDC_PDAP69                               RDC_PDAP_REG(RDC_BASE_PTR,69)
#define RDC_PDAP70                               RDC_PDAP_REG(RDC_BASE_PTR,70)
#define RDC_PDAP71                               RDC_PDAP_REG(RDC_BASE_PTR,71)
#define RDC_PDAP72                               RDC_PDAP_REG(RDC_BASE_PTR,72)
#define RDC_PDAP73                               RDC_PDAP_REG(RDC_BASE_PTR,73)
#define RDC_PDAP74                               RDC_PDAP_REG(RDC_BASE_PTR,74)
#define RDC_PDAP75                               RDC_PDAP_REG(RDC_BASE_PTR,75)
#define RDC_PDAP76                               RDC_PDAP_REG(RDC_BASE_PTR,76)
#define RDC_PDAP77                               RDC_PDAP_REG(RDC_BASE_PTR,77)
#define RDC_PDAP78                               RDC_PDAP_REG(RDC_BASE_PTR,78)
#define RDC_PDAP79                               RDC_PDAP_REG(RDC_BASE_PTR,79)
#define RDC_PDAP80                               RDC_PDAP_REG(RDC_BASE_PTR,80)
#define RDC_PDAP81                               RDC_PDAP_REG(RDC_BASE_PTR,81)
#define RDC_PDAP82                               RDC_PDAP_REG(RDC_BASE_PTR,82)
#define RDC_PDAP83                               RDC_PDAP_REG(RDC_BASE_PTR,83)
#define RDC_PDAP84                               RDC_PDAP_REG(RDC_BASE_PTR,84)
#define RDC_PDAP85                               RDC_PDAP_REG(RDC_BASE_PTR,85)
#define RDC_PDAP86                               RDC_PDAP_REG(RDC_BASE_PTR,86)
#define RDC_PDAP87                               RDC_PDAP_REG(RDC_BASE_PTR,87)
#define RDC_PDAP88                               RDC_PDAP_REG(RDC_BASE_PTR,88)
#define RDC_PDAP89                               RDC_PDAP_REG(RDC_BASE_PTR,89)
#define RDC_PDAP90                               RDC_PDAP_REG(RDC_BASE_PTR,90)
#define RDC_PDAP91                               RDC_PDAP_REG(RDC_BASE_PTR,91)
#define RDC_PDAP92                               RDC_PDAP_REG(RDC_BASE_PTR,92)
#define RDC_PDAP93                               RDC_PDAP_REG(RDC_BASE_PTR,93)
#define RDC_PDAP94                               RDC_PDAP_REG(RDC_BASE_PTR,94)
#define RDC_PDAP95                               RDC_PDAP_REG(RDC_BASE_PTR,95)
#define RDC_PDAP96                               RDC_PDAP_REG(RDC_BASE_PTR,96)
#define RDC_PDAP97                               RDC_PDAP_REG(RDC_BASE_PTR,97)
#define RDC_PDAP98                               RDC_PDAP_REG(RDC_BASE_PTR,98)
#define RDC_PDAP99                               RDC_PDAP_REG(RDC_BASE_PTR,99)
#define RDC_PDAP100                              RDC_PDAP_REG(RDC_BASE_PTR,100)
#define RDC_PDAP101                              RDC_PDAP_REG(RDC_BASE_PTR,101)
#define RDC_PDAP102                              RDC_PDAP_REG(RDC_BASE_PTR,102)
#define RDC_PDAP103                              RDC_PDAP_REG(RDC_BASE_PTR,103)
#define RDC_PDAP104                              RDC_PDAP_REG(RDC_BASE_PTR,104)
#define RDC_PDAP105                              RDC_PDAP_REG(RDC_BASE_PTR,105)
#define RDC_PDAP106                              RDC_PDAP_REG(RDC_BASE_PTR,106)
#define RDC_PDAP107                              RDC_PDAP_REG(RDC_BASE_PTR,107)
#define RDC_PDAP108                              RDC_PDAP_REG(RDC_BASE_PTR,108)
#define RDC_PDAP109                              RDC_PDAP_REG(RDC_BASE_PTR,109)
#define RDC_PDAP110                              RDC_PDAP_REG(RDC_BASE_PTR,110)
#define RDC_PDAP111                              RDC_PDAP_REG(RDC_BASE_PTR,111)
#define RDC_PDAP112                              RDC_PDAP_REG(RDC_BASE_PTR,112)
#define RDC_PDAP113                              RDC_PDAP_REG(RDC_BASE_PTR,113)
#define RDC_PDAP114                              RDC_PDAP_REG(RDC_BASE_PTR,114)
#define RDC_PDAP115                              RDC_PDAP_REG(RDC_BASE_PTR,115)
#define RDC_PDAP116                              RDC_PDAP_REG(RDC_BASE_PTR,116)
#define RDC_PDAP117                              RDC_PDAP_REG(RDC_BASE_PTR,117)
#define RDC_MRSA0                                RDC_MRSA_REG(RDC_BASE_PTR,0)
#define RDC_MREA0                                RDC_MREA_REG(RDC_BASE_PTR,0)
#define RDC_MRC0                                 RDC_MRC_REG(RDC_BASE_PTR,0)
#define RDC_MRVS0                                RDC_MRVS_REG(RDC_BASE_PTR,0)
#define RDC_MRSA1                                RDC_MRSA_REG(RDC_BASE_PTR,1)
#define RDC_MREA1                                RDC_MREA_REG(RDC_BASE_PTR,1)
#define RDC_MRC1                                 RDC_MRC_REG(RDC_BASE_PTR,1)
#define RDC_MRVS1                                RDC_MRVS_REG(RDC_BASE_PTR,1)
#define RDC_MRSA2                                RDC_MRSA_REG(RDC_BASE_PTR,2)
#define RDC_MREA2                                RDC_MREA_REG(RDC_BASE_PTR,2)
#define RDC_MRC2                                 RDC_MRC_REG(RDC_BASE_PTR,2)
#define RDC_MRVS2                                RDC_MRVS_REG(RDC_BASE_PTR,2)
#define RDC_MRSA3                                RDC_MRSA_REG(RDC_BASE_PTR,3)
#define RDC_MREA3                                RDC_MREA_REG(RDC_BASE_PTR,3)
#define RDC_MRC3                                 RDC_MRC_REG(RDC_BASE_PTR,3)
#define RDC_MRVS3                                RDC_MRVS_REG(RDC_BASE_PTR,3)
#define RDC_MRSA4                                RDC_MRSA_REG(RDC_BASE_PTR,4)
#define RDC_MREA4                                RDC_MREA_REG(RDC_BASE_PTR,4)
#define RDC_MRC4                                 RDC_MRC_REG(RDC_BASE_PTR,4)
#define RDC_MRVS4                                RDC_MRVS_REG(RDC_BASE_PTR,4)
#define RDC_MRSA5                                RDC_MRSA_REG(RDC_BASE_PTR,5)
#define RDC_MREA5                                RDC_MREA_REG(RDC_BASE_PTR,5)
#define RDC_MRC5                                 RDC_MRC_REG(RDC_BASE_PTR,5)
#define RDC_MRVS5                                RDC_MRVS_REG(RDC_BASE_PTR,5)
#define RDC_MRSA6                                RDC_MRSA_REG(RDC_BASE_PTR,6)
#define RDC_MREA6                                RDC_MREA_REG(RDC_BASE_PTR,6)
#define RDC_MRC6                                 RDC_MRC_REG(RDC_BASE_PTR,6)
#define RDC_MRVS6                                RDC_MRVS_REG(RDC_BASE_PTR,6)
#define RDC_MRSA7                                RDC_MRSA_REG(RDC_BASE_PTR,7)
#define RDC_MREA7                                RDC_MREA_REG(RDC_BASE_PTR,7)
#define RDC_MRC7                                 RDC_MRC_REG(RDC_BASE_PTR,7)
#define RDC_MRVS7                                RDC_MRVS_REG(RDC_BASE_PTR,7)
#define RDC_MRSA8                                RDC_MRSA_REG(RDC_BASE_PTR,8)
#define RDC_MREA8                                RDC_MREA_REG(RDC_BASE_PTR,8)
#define RDC_MRC8                                 RDC_MRC_REG(RDC_BASE_PTR,8)
#define RDC_MRVS8                                RDC_MRVS_REG(RDC_BASE_PTR,8)
#define RDC_MRSA9                                RDC_MRSA_REG(RDC_BASE_PTR,9)
#define RDC_MREA9                                RDC_MREA_REG(RDC_BASE_PTR,9)
#define RDC_MRC9                                 RDC_MRC_REG(RDC_BASE_PTR,9)
#define RDC_MRVS9                                RDC_MRVS_REG(RDC_BASE_PTR,9)
#define RDC_MRSA10                               RDC_MRSA_REG(RDC_BASE_PTR,10)
#define RDC_MREA10                               RDC_MREA_REG(RDC_BASE_PTR,10)
#define RDC_MRC10                                RDC_MRC_REG(RDC_BASE_PTR,10)
#define RDC_MRVS10                               RDC_MRVS_REG(RDC_BASE_PTR,10)
#define RDC_MRSA11                               RDC_MRSA_REG(RDC_BASE_PTR,11)
#define RDC_MREA11                               RDC_MREA_REG(RDC_BASE_PTR,11)
#define RDC_MRC11                                RDC_MRC_REG(RDC_BASE_PTR,11)
#define RDC_MRVS11                               RDC_MRVS_REG(RDC_BASE_PTR,11)
#define RDC_MRSA12                               RDC_MRSA_REG(RDC_BASE_PTR,12)
#define RDC_MREA12                               RDC_MREA_REG(RDC_BASE_PTR,12)
#define RDC_MRC12                                RDC_MRC_REG(RDC_BASE_PTR,12)
#define RDC_MRVS12                               RDC_MRVS_REG(RDC_BASE_PTR,12)
#define RDC_MRSA13                               RDC_MRSA_REG(RDC_BASE_PTR,13)
#define RDC_MREA13                               RDC_MREA_REG(RDC_BASE_PTR,13)
#define RDC_MRC13                                RDC_MRC_REG(RDC_BASE_PTR,13)
#define RDC_MRVS13                               RDC_MRVS_REG(RDC_BASE_PTR,13)
#define RDC_MRSA14                               RDC_MRSA_REG(RDC_BASE_PTR,14)
#define RDC_MREA14                               RDC_MREA_REG(RDC_BASE_PTR,14)
#define RDC_MRC14                                RDC_MRC_REG(RDC_BASE_PTR,14)
#define RDC_MRVS14                               RDC_MRVS_REG(RDC_BASE_PTR,14)
#define RDC_MRSA15                               RDC_MRSA_REG(RDC_BASE_PTR,15)
#define RDC_MREA15                               RDC_MREA_REG(RDC_BASE_PTR,15)
#define RDC_MRC15                                RDC_MRC_REG(RDC_BASE_PTR,15)
#define RDC_MRVS15                               RDC_MRVS_REG(RDC_BASE_PTR,15)
#define RDC_MRSA16                               RDC_MRSA_REG(RDC_BASE_PTR,16)
#define RDC_MREA16                               RDC_MREA_REG(RDC_BASE_PTR,16)
#define RDC_MRC16                                RDC_MRC_REG(RDC_BASE_PTR,16)
#define RDC_MRVS16                               RDC_MRVS_REG(RDC_BASE_PTR,16)
#define RDC_MRSA17                               RDC_MRSA_REG(RDC_BASE_PTR,17)
#define RDC_MREA17                               RDC_MREA_REG(RDC_BASE_PTR,17)
#define RDC_MRC17                                RDC_MRC_REG(RDC_BASE_PTR,17)
#define RDC_MRVS17                               RDC_MRVS_REG(RDC_BASE_PTR,17)
#define RDC_MRSA18                               RDC_MRSA_REG(RDC_BASE_PTR,18)
#define RDC_MREA18                               RDC_MREA_REG(RDC_BASE_PTR,18)
#define RDC_MRC18                                RDC_MRC_REG(RDC_BASE_PTR,18)
#define RDC_MRVS18                               RDC_MRVS_REG(RDC_BASE_PTR,18)
#define RDC_MRSA19                               RDC_MRSA_REG(RDC_BASE_PTR,19)
#define RDC_MREA19                               RDC_MREA_REG(RDC_BASE_PTR,19)
#define RDC_MRC19                                RDC_MRC_REG(RDC_BASE_PTR,19)
#define RDC_MRVS19                               RDC_MRVS_REG(RDC_BASE_PTR,19)
#define RDC_MRSA20                               RDC_MRSA_REG(RDC_BASE_PTR,20)
#define RDC_MREA20                               RDC_MREA_REG(RDC_BASE_PTR,20)
#define RDC_MRC20                                RDC_MRC_REG(RDC_BASE_PTR,20)
#define RDC_MRVS20                               RDC_MRVS_REG(RDC_BASE_PTR,20)
#define RDC_MRSA21                               RDC_MRSA_REG(RDC_BASE_PTR,21)
#define RDC_MREA21                               RDC_MREA_REG(RDC_BASE_PTR,21)
#define RDC_MRC21                                RDC_MRC_REG(RDC_BASE_PTR,21)
#define RDC_MRVS21                               RDC_MRVS_REG(RDC_BASE_PTR,21)
#define RDC_MRSA22                               RDC_MRSA_REG(RDC_BASE_PTR,22)
#define RDC_MREA22                               RDC_MREA_REG(RDC_BASE_PTR,22)
#define RDC_MRC22                                RDC_MRC_REG(RDC_BASE_PTR,22)
#define RDC_MRVS22                               RDC_MRVS_REG(RDC_BASE_PTR,22)
#define RDC_MRSA23                               RDC_MRSA_REG(RDC_BASE_PTR,23)
#define RDC_MREA23                               RDC_MREA_REG(RDC_BASE_PTR,23)
#define RDC_MRC23                                RDC_MRC_REG(RDC_BASE_PTR,23)
#define RDC_MRVS23                               RDC_MRVS_REG(RDC_BASE_PTR,23)
#define RDC_MRSA24                               RDC_MRSA_REG(RDC_BASE_PTR,24)
#define RDC_MREA24                               RDC_MREA_REG(RDC_BASE_PTR,24)
#define RDC_MRC24                                RDC_MRC_REG(RDC_BASE_PTR,24)
#define RDC_MRVS24                               RDC_MRVS_REG(RDC_BASE_PTR,24)
#define RDC_MRSA25                               RDC_MRSA_REG(RDC_BASE_PTR,25)
#define RDC_MREA25                               RDC_MREA_REG(RDC_BASE_PTR,25)
#define RDC_MRC25                                RDC_MRC_REG(RDC_BASE_PTR,25)
#define RDC_MRVS25                               RDC_MRVS_REG(RDC_BASE_PTR,25)
#define RDC_MRSA26                               RDC_MRSA_REG(RDC_BASE_PTR,26)
#define RDC_MREA26                               RDC_MREA_REG(RDC_BASE_PTR,26)
#define RDC_MRC26                                RDC_MRC_REG(RDC_BASE_PTR,26)
#define RDC_MRVS26                               RDC_MRVS_REG(RDC_BASE_PTR,26)
#define RDC_MRSA27                               RDC_MRSA_REG(RDC_BASE_PTR,27)
#define RDC_MREA27                               RDC_MREA_REG(RDC_BASE_PTR,27)
#define RDC_MRC27                                RDC_MRC_REG(RDC_BASE_PTR,27)
#define RDC_MRVS27                               RDC_MRVS_REG(RDC_BASE_PTR,27)
#define RDC_MRSA28                               RDC_MRSA_REG(RDC_BASE_PTR,28)
#define RDC_MREA28                               RDC_MREA_REG(RDC_BASE_PTR,28)
#define RDC_MRC28                                RDC_MRC_REG(RDC_BASE_PTR,28)
#define RDC_MRVS28                               RDC_MRVS_REG(RDC_BASE_PTR,28)
#define RDC_MRSA29                               RDC_MRSA_REG(RDC_BASE_PTR,29)
#define RDC_MREA29                               RDC_MREA_REG(RDC_BASE_PTR,29)
#define RDC_MRC29                                RDC_MRC_REG(RDC_BASE_PTR,29)
#define RDC_MRVS29                               RDC_MRVS_REG(RDC_BASE_PTR,29)
#define RDC_MRSA30                               RDC_MRSA_REG(RDC_BASE_PTR,30)
#define RDC_MREA30                               RDC_MREA_REG(RDC_BASE_PTR,30)
#define RDC_MRC30                                RDC_MRC_REG(RDC_BASE_PTR,30)
#define RDC_MRVS30                               RDC_MRVS_REG(RDC_BASE_PTR,30)
#define RDC_MRSA31                               RDC_MRSA_REG(RDC_BASE_PTR,31)
#define RDC_MREA31                               RDC_MREA_REG(RDC_BASE_PTR,31)
#define RDC_MRC31                                RDC_MRC_REG(RDC_BASE_PTR,31)
#define RDC_MRVS31                               RDC_MRVS_REG(RDC_BASE_PTR,31)
#define RDC_MRSA32                               RDC_MRSA_REG(RDC_BASE_PTR,32)
#define RDC_MREA32                               RDC_MREA_REG(RDC_BASE_PTR,32)
#define RDC_MRC32                                RDC_MRC_REG(RDC_BASE_PTR,32)
#define RDC_MRVS32                               RDC_MRVS_REG(RDC_BASE_PTR,32)
#define RDC_MRSA33                               RDC_MRSA_REG(RDC_BASE_PTR,33)
#define RDC_MREA33                               RDC_MREA_REG(RDC_BASE_PTR,33)
#define RDC_MRC33                                RDC_MRC_REG(RDC_BASE_PTR,33)
#define RDC_MRVS33                               RDC_MRVS_REG(RDC_BASE_PTR,33)
#define RDC_MRSA34                               RDC_MRSA_REG(RDC_BASE_PTR,34)
#define RDC_MREA34                               RDC_MREA_REG(RDC_BASE_PTR,34)
#define RDC_MRC34                                RDC_MRC_REG(RDC_BASE_PTR,34)
#define RDC_MRVS34                               RDC_MRVS_REG(RDC_BASE_PTR,34)
#define RDC_MRSA35                               RDC_MRSA_REG(RDC_BASE_PTR,35)
#define RDC_MREA35                               RDC_MREA_REG(RDC_BASE_PTR,35)
#define RDC_MRC35                                RDC_MRC_REG(RDC_BASE_PTR,35)
#define RDC_MRVS35                               RDC_MRVS_REG(RDC_BASE_PTR,35)
#define RDC_MRSA36                               RDC_MRSA_REG(RDC_BASE_PTR,36)
#define RDC_MREA36                               RDC_MREA_REG(RDC_BASE_PTR,36)
#define RDC_MRC36                                RDC_MRC_REG(RDC_BASE_PTR,36)
#define RDC_MRVS36                               RDC_MRVS_REG(RDC_BASE_PTR,36)
#define RDC_MRSA37                               RDC_MRSA_REG(RDC_BASE_PTR,37)
#define RDC_MREA37                               RDC_MREA_REG(RDC_BASE_PTR,37)
#define RDC_MRC37                                RDC_MRC_REG(RDC_BASE_PTR,37)
#define RDC_MRVS37                               RDC_MRVS_REG(RDC_BASE_PTR,37)
#define RDC_MRSA38                               RDC_MRSA_REG(RDC_BASE_PTR,38)
#define RDC_MREA38                               RDC_MREA_REG(RDC_BASE_PTR,38)
#define RDC_MRC38                                RDC_MRC_REG(RDC_BASE_PTR,38)
#define RDC_MRVS38                               RDC_MRVS_REG(RDC_BASE_PTR,38)
#define RDC_MRSA39                               RDC_MRSA_REG(RDC_BASE_PTR,39)
#define RDC_MREA39                               RDC_MREA_REG(RDC_BASE_PTR,39)
#define RDC_MRC39                                RDC_MRC_REG(RDC_BASE_PTR,39)
#define RDC_MRVS39                               RDC_MRVS_REG(RDC_BASE_PTR,39)
#define RDC_MRSA40                               RDC_MRSA_REG(RDC_BASE_PTR,40)
#define RDC_MREA40                               RDC_MREA_REG(RDC_BASE_PTR,40)
#define RDC_MRC40                                RDC_MRC_REG(RDC_BASE_PTR,40)
#define RDC_MRVS40                               RDC_MRVS_REG(RDC_BASE_PTR,40)
#define RDC_MRSA41                               RDC_MRSA_REG(RDC_BASE_PTR,41)
#define RDC_MREA41                               RDC_MREA_REG(RDC_BASE_PTR,41)
#define RDC_MRC41                                RDC_MRC_REG(RDC_BASE_PTR,41)
#define RDC_MRVS41                               RDC_MRVS_REG(RDC_BASE_PTR,41)
#define RDC_MRSA42                               RDC_MRSA_REG(RDC_BASE_PTR,42)
#define RDC_MREA42                               RDC_MREA_REG(RDC_BASE_PTR,42)
#define RDC_MRC42                                RDC_MRC_REG(RDC_BASE_PTR,42)
#define RDC_MRVS42                               RDC_MRVS_REG(RDC_BASE_PTR,42)
#define RDC_MRSA43                               RDC_MRSA_REG(RDC_BASE_PTR,43)
#define RDC_MREA43                               RDC_MREA_REG(RDC_BASE_PTR,43)
#define RDC_MRC43                                RDC_MRC_REG(RDC_BASE_PTR,43)
#define RDC_MRVS43                               RDC_MRVS_REG(RDC_BASE_PTR,43)
#define RDC_MRSA44                               RDC_MRSA_REG(RDC_BASE_PTR,44)
#define RDC_MREA44                               RDC_MREA_REG(RDC_BASE_PTR,44)
#define RDC_MRC44                                RDC_MRC_REG(RDC_BASE_PTR,44)
#define RDC_MRVS44                               RDC_MRVS_REG(RDC_BASE_PTR,44)
#define RDC_MRSA45                               RDC_MRSA_REG(RDC_BASE_PTR,45)
#define RDC_MREA45                               RDC_MREA_REG(RDC_BASE_PTR,45)
#define RDC_MRC45                                RDC_MRC_REG(RDC_BASE_PTR,45)
#define RDC_MRVS45                               RDC_MRVS_REG(RDC_BASE_PTR,45)
#define RDC_MRSA46                               RDC_MRSA_REG(RDC_BASE_PTR,46)
#define RDC_MREA46                               RDC_MREA_REG(RDC_BASE_PTR,46)
#define RDC_MRC46                                RDC_MRC_REG(RDC_BASE_PTR,46)
#define RDC_MRVS46                               RDC_MRVS_REG(RDC_BASE_PTR,46)
#define RDC_MRSA47                               RDC_MRSA_REG(RDC_BASE_PTR,47)
#define RDC_MREA47                               RDC_MREA_REG(RDC_BASE_PTR,47)
#define RDC_MRC47                                RDC_MRC_REG(RDC_BASE_PTR,47)
#define RDC_MRVS47                               RDC_MRVS_REG(RDC_BASE_PTR,47)
#define RDC_MRSA48                               RDC_MRSA_REG(RDC_BASE_PTR,48)
#define RDC_MREA48                               RDC_MREA_REG(RDC_BASE_PTR,48)
#define RDC_MRC48                                RDC_MRC_REG(RDC_BASE_PTR,48)
#define RDC_MRVS48                               RDC_MRVS_REG(RDC_BASE_PTR,48)
#define RDC_MRSA49                               RDC_MRSA_REG(RDC_BASE_PTR,49)
#define RDC_MREA49                               RDC_MREA_REG(RDC_BASE_PTR,49)
#define RDC_MRC49                                RDC_MRC_REG(RDC_BASE_PTR,49)
#define RDC_MRVS49                               RDC_MRVS_REG(RDC_BASE_PTR,49)
#define RDC_MRSA50                               RDC_MRSA_REG(RDC_BASE_PTR,50)
#define RDC_MREA50                               RDC_MREA_REG(RDC_BASE_PTR,50)
#define RDC_MRC50                                RDC_MRC_REG(RDC_BASE_PTR,50)
#define RDC_MRVS50                               RDC_MRVS_REG(RDC_BASE_PTR,50)
#define RDC_MRSA51                               RDC_MRSA_REG(RDC_BASE_PTR,51)
#define RDC_MREA51                               RDC_MREA_REG(RDC_BASE_PTR,51)
#define RDC_MRC51                                RDC_MRC_REG(RDC_BASE_PTR,51)
#define RDC_MRVS51                               RDC_MRVS_REG(RDC_BASE_PTR,51)

/* RDC - Register array accessors */
#define RDC_MDA(index)                           RDC_MDA_REG(RDC_BASE_PTR,index)
#define RDC_PDAP(index)                          RDC_PDAP_REG(RDC_BASE_PTR,index)
#define RDC_MRSA(index)                          RDC_MRSA_REG(RDC_BASE_PTR,index)
#define RDC_MREA(index)                          RDC_MREA_REG(RDC_BASE_PTR,index)
#define RDC_MRC(index)                           RDC_MRC_REG(RDC_BASE_PTR,index)
#define RDC_MRVS(index)                          RDC_MRVS_REG(RDC_BASE_PTR,index)

/*!
 * @}
 */ /* end of group RDC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group RDC_Peripheral */


/* ----------------------------------------------------------------------------
   -- RDC_SEMAPHORE
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RDC_SEMAPHORE_Peripheral RDC_SEMAPHORE
 * @{
 */

/** RDC_SEMAPHORE - Peripheral register structure */
typedef struct RDC_SEMAPHORE_MemMap {
  uint8_t GATE0;                                   /**< Gate Register, offset: 0x0 */
  uint8_t GATE1;                                   /**< Gate Register, offset: 0x1 */
  uint8_t GATE2;                                   /**< Gate Register, offset: 0x2 */
  uint8_t GATE3;                                   /**< Gate Register, offset: 0x3 */
  uint8_t GATE4;                                   /**< Gate Register, offset: 0x4 */
  uint8_t GATE5;                                   /**< Gate Register, offset: 0x5 */
  uint8_t GATE6;                                   /**< Gate Register, offset: 0x6 */
  uint8_t GATE7;                                   /**< Gate Register, offset: 0x7 */
  uint8_t GATE8;                                   /**< Gate Register, offset: 0x8 */
  uint8_t GATE9;                                   /**< Gate Register, offset: 0x9 */
  uint8_t GATE10;                                  /**< Gate Register, offset: 0xA */
  uint8_t GATE11;                                  /**< Gate Register, offset: 0xB */
  uint8_t GATE12;                                  /**< Gate Register, offset: 0xC */
  uint8_t GATE13;                                  /**< Gate Register, offset: 0xD */
  uint8_t GATE14;                                  /**< Gate Register, offset: 0xE */
  uint8_t GATE15;                                  /**< Gate Register, offset: 0xF */
  uint8_t GATE16;                                  /**< Gate Register, offset: 0x10 */
  uint8_t GATE17;                                  /**< Gate Register, offset: 0x11 */
  uint8_t GATE18;                                  /**< Gate Register, offset: 0x12 */
  uint8_t GATE19;                                  /**< Gate Register, offset: 0x13 */
  uint8_t GATE20;                                  /**< Gate Register, offset: 0x14 */
  uint8_t GATE21;                                  /**< Gate Register, offset: 0x15 */
  uint8_t GATE22;                                  /**< Gate Register, offset: 0x16 */
  uint8_t GATE23;                                  /**< Gate Register, offset: 0x17 */
  uint8_t GATE24;                                  /**< Gate Register, offset: 0x18 */
  uint8_t GATE25;                                  /**< Gate Register, offset: 0x19 */
  uint8_t GATE26;                                  /**< Gate Register, offset: 0x1A */
  uint8_t GATE27;                                  /**< Gate Register, offset: 0x1B */
  uint8_t GATE28;                                  /**< Gate Register, offset: 0x1C */
  uint8_t GATE29;                                  /**< Gate Register, offset: 0x1D */
  uint8_t GATE30;                                  /**< Gate Register, offset: 0x1E */
  uint8_t GATE31;                                  /**< Gate Register, offset: 0x1F */
  uint8_t GATE32;                                  /**< Gate Register, offset: 0x20 */
  uint8_t GATE33;                                  /**< Gate Register, offset: 0x21 */
  uint8_t GATE34;                                  /**< Gate Register, offset: 0x22 */
  uint8_t GATE35;                                  /**< Gate Register, offset: 0x23 */
  uint8_t GATE36;                                  /**< Gate Register, offset: 0x24 */
  uint8_t GATE37;                                  /**< Gate Register, offset: 0x25 */
  uint8_t GATE38;                                  /**< Gate Register, offset: 0x26 */
  uint8_t GATE39;                                  /**< Gate Register, offset: 0x27 */
  uint8_t GATE40;                                  /**< Gate Register, offset: 0x28 */
  uint8_t GATE41;                                  /**< Gate Register, offset: 0x29 */
  uint8_t GATE42;                                  /**< Gate Register, offset: 0x2A */
  uint8_t GATE43;                                  /**< Gate Register, offset: 0x2B */
  uint8_t GATE44;                                  /**< Gate Register, offset: 0x2C */
  uint8_t GATE45;                                  /**< Gate Register, offset: 0x2D */
  uint8_t GATE46;                                  /**< Gate Register, offset: 0x2E */
  uint8_t GATE47;                                  /**< Gate Register, offset: 0x2F */
  uint8_t GATE48;                                  /**< Gate Register, offset: 0x30 */
  uint8_t GATE49;                                  /**< Gate Register, offset: 0x31 */
  uint8_t GATE50;                                  /**< Gate Register, offset: 0x32 */
  uint8_t GATE51;                                  /**< Gate Register, offset: 0x33 */
  uint8_t GATE52;                                  /**< Gate Register, offset: 0x34 */
  uint8_t GATE53;                                  /**< Gate Register, offset: 0x35 */
  uint8_t GATE54;                                  /**< Gate Register, offset: 0x36 */
  uint8_t GATE55;                                  /**< Gate Register, offset: 0x37 */
  uint8_t GATE56;                                  /**< Gate Register, offset: 0x38 */
  uint8_t GATE57;                                  /**< Gate Register, offset: 0x39 */
  uint8_t GATE58;                                  /**< Gate Register, offset: 0x3A */
  uint8_t GATE59;                                  /**< Gate Register, offset: 0x3B */
  uint8_t GATE60;                                  /**< Gate Register, offset: 0x3C */
  uint8_t GATE61;                                  /**< Gate Register, offset: 0x3D */
  uint8_t GATE62;                                  /**< Gate Register, offset: 0x3E */
  uint8_t GATE63;                                  /**< Gate Register, offset: 0x3F */
  union {                                          /* offset: 0x40 */
    uint16_t RSTGT_R;                                /**< Reset Gate Read, offset: 0x40 */
    uint16_t RSTGT_W;                                /**< Reset Gate Write, offset: 0x40 */
  };
} volatile *RDC_SEMAPHORE_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- RDC_SEMAPHORE - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RDC_SEMAPHORE_Register_Accessor_Macros RDC_SEMAPHORE - Register accessor macros
 * @{
 */


/* RDC_SEMAPHORE - Register accessors */
#define RDC_SEMAPHORE_GATE0_REG(base)            ((base)->GATE0)
#define RDC_SEMAPHORE_GATE1_REG(base)            ((base)->GATE1)
#define RDC_SEMAPHORE_GATE2_REG(base)            ((base)->GATE2)
#define RDC_SEMAPHORE_GATE3_REG(base)            ((base)->GATE3)
#define RDC_SEMAPHORE_GATE4_REG(base)            ((base)->GATE4)
#define RDC_SEMAPHORE_GATE5_REG(base)            ((base)->GATE5)
#define RDC_SEMAPHORE_GATE6_REG(base)            ((base)->GATE6)
#define RDC_SEMAPHORE_GATE7_REG(base)            ((base)->GATE7)
#define RDC_SEMAPHORE_GATE8_REG(base)            ((base)->GATE8)
#define RDC_SEMAPHORE_GATE9_REG(base)            ((base)->GATE9)
#define RDC_SEMAPHORE_GATE10_REG(base)           ((base)->GATE10)
#define RDC_SEMAPHORE_GATE11_REG(base)           ((base)->GATE11)
#define RDC_SEMAPHORE_GATE12_REG(base)           ((base)->GATE12)
#define RDC_SEMAPHORE_GATE13_REG(base)           ((base)->GATE13)
#define RDC_SEMAPHORE_GATE14_REG(base)           ((base)->GATE14)
#define RDC_SEMAPHORE_GATE15_REG(base)           ((base)->GATE15)
#define RDC_SEMAPHORE_GATE16_REG(base)           ((base)->GATE16)
#define RDC_SEMAPHORE_GATE17_REG(base)           ((base)->GATE17)
#define RDC_SEMAPHORE_GATE18_REG(base)           ((base)->GATE18)
#define RDC_SEMAPHORE_GATE19_REG(base)           ((base)->GATE19)
#define RDC_SEMAPHORE_GATE20_REG(base)           ((base)->GATE20)
#define RDC_SEMAPHORE_GATE21_REG(base)           ((base)->GATE21)
#define RDC_SEMAPHORE_GATE22_REG(base)           ((base)->GATE22)
#define RDC_SEMAPHORE_GATE23_REG(base)           ((base)->GATE23)
#define RDC_SEMAPHORE_GATE24_REG(base)           ((base)->GATE24)
#define RDC_SEMAPHORE_GATE25_REG(base)           ((base)->GATE25)
#define RDC_SEMAPHORE_GATE26_REG(base)           ((base)->GATE26)
#define RDC_SEMAPHORE_GATE27_REG(base)           ((base)->GATE27)
#define RDC_SEMAPHORE_GATE28_REG(base)           ((base)->GATE28)
#define RDC_SEMAPHORE_GATE29_REG(base)           ((base)->GATE29)
#define RDC_SEMAPHORE_GATE30_REG(base)           ((base)->GATE30)
#define RDC_SEMAPHORE_GATE31_REG(base)           ((base)->GATE31)
#define RDC_SEMAPHORE_GATE32_REG(base)           ((base)->GATE32)
#define RDC_SEMAPHORE_GATE33_REG(base)           ((base)->GATE33)
#define RDC_SEMAPHORE_GATE34_REG(base)           ((base)->GATE34)
#define RDC_SEMAPHORE_GATE35_REG(base)           ((base)->GATE35)
#define RDC_SEMAPHORE_GATE36_REG(base)           ((base)->GATE36)
#define RDC_SEMAPHORE_GATE37_REG(base)           ((base)->GATE37)
#define RDC_SEMAPHORE_GATE38_REG(base)           ((base)->GATE38)
#define RDC_SEMAPHORE_GATE39_REG(base)           ((base)->GATE39)
#define RDC_SEMAPHORE_GATE40_REG(base)           ((base)->GATE40)
#define RDC_SEMAPHORE_GATE41_REG(base)           ((base)->GATE41)
#define RDC_SEMAPHORE_GATE42_REG(base)           ((base)->GATE42)
#define RDC_SEMAPHORE_GATE43_REG(base)           ((base)->GATE43)
#define RDC_SEMAPHORE_GATE44_REG(base)           ((base)->GATE44)
#define RDC_SEMAPHORE_GATE45_REG(base)           ((base)->GATE45)
#define RDC_SEMAPHORE_GATE46_REG(base)           ((base)->GATE46)
#define RDC_SEMAPHORE_GATE47_REG(base)           ((base)->GATE47)
#define RDC_SEMAPHORE_GATE48_REG(base)           ((base)->GATE48)
#define RDC_SEMAPHORE_GATE49_REG(base)           ((base)->GATE49)
#define RDC_SEMAPHORE_GATE50_REG(base)           ((base)->GATE50)
#define RDC_SEMAPHORE_GATE51_REG(base)           ((base)->GATE51)
#define RDC_SEMAPHORE_GATE52_REG(base)           ((base)->GATE52)
#define RDC_SEMAPHORE_GATE53_REG(base)           ((base)->GATE53)
#define RDC_SEMAPHORE_GATE54_REG(base)           ((base)->GATE54)
#define RDC_SEMAPHORE_GATE55_REG(base)           ((base)->GATE55)
#define RDC_SEMAPHORE_GATE56_REG(base)           ((base)->GATE56)
#define RDC_SEMAPHORE_GATE57_REG(base)           ((base)->GATE57)
#define RDC_SEMAPHORE_GATE58_REG(base)           ((base)->GATE58)
#define RDC_SEMAPHORE_GATE59_REG(base)           ((base)->GATE59)
#define RDC_SEMAPHORE_GATE60_REG(base)           ((base)->GATE60)
#define RDC_SEMAPHORE_GATE61_REG(base)           ((base)->GATE61)
#define RDC_SEMAPHORE_GATE62_REG(base)           ((base)->GATE62)
#define RDC_SEMAPHORE_GATE63_REG(base)           ((base)->GATE63)
#define RDC_SEMAPHORE_RSTGT_R_REG(base)          ((base)->RSTGT_R)
#define RDC_SEMAPHORE_RSTGT_W_REG(base)          ((base)->RSTGT_W)

/*!
 * @}
 */ /* end of group RDC_SEMAPHORE_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- RDC_SEMAPHORE Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RDC_SEMAPHORE_Register_Masks RDC_SEMAPHORE Register Masks
 * @{
 */

/*! @name GATE0 - Gate Register */
#define RDC_SEMAPHORE_GATE0_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE0_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE0_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE0_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE0_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE0_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE0_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE0_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE0_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE0_LDOM_MASK)

/*! @name GATE1 - Gate Register */
#define RDC_SEMAPHORE_GATE1_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE1_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE1_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE1_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE1_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE1_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE1_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE1_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE1_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE1_LDOM_MASK)

/*! @name GATE2 - Gate Register */
#define RDC_SEMAPHORE_GATE2_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE2_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE2_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE2_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE2_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE2_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE2_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE2_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE2_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE2_LDOM_MASK)

/*! @name GATE3 - Gate Register */
#define RDC_SEMAPHORE_GATE3_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE3_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE3_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE3_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE3_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE3_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE3_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE3_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE3_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE3_LDOM_MASK)

/*! @name GATE4 - Gate Register */
#define RDC_SEMAPHORE_GATE4_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE4_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE4_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE4_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE4_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE4_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE4_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE4_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE4_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE4_LDOM_MASK)

/*! @name GATE5 - Gate Register */
#define RDC_SEMAPHORE_GATE5_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE5_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE5_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE5_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE5_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE5_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE5_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE5_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE5_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE5_LDOM_MASK)

/*! @name GATE6 - Gate Register */
#define RDC_SEMAPHORE_GATE6_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE6_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE6_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE6_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE6_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE6_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE6_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE6_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE6_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE6_LDOM_MASK)

/*! @name GATE7 - Gate Register */
#define RDC_SEMAPHORE_GATE7_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE7_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE7_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE7_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE7_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE7_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE7_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE7_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE7_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE7_LDOM_MASK)

/*! @name GATE8 - Gate Register */
#define RDC_SEMAPHORE_GATE8_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE8_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE8_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE8_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE8_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE8_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE8_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE8_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE8_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE8_LDOM_MASK)

/*! @name GATE9 - Gate Register */
#define RDC_SEMAPHORE_GATE9_GTFSM_MASK           (0xFU)
#define RDC_SEMAPHORE_GATE9_GTFSM_SHIFT          (0U)
#define RDC_SEMAPHORE_GATE9_GTFSM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE9_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE9_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE9_LDOM_MASK            (0x30U)
#define RDC_SEMAPHORE_GATE9_LDOM_SHIFT           (4U)
#define RDC_SEMAPHORE_GATE9_LDOM(x)              (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE9_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE9_LDOM_MASK)

/*! @name GATE10 - Gate Register */
#define RDC_SEMAPHORE_GATE10_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE10_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE10_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE10_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE10_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE10_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE10_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE10_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE10_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE10_LDOM_MASK)

/*! @name GATE11 - Gate Register */
#define RDC_SEMAPHORE_GATE11_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE11_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE11_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE11_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE11_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE11_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE11_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE11_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE11_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE11_LDOM_MASK)

/*! @name GATE12 - Gate Register */
#define RDC_SEMAPHORE_GATE12_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE12_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE12_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE12_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE12_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE12_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE12_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE12_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE12_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE12_LDOM_MASK)

/*! @name GATE13 - Gate Register */
#define RDC_SEMAPHORE_GATE13_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE13_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE13_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE13_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE13_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE13_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE13_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE13_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE13_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE13_LDOM_MASK)

/*! @name GATE14 - Gate Register */
#define RDC_SEMAPHORE_GATE14_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE14_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE14_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE14_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE14_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE14_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE14_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE14_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE14_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE14_LDOM_MASK)

/*! @name GATE15 - Gate Register */
#define RDC_SEMAPHORE_GATE15_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE15_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE15_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE15_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE15_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE15_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE15_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE15_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE15_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE15_LDOM_MASK)

/*! @name GATE16 - Gate Register */
#define RDC_SEMAPHORE_GATE16_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE16_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE16_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE16_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE16_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE16_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE16_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE16_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE16_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE16_LDOM_MASK)

/*! @name GATE17 - Gate Register */
#define RDC_SEMAPHORE_GATE17_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE17_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE17_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE17_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE17_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE17_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE17_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE17_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE17_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE17_LDOM_MASK)

/*! @name GATE18 - Gate Register */
#define RDC_SEMAPHORE_GATE18_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE18_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE18_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE18_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE18_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE18_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE18_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE18_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE18_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE18_LDOM_MASK)

/*! @name GATE19 - Gate Register */
#define RDC_SEMAPHORE_GATE19_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE19_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE19_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE19_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE19_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE19_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE19_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE19_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE19_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE19_LDOM_MASK)

/*! @name GATE20 - Gate Register */
#define RDC_SEMAPHORE_GATE20_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE20_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE20_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE20_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE20_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE20_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE20_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE20_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE20_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE20_LDOM_MASK)

/*! @name GATE21 - Gate Register */
#define RDC_SEMAPHORE_GATE21_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE21_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE21_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE21_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE21_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE21_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE21_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE21_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE21_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE21_LDOM_MASK)

/*! @name GATE22 - Gate Register */
#define RDC_SEMAPHORE_GATE22_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE22_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE22_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE22_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE22_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE22_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE22_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE22_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE22_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE22_LDOM_MASK)

/*! @name GATE23 - Gate Register */
#define RDC_SEMAPHORE_GATE23_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE23_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE23_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE23_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE23_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE23_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE23_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE23_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE23_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE23_LDOM_MASK)

/*! @name GATE24 - Gate Register */
#define RDC_SEMAPHORE_GATE24_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE24_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE24_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE24_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE24_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE24_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE24_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE24_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE24_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE24_LDOM_MASK)

/*! @name GATE25 - Gate Register */
#define RDC_SEMAPHORE_GATE25_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE25_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE25_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE25_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE25_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE25_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE25_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE25_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE25_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE25_LDOM_MASK)

/*! @name GATE26 - Gate Register */
#define RDC_SEMAPHORE_GATE26_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE26_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE26_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE26_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE26_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE26_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE26_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE26_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE26_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE26_LDOM_MASK)

/*! @name GATE27 - Gate Register */
#define RDC_SEMAPHORE_GATE27_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE27_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE27_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE27_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE27_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE27_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE27_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE27_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE27_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE27_LDOM_MASK)

/*! @name GATE28 - Gate Register */
#define RDC_SEMAPHORE_GATE28_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE28_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE28_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE28_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE28_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE28_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE28_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE28_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE28_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE28_LDOM_MASK)

/*! @name GATE29 - Gate Register */
#define RDC_SEMAPHORE_GATE29_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE29_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE29_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE29_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE29_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE29_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE29_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE29_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE29_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE29_LDOM_MASK)

/*! @name GATE30 - Gate Register */
#define RDC_SEMAPHORE_GATE30_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE30_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE30_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE30_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE30_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE30_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE30_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE30_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE30_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE30_LDOM_MASK)

/*! @name GATE31 - Gate Register */
#define RDC_SEMAPHORE_GATE31_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE31_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE31_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE31_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE31_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE31_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE31_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE31_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE31_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE31_LDOM_MASK)

/*! @name GATE32 - Gate Register */
#define RDC_SEMAPHORE_GATE32_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE32_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE32_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE32_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE32_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE32_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE32_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE32_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE32_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE32_LDOM_MASK)

/*! @name GATE33 - Gate Register */
#define RDC_SEMAPHORE_GATE33_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE33_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE33_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE33_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE33_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE33_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE33_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE33_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE33_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE33_LDOM_MASK)

/*! @name GATE34 - Gate Register */
#define RDC_SEMAPHORE_GATE34_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE34_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE34_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE34_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE34_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE34_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE34_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE34_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE34_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE34_LDOM_MASK)

/*! @name GATE35 - Gate Register */
#define RDC_SEMAPHORE_GATE35_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE35_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE35_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE35_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE35_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE35_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE35_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE35_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE35_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE35_LDOM_MASK)

/*! @name GATE36 - Gate Register */
#define RDC_SEMAPHORE_GATE36_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE36_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE36_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE36_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE36_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE36_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE36_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE36_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE36_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE36_LDOM_MASK)

/*! @name GATE37 - Gate Register */
#define RDC_SEMAPHORE_GATE37_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE37_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE37_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE37_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE37_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE37_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE37_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE37_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE37_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE37_LDOM_MASK)

/*! @name GATE38 - Gate Register */
#define RDC_SEMAPHORE_GATE38_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE38_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE38_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE38_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE38_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE38_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE38_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE38_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE38_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE38_LDOM_MASK)

/*! @name GATE39 - Gate Register */
#define RDC_SEMAPHORE_GATE39_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE39_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE39_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE39_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE39_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE39_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE39_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE39_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE39_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE39_LDOM_MASK)

/*! @name GATE40 - Gate Register */
#define RDC_SEMAPHORE_GATE40_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE40_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE40_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE40_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE40_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE40_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE40_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE40_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE40_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE40_LDOM_MASK)

/*! @name GATE41 - Gate Register */
#define RDC_SEMAPHORE_GATE41_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE41_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE41_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE41_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE41_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE41_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE41_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE41_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE41_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE41_LDOM_MASK)

/*! @name GATE42 - Gate Register */
#define RDC_SEMAPHORE_GATE42_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE42_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE42_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE42_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE42_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE42_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE42_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE42_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE42_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE42_LDOM_MASK)

/*! @name GATE43 - Gate Register */
#define RDC_SEMAPHORE_GATE43_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE43_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE43_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE43_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE43_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE43_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE43_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE43_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE43_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE43_LDOM_MASK)

/*! @name GATE44 - Gate Register */
#define RDC_SEMAPHORE_GATE44_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE44_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE44_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE44_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE44_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE44_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE44_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE44_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE44_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE44_LDOM_MASK)

/*! @name GATE45 - Gate Register */
#define RDC_SEMAPHORE_GATE45_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE45_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE45_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE45_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE45_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE45_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE45_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE45_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE45_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE45_LDOM_MASK)

/*! @name GATE46 - Gate Register */
#define RDC_SEMAPHORE_GATE46_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE46_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE46_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE46_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE46_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE46_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE46_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE46_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE46_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE46_LDOM_MASK)

/*! @name GATE47 - Gate Register */
#define RDC_SEMAPHORE_GATE47_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE47_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE47_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE47_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE47_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE47_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE47_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE47_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE47_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE47_LDOM_MASK)

/*! @name GATE48 - Gate Register */
#define RDC_SEMAPHORE_GATE48_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE48_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE48_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE48_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE48_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE48_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE48_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE48_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE48_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE48_LDOM_MASK)

/*! @name GATE49 - Gate Register */
#define RDC_SEMAPHORE_GATE49_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE49_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE49_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE49_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE49_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE49_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE49_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE49_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE49_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE49_LDOM_MASK)

/*! @name GATE50 - Gate Register */
#define RDC_SEMAPHORE_GATE50_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE50_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE50_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE50_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE50_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE50_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE50_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE50_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE50_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE50_LDOM_MASK)

/*! @name GATE51 - Gate Register */
#define RDC_SEMAPHORE_GATE51_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE51_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE51_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE51_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE51_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE51_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE51_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE51_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE51_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE51_LDOM_MASK)

/*! @name GATE52 - Gate Register */
#define RDC_SEMAPHORE_GATE52_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE52_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE52_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE52_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE52_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE52_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE52_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE52_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE52_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE52_LDOM_MASK)

/*! @name GATE53 - Gate Register */
#define RDC_SEMAPHORE_GATE53_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE53_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE53_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE53_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE53_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE53_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE53_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE53_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE53_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE53_LDOM_MASK)

/*! @name GATE54 - Gate Register */
#define RDC_SEMAPHORE_GATE54_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE54_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE54_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE54_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE54_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE54_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE54_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE54_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE54_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE54_LDOM_MASK)

/*! @name GATE55 - Gate Register */
#define RDC_SEMAPHORE_GATE55_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE55_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE55_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE55_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE55_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE55_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE55_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE55_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE55_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE55_LDOM_MASK)

/*! @name GATE56 - Gate Register */
#define RDC_SEMAPHORE_GATE56_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE56_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE56_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE56_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE56_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE56_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE56_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE56_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE56_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE56_LDOM_MASK)

/*! @name GATE57 - Gate Register */
#define RDC_SEMAPHORE_GATE57_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE57_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE57_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE57_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE57_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE57_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE57_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE57_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE57_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE57_LDOM_MASK)

/*! @name GATE58 - Gate Register */
#define RDC_SEMAPHORE_GATE58_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE58_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE58_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE58_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE58_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE58_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE58_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE58_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE58_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE58_LDOM_MASK)

/*! @name GATE59 - Gate Register */
#define RDC_SEMAPHORE_GATE59_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE59_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE59_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE59_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE59_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE59_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE59_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE59_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE59_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE59_LDOM_MASK)

/*! @name GATE60 - Gate Register */
#define RDC_SEMAPHORE_GATE60_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE60_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE60_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE60_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE60_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE60_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE60_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE60_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE60_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE60_LDOM_MASK)

/*! @name GATE61 - Gate Register */
#define RDC_SEMAPHORE_GATE61_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE61_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE61_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE61_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE61_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE61_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE61_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE61_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE61_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE61_LDOM_MASK)

/*! @name GATE62 - Gate Register */
#define RDC_SEMAPHORE_GATE62_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE62_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE62_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE62_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE62_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE62_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE62_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE62_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE62_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE62_LDOM_MASK)

/*! @name GATE63 - Gate Register */
#define RDC_SEMAPHORE_GATE63_GTFSM_MASK          (0xFU)
#define RDC_SEMAPHORE_GATE63_GTFSM_SHIFT         (0U)
#define RDC_SEMAPHORE_GATE63_GTFSM(x)            (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE63_GTFSM_SHIFT)) & RDC_SEMAPHORE_GATE63_GTFSM_MASK)
#define RDC_SEMAPHORE_GATE63_LDOM_MASK           (0x30U)
#define RDC_SEMAPHORE_GATE63_LDOM_SHIFT          (4U)
#define RDC_SEMAPHORE_GATE63_LDOM(x)             (((uint8_t)(((uint8_t)(x)) << RDC_SEMAPHORE_GATE63_LDOM_SHIFT)) & RDC_SEMAPHORE_GATE63_LDOM_MASK)

/*! @name RSTGT_R - Reset Gate Read */
#define RDC_SEMAPHORE_RSTGT_R_RSTGMS_MASK        (0xFU)
#define RDC_SEMAPHORE_RSTGT_R_RSTGMS_SHIFT       (0U)
#define RDC_SEMAPHORE_RSTGT_R_RSTGMS(x)          (((uint16_t)(((uint16_t)(x)) << RDC_SEMAPHORE_RSTGT_R_RSTGMS_SHIFT)) & RDC_SEMAPHORE_RSTGT_R_RSTGMS_MASK)
#define RDC_SEMAPHORE_RSTGT_R_RSTGSM_MASK        (0x30U)
#define RDC_SEMAPHORE_RSTGT_R_RSTGSM_SHIFT       (4U)
#define RDC_SEMAPHORE_RSTGT_R_RSTGSM(x)          (((uint16_t)(((uint16_t)(x)) << RDC_SEMAPHORE_RSTGT_R_RSTGSM_SHIFT)) & RDC_SEMAPHORE_RSTGT_R_RSTGSM_MASK)
#define RDC_SEMAPHORE_RSTGT_R_RSTGTN_MASK        (0xFF00U)
#define RDC_SEMAPHORE_RSTGT_R_RSTGTN_SHIFT       (8U)
#define RDC_SEMAPHORE_RSTGT_R_RSTGTN(x)          (((uint16_t)(((uint16_t)(x)) << RDC_SEMAPHORE_RSTGT_R_RSTGTN_SHIFT)) & RDC_SEMAPHORE_RSTGT_R_RSTGTN_MASK)

/*! @name RSTGT_W - Reset Gate Write */
#define RDC_SEMAPHORE_RSTGT_W_RSTGDP_MASK        (0xFFU)
#define RDC_SEMAPHORE_RSTGT_W_RSTGDP_SHIFT       (0U)
#define RDC_SEMAPHORE_RSTGT_W_RSTGDP(x)          (((uint16_t)(((uint16_t)(x)) << RDC_SEMAPHORE_RSTGT_W_RSTGDP_SHIFT)) & RDC_SEMAPHORE_RSTGT_W_RSTGDP_MASK)
#define RDC_SEMAPHORE_RSTGT_W_RSTGTN_MASK        (0xFF00U)
#define RDC_SEMAPHORE_RSTGT_W_RSTGTN_SHIFT       (8U)
#define RDC_SEMAPHORE_RSTGT_W_RSTGTN(x)          (((uint16_t)(((uint16_t)(x)) << RDC_SEMAPHORE_RSTGT_W_RSTGTN_SHIFT)) & RDC_SEMAPHORE_RSTGT_W_RSTGTN_MASK)


/*!
 * @}
 */ /* end of group RDC_SEMAPHORE_Register_Masks */


/* RDC_SEMAPHORE - Peripheral instance base addresses */
/** Peripheral RDC_SEMAPHORE1 base pointer */
#define RDC_SEMAPHORE1_BASE_PTR                  ((RDC_SEMAPHORE_MemMapPtr)0x303B0000u)
/** Peripheral RDC_SEMAPHORE2 base pointer */
#define RDC_SEMAPHORE2_BASE_PTR                  ((RDC_SEMAPHORE_MemMapPtr)0x303C0000u)
/** Array initializer of RDC_SEMAPHORE peripheral base pointers */
#define RDC_SEMAPHORE_BASE_PTRS                  { RDC_SEMAPHORE1_BASE_PTR, RDC_SEMAPHORE2_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- RDC_SEMAPHORE - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RDC_SEMAPHORE_Register_Accessor_Macros RDC_SEMAPHORE - Register accessor macros
 * @{
 */


/* RDC_SEMAPHORE - Register instance definitions */
/* RDC_SEMAPHORE1 */
#define RDC_SEMAPHORE1_GATE0                     RDC_SEMAPHORE_GATE0_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE1                     RDC_SEMAPHORE_GATE1_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE2                     RDC_SEMAPHORE_GATE2_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE3                     RDC_SEMAPHORE_GATE3_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE4                     RDC_SEMAPHORE_GATE4_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE5                     RDC_SEMAPHORE_GATE5_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE6                     RDC_SEMAPHORE_GATE6_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE7                     RDC_SEMAPHORE_GATE7_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE8                     RDC_SEMAPHORE_GATE8_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE9                     RDC_SEMAPHORE_GATE9_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE10                    RDC_SEMAPHORE_GATE10_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE11                    RDC_SEMAPHORE_GATE11_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE12                    RDC_SEMAPHORE_GATE12_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE13                    RDC_SEMAPHORE_GATE13_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE14                    RDC_SEMAPHORE_GATE14_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE15                    RDC_SEMAPHORE_GATE15_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE16                    RDC_SEMAPHORE_GATE16_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE17                    RDC_SEMAPHORE_GATE17_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE18                    RDC_SEMAPHORE_GATE18_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE19                    RDC_SEMAPHORE_GATE19_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE20                    RDC_SEMAPHORE_GATE20_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE21                    RDC_SEMAPHORE_GATE21_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE22                    RDC_SEMAPHORE_GATE22_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE23                    RDC_SEMAPHORE_GATE23_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE24                    RDC_SEMAPHORE_GATE24_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE25                    RDC_SEMAPHORE_GATE25_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE26                    RDC_SEMAPHORE_GATE26_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE27                    RDC_SEMAPHORE_GATE27_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE28                    RDC_SEMAPHORE_GATE28_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE29                    RDC_SEMAPHORE_GATE29_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE30                    RDC_SEMAPHORE_GATE30_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE31                    RDC_SEMAPHORE_GATE31_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE32                    RDC_SEMAPHORE_GATE32_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE33                    RDC_SEMAPHORE_GATE33_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE34                    RDC_SEMAPHORE_GATE34_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE35                    RDC_SEMAPHORE_GATE35_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE36                    RDC_SEMAPHORE_GATE36_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE37                    RDC_SEMAPHORE_GATE37_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE38                    RDC_SEMAPHORE_GATE38_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE39                    RDC_SEMAPHORE_GATE39_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE40                    RDC_SEMAPHORE_GATE40_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE41                    RDC_SEMAPHORE_GATE41_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE42                    RDC_SEMAPHORE_GATE42_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE43                    RDC_SEMAPHORE_GATE43_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE44                    RDC_SEMAPHORE_GATE44_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE45                    RDC_SEMAPHORE_GATE45_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE46                    RDC_SEMAPHORE_GATE46_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE47                    RDC_SEMAPHORE_GATE47_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE48                    RDC_SEMAPHORE_GATE48_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE49                    RDC_SEMAPHORE_GATE49_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE50                    RDC_SEMAPHORE_GATE50_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE51                    RDC_SEMAPHORE_GATE51_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE52                    RDC_SEMAPHORE_GATE52_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE53                    RDC_SEMAPHORE_GATE53_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE54                    RDC_SEMAPHORE_GATE54_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE55                    RDC_SEMAPHORE_GATE55_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE56                    RDC_SEMAPHORE_GATE56_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE57                    RDC_SEMAPHORE_GATE57_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE58                    RDC_SEMAPHORE_GATE58_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE59                    RDC_SEMAPHORE_GATE59_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE60                    RDC_SEMAPHORE_GATE60_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE61                    RDC_SEMAPHORE_GATE61_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE62                    RDC_SEMAPHORE_GATE62_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_GATE63                    RDC_SEMAPHORE_GATE63_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_RSTGT_R                   RDC_SEMAPHORE_RSTGT_R_REG(RDC_SEMAPHORE1_BASE_PTR)
#define RDC_SEMAPHORE1_RSTGT_W                   RDC_SEMAPHORE_RSTGT_W_REG(RDC_SEMAPHORE1_BASE_PTR)
/* RDC_SEMAPHORE2 */
#define RDC_SEMAPHORE2_GATE0                     RDC_SEMAPHORE_GATE0_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE1                     RDC_SEMAPHORE_GATE1_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE2                     RDC_SEMAPHORE_GATE2_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE3                     RDC_SEMAPHORE_GATE3_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE4                     RDC_SEMAPHORE_GATE4_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE5                     RDC_SEMAPHORE_GATE5_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE6                     RDC_SEMAPHORE_GATE6_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE7                     RDC_SEMAPHORE_GATE7_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE8                     RDC_SEMAPHORE_GATE8_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE9                     RDC_SEMAPHORE_GATE9_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE10                    RDC_SEMAPHORE_GATE10_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE11                    RDC_SEMAPHORE_GATE11_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE12                    RDC_SEMAPHORE_GATE12_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE13                    RDC_SEMAPHORE_GATE13_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE14                    RDC_SEMAPHORE_GATE14_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE15                    RDC_SEMAPHORE_GATE15_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE16                    RDC_SEMAPHORE_GATE16_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE17                    RDC_SEMAPHORE_GATE17_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE18                    RDC_SEMAPHORE_GATE18_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE19                    RDC_SEMAPHORE_GATE19_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE20                    RDC_SEMAPHORE_GATE20_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE21                    RDC_SEMAPHORE_GATE21_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE22                    RDC_SEMAPHORE_GATE22_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE23                    RDC_SEMAPHORE_GATE23_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE24                    RDC_SEMAPHORE_GATE24_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE25                    RDC_SEMAPHORE_GATE25_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE26                    RDC_SEMAPHORE_GATE26_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE27                    RDC_SEMAPHORE_GATE27_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE28                    RDC_SEMAPHORE_GATE28_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE29                    RDC_SEMAPHORE_GATE29_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE30                    RDC_SEMAPHORE_GATE30_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE31                    RDC_SEMAPHORE_GATE31_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE32                    RDC_SEMAPHORE_GATE32_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE33                    RDC_SEMAPHORE_GATE33_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE34                    RDC_SEMAPHORE_GATE34_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE35                    RDC_SEMAPHORE_GATE35_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE36                    RDC_SEMAPHORE_GATE36_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE37                    RDC_SEMAPHORE_GATE37_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE38                    RDC_SEMAPHORE_GATE38_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE39                    RDC_SEMAPHORE_GATE39_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE40                    RDC_SEMAPHORE_GATE40_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE41                    RDC_SEMAPHORE_GATE41_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE42                    RDC_SEMAPHORE_GATE42_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE43                    RDC_SEMAPHORE_GATE43_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE44                    RDC_SEMAPHORE_GATE44_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE45                    RDC_SEMAPHORE_GATE45_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE46                    RDC_SEMAPHORE_GATE46_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE47                    RDC_SEMAPHORE_GATE47_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE48                    RDC_SEMAPHORE_GATE48_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE49                    RDC_SEMAPHORE_GATE49_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE50                    RDC_SEMAPHORE_GATE50_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE51                    RDC_SEMAPHORE_GATE51_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE52                    RDC_SEMAPHORE_GATE52_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE53                    RDC_SEMAPHORE_GATE53_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE54                    RDC_SEMAPHORE_GATE54_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE55                    RDC_SEMAPHORE_GATE55_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE56                    RDC_SEMAPHORE_GATE56_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE57                    RDC_SEMAPHORE_GATE57_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE58                    RDC_SEMAPHORE_GATE58_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE59                    RDC_SEMAPHORE_GATE59_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE60                    RDC_SEMAPHORE_GATE60_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE61                    RDC_SEMAPHORE_GATE61_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE62                    RDC_SEMAPHORE_GATE62_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_GATE63                    RDC_SEMAPHORE_GATE63_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_RSTGT_R                   RDC_SEMAPHORE_RSTGT_R_REG(RDC_SEMAPHORE2_BASE_PTR)
#define RDC_SEMAPHORE2_RSTGT_W                   RDC_SEMAPHORE_RSTGT_W_REG(RDC_SEMAPHORE2_BASE_PTR)

/*!
 * @}
 */ /* end of group RDC_SEMAPHORE_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group RDC_SEMAPHORE_Peripheral */


/* ----------------------------------------------------------------------------
   -- ROMC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ROMC_Peripheral ROMC
 * @{
 */

/** ROMC - Peripheral register structure */
typedef struct ROMC_MemMap {
  uint8_t RESERVED_0[212];
  uint32_t ROMPATCHD[8];                           /**< ROMC Data Registers, array offset: 0xD4, array step: 0x4 */
  uint32_t ROMPATCHCNTL;                           /**< ROMC Control Register, offset: 0xF4 */
  uint32_t ROMPATCHENH;                            /**< ROMC Enable Register High, offset: 0xF8 */
  uint32_t ROMPATCHENL;                            /**< ROMC Enable Register Low, offset: 0xFC */
  uint32_t ROMPATCHA[16];                          /**< ROMC Address Registers, array offset: 0x100, array step: 0x4 */
  uint8_t RESERVED_1[200];
  uint32_t ROMPATCHSR;                             /**< ROMC Status Register, offset: 0x208 */
} volatile *ROMC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- ROMC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ROMC_Register_Accessor_Macros ROMC - Register accessor macros
 * @{
 */


/* ROMC - Register accessors */
#define ROMC_ROMPATCHD_REG(base,index)           ((base)->ROMPATCHD[index])
#define ROMC_ROMPATCHCNTL_REG(base)              ((base)->ROMPATCHCNTL)
#define ROMC_ROMPATCHENH_REG(base)               ((base)->ROMPATCHENH)
#define ROMC_ROMPATCHENL_REG(base)               ((base)->ROMPATCHENL)
#define ROMC_ROMPATCHA_REG(base,index)           ((base)->ROMPATCHA[index])
#define ROMC_ROMPATCHSR_REG(base)                ((base)->ROMPATCHSR)

/*!
 * @}
 */ /* end of group ROMC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- ROMC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ROMC_Register_Masks ROMC Register Masks
 * @{
 */

/*! @name ROMPATCHD - ROMC Data Registers */
#define ROMC_ROMPATCHD_DATAX_MASK                (0xFFFFFFFFU)
#define ROMC_ROMPATCHD_DATAX_SHIFT               (0U)
#define ROMC_ROMPATCHD_DATAX(x)                  (((uint32_t)(((uint32_t)(x)) << ROMC_ROMPATCHD_DATAX_SHIFT)) & ROMC_ROMPATCHD_DATAX_MASK)

/* The count of ROMC_ROMPATCHD */
#define ROMC_ROMPATCHD_COUNT                     (8U)

/*! @name ROMPATCHCNTL - ROMC Control Register */
#define ROMC_ROMPATCHCNTL_DATAFIX_MASK           (0xFFU)
#define ROMC_ROMPATCHCNTL_DATAFIX_SHIFT          (0U)
#define ROMC_ROMPATCHCNTL_DATAFIX(x)             (((uint32_t)(((uint32_t)(x)) << ROMC_ROMPATCHCNTL_DATAFIX_SHIFT)) & ROMC_ROMPATCHCNTL_DATAFIX_MASK)
#define ROMC_ROMPATCHCNTL_DIS_MASK               (0x20000000U)
#define ROMC_ROMPATCHCNTL_DIS_SHIFT              (29U)

/*! @name ROMPATCHENL - ROMC Enable Register Low */
#define ROMC_ROMPATCHENL_ENABLE_MASK             (0xFFFFU)
#define ROMC_ROMPATCHENL_ENABLE_SHIFT            (0U)
#define ROMC_ROMPATCHENL_ENABLE(x)               (((uint32_t)(((uint32_t)(x)) << ROMC_ROMPATCHENL_ENABLE_SHIFT)) & ROMC_ROMPATCHENL_ENABLE_MASK)

/*! @name ROMPATCHA - ROMC Address Registers */
#define ROMC_ROMPATCHA_THUMBX_MASK               (0x1U)
#define ROMC_ROMPATCHA_THUMBX_SHIFT              (0U)
#define ROMC_ROMPATCHA_ADDRX_MASK                (0x7FFFFEU)
#define ROMC_ROMPATCHA_ADDRX_SHIFT               (1U)
#define ROMC_ROMPATCHA_ADDRX(x)                  (((uint32_t)(((uint32_t)(x)) << ROMC_ROMPATCHA_ADDRX_SHIFT)) & ROMC_ROMPATCHA_ADDRX_MASK)

/* The count of ROMC_ROMPATCHA */
#define ROMC_ROMPATCHA_COUNT                     (16U)

/*! @name ROMPATCHSR - ROMC Status Register */
#define ROMC_ROMPATCHSR_SOURCE_MASK              (0x3FU)
#define ROMC_ROMPATCHSR_SOURCE_SHIFT             (0U)
#define ROMC_ROMPATCHSR_SOURCE(x)                (((uint32_t)(((uint32_t)(x)) << ROMC_ROMPATCHSR_SOURCE_SHIFT)) & ROMC_ROMPATCHSR_SOURCE_MASK)
#define ROMC_ROMPATCHSR_SW_MASK                  (0x20000U)
#define ROMC_ROMPATCHSR_SW_SHIFT                 (17U)


/*!
 * @}
 */ /* end of group ROMC_Register_Masks */


/* ROMC - Peripheral instance base addresses */
/** Peripheral ROMC base pointer */
#define ROMC_BASE_PTR                            ((ROMC_MemMapPtr)0x30310000u)
/** Array initializer of ROMC peripheral base pointers */
#define ROMC_BASE_PTRS                           { ROMC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- ROMC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup ROMC_Register_Accessor_Macros ROMC - Register accessor macros
 * @{
 */


/* ROMC - Register instance definitions */
/* ROMC */
#define ROMC_ROMPATCH0D                          ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,0)
#define ROMC_ROMPATCH1D                          ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,1)
#define ROMC_ROMPATCH2D                          ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,2)
#define ROMC_ROMPATCH3D                          ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,3)
#define ROMC_ROMPATCH4D                          ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,4)
#define ROMC_ROMPATCH5D                          ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,5)
#define ROMC_ROMPATCH6D                          ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,6)
#define ROMC_ROMPATCH7D                          ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,7)
#define ROMC_ROMPATCHCNTL                        ROMC_ROMPATCHCNTL_REG(ROMC_BASE_PTR)
#define ROMC_ROMPATCHENH                         ROMC_ROMPATCHENH_REG(ROMC_BASE_PTR)
#define ROMC_ROMPATCHENL                         ROMC_ROMPATCHENL_REG(ROMC_BASE_PTR)
#define ROMC_ROMPATCH0A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,0)
#define ROMC_ROMPATCH1A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,1)
#define ROMC_ROMPATCH2A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,2)
#define ROMC_ROMPATCH3A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,3)
#define ROMC_ROMPATCH4A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,4)
#define ROMC_ROMPATCH5A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,5)
#define ROMC_ROMPATCH6A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,6)
#define ROMC_ROMPATCH7A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,7)
#define ROMC_ROMPATCH8A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,8)
#define ROMC_ROMPATCH9A                          ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,9)
#define ROMC_ROMPATCH10A                         ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,10)
#define ROMC_ROMPATCH11A                         ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,11)
#define ROMC_ROMPATCH12A                         ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,12)
#define ROMC_ROMPATCH13A                         ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,13)
#define ROMC_ROMPATCH14A                         ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,14)
#define ROMC_ROMPATCH15A                         ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,15)
#define ROMC_ROMPATCHSR                          ROMC_ROMPATCHSR_REG(ROMC_BASE_PTR)

/* ROMC - Register array accessors */
#define ROMC_ROMPATCHD(index)                    ROMC_ROMPATCHD_REG(ROMC_BASE_PTR,index)
#define ROMC_ROMPATCHA(index)                    ROMC_ROMPATCHA_REG(ROMC_BASE_PTR,index)

/*!
 * @}
 */ /* end of group ROMC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group ROMC_Peripheral */


/* ----------------------------------------------------------------------------
   -- SDMAARM
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SDMAARM_Peripheral SDMAARM
 * @{
 */

/** SDMAARM - Peripheral register structure */
typedef struct SDMAARM_MemMap {
  uint32_t MC0PTR;                                 /**< ARM platform Channel 0 Pointer, offset: 0x0 */
  uint32_t INTR;                                   /**< Channel Interrupts, offset: 0x4 */
  uint32_t STOP_STAT;                              /**< Channel Stop/Channel Status, offset: 0x8 */
  uint32_t HSTART;                                 /**< Channel Start, offset: 0xC */
  uint32_t EVTOVR;                                 /**< Channel Event Override, offset: 0x10 */
  uint32_t DSPOVR;                                 /**< Channel BP Override, offset: 0x14 */
  uint32_t HOSTOVR;                                /**< Channel ARM platform Override, offset: 0x18 */
  uint32_t EVTPEND;                                /**< Channel Event Pending, offset: 0x1C */
  uint8_t RESERVED_0[4];
  uint32_t RESET;                                  /**< Reset Register, offset: 0x24 */
  uint32_t EVTERR;                                 /**< DMA Request Error Register, offset: 0x28 */
  uint32_t INTRMASK;                               /**< Channel ARM platform Interrupt Mask, offset: 0x2C */
  uint32_t PSW;                                    /**< Schedule Status, offset: 0x30 */
  uint32_t EVTERRDBG;                              /**< DMA Request Error Register, offset: 0x34 */
  uint32_t CONFIG;                                 /**< Configuration Register, offset: 0x38 */
  uint32_t SDMA_LOCK;                              /**< SDMA LOCK, offset: 0x3C */
  uint32_t ONCE_ENB;                               /**< OnCE Enable, offset: 0x40 */
  uint32_t ONCE_DATA;                              /**< OnCE Data Register, offset: 0x44 */
  uint32_t ONCE_INSTR;                             /**< OnCE Instruction Register, offset: 0x48 */
  uint32_t ONCE_STAT;                              /**< OnCE Status Register, offset: 0x4C */
  uint32_t ONCE_CMD;                               /**< OnCE Command Register, offset: 0x50 */
  uint8_t RESERVED_1[4];
  uint32_t ILLINSTADDR;                            /**< Illegal Instruction Trap Address, offset: 0x58 */
  uint32_t CHN0ADDR;                               /**< Channel 0 Boot Address, offset: 0x5C */
  uint32_t EVT_MIRROR;                             /**< DMA Requests, offset: 0x60 */
  uint32_t EVT_MIRROR2;                            /**< DMA Requests 2, offset: 0x64 */
  uint8_t RESERVED_2[8];
  uint32_t XTRIG_CONF1;                            /**< Cross-Trigger Events Configuration Register 1, offset: 0x70 */
  uint32_t XTRIG_CONF2;                            /**< Cross-Trigger Events Configuration Register 2, offset: 0x74 */
  uint8_t RESERVED_3[136];
  uint32_t SDMA_CHNPRI[32];                        /**< Channel Priority Registers, array offset: 0x100, array step: 0x4 */
  uint8_t RESERVED_4[128];
  uint32_t CHNENBL[48];                            /**< Channel Enable RAM, array offset: 0x200, array step: 0x4 */
} volatile *SDMAARM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- SDMAARM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SDMAARM_Register_Accessor_Macros SDMAARM - Register accessor macros
 * @{
 */


/* SDMAARM - Register accessors */
#define SDMAARM_MC0PTR_REG(base)                 ((base)->MC0PTR)
#define SDMAARM_INTR_REG(base)                   ((base)->INTR)
#define SDMAARM_STOP_STAT_REG(base)              ((base)->STOP_STAT)
#define SDMAARM_HSTART_REG(base)                 ((base)->HSTART)
#define SDMAARM_EVTOVR_REG(base)                 ((base)->EVTOVR)
#define SDMAARM_DSPOVR_REG(base)                 ((base)->DSPOVR)
#define SDMAARM_HOSTOVR_REG(base)                ((base)->HOSTOVR)
#define SDMAARM_EVTPEND_REG(base)                ((base)->EVTPEND)
#define SDMAARM_RESET_REG(base)                  ((base)->RESET)
#define SDMAARM_EVTERR_REG(base)                 ((base)->EVTERR)
#define SDMAARM_INTRMASK_REG(base)               ((base)->INTRMASK)
#define SDMAARM_PSW_REG(base)                    ((base)->PSW)
#define SDMAARM_EVTERRDBG_REG(base)              ((base)->EVTERRDBG)
#define SDMAARM_CONFIG_REG(base)                 ((base)->CONFIG)
#define SDMAARM_SDMA_LOCK_REG(base)              ((base)->SDMA_LOCK)
#define SDMAARM_ONCE_ENB_REG(base)               ((base)->ONCE_ENB)
#define SDMAARM_ONCE_DATA_REG(base)              ((base)->ONCE_DATA)
#define SDMAARM_ONCE_INSTR_REG(base)             ((base)->ONCE_INSTR)
#define SDMAARM_ONCE_STAT_REG(base)              ((base)->ONCE_STAT)
#define SDMAARM_ONCE_CMD_REG(base)               ((base)->ONCE_CMD)
#define SDMAARM_ILLINSTADDR_REG(base)            ((base)->ILLINSTADDR)
#define SDMAARM_CHN0ADDR_REG(base)               ((base)->CHN0ADDR)
#define SDMAARM_EVT_MIRROR_REG(base)             ((base)->EVT_MIRROR)
#define SDMAARM_EVT_MIRROR2_REG(base)            ((base)->EVT_MIRROR2)
#define SDMAARM_XTRIG_CONF1_REG(base)            ((base)->XTRIG_CONF1)
#define SDMAARM_XTRIG_CONF2_REG(base)            ((base)->XTRIG_CONF2)
#define SDMAARM_SDMA_CHNPRI_REG(base,index)      ((base)->SDMA_CHNPRI[index])
#define SDMAARM_CHNENBL_REG(base,index)          ((base)->CHNENBL[index])

/*!
 * @}
 */ /* end of group SDMAARM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- SDMAARM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SDMAARM_Register_Masks SDMAARM Register Masks
 * @{
 */

/*! @name MC0PTR - ARM platform Channel 0 Pointer */
#define SDMAARM_MC0PTR_MC0PTR_MASK               (0xFFFFFFFFU)
#define SDMAARM_MC0PTR_MC0PTR_SHIFT              (0U)
#define SDMAARM_MC0PTR_MC0PTR(x)                 (((uint32_t)(((uint32_t)(x)) << SDMAARM_MC0PTR_MC0PTR_SHIFT)) & SDMAARM_MC0PTR_MC0PTR_MASK)

/*! @name INTR - Channel Interrupts */
#define SDMAARM_INTR_HI_MASK                     (0xFFFFFFFFU)
#define SDMAARM_INTR_HI_SHIFT                    (0U)
#define SDMAARM_INTR_HI(x)                       (((uint32_t)(((uint32_t)(x)) << SDMAARM_INTR_HI_SHIFT)) & SDMAARM_INTR_HI_MASK)

/*! @name STOP_STAT - Channel Stop/Channel Status */
#define SDMAARM_STOP_STAT_HE_MASK                (0xFFFFFFFFU)
#define SDMAARM_STOP_STAT_HE_SHIFT               (0U)
#define SDMAARM_STOP_STAT_HE(x)                  (((uint32_t)(((uint32_t)(x)) << SDMAARM_STOP_STAT_HE_SHIFT)) & SDMAARM_STOP_STAT_HE_MASK)

/*! @name HSTART - Channel Start */
#define SDMAARM_HSTART_HSTART_HE_MASK            (0xFFFFFFFFU)
#define SDMAARM_HSTART_HSTART_HE_SHIFT           (0U)
#define SDMAARM_HSTART_HSTART_HE(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_HSTART_HSTART_HE_SHIFT)) & SDMAARM_HSTART_HSTART_HE_MASK)

/*! @name EVTOVR - Channel Event Override */
#define SDMAARM_EVTOVR_EO_MASK                   (0xFFFFFFFFU)
#define SDMAARM_EVTOVR_EO_SHIFT                  (0U)
#define SDMAARM_EVTOVR_EO(x)                     (((uint32_t)(((uint32_t)(x)) << SDMAARM_EVTOVR_EO_SHIFT)) & SDMAARM_EVTOVR_EO_MASK)

/*! @name DSPOVR - Channel BP Override */
#define SDMAARM_DSPOVR_DO_MASK                   (0xFFFFFFFFU)
#define SDMAARM_DSPOVR_DO_SHIFT                  (0U)
#define SDMAARM_DSPOVR_DO(x)                     (((uint32_t)(((uint32_t)(x)) << SDMAARM_DSPOVR_DO_SHIFT)) & SDMAARM_DSPOVR_DO_MASK)

/*! @name HOSTOVR - Channel ARM platform Override */
#define SDMAARM_HOSTOVR_HO_MASK                  (0xFFFFFFFFU)
#define SDMAARM_HOSTOVR_HO_SHIFT                 (0U)
#define SDMAARM_HOSTOVR_HO(x)                    (((uint32_t)(((uint32_t)(x)) << SDMAARM_HOSTOVR_HO_SHIFT)) & SDMAARM_HOSTOVR_HO_MASK)

/*! @name EVTPEND - Channel Event Pending */
#define SDMAARM_EVTPEND_EP_MASK                  (0xFFFFFFFFU)
#define SDMAARM_EVTPEND_EP_SHIFT                 (0U)
#define SDMAARM_EVTPEND_EP(x)                    (((uint32_t)(((uint32_t)(x)) << SDMAARM_EVTPEND_EP_SHIFT)) & SDMAARM_EVTPEND_EP_MASK)

/*! @name RESET - Reset Register */
#define SDMAARM_RESET_RESET_MASK                 (0x1U)
#define SDMAARM_RESET_RESET_SHIFT                (0U)
#define SDMAARM_RESET_RESCHED_MASK               (0x2U)
#define SDMAARM_RESET_RESCHED_SHIFT              (1U)

/*! @name EVTERR - DMA Request Error Register */
#define SDMAARM_EVTERR_CHNERR_MASK               (0xFFFFFFFFU)
#define SDMAARM_EVTERR_CHNERR_SHIFT              (0U)
#define SDMAARM_EVTERR_CHNERR(x)                 (((uint32_t)(((uint32_t)(x)) << SDMAARM_EVTERR_CHNERR_SHIFT)) & SDMAARM_EVTERR_CHNERR_MASK)

/*! @name INTRMASK - Channel ARM platform Interrupt Mask */
#define SDMAARM_INTRMASK_HIMASK_MASK             (0xFFFFFFFFU)
#define SDMAARM_INTRMASK_HIMASK_SHIFT            (0U)
#define SDMAARM_INTRMASK_HIMASK(x)               (((uint32_t)(((uint32_t)(x)) << SDMAARM_INTRMASK_HIMASK_SHIFT)) & SDMAARM_INTRMASK_HIMASK_MASK)

/*! @name PSW - Schedule Status */
#define SDMAARM_PSW_CCR_MASK                     (0xFU)
#define SDMAARM_PSW_CCR_SHIFT                    (0U)
#define SDMAARM_PSW_CCR(x)                       (((uint32_t)(((uint32_t)(x)) << SDMAARM_PSW_CCR_SHIFT)) & SDMAARM_PSW_CCR_MASK)
#define SDMAARM_PSW_CCP_MASK                     (0xF0U)
#define SDMAARM_PSW_CCP_SHIFT                    (4U)
#define SDMAARM_PSW_CCP(x)                       (((uint32_t)(((uint32_t)(x)) << SDMAARM_PSW_CCP_SHIFT)) & SDMAARM_PSW_CCP_MASK)
#define SDMAARM_PSW_NCR_MASK                     (0x1F00U)
#define SDMAARM_PSW_NCR_SHIFT                    (8U)
#define SDMAARM_PSW_NCR(x)                       (((uint32_t)(((uint32_t)(x)) << SDMAARM_PSW_NCR_SHIFT)) & SDMAARM_PSW_NCR_MASK)
#define SDMAARM_PSW_NCP_MASK                     (0xE000U)
#define SDMAARM_PSW_NCP_SHIFT                    (13U)
#define SDMAARM_PSW_NCP(x)                       (((uint32_t)(((uint32_t)(x)) << SDMAARM_PSW_NCP_SHIFT)) & SDMAARM_PSW_NCP_MASK)

/*! @name EVTERRDBG - DMA Request Error Register */
#define SDMAARM_EVTERRDBG_CHNERR_MASK            (0xFFFFFFFFU)
#define SDMAARM_EVTERRDBG_CHNERR_SHIFT           (0U)
#define SDMAARM_EVTERRDBG_CHNERR(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_EVTERRDBG_CHNERR_SHIFT)) & SDMAARM_EVTERRDBG_CHNERR_MASK)

/*! @name CONFIG - Configuration Register */
#define SDMAARM_CONFIG_CSM_MASK                  (0x3U)
#define SDMAARM_CONFIG_CSM_SHIFT                 (0U)
#define SDMAARM_CONFIG_CSM(x)                    (((uint32_t)(((uint32_t)(x)) << SDMAARM_CONFIG_CSM_SHIFT)) & SDMAARM_CONFIG_CSM_MASK)
#define SDMAARM_CONFIG_ACR_MASK                  (0x10U)
#define SDMAARM_CONFIG_ACR_SHIFT                 (4U)
#define SDMAARM_CONFIG_RTDOBS_MASK               (0x800U)
#define SDMAARM_CONFIG_RTDOBS_SHIFT              (11U)
#define SDMAARM_CONFIG_DSPDMA_MASK               (0x1000U)
#define SDMAARM_CONFIG_DSPDMA_SHIFT              (12U)

/*! @name SDMA_LOCK - SDMA LOCK */
#define SDMAARM_SDMA_LOCK_LOCK_MASK              (0x1U)
#define SDMAARM_SDMA_LOCK_LOCK_SHIFT             (0U)
#define SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR_MASK   (0x2U)
#define SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR_SHIFT  (1U)

/*! @name ONCE_ENB - OnCE Enable */
#define SDMAARM_ONCE_ENB_ENB_MASK                (0x1U)
#define SDMAARM_ONCE_ENB_ENB_SHIFT               (0U)

/*! @name ONCE_DATA - OnCE Data Register */
#define SDMAARM_ONCE_DATA_DATA_MASK              (0xFFFFFFFFU)
#define SDMAARM_ONCE_DATA_DATA_SHIFT             (0U)
#define SDMAARM_ONCE_DATA_DATA(x)                (((uint32_t)(((uint32_t)(x)) << SDMAARM_ONCE_DATA_DATA_SHIFT)) & SDMAARM_ONCE_DATA_DATA_MASK)

/*! @name ONCE_INSTR - OnCE Instruction Register */
#define SDMAARM_ONCE_INSTR_INSTR_MASK            (0xFFFFU)
#define SDMAARM_ONCE_INSTR_INSTR_SHIFT           (0U)
#define SDMAARM_ONCE_INSTR_INSTR(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_ONCE_INSTR_INSTR_SHIFT)) & SDMAARM_ONCE_INSTR_INSTR_MASK)

/*! @name ONCE_STAT - OnCE Status Register */
#define SDMAARM_ONCE_STAT_ECDR_MASK              (0x7U)
#define SDMAARM_ONCE_STAT_ECDR_SHIFT             (0U)
#define SDMAARM_ONCE_STAT_ECDR(x)                (((uint32_t)(((uint32_t)(x)) << SDMAARM_ONCE_STAT_ECDR_SHIFT)) & SDMAARM_ONCE_STAT_ECDR_MASK)
#define SDMAARM_ONCE_STAT_MST_MASK               (0x80U)
#define SDMAARM_ONCE_STAT_MST_SHIFT              (7U)
#define SDMAARM_ONCE_STAT_SWB_MASK               (0x100U)
#define SDMAARM_ONCE_STAT_SWB_SHIFT              (8U)
#define SDMAARM_ONCE_STAT_ODR_MASK               (0x200U)
#define SDMAARM_ONCE_STAT_ODR_SHIFT              (9U)
#define SDMAARM_ONCE_STAT_EDR_MASK               (0x400U)
#define SDMAARM_ONCE_STAT_EDR_SHIFT              (10U)
#define SDMAARM_ONCE_STAT_RCV_MASK               (0x800U)
#define SDMAARM_ONCE_STAT_RCV_SHIFT              (11U)
#define SDMAARM_ONCE_STAT_PST_MASK               (0xF000U)
#define SDMAARM_ONCE_STAT_PST_SHIFT              (12U)
#define SDMAARM_ONCE_STAT_PST(x)                 (((uint32_t)(((uint32_t)(x)) << SDMAARM_ONCE_STAT_PST_SHIFT)) & SDMAARM_ONCE_STAT_PST_MASK)

/*! @name ONCE_CMD - OnCE Command Register */
#define SDMAARM_ONCE_CMD_CMD_MASK                (0xFU)
#define SDMAARM_ONCE_CMD_CMD_SHIFT               (0U)
#define SDMAARM_ONCE_CMD_CMD(x)                  (((uint32_t)(((uint32_t)(x)) << SDMAARM_ONCE_CMD_CMD_SHIFT)) & SDMAARM_ONCE_CMD_CMD_MASK)

/*! @name ILLINSTADDR - Illegal Instruction Trap Address */
#define SDMAARM_ILLINSTADDR_ILLINSTADDR_MASK     (0x3FFFU)
#define SDMAARM_ILLINSTADDR_ILLINSTADDR_SHIFT    (0U)
#define SDMAARM_ILLINSTADDR_ILLINSTADDR(x)       (((uint32_t)(((uint32_t)(x)) << SDMAARM_ILLINSTADDR_ILLINSTADDR_SHIFT)) & SDMAARM_ILLINSTADDR_ILLINSTADDR_MASK)

/*! @name CHN0ADDR - Channel 0 Boot Address */
#define SDMAARM_CHN0ADDR_CHN0ADDR_MASK           (0x3FFFU)
#define SDMAARM_CHN0ADDR_CHN0ADDR_SHIFT          (0U)
#define SDMAARM_CHN0ADDR_CHN0ADDR(x)             (((uint32_t)(((uint32_t)(x)) << SDMAARM_CHN0ADDR_CHN0ADDR_SHIFT)) & SDMAARM_CHN0ADDR_CHN0ADDR_MASK)
#define SDMAARM_CHN0ADDR_SMSZ_MASK               (0x4000U)
#define SDMAARM_CHN0ADDR_SMSZ_SHIFT              (14U)

/*! @name EVT_MIRROR - DMA Requests */
#define SDMAARM_EVT_MIRROR_EVENTS_MASK           (0xFFFFFFFFU)
#define SDMAARM_EVT_MIRROR_EVENTS_SHIFT          (0U)
#define SDMAARM_EVT_MIRROR_EVENTS(x)             (((uint32_t)(((uint32_t)(x)) << SDMAARM_EVT_MIRROR_EVENTS_SHIFT)) & SDMAARM_EVT_MIRROR_EVENTS_MASK)

/*! @name EVT_MIRROR2 - DMA Requests 2 */
#define SDMAARM_EVT_MIRROR2_EVENTS_MASK          (0xFFFFU)
#define SDMAARM_EVT_MIRROR2_EVENTS_SHIFT         (0U)
#define SDMAARM_EVT_MIRROR2_EVENTS(x)            (((uint32_t)(((uint32_t)(x)) << SDMAARM_EVT_MIRROR2_EVENTS_SHIFT)) & SDMAARM_EVT_MIRROR2_EVENTS_MASK)

/*! @name XTRIG_CONF1 - Cross-Trigger Events Configuration Register 1 */
#define SDMAARM_XTRIG_CONF1_NUM0_MASK            (0x3FU)
#define SDMAARM_XTRIG_CONF1_NUM0_SHIFT           (0U)
#define SDMAARM_XTRIG_CONF1_NUM0(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_XTRIG_CONF1_NUM0_SHIFT)) & SDMAARM_XTRIG_CONF1_NUM0_MASK)
#define SDMAARM_XTRIG_CONF1_CNF0_MASK            (0x40U)
#define SDMAARM_XTRIG_CONF1_CNF0_SHIFT           (6U)
#define SDMAARM_XTRIG_CONF1_NUM1_MASK            (0x3F00U)
#define SDMAARM_XTRIG_CONF1_NUM1_SHIFT           (8U)
#define SDMAARM_XTRIG_CONF1_NUM1(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_XTRIG_CONF1_NUM1_SHIFT)) & SDMAARM_XTRIG_CONF1_NUM1_MASK)
#define SDMAARM_XTRIG_CONF1_CNF1_MASK            (0x4000U)
#define SDMAARM_XTRIG_CONF1_CNF1_SHIFT           (14U)
#define SDMAARM_XTRIG_CONF1_NUM2_MASK            (0x3F0000U)
#define SDMAARM_XTRIG_CONF1_NUM2_SHIFT           (16U)
#define SDMAARM_XTRIG_CONF1_NUM2(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_XTRIG_CONF1_NUM2_SHIFT)) & SDMAARM_XTRIG_CONF1_NUM2_MASK)
#define SDMAARM_XTRIG_CONF1_CNF2_MASK            (0x400000U)
#define SDMAARM_XTRIG_CONF1_CNF2_SHIFT           (22U)
#define SDMAARM_XTRIG_CONF1_NUM3_MASK            (0x3F000000U)
#define SDMAARM_XTRIG_CONF1_NUM3_SHIFT           (24U)
#define SDMAARM_XTRIG_CONF1_NUM3(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_XTRIG_CONF1_NUM3_SHIFT)) & SDMAARM_XTRIG_CONF1_NUM3_MASK)
#define SDMAARM_XTRIG_CONF1_CNF3_MASK            (0x40000000U)
#define SDMAARM_XTRIG_CONF1_CNF3_SHIFT           (30U)

/*! @name XTRIG_CONF2 - Cross-Trigger Events Configuration Register 2 */
#define SDMAARM_XTRIG_CONF2_NUM4_MASK            (0x3FU)
#define SDMAARM_XTRIG_CONF2_NUM4_SHIFT           (0U)
#define SDMAARM_XTRIG_CONF2_NUM4(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_XTRIG_CONF2_NUM4_SHIFT)) & SDMAARM_XTRIG_CONF2_NUM4_MASK)
#define SDMAARM_XTRIG_CONF2_CNF4_MASK            (0x40U)
#define SDMAARM_XTRIG_CONF2_CNF4_SHIFT           (6U)
#define SDMAARM_XTRIG_CONF2_NUM5_MASK            (0x3F00U)
#define SDMAARM_XTRIG_CONF2_NUM5_SHIFT           (8U)
#define SDMAARM_XTRIG_CONF2_NUM5(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_XTRIG_CONF2_NUM5_SHIFT)) & SDMAARM_XTRIG_CONF2_NUM5_MASK)
#define SDMAARM_XTRIG_CONF2_CNF5_MASK            (0x4000U)
#define SDMAARM_XTRIG_CONF2_CNF5_SHIFT           (14U)
#define SDMAARM_XTRIG_CONF2_NUM6_MASK            (0x3F0000U)
#define SDMAARM_XTRIG_CONF2_NUM6_SHIFT           (16U)
#define SDMAARM_XTRIG_CONF2_NUM6(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_XTRIG_CONF2_NUM6_SHIFT)) & SDMAARM_XTRIG_CONF2_NUM6_MASK)
#define SDMAARM_XTRIG_CONF2_CNF6_MASK            (0x400000U)
#define SDMAARM_XTRIG_CONF2_CNF6_SHIFT           (22U)
#define SDMAARM_XTRIG_CONF2_NUM7_MASK            (0x3F000000U)
#define SDMAARM_XTRIG_CONF2_NUM7_SHIFT           (24U)
#define SDMAARM_XTRIG_CONF2_NUM7(x)              (((uint32_t)(((uint32_t)(x)) << SDMAARM_XTRIG_CONF2_NUM7_SHIFT)) & SDMAARM_XTRIG_CONF2_NUM7_MASK)
#define SDMAARM_XTRIG_CONF2_CNF7_MASK            (0x40000000U)
#define SDMAARM_XTRIG_CONF2_CNF7_SHIFT           (30U)

/*! @name SDMA_CHNPRI - Channel Priority Registers */
#define SDMAARM_SDMA_CHNPRI_CHNPRIn_MASK         (0x7U)
#define SDMAARM_SDMA_CHNPRI_CHNPRIn_SHIFT        (0U)
#define SDMAARM_SDMA_CHNPRI_CHNPRIn(x)           (((uint32_t)(((uint32_t)(x)) << SDMAARM_SDMA_CHNPRI_CHNPRIn_SHIFT)) & SDMAARM_SDMA_CHNPRI_CHNPRIn_MASK)

/* The count of SDMAARM_SDMA_CHNPRI */
#define SDMAARM_SDMA_CHNPRI_COUNT                (32U)

/*! @name CHNENBL - Channel Enable RAM */
#define SDMAARM_CHNENBL_ENBLn_MASK               (0xFFFFFFFFU)
#define SDMAARM_CHNENBL_ENBLn_SHIFT              (0U)
#define SDMAARM_CHNENBL_ENBLn(x)                 (((uint32_t)(((uint32_t)(x)) << SDMAARM_CHNENBL_ENBLn_SHIFT)) & SDMAARM_CHNENBL_ENBLn_MASK)

/* The count of SDMAARM_CHNENBL */
#define SDMAARM_CHNENBL_COUNT                    (48U)


/*!
 * @}
 */ /* end of group SDMAARM_Register_Masks */


/* SDMAARM - Peripheral instance base addresses */
/** Peripheral SDMAARM base pointer */
#define SDMAARM_BASE_PTR                         ((SDMAARM_MemMapPtr)0x30BD0000u)
/** Array initializer of SDMAARM peripheral base pointers */
#define SDMAARM_BASE_PTRS                        { SDMAARM_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- SDMAARM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SDMAARM_Register_Accessor_Macros SDMAARM - Register accessor macros
 * @{
 */


/* SDMAARM - Register instance definitions */
/* SDMAARM */
#define SDMAARM_MC0PTR                           SDMAARM_MC0PTR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_INTR                             SDMAARM_INTR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_STOP_STAT                        SDMAARM_STOP_STAT_REG(SDMAARM_BASE_PTR)
#define SDMAARM_HSTART                           SDMAARM_HSTART_REG(SDMAARM_BASE_PTR)
#define SDMAARM_EVTOVR                           SDMAARM_EVTOVR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_DSPOVR                           SDMAARM_DSPOVR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_HOSTOVR                          SDMAARM_HOSTOVR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_EVTPEND                          SDMAARM_EVTPEND_REG(SDMAARM_BASE_PTR)
#define SDMAARM_RESET                            SDMAARM_RESET_REG(SDMAARM_BASE_PTR)
#define SDMAARM_EVTERR                           SDMAARM_EVTERR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_INTRMASK                         SDMAARM_INTRMASK_REG(SDMAARM_BASE_PTR)
#define SDMAARM_PSW                              SDMAARM_PSW_REG(SDMAARM_BASE_PTR)
#define SDMAARM_EVTERRDBG                        SDMAARM_EVTERRDBG_REG(SDMAARM_BASE_PTR)
#define SDMAARM_CONFIG                           SDMAARM_CONFIG_REG(SDMAARM_BASE_PTR)
#define SDMAARM_SDMA_LOCK                        SDMAARM_SDMA_LOCK_REG(SDMAARM_BASE_PTR)
#define SDMAARM_ONCE_ENB                         SDMAARM_ONCE_ENB_REG(SDMAARM_BASE_PTR)
#define SDMAARM_ONCE_DATA                        SDMAARM_ONCE_DATA_REG(SDMAARM_BASE_PTR)
#define SDMAARM_ONCE_INSTR                       SDMAARM_ONCE_INSTR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_ONCE_STAT                        SDMAARM_ONCE_STAT_REG(SDMAARM_BASE_PTR)
#define SDMAARM_ONCE_CMD                         SDMAARM_ONCE_CMD_REG(SDMAARM_BASE_PTR)
#define SDMAARM_ILLINSTADDR                      SDMAARM_ILLINSTADDR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_CHN0ADDR                         SDMAARM_CHN0ADDR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_EVT_MIRROR                       SDMAARM_EVT_MIRROR_REG(SDMAARM_BASE_PTR)
#define SDMAARM_EVT_MIRROR2                      SDMAARM_EVT_MIRROR2_REG(SDMAARM_BASE_PTR)
#define SDMAARM_XTRIG_CONF1                      SDMAARM_XTRIG_CONF1_REG(SDMAARM_BASE_PTR)
#define SDMAARM_XTRIG_CONF2                      SDMAARM_XTRIG_CONF2_REG(SDMAARM_BASE_PTR)
#define SDMAARM_SDMA_CHNPRI0                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,0)
#define SDMAARM_SDMA_CHNPRI1                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,1)
#define SDMAARM_SDMA_CHNPRI2                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,2)
#define SDMAARM_SDMA_CHNPRI3                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,3)
#define SDMAARM_SDMA_CHNPRI4                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,4)
#define SDMAARM_SDMA_CHNPRI5                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,5)
#define SDMAARM_SDMA_CHNPRI6                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,6)
#define SDMAARM_SDMA_CHNPRI7                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,7)
#define SDMAARM_SDMA_CHNPRI8                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,8)
#define SDMAARM_SDMA_CHNPRI9                     SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,9)
#define SDMAARM_SDMA_CHNPRI10                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,10)
#define SDMAARM_SDMA_CHNPRI11                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,11)
#define SDMAARM_SDMA_CHNPRI12                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,12)
#define SDMAARM_SDMA_CHNPRI13                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,13)
#define SDMAARM_SDMA_CHNPRI14                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,14)
#define SDMAARM_SDMA_CHNPRI15                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,15)
#define SDMAARM_SDMA_CHNPRI16                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,16)
#define SDMAARM_SDMA_CHNPRI17                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,17)
#define SDMAARM_SDMA_CHNPRI18                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,18)
#define SDMAARM_SDMA_CHNPRI19                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,19)
#define SDMAARM_SDMA_CHNPRI20                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,20)
#define SDMAARM_SDMA_CHNPRI21                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,21)
#define SDMAARM_SDMA_CHNPRI22                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,22)
#define SDMAARM_SDMA_CHNPRI23                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,23)
#define SDMAARM_SDMA_CHNPRI24                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,24)
#define SDMAARM_SDMA_CHNPRI25                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,25)
#define SDMAARM_SDMA_CHNPRI26                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,26)
#define SDMAARM_SDMA_CHNPRI27                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,27)
#define SDMAARM_SDMA_CHNPRI28                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,28)
#define SDMAARM_SDMA_CHNPRI29                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,29)
#define SDMAARM_SDMA_CHNPRI30                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,30)
#define SDMAARM_SDMA_CHNPRI31                    SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,31)
#define SDMAARM_CHNENBL0                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,0)
#define SDMAARM_CHNENBL1                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,1)
#define SDMAARM_CHNENBL2                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,2)
#define SDMAARM_CHNENBL3                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,3)
#define SDMAARM_CHNENBL4                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,4)
#define SDMAARM_CHNENBL5                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,5)
#define SDMAARM_CHNENBL6                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,6)
#define SDMAARM_CHNENBL7                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,7)
#define SDMAARM_CHNENBL8                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,8)
#define SDMAARM_CHNENBL9                         SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,9)
#define SDMAARM_CHNENBL10                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,10)
#define SDMAARM_CHNENBL11                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,11)
#define SDMAARM_CHNENBL12                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,12)
#define SDMAARM_CHNENBL13                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,13)
#define SDMAARM_CHNENBL14                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,14)
#define SDMAARM_CHNENBL15                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,15)
#define SDMAARM_CHNENBL16                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,16)
#define SDMAARM_CHNENBL17                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,17)
#define SDMAARM_CHNENBL18                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,18)
#define SDMAARM_CHNENBL19                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,19)
#define SDMAARM_CHNENBL20                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,20)
#define SDMAARM_CHNENBL21                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,21)
#define SDMAARM_CHNENBL22                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,22)
#define SDMAARM_CHNENBL23                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,23)
#define SDMAARM_CHNENBL24                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,24)
#define SDMAARM_CHNENBL25                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,25)
#define SDMAARM_CHNENBL26                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,26)
#define SDMAARM_CHNENBL27                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,27)
#define SDMAARM_CHNENBL28                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,28)
#define SDMAARM_CHNENBL29                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,29)
#define SDMAARM_CHNENBL30                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,30)
#define SDMAARM_CHNENBL31                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,31)
#define SDMAARM_CHNENBL32                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,32)
#define SDMAARM_CHNENBL33                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,33)
#define SDMAARM_CHNENBL34                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,34)
#define SDMAARM_CHNENBL35                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,35)
#define SDMAARM_CHNENBL36                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,36)
#define SDMAARM_CHNENBL37                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,37)
#define SDMAARM_CHNENBL38                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,38)
#define SDMAARM_CHNENBL39                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,39)
#define SDMAARM_CHNENBL40                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,40)
#define SDMAARM_CHNENBL41                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,41)
#define SDMAARM_CHNENBL42                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,42)
#define SDMAARM_CHNENBL43                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,43)
#define SDMAARM_CHNENBL44                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,44)
#define SDMAARM_CHNENBL45                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,45)
#define SDMAARM_CHNENBL46                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,46)
#define SDMAARM_CHNENBL47                        SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,47)

/* SDMAARM - Register array accessors */
#define SDMAARM_SDMA_CHNPRI(index)               SDMAARM_SDMA_CHNPRI_REG(SDMAARM_BASE_PTR,index)
#define SDMAARM_CHNENBL(index)                   SDMAARM_CHNENBL_REG(SDMAARM_BASE_PTR,index)

/*!
 * @}
 */ /* end of group SDMAARM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group SDMAARM_Peripheral */


/* ----------------------------------------------------------------------------
   -- SEMA4
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SEMA4_Peripheral SEMA4
 * @{
 */

/** SEMA4 - Peripheral register structure */
typedef struct SEMA4_MemMap {
  uint8_t Gate00;                                  /**< Semaphores Gate 0 Register, offset: 0x0 */
  uint8_t Gate01;                                  /**< Semaphores Gate 1 Register, offset: 0x1 */
  uint8_t Gate02;                                  /**< Semaphores Gate 2 Register, offset: 0x2 */
  uint8_t Gate03;                                  /**< Semaphores Gate 3 Register, offset: 0x3 */
  uint8_t Gate04;                                  /**< Semaphores Gate 4 Register, offset: 0x4 */
  uint8_t Gate05;                                  /**< Semaphores Gate 5 Register, offset: 0x5 */
  uint8_t Gate06;                                  /**< Semaphores Gate 6 Register, offset: 0x6 */
  uint8_t Gate07;                                  /**< Semaphores Gate 7 Register, offset: 0x7 */
  uint8_t Gate08;                                  /**< Semaphores Gate 8 Register, offset: 0x8 */
  uint8_t Gate09;                                  /**< Semaphores Gate 9 Register, offset: 0x9 */
  uint8_t Gate10;                                  /**< Semaphores Gate 10 Register, offset: 0xA */
  uint8_t Gate11;                                  /**< Semaphores Gate 11 Register, offset: 0xB */
  uint8_t Gate12;                                  /**< Semaphores Gate 12 Register, offset: 0xC */
  uint8_t Gate13;                                  /**< Semaphores Gate 13 Register, offset: 0xD */
  uint8_t Gate14;                                  /**< Semaphores Gate 14 Register, offset: 0xE */
  uint8_t Gate15;                                  /**< Semaphores Gate 15 Register, offset: 0xF */
  uint8_t RESERVED_0[48];
  struct {                                         /* offset: 0x40, array step: 0x8 */
    uint16_t CPINE;                                  /**< Semaphores Processor n IRQ Notification Enable, array offset: 0x40, array step: 0x8 */
    uint8_t RESERVED_0[6];
  } CPINE[2];
  uint8_t RESERVED_1[48];
  struct {                                         /* offset: 0x80, array step: 0x8 */
    uint16_t CPNTF;                                  /**< Semaphores Processor n IRQ Notification, array offset: 0x80, array step: 0x8 */
    uint8_t RESERVED_0[6];
  } CPNTF[2];
  uint8_t RESERVED_2[112];
  uint16_t RSTGT;                                  /**< Semaphores (Secure) Reset Gate n, offset: 0x100 */
  uint8_t RESERVED_3[2];
  uint16_t RSTNTF;                                 /**< Semaphores (Secure) Reset IRQ Notification, offset: 0x104 */
} volatile *SEMA4_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- SEMA4 - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SEMA4_Register_Accessor_Macros SEMA4 - Register accessor macros
 * @{
 */


/* SEMA4 - Register accessors */
#define SEMA4_Gate00_REG(base)                   ((base)->Gate00)
#define SEMA4_Gate01_REG(base)                   ((base)->Gate01)
#define SEMA4_Gate02_REG(base)                   ((base)->Gate02)
#define SEMA4_Gate03_REG(base)                   ((base)->Gate03)
#define SEMA4_Gate04_REG(base)                   ((base)->Gate04)
#define SEMA4_Gate05_REG(base)                   ((base)->Gate05)
#define SEMA4_Gate06_REG(base)                   ((base)->Gate06)
#define SEMA4_Gate07_REG(base)                   ((base)->Gate07)
#define SEMA4_Gate08_REG(base)                   ((base)->Gate08)
#define SEMA4_Gate09_REG(base)                   ((base)->Gate09)
#define SEMA4_Gate10_REG(base)                   ((base)->Gate10)
#define SEMA4_Gate11_REG(base)                   ((base)->Gate11)
#define SEMA4_Gate12_REG(base)                   ((base)->Gate12)
#define SEMA4_Gate13_REG(base)                   ((base)->Gate13)
#define SEMA4_Gate14_REG(base)                   ((base)->Gate14)
#define SEMA4_Gate15_REG(base)                   ((base)->Gate15)
#define SEMA4_CPINE_REG(base,index)              ((base)->CPINE[index].CPINE)
#define SEMA4_CPNTF_REG(base,index)              ((base)->CPNTF[index].CPNTF)
#define SEMA4_RSTGT_REG(base)                    ((base)->RSTGT)
#define SEMA4_RSTNTF_REG(base)                   ((base)->RSTNTF)

/*!
 * @}
 */ /* end of group SEMA4_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- SEMA4 Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SEMA4_Register_Masks SEMA4 Register Masks
 * @{
 */

/*! @name Gate00 - Semaphores Gate 0 Register */
#define SEMA4_Gate00_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate00_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate00_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate00_GTFSM_SHIFT)) & SEMA4_Gate00_GTFSM_MASK)

/*! @name Gate01 - Semaphores Gate 1 Register */
#define SEMA4_Gate01_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate01_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate01_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate01_GTFSM_SHIFT)) & SEMA4_Gate01_GTFSM_MASK)

/*! @name Gate02 - Semaphores Gate 2 Register */
#define SEMA4_Gate02_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate02_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate02_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate02_GTFSM_SHIFT)) & SEMA4_Gate02_GTFSM_MASK)

/*! @name Gate03 - Semaphores Gate 3 Register */
#define SEMA4_Gate03_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate03_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate03_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate03_GTFSM_SHIFT)) & SEMA4_Gate03_GTFSM_MASK)

/*! @name Gate04 - Semaphores Gate 4 Register */
#define SEMA4_Gate04_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate04_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate04_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate04_GTFSM_SHIFT)) & SEMA4_Gate04_GTFSM_MASK)

/*! @name Gate05 - Semaphores Gate 5 Register */
#define SEMA4_Gate05_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate05_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate05_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate05_GTFSM_SHIFT)) & SEMA4_Gate05_GTFSM_MASK)

/*! @name Gate06 - Semaphores Gate 6 Register */
#define SEMA4_Gate06_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate06_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate06_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate06_GTFSM_SHIFT)) & SEMA4_Gate06_GTFSM_MASK)

/*! @name Gate07 - Semaphores Gate 7 Register */
#define SEMA4_Gate07_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate07_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate07_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate07_GTFSM_SHIFT)) & SEMA4_Gate07_GTFSM_MASK)

/*! @name Gate08 - Semaphores Gate 8 Register */
#define SEMA4_Gate08_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate08_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate08_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate08_GTFSM_SHIFT)) & SEMA4_Gate08_GTFSM_MASK)

/*! @name Gate09 - Semaphores Gate 9 Register */
#define SEMA4_Gate09_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate09_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate09_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate09_GTFSM_SHIFT)) & SEMA4_Gate09_GTFSM_MASK)

/*! @name Gate10 - Semaphores Gate 10 Register */
#define SEMA4_Gate10_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate10_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate10_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate10_GTFSM_SHIFT)) & SEMA4_Gate10_GTFSM_MASK)

/*! @name Gate11 - Semaphores Gate 11 Register */
#define SEMA4_Gate11_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate11_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate11_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate11_GTFSM_SHIFT)) & SEMA4_Gate11_GTFSM_MASK)

/*! @name Gate12 - Semaphores Gate 12 Register */
#define SEMA4_Gate12_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate12_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate12_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate12_GTFSM_SHIFT)) & SEMA4_Gate12_GTFSM_MASK)

/*! @name Gate13 - Semaphores Gate 13 Register */
#define SEMA4_Gate13_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate13_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate13_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate13_GTFSM_SHIFT)) & SEMA4_Gate13_GTFSM_MASK)

/*! @name Gate14 - Semaphores Gate 14 Register */
#define SEMA4_Gate14_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate14_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate14_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate14_GTFSM_SHIFT)) & SEMA4_Gate14_GTFSM_MASK)

/*! @name Gate15 - Semaphores Gate 15 Register */
#define SEMA4_Gate15_GTFSM_MASK                  (0x3U)
#define SEMA4_Gate15_GTFSM_SHIFT                 (0U)
#define SEMA4_Gate15_GTFSM(x)                    (((uint8_t)(((uint8_t)(x)) << SEMA4_Gate15_GTFSM_SHIFT)) & SEMA4_Gate15_GTFSM_MASK)

/*! @name CPINE - Semaphores Processor n IRQ Notification Enable */
#define SEMA4_CPINE_INE7_MASK                    (0x1U)
#define SEMA4_CPINE_INE7_SHIFT                   (0U)
#define SEMA4_CPINE_INE6_MASK                    (0x2U)
#define SEMA4_CPINE_INE6_SHIFT                   (1U)
#define SEMA4_CPINE_INE5_MASK                    (0x4U)
#define SEMA4_CPINE_INE5_SHIFT                   (2U)
#define SEMA4_CPINE_INE4_MASK                    (0x8U)
#define SEMA4_CPINE_INE4_SHIFT                   (3U)
#define SEMA4_CPINE_INE3_MASK                    (0x10U)
#define SEMA4_CPINE_INE3_SHIFT                   (4U)
#define SEMA4_CPINE_INE2_MASK                    (0x20U)
#define SEMA4_CPINE_INE2_SHIFT                   (5U)
#define SEMA4_CPINE_INE1_MASK                    (0x40U)
#define SEMA4_CPINE_INE1_SHIFT                   (6U)
#define SEMA4_CPINE_INE0_MASK                    (0x80U)
#define SEMA4_CPINE_INE0_SHIFT                   (7U)
#define SEMA4_CPINE_INE15_MASK                   (0x100U)
#define SEMA4_CPINE_INE15_SHIFT                  (8U)
#define SEMA4_CPINE_INE14_MASK                   (0x200U)
#define SEMA4_CPINE_INE14_SHIFT                  (9U)
#define SEMA4_CPINE_INE13_MASK                   (0x400U)
#define SEMA4_CPINE_INE13_SHIFT                  (10U)
#define SEMA4_CPINE_INE12_MASK                   (0x800U)
#define SEMA4_CPINE_INE12_SHIFT                  (11U)
#define SEMA4_CPINE_INE11_MASK                   (0x1000U)
#define SEMA4_CPINE_INE11_SHIFT                  (12U)
#define SEMA4_CPINE_INE10_MASK                   (0x2000U)
#define SEMA4_CPINE_INE10_SHIFT                  (13U)
#define SEMA4_CPINE_INE9_MASK                    (0x4000U)
#define SEMA4_CPINE_INE9_SHIFT                   (14U)
#define SEMA4_CPINE_INE8_MASK                    (0x8000U)
#define SEMA4_CPINE_INE8_SHIFT                   (15U)

/* The count of SEMA4_CPINE */
#define SEMA4_CPINE_COUNT                        (2U)

/*! @name CPNTF - Semaphores Processor n IRQ Notification */
#define SEMA4_CPNTF_GN7_MASK                     (0x1U)
#define SEMA4_CPNTF_GN7_SHIFT                    (0U)
#define SEMA4_CPNTF_GN6_MASK                     (0x2U)
#define SEMA4_CPNTF_GN6_SHIFT                    (1U)
#define SEMA4_CPNTF_GN5_MASK                     (0x4U)
#define SEMA4_CPNTF_GN5_SHIFT                    (2U)
#define SEMA4_CPNTF_GN4_MASK                     (0x8U)
#define SEMA4_CPNTF_GN4_SHIFT                    (3U)
#define SEMA4_CPNTF_GN3_MASK                     (0x10U)
#define SEMA4_CPNTF_GN3_SHIFT                    (4U)
#define SEMA4_CPNTF_GN2_MASK                     (0x20U)
#define SEMA4_CPNTF_GN2_SHIFT                    (5U)
#define SEMA4_CPNTF_GN1_MASK                     (0x40U)
#define SEMA4_CPNTF_GN1_SHIFT                    (6U)
#define SEMA4_CPNTF_GN0_MASK                     (0x80U)
#define SEMA4_CPNTF_GN0_SHIFT                    (7U)
#define SEMA4_CPNTF_GN15_MASK                    (0x100U)
#define SEMA4_CPNTF_GN15_SHIFT                   (8U)
#define SEMA4_CPNTF_GN14_MASK                    (0x200U)
#define SEMA4_CPNTF_GN14_SHIFT                   (9U)
#define SEMA4_CPNTF_GN13_MASK                    (0x400U)
#define SEMA4_CPNTF_GN13_SHIFT                   (10U)
#define SEMA4_CPNTF_GN12_MASK                    (0x800U)
#define SEMA4_CPNTF_GN12_SHIFT                   (11U)
#define SEMA4_CPNTF_GN11_MASK                    (0x1000U)
#define SEMA4_CPNTF_GN11_SHIFT                   (12U)
#define SEMA4_CPNTF_GN10_MASK                    (0x2000U)
#define SEMA4_CPNTF_GN10_SHIFT                   (13U)
#define SEMA4_CPNTF_GN9_MASK                     (0x4000U)
#define SEMA4_CPNTF_GN9_SHIFT                    (14U)
#define SEMA4_CPNTF_GN8_MASK                     (0x8000U)
#define SEMA4_CPNTF_GN8_SHIFT                    (15U)

/* The count of SEMA4_CPNTF */
#define SEMA4_CPNTF_COUNT                        (2U)

/*! @name RSTGT - Semaphores (Secure) Reset Gate n */
#define SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP_MASK    (0xFFU)
#define SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP_SHIFT   (0U)
#define SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(x)      (((uint16_t)(((uint16_t)(x)) << SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP_SHIFT)) & SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP_MASK)
#define SEMA4_RSTGT_RSTGTN_MASK                  (0xFF00U)
#define SEMA4_RSTGT_RSTGTN_SHIFT                 (8U)
#define SEMA4_RSTGT_RSTGTN(x)                    (((uint16_t)(((uint16_t)(x)) << SEMA4_RSTGT_RSTGTN_SHIFT)) & SEMA4_RSTGT_RSTGTN_MASK)

/*! @name RSTNTF - Semaphores (Secure) Reset IRQ Notification */
#define SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP_MASK   (0xFFU)
#define SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP_SHIFT  (0U)
#define SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(x)     (((uint16_t)(((uint16_t)(x)) << SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP_SHIFT)) & SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP_MASK)
#define SEMA4_RSTNTF_RSTNTN_MASK                 (0xFF00U)
#define SEMA4_RSTNTF_RSTNTN_SHIFT                (8U)
#define SEMA4_RSTNTF_RSTNTN(x)                   (((uint16_t)(((uint16_t)(x)) << SEMA4_RSTNTF_RSTNTN_SHIFT)) & SEMA4_RSTNTF_RSTNTN_MASK)


/*!
 * @}
 */ /* end of group SEMA4_Register_Masks */


/* SEMA4 - Peripheral instance base addresses */
/** Peripheral SEMA4 base pointer */
#define SEMA4_BASE_PTR                           ((SEMA4_MemMapPtr)0x30AC0000u)
/** Array initializer of SEMA4 peripheral base pointers */
#define SEMA4_BASE_PTRS                          { SEMA4_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- SEMA4 - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SEMA4_Register_Accessor_Macros SEMA4 - Register accessor macros
 * @{
 */


/* SEMA4 - Register instance definitions */
/* SEMA4 */
#define SEMA4_Gate00                             SEMA4_Gate00_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate01                             SEMA4_Gate01_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate02                             SEMA4_Gate02_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate03                             SEMA4_Gate03_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate04                             SEMA4_Gate04_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate05                             SEMA4_Gate05_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate06                             SEMA4_Gate06_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate07                             SEMA4_Gate07_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate08                             SEMA4_Gate08_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate09                             SEMA4_Gate09_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate10                             SEMA4_Gate10_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate11                             SEMA4_Gate11_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate12                             SEMA4_Gate12_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate13                             SEMA4_Gate13_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate14                             SEMA4_Gate14_REG(SEMA4_BASE_PTR)
#define SEMA4_Gate15                             SEMA4_Gate15_REG(SEMA4_BASE_PTR)
#define SEMA4_CP0INE                             SEMA4_CPINE_REG(SEMA4_BASE_PTR,0)
#define SEMA4_CP1INE                             SEMA4_CPINE_REG(SEMA4_BASE_PTR,1)
#define SEMA4_CP0NTF                             SEMA4_CPNTF_REG(SEMA4_BASE_PTR,0)
#define SEMA4_CP1NTF                             SEMA4_CPNTF_REG(SEMA4_BASE_PTR,1)
#define SEMA4_RSTGT                              SEMA4_RSTGT_REG(SEMA4_BASE_PTR)
#define SEMA4_RSTNTF                             SEMA4_RSTNTF_REG(SEMA4_BASE_PTR)

/* SEMA4 - Register array accessors */
#define SEMA4_CPINE(index)                       SEMA4_CPINE_REG(SEMA4_BASE_PTR,index)
#define SEMA4_CPNTF(index)                       SEMA4_CPNTF_REG(SEMA4_BASE_PTR,index)

/*!
 * @}
 */ /* end of group SEMA4_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group SEMA4_Peripheral */


/* ----------------------------------------------------------------------------
   -- SIM
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SIM_Peripheral SIM
 * @{
 */

/** SIM - Peripheral register structure */
typedef struct SIM_MemMap {
  uint32_t PORT1_CNTL;                             /**< SIM Port1 Control Register, offset: 0x0 */
  uint32_t SETUP;                                  /**< SIM Setup Register, offset: 0x4 */
  uint32_t PORT1_DETECT;                           /**< SIM Port 1 Detect Register, offset: 0x8 */
  uint32_t XMT_BUF;                                /**< SIM Transmit Buffer Register, offset: 0xC */
  uint32_t RCV_BUF;                                /**< SIM Receive Buffer Register, offset: 0x10 */
  uint32_t PORT0_CNTL;                             /**< SIM Port0 Control Register, offset: 0x14 */
  uint32_t CNTL;                                   /**< SIM Control Register, offset: 0x18 */
  uint32_t CLK_PRESCALER;                          /**< SIM Clock Prescaler Register, offset: 0x1C */
  uint32_t RCV_THRESHOLD;                          /**< SIM Receive Threshold Register, offset: 0x20 */
  uint32_t ENABLE;                                 /**< SIM Enable Register, offset: 0x24 */
  uint32_t XMT_STATUS;                             /**< SIM Transmit Status Register, offset: 0x28 */
  uint32_t RCV_STATUS;                             /**< SIM Receive Status Register, offset: 0x2C */
  uint32_t INT_MASK;                               /**< SIM Interrupt Mask Register, offset: 0x30 */
  uint8_t RESERVED_0[8];
  uint32_t PORT0_DETECT;                           /**< SIM Port0 Detect Register, offset: 0x3C */
  uint32_t DATA_FORMAT;                            /**< SIM Data Format Register, offset: 0x40 */
  uint32_t XMT_THRESHOLD;                          /**< SIM Transmit Threshold Register, offset: 0x44 */
  uint32_t GUARD_CNTL;                             /**< SIM Transmit Guard Control Register, offset: 0x48 */
  uint32_t OD_CONFIG;                              /**< SIM Open Drain Configuration Control Register, offset: 0x4C */
  uint32_t RESET_CNTL;                             /**< SIM Reset Control Register, offset: 0x50 */
  uint32_t CHAR_WAIT;                              /**< SIM Character Wait Time Register, offset: 0x54 */
  uint32_t GPCNT;                                  /**< SIM General Purpose Counter Register, offset: 0x58 */
  uint32_t DIVISOR;                                /**< SIM Divisor Register, offset: 0x5C */
  uint32_t BWT;                                    /**< SIM Block Wait Time Register, offset: 0x60 */
  uint32_t BGT;                                    /**< SIM Block Guard Time Register, offset: 0x64 */
  uint32_t BWT_H;                                  /**< SIM Block Wait Time Register HIGH, offset: 0x68 */
  uint32_t XMT_FIFO_STAT;                          /**< SIM Transmit FIFO Status Register, offset: 0x6C */
  uint32_t RCV_FIFO_CNT;                           /**< SIM Receive FIFO Counter Register, offset: 0x70 */
  uint32_t RCV_FIFO_WPTR;                          /**< SIM Receive FIFO Write Pointer Register, offset: 0x74 */
  uint32_t RCV_FIFO_RPTR;                          /**< SIM Receive FIFO Read Pointer Register, offset: 0x78 */
} volatile *SIM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- SIM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SIM_Register_Accessor_Macros SIM - Register accessor macros
 * @{
 */


/* SIM - Register accessors */
#define SIM_PORT1_CNTL_REG(base)                 ((base)->PORT1_CNTL)
#define SIM_SETUP_REG(base)                      ((base)->SETUP)
#define SIM_PORT1_DETECT_REG(base)               ((base)->PORT1_DETECT)
#define SIM_XMT_BUF_REG(base)                    ((base)->XMT_BUF)
#define SIM_RCV_BUF_REG(base)                    ((base)->RCV_BUF)
#define SIM_PORT0_CNTL_REG(base)                 ((base)->PORT0_CNTL)
#define SIM_CNTL_REG(base)                       ((base)->CNTL)
#define SIM_CLK_PRESCALER_REG(base)              ((base)->CLK_PRESCALER)
#define SIM_RCV_THRESHOLD_REG(base)              ((base)->RCV_THRESHOLD)
#define SIM_ENABLE_REG(base)                     ((base)->ENABLE)
#define SIM_XMT_STATUS_REG(base)                 ((base)->XMT_STATUS)
#define SIM_RCV_STATUS_REG(base)                 ((base)->RCV_STATUS)
#define SIM_INT_MASK_REG(base)                   ((base)->INT_MASK)
#define SIM_PORT0_DETECT_REG(base)               ((base)->PORT0_DETECT)
#define SIM_DATA_FORMAT_REG(base)                ((base)->DATA_FORMAT)
#define SIM_XMT_THRESHOLD_REG(base)              ((base)->XMT_THRESHOLD)
#define SIM_GUARD_CNTL_REG(base)                 ((base)->GUARD_CNTL)
#define SIM_OD_CONFIG_REG(base)                  ((base)->OD_CONFIG)
#define SIM_RESET_CNTL_REG(base)                 ((base)->RESET_CNTL)
#define SIM_CHAR_WAIT_REG(base)                  ((base)->CHAR_WAIT)
#define SIM_GPCNT_REG(base)                      ((base)->GPCNT)
#define SIM_DIVISOR_REG(base)                    ((base)->DIVISOR)
#define SIM_BWT_REG(base)                        ((base)->BWT)
#define SIM_BGT_REG(base)                        ((base)->BGT)
#define SIM_BWT_H_REG(base)                      ((base)->BWT_H)
#define SIM_XMT_FIFO_STAT_REG(base)              ((base)->XMT_FIFO_STAT)
#define SIM_RCV_FIFO_CNT_REG(base)               ((base)->RCV_FIFO_CNT)
#define SIM_RCV_FIFO_WPTR_REG(base)              ((base)->RCV_FIFO_WPTR)
#define SIM_RCV_FIFO_RPTR_REG(base)              ((base)->RCV_FIFO_RPTR)

/*!
 * @}
 */ /* end of group SIM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- SIM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SIM_Register_Masks SIM Register Masks
 * @{
 */

/*! @name PORT1_CNTL - SIM Port1 Control Register */
#define SIM_PORT1_CNTL_SAPD1_MASK                (0x1U)
#define SIM_PORT1_CNTL_SAPD1_SHIFT               (0U)
#define SIM_PORT1_CNTL_SVEN1_MASK                (0x2U)
#define SIM_PORT1_CNTL_SVEN1_SHIFT               (1U)
#define SIM_PORT1_CNTL_STEN1_MASK                (0x4U)
#define SIM_PORT1_CNTL_STEN1_SHIFT               (2U)
#define SIM_PORT1_CNTL_SRST1_MASK                (0x8U)
#define SIM_PORT1_CNTL_SRST1_SHIFT               (3U)
#define SIM_PORT1_CNTL_SCEN1_MASK                (0x10U)
#define SIM_PORT1_CNTL_SCEN1_SHIFT               (4U)
#define SIM_PORT1_CNTL_SCSP1_MASK                (0x20U)
#define SIM_PORT1_CNTL_SCSP1_SHIFT               (5U)
#define SIM_PORT1_CNTL_VOLT3_1_MASK              (0x40U)
#define SIM_PORT1_CNTL_VOLT3_1_SHIFT             (6U)
#define SIM_PORT1_CNTL_SFPD1_MASK                (0x80U)
#define SIM_PORT1_CNTL_SFPD1_SHIFT               (7U)

/*! @name SETUP - SIM Setup Register */
#define SIM_SETUP_AMODE_MASK                     (0x1U)
#define SIM_SETUP_AMODE_SHIFT                    (0U)
#define SIM_SETUP_SPS_MASK                       (0x2U)
#define SIM_SETUP_SPS_SHIFT                      (1U)

/*! @name PORT1_DETECT - SIM Port 1 Detect Register */
#define SIM_PORT1_DETECT_SDIM1_MASK              (0x1U)
#define SIM_PORT1_DETECT_SDIM1_SHIFT             (0U)
#define SIM_PORT1_DETECT_SDI1_MASK               (0x2U)
#define SIM_PORT1_DETECT_SDI1_SHIFT              (1U)
#define SIM_PORT1_DETECT_SPDP1_MASK              (0x4U)
#define SIM_PORT1_DETECT_SPDP1_SHIFT             (2U)
#define SIM_PORT1_DETECT_SPDS1_MASK              (0x8U)
#define SIM_PORT1_DETECT_SPDS1_SHIFT             (3U)

/*! @name XMT_BUF - SIM Transmit Buffer Register */
#define SIM_XMT_BUF_XMT_MASK                     (0xFFU)
#define SIM_XMT_BUF_XMT_SHIFT                    (0U)
#define SIM_XMT_BUF_XMT(x)                       (((uint32_t)(((uint32_t)(x)) << SIM_XMT_BUF_XMT_SHIFT)) & SIM_XMT_BUF_XMT_MASK)

/*! @name RCV_BUF - SIM Receive Buffer Register */
#define SIM_RCV_BUF_RCV_MASK                     (0xFFU)
#define SIM_RCV_BUF_RCV_SHIFT                    (0U)
#define SIM_RCV_BUF_RCV(x)                       (((uint32_t)(((uint32_t)(x)) << SIM_RCV_BUF_RCV_SHIFT)) & SIM_RCV_BUF_RCV_MASK)
#define SIM_RCV_BUF_PE_MASK                      (0x100U)
#define SIM_RCV_BUF_PE_SHIFT                     (8U)
#define SIM_RCV_BUF_FE_MASK                      (0x200U)
#define SIM_RCV_BUF_FE_SHIFT                     (9U)
#define SIM_RCV_BUF_CWT_MASK                     (0x400U)
#define SIM_RCV_BUF_CWT_SHIFT                    (10U)

/*! @name PORT0_CNTL - SIM Port0 Control Register */
#define SIM_PORT0_CNTL_SAPD0_MASK                (0x1U)
#define SIM_PORT0_CNTL_SAPD0_SHIFT               (0U)
#define SIM_PORT0_CNTL_SVEN0_MASK                (0x2U)
#define SIM_PORT0_CNTL_SVEN0_SHIFT               (1U)
#define SIM_PORT0_CNTL_STEN0_MASK                (0x4U)
#define SIM_PORT0_CNTL_STEN0_SHIFT               (2U)
#define SIM_PORT0_CNTL_SRST0_MASK                (0x8U)
#define SIM_PORT0_CNTL_SRST0_SHIFT               (3U)
#define SIM_PORT0_CNTL_SCEN0_MASK                (0x10U)
#define SIM_PORT0_CNTL_SCEN0_SHIFT               (4U)
#define SIM_PORT0_CNTL_SCSP0_MASK                (0x20U)
#define SIM_PORT0_CNTL_SCSP0_SHIFT               (5U)
#define SIM_PORT0_CNTL_VOLT3_0_MASK              (0x40U)
#define SIM_PORT0_CNTL_VOLT3_0_SHIFT             (6U)
#define SIM_PORT0_CNTL_SFPD0_MASK                (0x80U)
#define SIM_PORT0_CNTL_SFPD0_SHIFT               (7U)

/*! @name CNTL - SIM Control Register */
#define SIM_CNTL_ICM_MASK                        (0x2U)
#define SIM_CNTL_ICM_SHIFT                       (1U)
#define SIM_CNTL_ANACK_MASK                      (0x4U)
#define SIM_CNTL_ANACK_SHIFT                     (2U)
#define SIM_CNTL_ONACK_MASK                      (0x8U)
#define SIM_CNTL_ONACK_SHIFT                     (3U)
#define SIM_CNTL_Sample12_MASK                   (0x20U)
#define SIM_CNTL_Sample12_SHIFT                  (5U)
#define SIM_CNTL_baud_sel_MASK                   (0x1C0U)
#define SIM_CNTL_baud_sel_SHIFT                  (6U)
#define SIM_CNTL_baud_sel(x)                     (((uint32_t)(((uint32_t)(x)) << SIM_CNTL_baud_sel_SHIFT)) & SIM_CNTL_baud_sel_MASK)
#define SIM_CNTL_gpcnt_clk_sel_MASK              (0x600U)
#define SIM_CNTL_gpcnt_clk_sel_SHIFT             (9U)
#define SIM_CNTL_gpcnt_clk_sel(x)                (((uint32_t)(((uint32_t)(x)) << SIM_CNTL_gpcnt_clk_sel_SHIFT)) & SIM_CNTL_gpcnt_clk_sel_MASK)
#define SIM_CNTL_CWTEN_MASK                      (0x800U)
#define SIM_CNTL_CWTEN_SHIFT                     (11U)
#define SIM_CNTL_LRCEN_MASK                      (0x1000U)
#define SIM_CNTL_LRCEN_SHIFT                     (12U)
#define SIM_CNTL_CRCEN_MASK                      (0x2000U)
#define SIM_CNTL_CRCEN_SHIFT                     (13U)
#define SIM_CNTL_xmt_crc_lrc_MASK                (0x4000U)
#define SIM_CNTL_xmt_crc_lrc_SHIFT               (14U)
#define SIM_CNTL_BWTEN_MASK                      (0x8000U)
#define SIM_CNTL_BWTEN_SHIFT                     (15U)

/*! @name CLK_PRESCALER - SIM Clock Prescaler Register */
#define SIM_CLK_PRESCALER_CLK_PRESCALER_MASK     (0xFFU)
#define SIM_CLK_PRESCALER_CLK_PRESCALER_SHIFT    (0U)
#define SIM_CLK_PRESCALER_CLK_PRESCALER(x)       (((uint32_t)(((uint32_t)(x)) << SIM_CLK_PRESCALER_CLK_PRESCALER_SHIFT)) & SIM_CLK_PRESCALER_CLK_PRESCALER_MASK)

/*! @name RCV_THRESHOLD - SIM Receive Threshold Register */
#define SIM_RCV_THRESHOLD_RDT_MASK               (0x1FFU)
#define SIM_RCV_THRESHOLD_RDT_SHIFT              (0U)
#define SIM_RCV_THRESHOLD_RDT(x)                 (((uint32_t)(((uint32_t)(x)) << SIM_RCV_THRESHOLD_RDT_SHIFT)) & SIM_RCV_THRESHOLD_RDT_MASK)
#define SIM_RCV_THRESHOLD_RTH_MASK               (0x1E00U)
#define SIM_RCV_THRESHOLD_RTH_SHIFT              (9U)
#define SIM_RCV_THRESHOLD_RTH(x)                 (((uint32_t)(((uint32_t)(x)) << SIM_RCV_THRESHOLD_RTH_SHIFT)) & SIM_RCV_THRESHOLD_RTH_MASK)

/*! @name ENABLE - SIM Enable Register */
#define SIM_ENABLE_RCV_EN_MASK                   (0x1U)
#define SIM_ENABLE_RCV_EN_SHIFT                  (0U)
#define SIM_ENABLE_XMT_EN_MASK                   (0x2U)
#define SIM_ENABLE_XMT_EN_SHIFT                  (1U)
#define SIM_ENABLE_RXDMA_EN_MASK                 (0x4U)
#define SIM_ENABLE_RXDMA_EN_SHIFT                (2U)
#define SIM_ENABLE_TXDMA_EN_MASK                 (0x8U)
#define SIM_ENABLE_TXDMA_EN_SHIFT                (3U)
#define SIM_ENABLE_NACK_DD_EN_MASK               (0x10U)
#define SIM_ENABLE_NACK_DD_EN_SHIFT              (4U)
#define SIM_ENABLE_ESTOP_EN_MASK                 (0x20U)
#define SIM_ENABLE_ESTOP_EN_SHIFT                (5U)
#define SIM_ENABLE_ESTOP_EXE_MASK                (0x40U)
#define SIM_ENABLE_ESTOP_EXE_SHIFT               (6U)
#define SIM_ENABLE_RXCL_MASK                     (0x80U)
#define SIM_ENABLE_RXCL_SHIFT                    (7U)

/*! @name XMT_STATUS - SIM Transmit Status Register */
#define SIM_XMT_STATUS_XTE_MASK                  (0x1U)
#define SIM_XMT_STATUS_XTE_SHIFT                 (0U)
#define SIM_XMT_STATUS_TFE_MASK                  (0x8U)
#define SIM_XMT_STATUS_TFE_SHIFT                 (3U)
#define SIM_XMT_STATUS_ETC_MASK                  (0x10U)
#define SIM_XMT_STATUS_ETC_SHIFT                 (4U)
#define SIM_XMT_STATUS_TC_MASK                   (0x20U)
#define SIM_XMT_STATUS_TC_SHIFT                  (5U)
#define SIM_XMT_STATUS_TFO_MASK                  (0x40U)
#define SIM_XMT_STATUS_TFO_SHIFT                 (6U)
#define SIM_XMT_STATUS_TDTF_MASK                 (0x80U)
#define SIM_XMT_STATUS_TDTF_SHIFT                (7U)
#define SIM_XMT_STATUS_GPCNT_MASK                (0x100U)
#define SIM_XMT_STATUS_GPCNT_SHIFT               (8U)

/*! @name RCV_STATUS - SIM Receive Status Register */
#define SIM_RCV_STATUS_OEF_MASK                  (0x1U)
#define SIM_RCV_STATUS_OEF_SHIFT                 (0U)
#define SIM_RCV_STATUS_RFE_MASK                  (0x2U)
#define SIM_RCV_STATUS_RFE_SHIFT                 (1U)
#define SIM_RCV_STATUS_RFD_MASK                  (0x10U)
#define SIM_RCV_STATUS_RFD_SHIFT                 (4U)
#define SIM_RCV_STATUS_RDRF_MASK                 (0x20U)
#define SIM_RCV_STATUS_RDRF_SHIFT                (5U)
#define SIM_RCV_STATUS_LRCOK_MASK                (0x40U)
#define SIM_RCV_STATUS_LRCOK_SHIFT               (6U)
#define SIM_RCV_STATUS_CRCOK_MASK                (0x80U)
#define SIM_RCV_STATUS_CRCOK_SHIFT               (7U)
#define SIM_RCV_STATUS_CWT_MASK                  (0x100U)
#define SIM_RCV_STATUS_CWT_SHIFT                 (8U)
#define SIM_RCV_STATUS_RTE_MASK                  (0x200U)
#define SIM_RCV_STATUS_RTE_SHIFT                 (9U)
#define SIM_RCV_STATUS_BWT_MASK                  (0x400U)
#define SIM_RCV_STATUS_BWT_SHIFT                 (10U)
#define SIM_RCV_STATUS_BGT_MASK                  (0x800U)
#define SIM_RCV_STATUS_BGT_SHIFT                 (11U)

/*! @name INT_MASK - SIM Interrupt Mask Register */
#define SIM_INT_MASK_RIM_MASK                    (0x1U)
#define SIM_INT_MASK_RIM_SHIFT                   (0U)
#define SIM_INT_MASK_TCIM_MASK                   (0x2U)
#define SIM_INT_MASK_TCIM_SHIFT                  (1U)
#define SIM_INT_MASK_OIM_MASK                    (0x4U)
#define SIM_INT_MASK_OIM_SHIFT                   (2U)
#define SIM_INT_MASK_ETCIM_MASK                  (0x8U)
#define SIM_INT_MASK_ETCIM_SHIFT                 (3U)
#define SIM_INT_MASK_TFEIM_MASK                  (0x10U)
#define SIM_INT_MASK_TFEIM_SHIFT                 (4U)
#define SIM_INT_MASK_XTM_MASK                    (0x20U)
#define SIM_INT_MASK_XTM_SHIFT                   (5U)
#define SIM_INT_MASK_TFOM_MASK                   (0x40U)
#define SIM_INT_MASK_TFOM_SHIFT                  (6U)
#define SIM_INT_MASK_TDTFM_MASK                  (0x80U)
#define SIM_INT_MASK_TDTFM_SHIFT                 (7U)
#define SIM_INT_MASK_GPCNTM_MASK                 (0x100U)
#define SIM_INT_MASK_GPCNTM_SHIFT                (8U)
#define SIM_INT_MASK_CWTM_MASK                   (0x200U)
#define SIM_INT_MASK_CWTM_SHIFT                  (9U)
#define SIM_INT_MASK_RTM_MASK                    (0x400U)
#define SIM_INT_MASK_RTM_SHIFT                   (10U)
#define SIM_INT_MASK_BWTM_MASK                   (0x800U)
#define SIM_INT_MASK_BWTM_SHIFT                  (11U)
#define SIM_INT_MASK_BGTM_MASK                   (0x1000U)
#define SIM_INT_MASK_BGTM_SHIFT                  (12U)
#define SIM_INT_MASK_RFEM_MASK                   (0x2000U)
#define SIM_INT_MASK_RFEM_SHIFT                  (13U)

/*! @name PORT0_DETECT - SIM Port0 Detect Register */
#define SIM_PORT0_DETECT_SDIM0_MASK              (0x1U)
#define SIM_PORT0_DETECT_SDIM0_SHIFT             (0U)
#define SIM_PORT0_DETECT_SDI0_MASK               (0x2U)
#define SIM_PORT0_DETECT_SDI0_SHIFT              (1U)
#define SIM_PORT0_DETECT_SPDP0_MASK              (0x4U)
#define SIM_PORT0_DETECT_SPDP0_SHIFT             (2U)
#define SIM_PORT0_DETECT_SPDS0_MASK              (0x8U)
#define SIM_PORT0_DETECT_SPDS0_SHIFT             (3U)

/*! @name DATA_FORMAT - SIM Data Format Register */
#define SIM_DATA_FORMAT_IC_MASK                  (0x1U)
#define SIM_DATA_FORMAT_IC_SHIFT                 (0U)

/*! @name XMT_THRESHOLD - SIM Transmit Threshold Register */
#define SIM_XMT_THRESHOLD_TDT_MASK               (0xFU)
#define SIM_XMT_THRESHOLD_TDT_SHIFT              (0U)
#define SIM_XMT_THRESHOLD_TDT(x)                 (((uint32_t)(((uint32_t)(x)) << SIM_XMT_THRESHOLD_TDT_SHIFT)) & SIM_XMT_THRESHOLD_TDT_MASK)
#define SIM_XMT_THRESHOLD_XTH_MASK               (0xF0U)
#define SIM_XMT_THRESHOLD_XTH_SHIFT              (4U)
#define SIM_XMT_THRESHOLD_XTH(x)                 (((uint32_t)(((uint32_t)(x)) << SIM_XMT_THRESHOLD_XTH_SHIFT)) & SIM_XMT_THRESHOLD_XTH_MASK)

/*! @name GUARD_CNTL - SIM Transmit Guard Control Register */
#define SIM_GUARD_CNTL_GETU_MASK                 (0xFFU)
#define SIM_GUARD_CNTL_GETU_SHIFT                (0U)
#define SIM_GUARD_CNTL_GETU(x)                   (((uint32_t)(((uint32_t)(x)) << SIM_GUARD_CNTL_GETU_SHIFT)) & SIM_GUARD_CNTL_GETU_MASK)
#define SIM_GUARD_CNTL_RCVR11_MASK               (0x100U)
#define SIM_GUARD_CNTL_RCVR11_SHIFT              (8U)

/*! @name OD_CONFIG - SIM Open Drain Configuration Control Register */
#define SIM_OD_CONFIG_OD_P0_MASK                 (0x1U)
#define SIM_OD_CONFIG_OD_P0_SHIFT                (0U)
#define SIM_OD_CONFIG_OD_P1_MASK                 (0x2U)
#define SIM_OD_CONFIG_OD_P1_SHIFT                (1U)

/*! @name RESET_CNTL - SIM Reset Control Register */
#define SIM_RESET_CNTL_FLUSH_RCV_MASK            (0x1U)
#define SIM_RESET_CNTL_FLUSH_RCV_SHIFT           (0U)
#define SIM_RESET_CNTL_FLUSH_XMT_MASK            (0x2U)
#define SIM_RESET_CNTL_FLUSH_XMT_SHIFT           (1U)
#define SIM_RESET_CNTL_SOFT_RST_MASK             (0x4U)
#define SIM_RESET_CNTL_SOFT_RST_SHIFT            (2U)
#define SIM_RESET_CNTL_KILL_CLOCK_MASK           (0x8U)
#define SIM_RESET_CNTL_KILL_CLOCK_SHIFT          (3U)
#define SIM_RESET_CNTL_DOZE_MASK                 (0x10U)
#define SIM_RESET_CNTL_DOZE_SHIFT                (4U)
#define SIM_RESET_CNTL_STOP_MASK                 (0x20U)
#define SIM_RESET_CNTL_STOP_SHIFT                (5U)

/*! @name CHAR_WAIT - SIM Character Wait Time Register */
#define SIM_CHAR_WAIT_CWT_MASK                   (0xFFFFU)
#define SIM_CHAR_WAIT_CWT_SHIFT                  (0U)
#define SIM_CHAR_WAIT_CWT(x)                     (((uint32_t)(((uint32_t)(x)) << SIM_CHAR_WAIT_CWT_SHIFT)) & SIM_CHAR_WAIT_CWT_MASK)

/*! @name GPCNT - SIM General Purpose Counter Register */
#define SIM_GPCNT_GPCNT_MASK                     (0xFFFFU)
#define SIM_GPCNT_GPCNT_SHIFT                    (0U)
#define SIM_GPCNT_GPCNT(x)                       (((uint32_t)(((uint32_t)(x)) << SIM_GPCNT_GPCNT_SHIFT)) & SIM_GPCNT_GPCNT_MASK)

/*! @name DIVISOR - SIM Divisor Register */
#define SIM_DIVISOR_DIVISOR_MASK                 (0xFFU)
#define SIM_DIVISOR_DIVISOR_SHIFT                (0U)
#define SIM_DIVISOR_DIVISOR(x)                   (((uint32_t)(((uint32_t)(x)) << SIM_DIVISOR_DIVISOR_SHIFT)) & SIM_DIVISOR_DIVISOR_MASK)

/*! @name BWT - SIM Block Wait Time Register */
#define SIM_BWT_BWT_MASK                         (0xFFFFU)
#define SIM_BWT_BWT_SHIFT                        (0U)
#define SIM_BWT_BWT(x)                           (((uint32_t)(((uint32_t)(x)) << SIM_BWT_BWT_SHIFT)) & SIM_BWT_BWT_MASK)

/*! @name BGT - SIM Block Guard Time Register */
#define SIM_BGT_BGT_MASK                         (0xFFFFU)
#define SIM_BGT_BGT_SHIFT                        (0U)
#define SIM_BGT_BGT(x)                           (((uint32_t)(((uint32_t)(x)) << SIM_BGT_BGT_SHIFT)) & SIM_BGT_BGT_MASK)

/*! @name BWT_H - SIM Block Wait Time Register HIGH */
#define SIM_BWT_H_BWT_H_MASK                     (0xFFFFU)
#define SIM_BWT_H_BWT_H_SHIFT                    (0U)
#define SIM_BWT_H_BWT_H(x)                       (((uint32_t)(((uint32_t)(x)) << SIM_BWT_H_BWT_H_SHIFT)) & SIM_BWT_H_BWT_H_MASK)

/*! @name XMT_FIFO_STAT - SIM Transmit FIFO Status Register */
#define SIM_XMT_FIFO_STAT_XMT_RPTR_MASK          (0xFU)
#define SIM_XMT_FIFO_STAT_XMT_RPTR_SHIFT         (0U)
#define SIM_XMT_FIFO_STAT_XMT_RPTR(x)            (((uint32_t)(((uint32_t)(x)) << SIM_XMT_FIFO_STAT_XMT_RPTR_SHIFT)) & SIM_XMT_FIFO_STAT_XMT_RPTR_MASK)
#define SIM_XMT_FIFO_STAT_XMT_WPTR_MASK          (0xF0U)
#define SIM_XMT_FIFO_STAT_XMT_WPTR_SHIFT         (4U)
#define SIM_XMT_FIFO_STAT_XMT_WPTR(x)            (((uint32_t)(((uint32_t)(x)) << SIM_XMT_FIFO_STAT_XMT_WPTR_SHIFT)) & SIM_XMT_FIFO_STAT_XMT_WPTR_MASK)
#define SIM_XMT_FIFO_STAT_XMT_CNT_MASK           (0xF00U)
#define SIM_XMT_FIFO_STAT_XMT_CNT_SHIFT          (8U)
#define SIM_XMT_FIFO_STAT_XMT_CNT(x)             (((uint32_t)(((uint32_t)(x)) << SIM_XMT_FIFO_STAT_XMT_CNT_SHIFT)) & SIM_XMT_FIFO_STAT_XMT_CNT_MASK)

/*! @name RCV_FIFO_CNT - SIM Receive FIFO Counter Register */
#define SIM_RCV_FIFO_CNT_RCV_CNT_MASK            (0x1FFU)
#define SIM_RCV_FIFO_CNT_RCV_CNT_SHIFT           (0U)
#define SIM_RCV_FIFO_CNT_RCV_CNT(x)              (((uint32_t)(((uint32_t)(x)) << SIM_RCV_FIFO_CNT_RCV_CNT_SHIFT)) & SIM_RCV_FIFO_CNT_RCV_CNT_MASK)

/*! @name RCV_FIFO_WPTR - SIM Receive FIFO Write Pointer Register */
#define SIM_RCV_FIFO_WPTR_RCV_WPTR_MASK          (0x1FFU)
#define SIM_RCV_FIFO_WPTR_RCV_WPTR_SHIFT         (0U)
#define SIM_RCV_FIFO_WPTR_RCV_WPTR(x)            (((uint32_t)(((uint32_t)(x)) << SIM_RCV_FIFO_WPTR_RCV_WPTR_SHIFT)) & SIM_RCV_FIFO_WPTR_RCV_WPTR_MASK)

/*! @name RCV_FIFO_RPTR - SIM Receive FIFO Read Pointer Register */
#define SIM_RCV_FIFO_RPTR_RCV_RPTR_MASK          (0x1FFU)
#define SIM_RCV_FIFO_RPTR_RCV_RPTR_SHIFT         (0U)
#define SIM_RCV_FIFO_RPTR_RCV_RPTR(x)            (((uint32_t)(((uint32_t)(x)) << SIM_RCV_FIFO_RPTR_RCV_RPTR_SHIFT)) & SIM_RCV_FIFO_RPTR_RCV_RPTR_MASK)


/*!
 * @}
 */ /* end of group SIM_Register_Masks */


/* SIM - Peripheral instance base addresses */
/** Peripheral SIM1 base pointer */
#define SIM1_BASE_PTR                            ((SIM_MemMapPtr)0x30B90000u)
/** Peripheral SIM2 base pointer */
#define SIM2_BASE_PTR                            ((SIM_MemMapPtr)0x30BA0000u)
/** Array initializer of SIM peripheral base pointers */
#define SIM_BASE_PTRS                            { SIM1_BASE_PTR, SIM2_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- SIM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SIM_Register_Accessor_Macros SIM - Register accessor macros
 * @{
 */


/* SIM - Register instance definitions */
/* SIM1 */
#define SIM1_PORT1_CNTL                          SIM_PORT1_CNTL_REG(SIM1_BASE_PTR)
#define SIM1_SETUP                               SIM_SETUP_REG(SIM1_BASE_PTR)
#define SIM1_PORT1_DETECT                        SIM_PORT1_DETECT_REG(SIM1_BASE_PTR)
#define SIM1_XMT_BUF                             SIM_XMT_BUF_REG(SIM1_BASE_PTR)
#define SIM1_RCV_BUF                             SIM_RCV_BUF_REG(SIM1_BASE_PTR)
#define SIM1_PORT0_CNTL                          SIM_PORT0_CNTL_REG(SIM1_BASE_PTR)
#define SIM1_CNTL                                SIM_CNTL_REG(SIM1_BASE_PTR)
#define SIM1_CLK_PRESCALER                       SIM_CLK_PRESCALER_REG(SIM1_BASE_PTR)
#define SIM1_RCV_THRESHOLD                       SIM_RCV_THRESHOLD_REG(SIM1_BASE_PTR)
#define SIM1_ENABLE                              SIM_ENABLE_REG(SIM1_BASE_PTR)
#define SIM1_XMT_STATUS                          SIM_XMT_STATUS_REG(SIM1_BASE_PTR)
#define SIM1_RCV_STATUS                          SIM_RCV_STATUS_REG(SIM1_BASE_PTR)
#define SIM1_INT_MASK                            SIM_INT_MASK_REG(SIM1_BASE_PTR)
#define SIM1_PORT0_DETECT                        SIM_PORT0_DETECT_REG(SIM1_BASE_PTR)
#define SIM1_DATA_FORMAT                         SIM_DATA_FORMAT_REG(SIM1_BASE_PTR)
#define SIM1_XMT_THRESHOLD                       SIM_XMT_THRESHOLD_REG(SIM1_BASE_PTR)
#define SIM1_GUARD_CNTL                          SIM_GUARD_CNTL_REG(SIM1_BASE_PTR)
#define SIM1_OD_CONFIG                           SIM_OD_CONFIG_REG(SIM1_BASE_PTR)
#define SIM1_RESET_CNTL                          SIM_RESET_CNTL_REG(SIM1_BASE_PTR)
#define SIM1_CHAR_WAIT                           SIM_CHAR_WAIT_REG(SIM1_BASE_PTR)
#define SIM1_GPCNT                               SIM_GPCNT_REG(SIM1_BASE_PTR)
#define SIM1_DIVISOR                             SIM_DIVISOR_REG(SIM1_BASE_PTR)
#define SIM1_BWT                                 SIM_BWT_REG(SIM1_BASE_PTR)
#define SIM1_BGT                                 SIM_BGT_REG(SIM1_BASE_PTR)
#define SIM1_BWT_H                               SIM_BWT_H_REG(SIM1_BASE_PTR)
#define SIM1_XMT_FIFO_STAT                       SIM_XMT_FIFO_STAT_REG(SIM1_BASE_PTR)
#define SIM1_RCV_FIFO_CNT                        SIM_RCV_FIFO_CNT_REG(SIM1_BASE_PTR)
#define SIM1_RCV_FIFO_WPTR                       SIM_RCV_FIFO_WPTR_REG(SIM1_BASE_PTR)
#define SIM1_RCV_FIFO_RPTR                       SIM_RCV_FIFO_RPTR_REG(SIM1_BASE_PTR)
/* SIM2 */
#define SIM2_PORT1_CNTL                          SIM_PORT1_CNTL_REG(SIM2_BASE_PTR)
#define SIM2_SETUP                               SIM_SETUP_REG(SIM2_BASE_PTR)
#define SIM2_PORT1_DETECT                        SIM_PORT1_DETECT_REG(SIM2_BASE_PTR)
#define SIM2_XMT_BUF                             SIM_XMT_BUF_REG(SIM2_BASE_PTR)
#define SIM2_RCV_BUF                             SIM_RCV_BUF_REG(SIM2_BASE_PTR)
#define SIM2_PORT0_CNTL                          SIM_PORT0_CNTL_REG(SIM2_BASE_PTR)
#define SIM2_CNTL                                SIM_CNTL_REG(SIM2_BASE_PTR)
#define SIM2_CLK_PRESCALER                       SIM_CLK_PRESCALER_REG(SIM2_BASE_PTR)
#define SIM2_RCV_THRESHOLD                       SIM_RCV_THRESHOLD_REG(SIM2_BASE_PTR)
#define SIM2_ENABLE                              SIM_ENABLE_REG(SIM2_BASE_PTR)
#define SIM2_XMT_STATUS                          SIM_XMT_STATUS_REG(SIM2_BASE_PTR)
#define SIM2_RCV_STATUS                          SIM_RCV_STATUS_REG(SIM2_BASE_PTR)
#define SIM2_INT_MASK                            SIM_INT_MASK_REG(SIM2_BASE_PTR)
#define SIM2_PORT0_DETECT                        SIM_PORT0_DETECT_REG(SIM2_BASE_PTR)
#define SIM2_DATA_FORMAT                         SIM_DATA_FORMAT_REG(SIM2_BASE_PTR)
#define SIM2_XMT_THRESHOLD                       SIM_XMT_THRESHOLD_REG(SIM2_BASE_PTR)
#define SIM2_GUARD_CNTL                          SIM_GUARD_CNTL_REG(SIM2_BASE_PTR)
#define SIM2_OD_CONFIG                           SIM_OD_CONFIG_REG(SIM2_BASE_PTR)
#define SIM2_RESET_CNTL                          SIM_RESET_CNTL_REG(SIM2_BASE_PTR)
#define SIM2_CHAR_WAIT                           SIM_CHAR_WAIT_REG(SIM2_BASE_PTR)
#define SIM2_GPCNT                               SIM_GPCNT_REG(SIM2_BASE_PTR)
#define SIM2_DIVISOR                             SIM_DIVISOR_REG(SIM2_BASE_PTR)
#define SIM2_BWT                                 SIM_BWT_REG(SIM2_BASE_PTR)
#define SIM2_BGT                                 SIM_BGT_REG(SIM2_BASE_PTR)
#define SIM2_BWT_H                               SIM_BWT_H_REG(SIM2_BASE_PTR)
#define SIM2_XMT_FIFO_STAT                       SIM_XMT_FIFO_STAT_REG(SIM2_BASE_PTR)
#define SIM2_RCV_FIFO_CNT                        SIM_RCV_FIFO_CNT_REG(SIM2_BASE_PTR)
#define SIM2_RCV_FIFO_WPTR                       SIM_RCV_FIFO_WPTR_REG(SIM2_BASE_PTR)
#define SIM2_RCV_FIFO_RPTR                       SIM_RCV_FIFO_RPTR_REG(SIM2_BASE_PTR)

/*!
 * @}
 */ /* end of group SIM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group SIM_Peripheral */


/* ----------------------------------------------------------------------------
   -- SNVS
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SNVS_Peripheral SNVS
 * @{
 */

/** SNVS - Peripheral register structure */
typedef struct SNVS_MemMap {
  uint32_t HPLR;                                   /**< SNVS_HP Lock Register, offset: 0x0 */
  uint32_t HPCOMR;                                 /**< SNVS_HP Command Register, offset: 0x4 */
  uint32_t HPCR;                                   /**< SNVS_HP Control Register, offset: 0x8 */
  uint8_t RESERVED_0[8];
  uint32_t HPSR;                                   /**< SNVS_HP Status Register, offset: 0x14 */
  uint8_t RESERVED_1[12];
  uint32_t HPRTCMR;                                /**< SNVS_HP Real Time Counter MSB Register, offset: 0x24 */
  uint32_t HPRTCLR;                                /**< SNVS_HP Real Time Counter LSB Register, offset: 0x28 */
  uint32_t HPTAMR;                                 /**< SNVS_HP Time Alarm MSB Register, offset: 0x2C */
  uint32_t HPTALR;                                 /**< SNVS_HP Time Alarm LSB Register, offset: 0x30 */
  uint32_t LPLR;                                   /**< SNVS_LP Lock Register, offset: 0x34 */
  uint32_t LPCR;                                   /**< SNVS_LP Control Register, offset: 0x38 */
  uint8_t RESERVED_2[16];
  uint32_t LPSR;                                   /**< SNVS_LP Status Register, offset: 0x4C */
  uint8_t RESERVED_3[12];
  uint32_t LPSMCMR;                                /**< SNVS_LP Secure Monotonic Counter MSB Register, offset: 0x5C */
  uint32_t LPSMCLR;                                /**< SNVS_LP Secure Monotonic Counter LSB Register, offset: 0x60 */
  uint8_t RESERVED_4[4];
  uint32_t LPGPR;                                  /**< SNVS_LP General Purpose Register, offset: 0x68 */
  uint8_t RESERVED_5[2956];
  uint32_t HPVIDR1;                                /**< SNVS_HP Version ID Register 1, offset: 0xBF8 */
  uint32_t HPVIDR2;                                /**< SNVS_HP Version ID Register 2, offset: 0xBFC */
} volatile *SNVS_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- SNVS - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SNVS_Register_Accessor_Macros SNVS - Register accessor macros
 * @{
 */


/* SNVS - Register accessors */
#define SNVS_HPLR_REG(base)                      ((base)->HPLR)
#define SNVS_HPCOMR_REG(base)                    ((base)->HPCOMR)
#define SNVS_HPCR_REG(base)                      ((base)->HPCR)
#define SNVS_HPSR_REG(base)                      ((base)->HPSR)
#define SNVS_HPRTCMR_REG(base)                   ((base)->HPRTCMR)
#define SNVS_HPRTCLR_REG(base)                   ((base)->HPRTCLR)
#define SNVS_HPTAMR_REG(base)                    ((base)->HPTAMR)
#define SNVS_HPTALR_REG(base)                    ((base)->HPTALR)
#define SNVS_LPLR_REG(base)                      ((base)->LPLR)
#define SNVS_LPCR_REG(base)                      ((base)->LPCR)
#define SNVS_LPSR_REG(base)                      ((base)->LPSR)
#define SNVS_LPSMCMR_REG(base)                   ((base)->LPSMCMR)
#define SNVS_LPSMCLR_REG(base)                   ((base)->LPSMCLR)
#define SNVS_LPGPR_REG(base)                     ((base)->LPGPR)
#define SNVS_HPVIDR1_REG(base)                   ((base)->HPVIDR1)
#define SNVS_HPVIDR2_REG(base)                   ((base)->HPVIDR2)

/*!
 * @}
 */ /* end of group SNVS_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- SNVS Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SNVS_Register_Masks SNVS Register Masks
 * @{
 */

/*! @name HPLR - SNVS_HP Lock Register */
#define SNVS_HPLR_MC_SL_MASK                     (0x10U)
#define SNVS_HPLR_MC_SL_SHIFT                    (4U)
#define SNVS_HPLR_GPR_SL_MASK                    (0x20U)
#define SNVS_HPLR_GPR_SL_SHIFT                   (5U)

/*! @name HPCOMR - SNVS_HP Command Register */
#define SNVS_HPCOMR_LP_SWR_MASK                  (0x10U)
#define SNVS_HPCOMR_LP_SWR_SHIFT                 (4U)
#define SNVS_HPCOMR_LP_SWR_DIS_MASK              (0x20U)
#define SNVS_HPCOMR_LP_SWR_DIS_SHIFT             (5U)
#define SNVS_HPCOMR_NPSWA_EN_MASK                (0x80000000U)
#define SNVS_HPCOMR_NPSWA_EN_SHIFT               (31U)

/*! @name HPCR - SNVS_HP Control Register */
#define SNVS_HPCR_RTC_EN_MASK                    (0x1U)
#define SNVS_HPCR_RTC_EN_SHIFT                   (0U)
#define SNVS_HPCR_HPTA_EN_MASK                   (0x2U)
#define SNVS_HPCR_HPTA_EN_SHIFT                  (1U)
#define SNVS_HPCR_PI_EN_MASK                     (0x8U)
#define SNVS_HPCR_PI_EN_SHIFT                    (3U)
#define SNVS_HPCR_PI_FREQ_MASK                   (0xF0U)
#define SNVS_HPCR_PI_FREQ_SHIFT                  (4U)
#define SNVS_HPCR_PI_FREQ(x)                     (((uint32_t)(((uint32_t)(x)) << SNVS_HPCR_PI_FREQ_SHIFT)) & SNVS_HPCR_PI_FREQ_MASK)
#define SNVS_HPCR_HPCALB_EN_MASK                 (0x100U)
#define SNVS_HPCR_HPCALB_EN_SHIFT                (8U)
#define SNVS_HPCR_HPCALB_VAL_MASK                (0x7C00U)
#define SNVS_HPCR_HPCALB_VAL_SHIFT               (10U)
#define SNVS_HPCR_HPCALB_VAL(x)                  (((uint32_t)(((uint32_t)(x)) << SNVS_HPCR_HPCALB_VAL_SHIFT)) & SNVS_HPCR_HPCALB_VAL_MASK)
#define SNVS_HPCR_BTN_CONFIG_MASK                (0x7000000U)
#define SNVS_HPCR_BTN_CONFIG_SHIFT               (24U)
#define SNVS_HPCR_BTN_CONFIG(x)                  (((uint32_t)(((uint32_t)(x)) << SNVS_HPCR_BTN_CONFIG_SHIFT)) & SNVS_HPCR_BTN_CONFIG_MASK)
#define SNVS_HPCR_BTN_MASK_MASK                  (0x8000000U)
#define SNVS_HPCR_BTN_MASK_SHIFT                 (27U)

/*! @name HPSR - SNVS_HP Status Register */
#define SNVS_HPSR_BTN_MASK                       (0x40U)
#define SNVS_HPSR_BTN_SHIFT                      (6U)
#define SNVS_HPSR_BI_MASK                        (0x80U)
#define SNVS_HPSR_BI_SHIFT                       (7U)

/*! @name HPRTCMR - SNVS_HP Real Time Counter MSB Register */
#define SNVS_HPRTCMR_RTC_MASK                    (0xFFFFFFFFU)
#define SNVS_HPRTCMR_RTC_SHIFT                   (0U)
#define SNVS_HPRTCMR_RTC(x)                      (((uint32_t)(((uint32_t)(x)) << SNVS_HPRTCMR_RTC_SHIFT)) & SNVS_HPRTCMR_RTC_MASK)

/*! @name HPRTCLR - SNVS_HP Real Time Counter LSB Register */
#define SNVS_HPRTCLR_RTC_MASK                    (0xFFFFFFFFU)
#define SNVS_HPRTCLR_RTC_SHIFT                   (0U)
#define SNVS_HPRTCLR_RTC(x)                      (((uint32_t)(((uint32_t)(x)) << SNVS_HPRTCLR_RTC_SHIFT)) & SNVS_HPRTCLR_RTC_MASK)

/*! @name HPTAMR - SNVS_HP Time Alarm MSB Register */
#define SNVS_HPTAMR_HPTA_MASK                    (0x7FFFU)
#define SNVS_HPTAMR_HPTA_SHIFT                   (0U)
#define SNVS_HPTAMR_HPTA(x)                      (((uint32_t)(((uint32_t)(x)) << SNVS_HPTAMR_HPTA_SHIFT)) & SNVS_HPTAMR_HPTA_MASK)

/*! @name HPTALR - SNVS_HP Time Alarm LSB Register */
#define SNVS_HPTALR_HPTA_MASK                    (0xFFFFFFFFU)
#define SNVS_HPTALR_HPTA_SHIFT                   (0U)
#define SNVS_HPTALR_HPTA(x)                      (((uint32_t)(((uint32_t)(x)) << SNVS_HPTALR_HPTA_SHIFT)) & SNVS_HPTALR_HPTA_MASK)

/*! @name LPLR - SNVS_LP Lock Register */
#define SNVS_LPLR_MC_HL_MASK                     (0x10U)
#define SNVS_LPLR_MC_HL_SHIFT                    (4U)
#define SNVS_LPLR_GPR_HL_MASK                    (0x20U)
#define SNVS_LPLR_GPR_HL_SHIFT                   (5U)

/*! @name LPCR - SNVS_LP Control Register */
#define SNVS_LPCR_MC_ENV_MASK                    (0x4U)
#define SNVS_LPCR_MC_ENV_SHIFT                   (2U)
#define SNVS_LPCR_DP_EN_MASK                     (0x20U)
#define SNVS_LPCR_DP_EN_SHIFT                    (5U)
#define SNVS_LPCR_TOP_MASK                       (0x40U)
#define SNVS_LPCR_TOP_SHIFT                      (6U)
#define SNVS_LPCR_PWR_GLITCH_EN_MASK             (0x80U)
#define SNVS_LPCR_PWR_GLITCH_EN_SHIFT            (7U)
#define SNVS_LPCR_BTN_PRESS_TIME_MASK            (0x30000U)
#define SNVS_LPCR_BTN_PRESS_TIME_SHIFT           (16U)
#define SNVS_LPCR_BTN_PRESS_TIME(x)              (((uint32_t)(((uint32_t)(x)) << SNVS_LPCR_BTN_PRESS_TIME_SHIFT)) & SNVS_LPCR_BTN_PRESS_TIME_MASK)
#define SNVS_LPCR_DEBOUNCE_MASK                  (0xC0000U)
#define SNVS_LPCR_DEBOUNCE_SHIFT                 (18U)
#define SNVS_LPCR_DEBOUNCE(x)                    (((uint32_t)(((uint32_t)(x)) << SNVS_LPCR_DEBOUNCE_SHIFT)) & SNVS_LPCR_DEBOUNCE_MASK)
#define SNVS_LPCR_ON_TIME_MASK                   (0x300000U)
#define SNVS_LPCR_ON_TIME_SHIFT                  (20U)
#define SNVS_LPCR_ON_TIME(x)                     (((uint32_t)(((uint32_t)(x)) << SNVS_LPCR_ON_TIME_SHIFT)) & SNVS_LPCR_ON_TIME_MASK)
#define SNVS_LPCR_PK_EN_MASK                     (0x400000U)
#define SNVS_LPCR_PK_EN_SHIFT                    (22U)
#define SNVS_LPCR_PK_OVERRIDE_MASK               (0x800000U)
#define SNVS_LPCR_PK_OVERRIDE_SHIFT              (23U)

/*! @name LPSR - SNVS_LP Status Register */
#define SNVS_LPSR_MCR_MASK                       (0x4U)
#define SNVS_LPSR_MCR_SHIFT                      (2U)
#define SNVS_LPSR_EO_MASK                        (0x20000U)
#define SNVS_LPSR_EO_SHIFT                       (17U)
#define SNVS_LPSR_SPO_MASK                       (0x40000U)
#define SNVS_LPSR_SPO_SHIFT                      (18U)

/*! @name LPSMCMR - SNVS_LP Secure Monotonic Counter MSB Register */
#define SNVS_LPSMCMR_MON_COUNTER_MASK            (0xFFFFU)
#define SNVS_LPSMCMR_MON_COUNTER_SHIFT           (0U)
#define SNVS_LPSMCMR_MON_COUNTER(x)              (((uint32_t)(((uint32_t)(x)) << SNVS_LPSMCMR_MON_COUNTER_SHIFT)) & SNVS_LPSMCMR_MON_COUNTER_MASK)
#define SNVS_LPSMCMR_MC_ERA_BITS_MASK            (0xFFFF0000U)
#define SNVS_LPSMCMR_MC_ERA_BITS_SHIFT           (16U)
#define SNVS_LPSMCMR_MC_ERA_BITS(x)              (((uint32_t)(((uint32_t)(x)) << SNVS_LPSMCMR_MC_ERA_BITS_SHIFT)) & SNVS_LPSMCMR_MC_ERA_BITS_MASK)

/*! @name LPSMCLR - SNVS_LP Secure Monotonic Counter LSB Register */
#define SNVS_LPSMCLR_MON_COUNTER_MASK            (0xFFFFFFFFU)
#define SNVS_LPSMCLR_MON_COUNTER_SHIFT           (0U)
#define SNVS_LPSMCLR_MON_COUNTER(x)              (((uint32_t)(((uint32_t)(x)) << SNVS_LPSMCLR_MON_COUNTER_SHIFT)) & SNVS_LPSMCLR_MON_COUNTER_MASK)

/*! @name LPGPR - SNVS_LP General Purpose Register */
#define SNVS_LPGPR_GPR_MASK                      (0xFFFFFFFFU)
#define SNVS_LPGPR_GPR_SHIFT                     (0U)
#define SNVS_LPGPR_GPR(x)                        (((uint32_t)(((uint32_t)(x)) << SNVS_LPGPR_GPR_SHIFT)) & SNVS_LPGPR_GPR_MASK)

/*! @name HPVIDR1 - SNVS_HP Version ID Register 1 */
#define SNVS_HPVIDR1_MINOR_REV_MASK              (0xFFU)
#define SNVS_HPVIDR1_MINOR_REV_SHIFT             (0U)
#define SNVS_HPVIDR1_MINOR_REV(x)                (((uint32_t)(((uint32_t)(x)) << SNVS_HPVIDR1_MINOR_REV_SHIFT)) & SNVS_HPVIDR1_MINOR_REV_MASK)
#define SNVS_HPVIDR1_MAJOR_REV_MASK              (0xFF00U)
#define SNVS_HPVIDR1_MAJOR_REV_SHIFT             (8U)
#define SNVS_HPVIDR1_MAJOR_REV(x)                (((uint32_t)(((uint32_t)(x)) << SNVS_HPVIDR1_MAJOR_REV_SHIFT)) & SNVS_HPVIDR1_MAJOR_REV_MASK)
#define SNVS_HPVIDR1_IP_ID_MASK                  (0xFFFF0000U)
#define SNVS_HPVIDR1_IP_ID_SHIFT                 (16U)
#define SNVS_HPVIDR1_IP_ID(x)                    (((uint32_t)(((uint32_t)(x)) << SNVS_HPVIDR1_IP_ID_SHIFT)) & SNVS_HPVIDR1_IP_ID_MASK)

/*! @name HPVIDR2 - SNVS_HP Version ID Register 2 */
#define SNVS_HPVIDR2_CONFIG_OPT_MASK             (0xFFU)
#define SNVS_HPVIDR2_CONFIG_OPT_SHIFT            (0U)
#define SNVS_HPVIDR2_CONFIG_OPT(x)               (((uint32_t)(((uint32_t)(x)) << SNVS_HPVIDR2_CONFIG_OPT_SHIFT)) & SNVS_HPVIDR2_CONFIG_OPT_MASK)
#define SNVS_HPVIDR2_ECO_REV_MASK                (0xFF00U)
#define SNVS_HPVIDR2_ECO_REV_SHIFT               (8U)
#define SNVS_HPVIDR2_ECO_REV(x)                  (((uint32_t)(((uint32_t)(x)) << SNVS_HPVIDR2_ECO_REV_SHIFT)) & SNVS_HPVIDR2_ECO_REV_MASK)
#define SNVS_HPVIDR2_INTG_OPT_MASK               (0xFF0000U)
#define SNVS_HPVIDR2_INTG_OPT_SHIFT              (16U)
#define SNVS_HPVIDR2_INTG_OPT(x)                 (((uint32_t)(((uint32_t)(x)) << SNVS_HPVIDR2_INTG_OPT_SHIFT)) & SNVS_HPVIDR2_INTG_OPT_MASK)
#define SNVS_HPVIDR2_IP_ERA_MASK                 (0xFF000000U)
#define SNVS_HPVIDR2_IP_ERA_SHIFT                (24U)
#define SNVS_HPVIDR2_IP_ERA(x)                   (((uint32_t)(((uint32_t)(x)) << SNVS_HPVIDR2_IP_ERA_SHIFT)) & SNVS_HPVIDR2_IP_ERA_MASK)


/*!
 * @}
 */ /* end of group SNVS_Register_Masks */


/* SNVS - Peripheral instance base addresses */
/** Peripheral SNVS base pointer */
#define SNVS_BASE_PTR                            ((SNVS_MemMapPtr)0x30370000u)
/** Array initializer of SNVS peripheral base pointers */
#define SNVS_BASE_PTRS                           { SNVS_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- SNVS - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SNVS_Register_Accessor_Macros SNVS - Register accessor macros
 * @{
 */


/* SNVS - Register instance definitions */
/* SNVS */
#define SNVS_HPLR                                SNVS_HPLR_REG(SNVS_BASE_PTR)
#define SNVS_HPCOMR                              SNVS_HPCOMR_REG(SNVS_BASE_PTR)
#define SNVS_HPCR                                SNVS_HPCR_REG(SNVS_BASE_PTR)
#define SNVS_HPSR                                SNVS_HPSR_REG(SNVS_BASE_PTR)
#define SNVS_HPRTCMR                             SNVS_HPRTCMR_REG(SNVS_BASE_PTR)
#define SNVS_HPRTCLR                             SNVS_HPRTCLR_REG(SNVS_BASE_PTR)
#define SNVS_HPTAMR                              SNVS_HPTAMR_REG(SNVS_BASE_PTR)
#define SNVS_HPTALR                              SNVS_HPTALR_REG(SNVS_BASE_PTR)
#define SNVS_LPLR                                SNVS_LPLR_REG(SNVS_BASE_PTR)
#define SNVS_LPCR                                SNVS_LPCR_REG(SNVS_BASE_PTR)
#define SNVS_LPSR                                SNVS_LPSR_REG(SNVS_BASE_PTR)
#define SNVS_LPSMCMR                             SNVS_LPSMCMR_REG(SNVS_BASE_PTR)
#define SNVS_LPSMCLR                             SNVS_LPSMCLR_REG(SNVS_BASE_PTR)
#define SNVS_LPGPR                               SNVS_LPGPR_REG(SNVS_BASE_PTR)
#define SNVS_HPVIDR1                             SNVS_HPVIDR1_REG(SNVS_BASE_PTR)
#define SNVS_HPVIDR2                             SNVS_HPVIDR2_REG(SNVS_BASE_PTR)

/*!
 * @}
 */ /* end of group SNVS_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group SNVS_Peripheral */


/* ----------------------------------------------------------------------------
   -- SPBA
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SPBA_Peripheral SPBA
 * @{
 */

/** SPBA - Peripheral register structure */
typedef struct SPBA_MemMap {
  uint32_t PRR[32];                                /**< Peripheral Rights Register, array offset: 0x0, array step: 0x4 */
} volatile *SPBA_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- SPBA - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SPBA_Register_Accessor_Macros SPBA - Register accessor macros
 * @{
 */


/* SPBA - Register accessors */
#define SPBA_PRR_REG(base,index)                 ((base)->PRR[index])

/*!
 * @}
 */ /* end of group SPBA_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- SPBA Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SPBA_Register_Masks SPBA Register Masks
 * @{
 */

/*! @name PRR - Peripheral Rights Register */
#define SPBA_PRR_RARA_MASK                       (0x1U)
#define SPBA_PRR_RARA_SHIFT                      (0U)
#define SPBA_PRR_RARB_MASK                       (0x2U)
#define SPBA_PRR_RARB_SHIFT                      (1U)
#define SPBA_PRR_RARC_MASK                       (0x4U)
#define SPBA_PRR_RARC_SHIFT                      (2U)
#define SPBA_PRR_ROI_MASK                        (0x30000U)
#define SPBA_PRR_ROI_SHIFT                       (16U)
#define SPBA_PRR_ROI(x)                          (((uint32_t)(((uint32_t)(x)) << SPBA_PRR_ROI_SHIFT)) & SPBA_PRR_ROI_MASK)
#define SPBA_PRR_RMO_MASK                        (0xC0000000U)
#define SPBA_PRR_RMO_SHIFT                       (30U)
#define SPBA_PRR_RMO(x)                          (((uint32_t)(((uint32_t)(x)) << SPBA_PRR_RMO_SHIFT)) & SPBA_PRR_RMO_MASK)

/* The count of SPBA_PRR */
#define SPBA_PRR_COUNT                           (32U)


/*!
 * @}
 */ /* end of group SPBA_Register_Masks */


/* SPBA - Peripheral instance base addresses */
/** Peripheral SPBA base pointer */
#define SPBA_BASE_PTR                            ((SPBA_MemMapPtr)0x308F0000u)
/** Array initializer of SPBA peripheral base pointers */
#define SPBA_BASE_PTRS                           { SPBA_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- SPBA - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SPBA_Register_Accessor_Macros SPBA - Register accessor macros
 * @{
 */


/* SPBA - Register instance definitions */
/* SPBA */
#define SPBA_PRR0                                SPBA_PRR_REG(SPBA_BASE_PTR,0)
#define SPBA_PRR1                                SPBA_PRR_REG(SPBA_BASE_PTR,1)
#define SPBA_PRR2                                SPBA_PRR_REG(SPBA_BASE_PTR,2)
#define SPBA_PRR3                                SPBA_PRR_REG(SPBA_BASE_PTR,3)
#define SPBA_PRR4                                SPBA_PRR_REG(SPBA_BASE_PTR,4)
#define SPBA_PRR5                                SPBA_PRR_REG(SPBA_BASE_PTR,5)
#define SPBA_PRR6                                SPBA_PRR_REG(SPBA_BASE_PTR,6)
#define SPBA_PRR7                                SPBA_PRR_REG(SPBA_BASE_PTR,7)
#define SPBA_PRR8                                SPBA_PRR_REG(SPBA_BASE_PTR,8)
#define SPBA_PRR9                                SPBA_PRR_REG(SPBA_BASE_PTR,9)
#define SPBA_PRR10                               SPBA_PRR_REG(SPBA_BASE_PTR,10)
#define SPBA_PRR11                               SPBA_PRR_REG(SPBA_BASE_PTR,11)
#define SPBA_PRR12                               SPBA_PRR_REG(SPBA_BASE_PTR,12)
#define SPBA_PRR13                               SPBA_PRR_REG(SPBA_BASE_PTR,13)
#define SPBA_PRR14                               SPBA_PRR_REG(SPBA_BASE_PTR,14)
#define SPBA_PRR15                               SPBA_PRR_REG(SPBA_BASE_PTR,15)
#define SPBA_PRR16                               SPBA_PRR_REG(SPBA_BASE_PTR,16)
#define SPBA_PRR17                               SPBA_PRR_REG(SPBA_BASE_PTR,17)
#define SPBA_PRR18                               SPBA_PRR_REG(SPBA_BASE_PTR,18)
#define SPBA_PRR19                               SPBA_PRR_REG(SPBA_BASE_PTR,19)
#define SPBA_PRR20                               SPBA_PRR_REG(SPBA_BASE_PTR,20)
#define SPBA_PRR21                               SPBA_PRR_REG(SPBA_BASE_PTR,21)
#define SPBA_PRR22                               SPBA_PRR_REG(SPBA_BASE_PTR,22)
#define SPBA_PRR23                               SPBA_PRR_REG(SPBA_BASE_PTR,23)
#define SPBA_PRR24                               SPBA_PRR_REG(SPBA_BASE_PTR,24)
#define SPBA_PRR25                               SPBA_PRR_REG(SPBA_BASE_PTR,25)
#define SPBA_PRR26                               SPBA_PRR_REG(SPBA_BASE_PTR,26)
#define SPBA_PRR27                               SPBA_PRR_REG(SPBA_BASE_PTR,27)
#define SPBA_PRR28                               SPBA_PRR_REG(SPBA_BASE_PTR,28)
#define SPBA_PRR29                               SPBA_PRR_REG(SPBA_BASE_PTR,29)
#define SPBA_PRR30                               SPBA_PRR_REG(SPBA_BASE_PTR,30)
#define SPBA_PRR31                               SPBA_PRR_REG(SPBA_BASE_PTR,31)

/* SPBA - Register array accessors */
#define SPBA_PRR(index)                          SPBA_PRR_REG(SPBA_BASE_PTR,index)

/*!
 * @}
 */ /* end of group SPBA_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group SPBA_Peripheral */


/* ----------------------------------------------------------------------------
   -- SRC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SRC_Peripheral SRC
 * @{
 */

/** SRC - Peripheral register structure */
typedef struct SRC_MemMap {
  uint32_t SCR;                                    /**< SRC Reset Control Register, offset: 0x0 */
  uint32_t A7RCR0;                                 /**< A7 Reset Control Register, offset: 0x4 */
  uint32_t A7RCR1;                                 /**< A7 Reset Control Register, offset: 0x8 */
  uint32_t M4RCR;                                  /**< M4 Reset Control Register, offset: 0xC */
  uint8_t RESERVED_0[4];
  uint32_t ERCR;                                   /**< EIM Reset Control Register, offset: 0x14 */
  uint8_t RESERVED_1[4];
  uint32_t HSICPHY_RCR;                            /**< HSIC PHY Reset Control Register, offset: 0x1C */
  uint32_t USBOPHY1_RCR;                           /**< USB OTG PHY1 Reset Control Register, offset: 0x20 */
  uint32_t USBOPHY2_RCR;                           /**< USB OTG PHY2 Reset Control Register, offset: 0x24 */
  uint32_t MIPIPHY_RCR;                            /**< MIPI PHY Reset Control Register, offset: 0x28 */
  uint32_t PCIEPHY_RCR;                            /**< PCIE PHY Reset Control Register, offset: 0x2C */
  uint8_t RESERVED_2[40];
  uint32_t SBMR1;                                  /**< SRC Boot Mode Register 1, offset: 0x58 */
  uint32_t SRSR;                                   /**< SRC Reset Status Register, offset: 0x5C */
  uint8_t RESERVED_3[8];
  uint32_t SISR;                                   /**< SRC Interrupt Status Register, offset: 0x68 */
  uint32_t SIMR;                                   /**< SRC Interrupt Mask Register, offset: 0x6C */
  uint32_t SBMR2;                                  /**< SRC Boot Mode Register 2, offset: 0x70 */
  uint32_t GPR1;                                   /**< SRC General Purpose Register 1, offset: 0x74 */
  uint32_t GPR2;                                   /**< SRC General Purpose Register 2, offset: 0x78 */
  uint32_t GPR3;                                   /**< SRC General Purpose Register 3, offset: 0x7C */
  uint32_t GPR4;                                   /**< SRC General Purpose Register 4, offset: 0x80 */
  uint32_t GPR5;                                   /**< SRC General Purpose Register 5, offset: 0x84 */
  uint32_t GPR6;                                   /**< SRC General Purpose Register 6, offset: 0x88 */
  uint32_t GPR7;                                   /**< SRC General Purpose Register 7, offset: 0x8C */
  uint32_t GPR8;                                   /**< SRC General Purpose Register 8, offset: 0x90 */
  uint32_t GPR9;                                   /**< SRC General Purpose Register 9, offset: 0x94 */
  uint32_t GPR10;                                  /**< SRC General Purpose Register 10, offset: 0x98 */
  uint8_t RESERVED_4[3940];
  uint32_t DDRC_RCR;                               /**< SRC DDR Controller Reset Control Register, offset: 0x1000 */
} volatile *SRC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- SRC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SRC_Register_Accessor_Macros SRC - Register accessor macros
 * @{
 */


/* SRC - Register accessors */
#define SRC_SCR_REG(base)                        ((base)->SCR)
#define SRC_A7RCR0_REG(base)                     ((base)->A7RCR0)
#define SRC_A7RCR1_REG(base)                     ((base)->A7RCR1)
#define SRC_M4RCR_REG(base)                      ((base)->M4RCR)
#define SRC_ERCR_REG(base)                       ((base)->ERCR)
#define SRC_HSICPHY_RCR_REG(base)                ((base)->HSICPHY_RCR)
#define SRC_USBOPHY1_RCR_REG(base)               ((base)->USBOPHY1_RCR)
#define SRC_USBOPHY2_RCR_REG(base)               ((base)->USBOPHY2_RCR)
#define SRC_MIPIPHY_RCR_REG(base)                ((base)->MIPIPHY_RCR)
#define SRC_PCIEPHY_RCR_REG(base)                ((base)->PCIEPHY_RCR)
#define SRC_SBMR1_REG(base)                      ((base)->SBMR1)
#define SRC_SRSR_REG(base)                       ((base)->SRSR)
#define SRC_SISR_REG(base)                       ((base)->SISR)
#define SRC_SIMR_REG(base)                       ((base)->SIMR)
#define SRC_SBMR2_REG(base)                      ((base)->SBMR2)
#define SRC_GPR1_REG(base)                       ((base)->GPR1)
#define SRC_GPR2_REG(base)                       ((base)->GPR2)
#define SRC_GPR3_REG(base)                       ((base)->GPR3)
#define SRC_GPR4_REG(base)                       ((base)->GPR4)
#define SRC_GPR5_REG(base)                       ((base)->GPR5)
#define SRC_GPR6_REG(base)                       ((base)->GPR6)
#define SRC_GPR7_REG(base)                       ((base)->GPR7)
#define SRC_GPR8_REG(base)                       ((base)->GPR8)
#define SRC_GPR9_REG(base)                       ((base)->GPR9)
#define SRC_GPR10_REG(base)                      ((base)->GPR10)
#define SRC_DDRC_RCR_REG(base)                   ((base)->DDRC_RCR)

/*!
 * @}
 */ /* end of group SRC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- SRC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SRC_Register_Masks SRC Register Masks
 * @{
 */

/*! @name SCR - SRC Reset Control Register */
#define SRC_SCR_MASK_TEMPSENSE_RESET_MASK        (0xF0U)
#define SRC_SCR_MASK_TEMPSENSE_RESET_SHIFT       (4U)
#define SRC_SCR_MASK_TEMPSENSE_RESET(x)          (((uint32_t)(((uint32_t)(x)) << SRC_SCR_MASK_TEMPSENSE_RESET_SHIFT)) & SRC_SCR_MASK_TEMPSENSE_RESET_MASK)
#define SRC_SCR_DOMAIN0_MASK                     (0x1000000U)
#define SRC_SCR_DOMAIN0_SHIFT                    (24U)
#define SRC_SCR_DOMAIN1_MASK                     (0x2000000U)
#define SRC_SCR_DOMAIN1_SHIFT                    (25U)
#define SRC_SCR_DOMAIN2_MASK                     (0x4000000U)
#define SRC_SCR_DOMAIN2_SHIFT                    (26U)
#define SRC_SCR_DOMAIN3_MASK                     (0x8000000U)
#define SRC_SCR_DOMAIN3_SHIFT                    (27U)
#define SRC_SCR_LOCK_MASK                        (0x40000000U)
#define SRC_SCR_LOCK_SHIFT                       (30U)
#define SRC_SCR_DOM_EN_MASK                      (0x80000000U)
#define SRC_SCR_DOM_EN_SHIFT                     (31U)

/*! @name A7RCR0 - A7 Reset Control Register */
#define SRC_A7RCR0_A7_CORE_POR_RESET0_MASK       (0x1U)
#define SRC_A7RCR0_A7_CORE_POR_RESET0_SHIFT      (0U)
#define SRC_A7RCR0_A7_CORE_POR_RESET1_MASK       (0x2U)
#define SRC_A7RCR0_A7_CORE_POR_RESET1_SHIFT      (1U)
#define SRC_A7RCR0_A7_CORE_RESET0_MASK           (0x10U)
#define SRC_A7RCR0_A7_CORE_RESET0_SHIFT          (4U)
#define SRC_A7RCR0_A7_CORE_RESET1_MASK           (0x20U)
#define SRC_A7RCR0_A7_CORE_RESET1_SHIFT          (5U)
#define SRC_A7RCR0_A7_DBG_RESET0_MASK            (0x100U)
#define SRC_A7RCR0_A7_DBG_RESET0_SHIFT           (8U)
#define SRC_A7RCR0_A7_DBG_RESET1_MASK            (0x200U)
#define SRC_A7RCR0_A7_DBG_RESET1_SHIFT           (9U)
#define SRC_A7RCR0_A7_ETM_RESET0_MASK            (0x1000U)
#define SRC_A7RCR0_A7_ETM_RESET0_SHIFT           (12U)
#define SRC_A7RCR0_A7_ETM_RESET1_MASK            (0x2000U)
#define SRC_A7RCR0_A7_ETM_RESET1_SHIFT           (13U)
#define SRC_A7RCR0_MASK_WDOG1_RST_MASK           (0xF0000U)
#define SRC_A7RCR0_MASK_WDOG1_RST_SHIFT          (16U)
#define SRC_A7RCR0_MASK_WDOG1_RST(x)             (((uint32_t)(((uint32_t)(x)) << SRC_A7RCR0_MASK_WDOG1_RST_SHIFT)) & SRC_A7RCR0_MASK_WDOG1_RST_MASK)
#define SRC_A7RCR0_A7_SOC_DBG_RESET_MASK         (0x100000U)
#define SRC_A7RCR0_A7_SOC_DBG_RESET_SHIFT        (20U)
#define SRC_A7RCR0_A7_L2RESET_MASK               (0x200000U)
#define SRC_A7RCR0_A7_L2RESET_SHIFT              (21U)
#define SRC_A7RCR0_DOMAIN0_MASK                  (0x1000000U)
#define SRC_A7RCR0_DOMAIN0_SHIFT                 (24U)
#define SRC_A7RCR0_DOMAIN1_MASK                  (0x2000000U)
#define SRC_A7RCR0_DOMAIN1_SHIFT                 (25U)
#define SRC_A7RCR0_DOMAIN2_MASK                  (0x4000000U)
#define SRC_A7RCR0_DOMAIN2_SHIFT                 (26U)
#define SRC_A7RCR0_DOMAIN3_MASK                  (0x8000000U)
#define SRC_A7RCR0_DOMAIN3_SHIFT                 (27U)
#define SRC_A7RCR0_LOCK_MASK                     (0x40000000U)
#define SRC_A7RCR0_LOCK_SHIFT                    (30U)
#define SRC_A7RCR0_DOM_EN_MASK                   (0x80000000U)
#define SRC_A7RCR0_DOM_EN_SHIFT                  (31U)

/*! @name A7RCR1 - A7 Reset Control Register */
#define SRC_A7RCR1_A7_CORE1_ENABLE_MASK          (0x2U)
#define SRC_A7RCR1_A7_CORE1_ENABLE_SHIFT         (1U)
#define SRC_A7RCR1_DOMAIN0_MASK                  (0x1000000U)
#define SRC_A7RCR1_DOMAIN0_SHIFT                 (24U)
#define SRC_A7RCR1_DOMAIN1_MASK                  (0x2000000U)
#define SRC_A7RCR1_DOMAIN1_SHIFT                 (25U)
#define SRC_A7RCR1_DOMAIN2_MASK                  (0x4000000U)
#define SRC_A7RCR1_DOMAIN2_SHIFT                 (26U)
#define SRC_A7RCR1_DOMAIN3_MASK                  (0x8000000U)
#define SRC_A7RCR1_DOMAIN3_SHIFT                 (27U)
#define SRC_A7RCR1_LOCK_MASK                     (0x40000000U)
#define SRC_A7RCR1_LOCK_SHIFT                    (30U)
#define SRC_A7RCR1_DOM_EN_MASK                   (0x80000000U)
#define SRC_A7RCR1_DOM_EN_SHIFT                  (31U)

/*! @name M4RCR - M4 Reset Control Register */
#define SRC_M4RCR_SW_M4C_NON_SCLR_RST_MASK       (0x1U)
#define SRC_M4RCR_SW_M4C_NON_SCLR_RST_SHIFT      (0U)
#define SRC_M4RCR_SW_M4C_RST_MASK                (0x2U)
#define SRC_M4RCR_SW_M4C_RST_SHIFT               (1U)
#define SRC_M4RCR_SW_M4P_RST_MASK                (0x4U)
#define SRC_M4RCR_SW_M4P_RST_SHIFT               (2U)
#define SRC_M4RCR_ENABLE_M4_MASK                 (0x8U)
#define SRC_M4RCR_ENABLE_M4_SHIFT                (3U)
#define SRC_M4RCR_MASK_WDOG3_RST_MASK            (0xF0U)
#define SRC_M4RCR_MASK_WDOG3_RST_SHIFT           (4U)
#define SRC_M4RCR_MASK_WDOG3_RST(x)              (((uint32_t)(((uint32_t)(x)) << SRC_M4RCR_MASK_WDOG3_RST_SHIFT)) & SRC_M4RCR_MASK_WDOG3_RST_MASK)
#define SRC_M4RCR_WDOG3_RST_OPTION_M4_MASK       (0x100U)
#define SRC_M4RCR_WDOG3_RST_OPTION_M4_SHIFT      (8U)
#define SRC_M4RCR_WDOG3_RST_OPTION_MASK          (0x200U)
#define SRC_M4RCR_WDOG3_RST_OPTION_SHIFT         (9U)
#define SRC_M4RCR_DOMAIN0_MASK                   (0x1000000U)
#define SRC_M4RCR_DOMAIN0_SHIFT                  (24U)
#define SRC_M4RCR_DOMAIN1_MASK                   (0x2000000U)
#define SRC_M4RCR_DOMAIN1_SHIFT                  (25U)
#define SRC_M4RCR_DOMAIN2_MASK                   (0x4000000U)
#define SRC_M4RCR_DOMAIN2_SHIFT                  (26U)
#define SRC_M4RCR_DOMAIN3_MASK                   (0x8000000U)
#define SRC_M4RCR_DOMAIN3_SHIFT                  (27U)
#define SRC_M4RCR_LOCK_MASK                      (0x40000000U)
#define SRC_M4RCR_LOCK_SHIFT                     (30U)
#define SRC_M4RCR_DOM_EN_MASK                    (0x80000000U)
#define SRC_M4RCR_DOM_EN_SHIFT                   (31U)

/*! @name ERCR - EIM Reset Control Register */
#define SRC_ERCR_EIM_RST_MASK                    (0x1U)
#define SRC_ERCR_EIM_RST_SHIFT                   (0U)
#define SRC_ERCR_DOMAIN0_MASK                    (0x1000000U)
#define SRC_ERCR_DOMAIN0_SHIFT                   (24U)
#define SRC_ERCR_DOMAIN1_MASK                    (0x2000000U)
#define SRC_ERCR_DOMAIN1_SHIFT                   (25U)
#define SRC_ERCR_DOMAIN2_MASK                    (0x4000000U)
#define SRC_ERCR_DOMAIN2_SHIFT                   (26U)
#define SRC_ERCR_DOMAIN3_MASK                    (0x8000000U)
#define SRC_ERCR_DOMAIN3_SHIFT                   (27U)
#define SRC_ERCR_LOCK_MASK                       (0x40000000U)
#define SRC_ERCR_LOCK_SHIFT                      (30U)
#define SRC_ERCR_DOM_EN_MASK                     (0x80000000U)
#define SRC_ERCR_DOM_EN_SHIFT                    (31U)

/*! @name HSICPHY_RCR - HSIC PHY Reset Control Register */
#define SRC_HSICPHY_RCR_HSIC_PHY_POR_MASK        (0x1U)
#define SRC_HSICPHY_RCR_HSIC_PHY_POR_SHIFT       (0U)
#define SRC_HSICPHY_RCR_HSICPHY_PORT_RST_MASK    (0x2U)
#define SRC_HSICPHY_RCR_HSICPHY_PORT_RST_SHIFT   (1U)
#define SRC_HSICPHY_RCR_DOMAIN0_MASK             (0x1000000U)
#define SRC_HSICPHY_RCR_DOMAIN0_SHIFT            (24U)
#define SRC_HSICPHY_RCR_DOMAIN1_MASK             (0x2000000U)
#define SRC_HSICPHY_RCR_DOMAIN1_SHIFT            (25U)
#define SRC_HSICPHY_RCR_DOMAIN2_MASK             (0x4000000U)
#define SRC_HSICPHY_RCR_DOMAIN2_SHIFT            (26U)
#define SRC_HSICPHY_RCR_DOMAIN3_MASK             (0x8000000U)
#define SRC_HSICPHY_RCR_DOMAIN3_SHIFT            (27U)
#define SRC_HSICPHY_RCR_LOCK_MASK                (0x40000000U)
#define SRC_HSICPHY_RCR_LOCK_SHIFT               (30U)
#define SRC_HSICPHY_RCR_DOM_EN_MASK              (0x80000000U)
#define SRC_HSICPHY_RCR_DOM_EN_SHIFT             (31U)

/*! @name USBOPHY1_RCR - USB OTG PHY1 Reset Control Register */
#define SRC_USBOPHY1_RCR_USBPHY1_POR_MASK        (0x1U)
#define SRC_USBOPHY1_RCR_USBPHY1_POR_SHIFT       (0U)
#define SRC_USBOPHY1_RCR_USBPHY1_PORT_RST_MASK   (0x2U)
#define SRC_USBOPHY1_RCR_USBPHY1_PORT_RST_SHIFT  (1U)
#define SRC_USBOPHY1_RCR_DOMAIN0_MASK            (0x1000000U)
#define SRC_USBOPHY1_RCR_DOMAIN0_SHIFT           (24U)
#define SRC_USBOPHY1_RCR_DOMAIN1_MASK            (0x2000000U)
#define SRC_USBOPHY1_RCR_DOMAIN1_SHIFT           (25U)
#define SRC_USBOPHY1_RCR_DOMAIN2_MASK            (0x4000000U)
#define SRC_USBOPHY1_RCR_DOMAIN2_SHIFT           (26U)
#define SRC_USBOPHY1_RCR_DOMAIN3_MASK            (0x8000000U)
#define SRC_USBOPHY1_RCR_DOMAIN3_SHIFT           (27U)
#define SRC_USBOPHY1_RCR_LOCK_MASK               (0x40000000U)
#define SRC_USBOPHY1_RCR_LOCK_SHIFT              (30U)
#define SRC_USBOPHY1_RCR_DOM_EN_MASK             (0x80000000U)
#define SRC_USBOPHY1_RCR_DOM_EN_SHIFT            (31U)

/*! @name USBOPHY2_RCR - USB OTG PHY2 Reset Control Register */
#define SRC_USBOPHY2_RCR_USBPHY2_POR_MASK        (0x1U)
#define SRC_USBOPHY2_RCR_USBPHY2_POR_SHIFT       (0U)
#define SRC_USBOPHY2_RCR_USBPHY2_PORT_RST_MASK   (0x2U)
#define SRC_USBOPHY2_RCR_USBPHY2_PORT_RST_SHIFT  (1U)
#define SRC_USBOPHY2_RCR_DOMAIN0_MASK            (0x1000000U)
#define SRC_USBOPHY2_RCR_DOMAIN0_SHIFT           (24U)
#define SRC_USBOPHY2_RCR_DOMAIN1_MASK            (0x2000000U)
#define SRC_USBOPHY2_RCR_DOMAIN1_SHIFT           (25U)
#define SRC_USBOPHY2_RCR_DOMAIN2_MASK            (0x4000000U)
#define SRC_USBOPHY2_RCR_DOMAIN2_SHIFT           (26U)
#define SRC_USBOPHY2_RCR_DOMAIN3_MASK            (0x8000000U)
#define SRC_USBOPHY2_RCR_DOMAIN3_SHIFT           (27U)
#define SRC_USBOPHY2_RCR_LOCK_MASK               (0x40000000U)
#define SRC_USBOPHY2_RCR_LOCK_SHIFT              (30U)
#define SRC_USBOPHY2_RCR_DOM_EN_MASK             (0x80000000U)
#define SRC_USBOPHY2_RCR_DOM_EN_SHIFT            (31U)

/*! @name MIPIPHY_RCR - MIPI PHY Reset Control Register */
#define SRC_MIPIPHY_RCR_MIPI_PHY_MRST_MASK       (0x2U)
#define SRC_MIPIPHY_RCR_MIPI_PHY_MRST_SHIFT      (1U)
#define SRC_MIPIPHY_RCR_MIPI_PHY_SRST_MASK       (0x4U)
#define SRC_MIPIPHY_RCR_MIPI_PHY_SRST_SHIFT      (2U)
#define SRC_MIPIPHY_RCR_DOMAIN0_MASK             (0x1000000U)
#define SRC_MIPIPHY_RCR_DOMAIN0_SHIFT            (24U)
#define SRC_MIPIPHY_RCR_DOMAIN1_MASK             (0x2000000U)
#define SRC_MIPIPHY_RCR_DOMAIN1_SHIFT            (25U)
#define SRC_MIPIPHY_RCR_DOMAIN2_MASK             (0x4000000U)
#define SRC_MIPIPHY_RCR_DOMAIN2_SHIFT            (26U)
#define SRC_MIPIPHY_RCR_DOMAIN3_MASK             (0x8000000U)
#define SRC_MIPIPHY_RCR_DOMAIN3_SHIFT            (27U)
#define SRC_MIPIPHY_RCR_LOCK_MASK                (0x40000000U)
#define SRC_MIPIPHY_RCR_LOCK_SHIFT               (30U)
#define SRC_MIPIPHY_RCR_DOM_EN_MASK              (0x80000000U)
#define SRC_MIPIPHY_RCR_DOM_EN_SHIFT             (31U)

/*! @name PCIEPHY_RCR - PCIE PHY Reset Control Register */
#define SRC_PCIEPHY_RCR_PCIEPHY_G_RST_MASK       (0x2U)
#define SRC_PCIEPHY_RCR_PCIEPHY_G_RST_SHIFT      (1U)
#define SRC_PCIEPHY_RCR_PCIEPHY_BTN_MASK         (0x4U)
#define SRC_PCIEPHY_RCR_PCIEPHY_BTN_SHIFT        (2U)
#define SRC_PCIEPHY_RCR_PCIEPHY_PERST_MASK       (0x8U)
#define SRC_PCIEPHY_RCR_PCIEPHY_PERST_SHIFT      (3U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ_MASK (0x10U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ_SHIFT (4U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST_MASK  (0x20U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST_SHIFT (5U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN_MASK   (0x40U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN_SHIFT  (6U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY_MASK (0x80U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY_SHIFT (7U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER_MASK (0x100U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER_SHIFT (8U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT_MASK (0x200U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT_SHIFT (9U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME_MASK  (0x400U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME_SHIFT (10U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF_MASK (0x800U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF_SHIFT (11U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX_MASK (0x1000U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX_SHIFT (12U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC_MASK (0x2000U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC_SHIFT (13U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT_MASK   (0x4000U)
#define SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT_SHIFT  (14U)
#define SRC_PCIEPHY_RCR_DOMAIN0_MASK             (0x1000000U)
#define SRC_PCIEPHY_RCR_DOMAIN0_SHIFT            (24U)
#define SRC_PCIEPHY_RCR_DOMAIN1_MASK             (0x2000000U)
#define SRC_PCIEPHY_RCR_DOMAIN1_SHIFT            (25U)
#define SRC_PCIEPHY_RCR_DOMAIN2_MASK             (0x4000000U)
#define SRC_PCIEPHY_RCR_DOMAIN2_SHIFT            (26U)
#define SRC_PCIEPHY_RCR_DOMAIN3_MASK             (0x8000000U)
#define SRC_PCIEPHY_RCR_DOMAIN3_SHIFT            (27U)
#define SRC_PCIEPHY_RCR_LOCK_MASK                (0x40000000U)
#define SRC_PCIEPHY_RCR_LOCK_SHIFT               (30U)
#define SRC_PCIEPHY_RCR_DOM_EN_MASK              (0x80000000U)
#define SRC_PCIEPHY_RCR_DOM_EN_SHIFT             (31U)

/*! @name SBMR1 - SRC Boot Mode Register 1 */
#define SRC_SBMR1_BOOT_CFG1_MASK                 (0xFFU)
#define SRC_SBMR1_BOOT_CFG1_SHIFT                (0U)
#define SRC_SBMR1_BOOT_CFG1(x)                   (((uint32_t)(((uint32_t)(x)) << SRC_SBMR1_BOOT_CFG1_SHIFT)) & SRC_SBMR1_BOOT_CFG1_MASK)
#define SRC_SBMR1_BOOT_CFG2_MASK                 (0xFF00U)
#define SRC_SBMR1_BOOT_CFG2_SHIFT                (8U)
#define SRC_SBMR1_BOOT_CFG2(x)                   (((uint32_t)(((uint32_t)(x)) << SRC_SBMR1_BOOT_CFG2_SHIFT)) & SRC_SBMR1_BOOT_CFG2_MASK)
#define SRC_SBMR1_BOOT_CFG3_MASK                 (0xFF0000U)
#define SRC_SBMR1_BOOT_CFG3_SHIFT                (16U)
#define SRC_SBMR1_BOOT_CFG3(x)                   (((uint32_t)(((uint32_t)(x)) << SRC_SBMR1_BOOT_CFG3_SHIFT)) & SRC_SBMR1_BOOT_CFG3_MASK)
#define SRC_SBMR1_BOOT_CFG4_MASK                 (0xFF000000U)
#define SRC_SBMR1_BOOT_CFG4_SHIFT                (24U)
#define SRC_SBMR1_BOOT_CFG4(x)                   (((uint32_t)(((uint32_t)(x)) << SRC_SBMR1_BOOT_CFG4_SHIFT)) & SRC_SBMR1_BOOT_CFG4_MASK)

/*! @name SRSR - SRC Reset Status Register */
#define SRC_SRSR_ipp_reset_b_MASK                (0x1U)
#define SRC_SRSR_ipp_reset_b_SHIFT               (0U)
#define SRC_SRSR_csu_reset_b_MASK                (0x4U)
#define SRC_SRSR_csu_reset_b_SHIFT               (2U)
#define SRC_SRSR_ipp_user_reset_b_MASK           (0x8U)
#define SRC_SRSR_ipp_user_reset_b_SHIFT          (3U)
#define SRC_SRSR_wdog1_rst_b_MASK                (0x10U)
#define SRC_SRSR_wdog1_rst_b_SHIFT               (4U)
#define SRC_SRSR_jtag_rst_b_MASK                 (0x20U)
#define SRC_SRSR_jtag_rst_b_SHIFT                (5U)
#define SRC_SRSR_jtag_sw_rst_MASK                (0x40U)
#define SRC_SRSR_jtag_sw_rst_SHIFT               (6U)
#define SRC_SRSR_wdog3_rst_b_MASK                (0x80U)
#define SRC_SRSR_wdog3_rst_b_SHIFT               (7U)
#define SRC_SRSR_wdog4_rst_b_MASK                (0x100U)
#define SRC_SRSR_wdog4_rst_b_SHIFT               (8U)
#define SRC_SRSR_tempsense_rst_b_MASK            (0x200U)
#define SRC_SRSR_tempsense_rst_b_SHIFT           (9U)

/*! @name SISR - SRC Interrupt Status Register */
#define SRC_SISR_HSICPHY_PASSED_RESET_MASK       (0x2U)
#define SRC_SISR_HSICPHY_PASSED_RESET_SHIFT      (1U)
#define SRC_SISR_OTGPHY1_PASSED_RESET_MASK       (0x4U)
#define SRC_SISR_OTGPHY1_PASSED_RESET_SHIFT      (2U)
#define SRC_SISR_OTGPHY2_PASSED_RESET_MASK       (0x8U)
#define SRC_SISR_OTGPHY2_PASSED_RESET_SHIFT      (3U)
#define SRC_SISR_MIPIPHY_PASSED_RESET_MASK       (0x10U)
#define SRC_SISR_MIPIPHY_PASSED_RESET_SHIFT      (4U)
#define SRC_SISR_M4C_PASSED_RESET_MASK           (0x100U)
#define SRC_SISR_M4C_PASSED_RESET_SHIFT          (8U)
#define SRC_SISR_M4P_PASSED_RESET_MASK           (0x200U)
#define SRC_SISR_M4P_PASSED_RESET_SHIFT          (9U)

/*! @name SIMR - SRC Interrupt Mask Register */
#define SRC_SIMR_MASK_HSICPHY_PASSED_RESET_MASK  (0x2U)
#define SRC_SIMR_MASK_HSICPHY_PASSED_RESET_SHIFT (1U)
#define SRC_SIMR_MASK_OTGPHY1_PASSED_RESET_MASK  (0x4U)
#define SRC_SIMR_MASK_OTGPHY1_PASSED_RESET_SHIFT (2U)
#define SRC_SIMR_MASK_OTGPHY2_PASSED_RESET_MASK  (0x8U)
#define SRC_SIMR_MASK_OTGPHY2_PASSED_RESET_SHIFT (3U)
#define SRC_SIMR_MASK_MIPIPHY_PASSED_RESET_MASK  (0x10U)
#define SRC_SIMR_MASK_MIPIPHY_PASSED_RESET_SHIFT (4U)
#define SRC_SIMR_MASK_M4C_PASSED_RESET_MASK      (0x100U)
#define SRC_SIMR_MASK_M4C_PASSED_RESET_SHIFT     (8U)
#define SRC_SIMR_MASK_M4P_PASSED_RESET_MASK      (0x200U)
#define SRC_SIMR_MASK_M4P_PASSED_RESET_SHIFT     (9U)

/*! @name SBMR2 - SRC Boot Mode Register 2 */
#define SRC_SBMR2_SEC_CONFIG_MASK                (0x3U)
#define SRC_SBMR2_SEC_CONFIG_SHIFT               (0U)
#define SRC_SBMR2_SEC_CONFIG(x)                  (((uint32_t)(((uint32_t)(x)) << SRC_SBMR2_SEC_CONFIG_SHIFT)) & SRC_SBMR2_SEC_CONFIG_MASK)
#define SRC_SBMR2_DIR_BT_DIS_MASK                (0x8U)
#define SRC_SBMR2_DIR_BT_DIS_SHIFT               (3U)
#define SRC_SBMR2_BT_FUSE_SEL_MASK               (0x10U)
#define SRC_SBMR2_BT_FUSE_SEL_SHIFT              (4U)
#define SRC_SBMR2_BMOD_MASK                      (0x3000000U)
#define SRC_SBMR2_BMOD_SHIFT                     (24U)
#define SRC_SBMR2_BMOD(x)                        (((uint32_t)(((uint32_t)(x)) << SRC_SBMR2_BMOD_SHIFT)) & SRC_SBMR2_BMOD_MASK)

/*! @name GPR1 - SRC General Purpose Register 1 */
#define SRC_GPR1_PERSISTENT_ENTRY0_MASK          (0xFFFFFFFFU)
#define SRC_GPR1_PERSISTENT_ENTRY0_SHIFT         (0U)
#define SRC_GPR1_PERSISTENT_ENTRY0(x)            (((uint32_t)(((uint32_t)(x)) << SRC_GPR1_PERSISTENT_ENTRY0_SHIFT)) & SRC_GPR1_PERSISTENT_ENTRY0_MASK)

/*! @name GPR2 - SRC General Purpose Register 2 */
#define SRC_GPR2_PERSISTENT_ARG0_MASK            (0xFFFFFFFFU)
#define SRC_GPR2_PERSISTENT_ARG0_SHIFT           (0U)
#define SRC_GPR2_PERSISTENT_ARG0(x)              (((uint32_t)(((uint32_t)(x)) << SRC_GPR2_PERSISTENT_ARG0_SHIFT)) & SRC_GPR2_PERSISTENT_ARG0_MASK)

/*! @name GPR3 - SRC General Purpose Register 3 */
#define SRC_GPR3_PERSISTENT_ENTRY1_MASK          (0xFFFFFFFFU)
#define SRC_GPR3_PERSISTENT_ENTRY1_SHIFT         (0U)
#define SRC_GPR3_PERSISTENT_ENTRY1(x)            (((uint32_t)(((uint32_t)(x)) << SRC_GPR3_PERSISTENT_ENTRY1_SHIFT)) & SRC_GPR3_PERSISTENT_ENTRY1_MASK)

/*! @name GPR4 - SRC General Purpose Register 4 */
#define SRC_GPR4_PERSISTENT_ARG1_MASK            (0xFFFFFFFFU)
#define SRC_GPR4_PERSISTENT_ARG1_SHIFT           (0U)
#define SRC_GPR4_PERSISTENT_ARG1(x)              (((uint32_t)(((uint32_t)(x)) << SRC_GPR4_PERSISTENT_ARG1_SHIFT)) & SRC_GPR4_PERSISTENT_ARG1_MASK)

/*! @name DDRC_RCR - SRC DDR Controller Reset Control Register */
#define SRC_DDRC_RCR_DDRC_PRST_MASK              (0x1U)
#define SRC_DDRC_RCR_DDRC_PRST_SHIFT             (0U)
#define SRC_DDRC_RCR_DDRC_CORE_RST_MASK          (0x2U)
#define SRC_DDRC_RCR_DDRC_CORE_RST_SHIFT         (1U)
#define SRC_DDRC_RCR_DOMAIN0_MASK                (0x1000000U)
#define SRC_DDRC_RCR_DOMAIN0_SHIFT               (24U)
#define SRC_DDRC_RCR_DOMAIN1_MASK                (0x2000000U)
#define SRC_DDRC_RCR_DOMAIN1_SHIFT               (25U)
#define SRC_DDRC_RCR_DOMAIN2_MASK                (0x4000000U)
#define SRC_DDRC_RCR_DOMAIN2_SHIFT               (26U)
#define SRC_DDRC_RCR_DOMAIN3_MASK                (0x8000000U)
#define SRC_DDRC_RCR_DOMAIN3_SHIFT               (27U)
#define SRC_DDRC_RCR_LOCK_MASK                   (0x40000000U)
#define SRC_DDRC_RCR_LOCK_SHIFT                  (30U)
#define SRC_DDRC_RCR_DOM_EN_MASK                 (0x80000000U)
#define SRC_DDRC_RCR_DOM_EN_SHIFT                (31U)


/*!
 * @}
 */ /* end of group SRC_Register_Masks */


/* SRC - Peripheral instance base addresses */
/** Peripheral SRC base pointer */
#define SRC_BASE_PTR                             ((SRC_MemMapPtr)0x30390000u)
/** Array initializer of SRC peripheral base pointers */
#define SRC_BASE_PTRS                            { SRC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- SRC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SRC_Register_Accessor_Macros SRC - Register accessor macros
 * @{
 */


/* SRC - Register instance definitions */
/* SRC */
#define SRC_SCR                                  SRC_SCR_REG(SRC_BASE_PTR)
#define SRC_A7RCR0                               SRC_A7RCR0_REG(SRC_BASE_PTR)
#define SRC_A7RCR1                               SRC_A7RCR1_REG(SRC_BASE_PTR)
#define SRC_M4RCR                                SRC_M4RCR_REG(SRC_BASE_PTR)
#define SRC_ERCR                                 SRC_ERCR_REG(SRC_BASE_PTR)
#define SRC_HSICPHY_RCR                          SRC_HSICPHY_RCR_REG(SRC_BASE_PTR)
#define SRC_USBOPHY1_RCR                         SRC_USBOPHY1_RCR_REG(SRC_BASE_PTR)
#define SRC_USBOPHY2_RCR                         SRC_USBOPHY2_RCR_REG(SRC_BASE_PTR)
#define SRC_MIPIPHY_RCR                          SRC_MIPIPHY_RCR_REG(SRC_BASE_PTR)
#define SRC_PCIEPHY_RCR                          SRC_PCIEPHY_RCR_REG(SRC_BASE_PTR)
#define SRC_SBMR1                                SRC_SBMR1_REG(SRC_BASE_PTR)
#define SRC_SRSR                                 SRC_SRSR_REG(SRC_BASE_PTR)
#define SRC_SISR                                 SRC_SISR_REG(SRC_BASE_PTR)
#define SRC_SIMR                                 SRC_SIMR_REG(SRC_BASE_PTR)
#define SRC_SBMR2                                SRC_SBMR2_REG(SRC_BASE_PTR)
#define SRC_GPR1                                 SRC_GPR1_REG(SRC_BASE_PTR)
#define SRC_GPR2                                 SRC_GPR2_REG(SRC_BASE_PTR)
#define SRC_GPR3                                 SRC_GPR3_REG(SRC_BASE_PTR)
#define SRC_GPR4                                 SRC_GPR4_REG(SRC_BASE_PTR)
#define SRC_GPR5                                 SRC_GPR5_REG(SRC_BASE_PTR)
#define SRC_GPR6                                 SRC_GPR6_REG(SRC_BASE_PTR)
#define SRC_GPR7                                 SRC_GPR7_REG(SRC_BASE_PTR)
#define SRC_GPR8                                 SRC_GPR8_REG(SRC_BASE_PTR)
#define SRC_GPR9                                 SRC_GPR9_REG(SRC_BASE_PTR)
#define SRC_GPR10                                SRC_GPR10_REG(SRC_BASE_PTR)
#define SRC_DDRC_RCR                             SRC_DDRC_RCR_REG(SRC_BASE_PTR)

/*!
 * @}
 */ /* end of group SRC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group SRC_Peripheral */


/* ----------------------------------------------------------------------------
   -- TEMPMON
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup TEMPMON_Peripheral TEMPMON
 * @{
 */

/** TEMPMON - Peripheral register structure */
typedef struct TEMPMON_MemMap {
  uint32_t HW_ANADIG_TEMPSENSE0;                   /**< Anadig Tempsensor Control Register 0, offset: 0x0 */
  uint32_t HW_ANADIG_TEMPSENSE0_SET;               /**< Anadig Tempsensor Control Register 0, offset: 0x4 */
  uint32_t HW_ANADIG_TEMPSENSE0_CLR;               /**< Anadig Tempsensor Control Register 0, offset: 0x8 */
  uint32_t HW_ANADIG_TEMPSENSE0_TOG;               /**< Anadig Tempsensor Control Register 0, offset: 0xC */
  uint32_t HW_ANADIG_TEMPSENSE1;                   /**< Anadig Tempsensor Control Register 1, offset: 0x10 */
  uint32_t HW_ANADIG_TEMPSENSE1_SET;               /**< Anadig Tempsensor Control Register 1, offset: 0x14 */
  uint32_t HW_ANADIG_TEMPSENSE1_CLR;               /**< Anadig Tempsensor Control Register 1, offset: 0x18 */
  uint32_t HW_ANADIG_TEMPSENSE1_TOG;               /**< Anadig Tempsensor Control Register 1, offset: 0x1C */
  uint32_t HW_ANADIG_TEMPSENSE_TRIM;               /**< Anadig Tempsensor Trim Control Register, offset: 0x20 */
  uint32_t HW_ANADIG_TEMPSENSE_TRIM_SET;           /**< Anadig Tempsensor Trim Control Register, offset: 0x24 */
  uint32_t HW_ANADIG_TEMPSENSE_TRIM_CLR;           /**< Anadig Tempsensor Trim Control Register, offset: 0x28 */
  uint32_t HW_ANADIG_TEMPSENSE_TRIM_TOG;           /**< Anadig Tempsensor Trim Control Register, offset: 0x2C */
} volatile *TEMPMON_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- TEMPMON - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup TEMPMON_Register_Accessor_Macros TEMPMON - Register accessor macros
 * @{
 */


/* TEMPMON - Register accessors */
#define TEMPMON_HW_ANADIG_TEMPSENSE0_REG(base)   ((base)->HW_ANADIG_TEMPSENSE0)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_REG(base) ((base)->HW_ANADIG_TEMPSENSE0_SET)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_REG(base) ((base)->HW_ANADIG_TEMPSENSE0_CLR)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_REG(base) ((base)->HW_ANADIG_TEMPSENSE0_TOG)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_REG(base)   ((base)->HW_ANADIG_TEMPSENSE1)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_REG(base) ((base)->HW_ANADIG_TEMPSENSE1_SET)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_REG(base) ((base)->HW_ANADIG_TEMPSENSE1_CLR)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_REG(base) ((base)->HW_ANADIG_TEMPSENSE1_TOG)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_REG(base) ((base)->HW_ANADIG_TEMPSENSE_TRIM)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_REG(base) ((base)->HW_ANADIG_TEMPSENSE_TRIM_SET)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_REG(base) ((base)->HW_ANADIG_TEMPSENSE_TRIM_CLR)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_REG(base) ((base)->HW_ANADIG_TEMPSENSE_TRIM_TOG)

/*!
 * @}
 */ /* end of group TEMPMON_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- TEMPMON Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup TEMPMON_Register_Masks TEMPMON Register Masks
 * @{
 */

/*! @name HW_ANADIG_TEMPSENSE0 - Anadig Tempsensor Control Register 0 */
#define TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE_MASK (0x1FFU)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE_MASK (0x3FE00U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE_SHIFT (9U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE_MASK (0x7FC0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE_SHIFT (18U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1_MASK  (0xF8000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1_SHIFT (27U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1(x)    (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1_MASK)

/*! @name HW_ANADIG_TEMPSENSE0_SET - Anadig Tempsensor Control Register 0 */
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_LOW_ALARM_VALUE_MASK (0x1FFU)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_LOW_ALARM_VALUE_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_LOW_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_SET_LOW_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_SET_LOW_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_HIGH_ALARM_VALUE_MASK (0x3FE00U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_HIGH_ALARM_VALUE_SHIFT (9U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_HIGH_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_SET_HIGH_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_SET_HIGH_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_PANIC_ALARM_VALUE_MASK (0x7FC0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_PANIC_ALARM_VALUE_SHIFT (18U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_PANIC_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_SET_PANIC_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_SET_PANIC_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_RSVD1_MASK (0xF8000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_RSVD1_SHIFT (27U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_SET_RSVD1_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_SET_RSVD1_MASK)

/*! @name HW_ANADIG_TEMPSENSE0_CLR - Anadig Tempsensor Control Register 0 */
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_LOW_ALARM_VALUE_MASK (0x1FFU)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_LOW_ALARM_VALUE_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_LOW_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_LOW_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_LOW_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_HIGH_ALARM_VALUE_MASK (0x3FE00U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_HIGH_ALARM_VALUE_SHIFT (9U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_HIGH_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_HIGH_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_HIGH_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_PANIC_ALARM_VALUE_MASK (0x7FC0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_PANIC_ALARM_VALUE_SHIFT (18U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_PANIC_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_PANIC_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_PANIC_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_RSVD1_MASK (0xF8000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_RSVD1_SHIFT (27U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_RSVD1_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_RSVD1_MASK)

/*! @name HW_ANADIG_TEMPSENSE0_TOG - Anadig Tempsensor Control Register 0 */
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_LOW_ALARM_VALUE_MASK (0x1FFU)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_LOW_ALARM_VALUE_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_LOW_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_LOW_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_LOW_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_HIGH_ALARM_VALUE_MASK (0x3FE00U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_HIGH_ALARM_VALUE_SHIFT (9U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_HIGH_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_HIGH_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_HIGH_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_PANIC_ALARM_VALUE_MASK (0x7FC0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_PANIC_ALARM_VALUE_SHIFT (18U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_PANIC_ALARM_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_PANIC_ALARM_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_PANIC_ALARM_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_RSVD1_MASK (0xF8000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_RSVD1_SHIFT (27U)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_RSVD1_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_RSVD1_MASK)

/*! @name HW_ANADIG_TEMPSENSE1 - Anadig Tempsensor Control Register 1 */
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE_MASK (0x1FFU)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN_MASK (0x200U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN_SHIFT (9U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP_MASK (0x400U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP_SHIFT (10U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED_MASK (0x800U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED_SHIFT (11U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0_MASK  (0xF000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0_SHIFT (12U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0(x)    (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ_MASK (0xFFFF0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ_SHIFT (16U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ_MASK)

/*! @name HW_ANADIG_TEMPSENSE1_SET - Anadig Tempsensor Control Register 1 */
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_TEMP_VALUE_MASK (0x1FFU)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_TEMP_VALUE_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_TEMP_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_SET_TEMP_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_SET_TEMP_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_POWER_DOWN_MASK (0x200U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_POWER_DOWN_SHIFT (9U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_MEASURE_TEMP_MASK (0x400U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_MEASURE_TEMP_SHIFT (10U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_FINISHED_MASK (0x800U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_FINISHED_SHIFT (11U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_RSVD0_MASK (0xF000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_RSVD0_SHIFT (12U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_SET_RSVD0_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_SET_RSVD0_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_MEASURE_FREQ_MASK (0xFFFF0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_MEASURE_FREQ_SHIFT (16U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET_MEASURE_FREQ(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_SET_MEASURE_FREQ_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_SET_MEASURE_FREQ_MASK)

/*! @name HW_ANADIG_TEMPSENSE1_CLR - Anadig Tempsensor Control Register 1 */
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_TEMP_VALUE_MASK (0x1FFU)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_TEMP_VALUE_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_TEMP_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_TEMP_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_TEMP_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_POWER_DOWN_MASK (0x200U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_POWER_DOWN_SHIFT (9U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_MEASURE_TEMP_MASK (0x400U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_MEASURE_TEMP_SHIFT (10U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_FINISHED_MASK (0x800U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_FINISHED_SHIFT (11U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_RSVD0_MASK (0xF000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_RSVD0_SHIFT (12U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_RSVD0_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_RSVD0_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_MEASURE_FREQ_MASK (0xFFFF0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_MEASURE_FREQ_SHIFT (16U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_MEASURE_FREQ(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_MEASURE_FREQ_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_MEASURE_FREQ_MASK)

/*! @name HW_ANADIG_TEMPSENSE1_TOG - Anadig Tempsensor Control Register 1 */
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_TEMP_VALUE_MASK (0x1FFU)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_TEMP_VALUE_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_TEMP_VALUE(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_TEMP_VALUE_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_TEMP_VALUE_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_POWER_DOWN_MASK (0x200U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_POWER_DOWN_SHIFT (9U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_MEASURE_TEMP_MASK (0x400U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_MEASURE_TEMP_SHIFT (10U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_FINISHED_MASK (0x800U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_FINISHED_SHIFT (11U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_RSVD0_MASK (0xF000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_RSVD0_SHIFT (12U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_RSVD0_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_RSVD0_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_MEASURE_FREQ_MASK (0xFFFF0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_MEASURE_FREQ_SHIFT (16U)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_MEASURE_FREQ(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_MEASURE_FREQ_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_MEASURE_FREQ_MASK)

/*! @name HW_ANADIG_TEMPSENSE_TRIM - Anadig Tempsensor Trim Control Register */
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL_MASK (0x1FU)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0_MASK (0x60U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0_SHIFT (5U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ_MASK (0x80U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ_SHIFT (7U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL_MASK (0x1FF00U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL_SHIFT (8U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1_MASK (0xE0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1_SHIFT (17U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL_MASK (0xF00000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL_SHIFT (20U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2_MASK (0x1F000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2_SHIFT (24U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR_MASK (0xE0000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR_SHIFT (29U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR_MASK)

/*! @name HW_ANADIG_TEMPSENSE_TRIM_SET - Anadig Tempsensor Trim Control Register */
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_VREF_SEL_MASK (0x1FU)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_VREF_SEL_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_VREF_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_VREF_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_VREF_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD0_MASK (0x60U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD0_SHIFT (5U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD0_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD0_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_EN_READ_MASK (0x80U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_EN_READ_SHIFT (7U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_VREF_VBE_SEL_MASK (0x1FF00U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_VREF_VBE_SEL_SHIFT (8U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_VREF_VBE_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_VREF_VBE_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_VREF_VBE_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD1_MASK (0xE0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD1_SHIFT (17U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD1_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD1_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_SLOPE_SEL_MASK (0xF00000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_SLOPE_SEL_SHIFT (20U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_SLOPE_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_SLOPE_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_BUF_SLOPE_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD2_MASK (0x1F000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD2_SHIFT (24U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD2_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_RSVD2_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_MUX_ADDR_MASK (0xE0000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_MUX_ADDR_SHIFT (29U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_MUX_ADDR(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_MUX_ADDR_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_T_MUX_ADDR_MASK)

/*! @name HW_ANADIG_TEMPSENSE_TRIM_CLR - Anadig Tempsensor Trim Control Register */
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_VREF_SEL_MASK (0x1FU)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_VREF_SEL_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_VREF_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_VREF_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_VREF_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD0_MASK (0x60U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD0_SHIFT (5U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD0_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD0_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_EN_READ_MASK (0x80U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_EN_READ_SHIFT (7U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_VREF_VBE_SEL_MASK (0x1FF00U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_VREF_VBE_SEL_SHIFT (8U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_VREF_VBE_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_VREF_VBE_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_VREF_VBE_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD1_MASK (0xE0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD1_SHIFT (17U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD1_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD1_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_SLOPE_SEL_MASK (0xF00000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_SLOPE_SEL_SHIFT (20U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_SLOPE_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_SLOPE_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_BUF_SLOPE_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD2_MASK (0x1F000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD2_SHIFT (24U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD2_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_RSVD2_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_MUX_ADDR_MASK (0xE0000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_MUX_ADDR_SHIFT (29U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_MUX_ADDR(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_MUX_ADDR_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_T_MUX_ADDR_MASK)

/*! @name HW_ANADIG_TEMPSENSE_TRIM_TOG - Anadig Tempsensor Trim Control Register */
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_VREF_SEL_MASK (0x1FU)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_VREF_SEL_SHIFT (0U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_VREF_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_VREF_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_VREF_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD0_MASK (0x60U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD0_SHIFT (5U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD0(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD0_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD0_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_EN_READ_MASK (0x80U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_EN_READ_SHIFT (7U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_VREF_VBE_SEL_MASK (0x1FF00U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_VREF_VBE_SEL_SHIFT (8U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_VREF_VBE_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_VREF_VBE_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_VREF_VBE_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD1_MASK (0xE0000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD1_SHIFT (17U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD1(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD1_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD1_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_SLOPE_SEL_MASK (0xF00000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_SLOPE_SEL_SHIFT (20U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_SLOPE_SEL(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_SLOPE_SEL_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_BUF_SLOPE_SEL_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD2_MASK (0x1F000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD2_SHIFT (24U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD2(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD2_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_RSVD2_MASK)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_MUX_ADDR_MASK (0xE0000000U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_MUX_ADDR_SHIFT (29U)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_MUX_ADDR(x) (((uint32_t)(((uint32_t)(x)) << TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_MUX_ADDR_SHIFT)) & TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_T_MUX_ADDR_MASK)


/*!
 * @}
 */ /* end of group TEMPMON_Register_Masks */


/* TEMPMON - Peripheral instance base addresses */
/** Peripheral TEMPMON base pointer */
#define TEMPMON_BASE_PTR                         ((TEMPMON_MemMapPtr)0x30360300u)
/** Array initializer of TEMPMON peripheral base pointers */
#define TEMPMON_BASE_PTRS                        { TEMPMON_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- TEMPMON - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup TEMPMON_Register_Accessor_Macros TEMPMON - Register accessor macros
 * @{
 */


/* TEMPMON - Register instance definitions */
/* TEMPMON */
#define TEMPMON_HW_ANADIG_TEMPSENSE0             TEMPMON_HW_ANADIG_TEMPSENSE0_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_SET         TEMPMON_HW_ANADIG_TEMPSENSE0_SET_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_CLR         TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE0_TOG         TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE1             TEMPMON_HW_ANADIG_TEMPSENSE1_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_SET         TEMPMON_HW_ANADIG_TEMPSENSE1_SET_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_CLR         TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE1_TOG         TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM         TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET     TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR     TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_REG(TEMPMON_BASE_PTR)
#define TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG     TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_REG(TEMPMON_BASE_PTR)

/*!
 * @}
 */ /* end of group TEMPMON_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group TEMPMON_Peripheral */


/* ----------------------------------------------------------------------------
   -- UART
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup UART_Peripheral UART
 * @{
 */

/** UART - Peripheral register structure */
typedef struct UART_MemMap {
  uint32_t URXD;                                   /**< UART Receiver Register, offset: 0x0 */
  uint8_t RESERVED_0[60];
  uint32_t UTXD;                                   /**< UART Transmitter Register, offset: 0x40 */
  uint8_t RESERVED_1[60];
  uint32_t UCR1;                                   /**< UART Control Register 1, offset: 0x80 */
  uint32_t UCR2;                                   /**< UART Control Register 2, offset: 0x84 */
  uint32_t UCR3;                                   /**< UART Control Register 3, offset: 0x88 */
  uint32_t UCR4;                                   /**< UART Control Register 4, offset: 0x8C */
  uint32_t UFCR;                                   /**< UART FIFO Control Register, offset: 0x90 */
  uint32_t USR1;                                   /**< UART Status Register 1, offset: 0x94 */
  uint32_t USR2;                                   /**< UART Status Register 2, offset: 0x98 */
  uint32_t UESC;                                   /**< UART Escape Character Register, offset: 0x9C */
  uint32_t UTIM;                                   /**< UART Escape Timer Register, offset: 0xA0 */
  uint32_t UBIR;                                   /**< UART BRM Incremental Register, offset: 0xA4 */
  uint32_t UBMR;                                   /**< UART BRM Modulator Register, offset: 0xA8 */
  uint32_t UBRC;                                   /**< UART Baud Rate Count Register, offset: 0xAC */
  uint32_t ONEMS;                                  /**< UART One Millisecond Register, offset: 0xB0 */
  uint32_t UTS;                                    /**< UART Test Register, offset: 0xB4 */
  uint32_t UMCR;                                   /**< UART RS-485 Mode Control Register, offset: 0xB8 */
} volatile *UART_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- UART - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup UART_Register_Accessor_Macros UART - Register accessor macros
 * @{
 */


/* UART - Register accessors */
#define UART_URXD_REG(base)                      ((base)->URXD)
#define UART_UTXD_REG(base)                      ((base)->UTXD)
#define UART_UCR1_REG(base)                      ((base)->UCR1)
#define UART_UCR2_REG(base)                      ((base)->UCR2)
#define UART_UCR3_REG(base)                      ((base)->UCR3)
#define UART_UCR4_REG(base)                      ((base)->UCR4)
#define UART_UFCR_REG(base)                      ((base)->UFCR)
#define UART_USR1_REG(base)                      ((base)->USR1)
#define UART_USR2_REG(base)                      ((base)->USR2)
#define UART_UESC_REG(base)                      ((base)->UESC)
#define UART_UTIM_REG(base)                      ((base)->UTIM)
#define UART_UBIR_REG(base)                      ((base)->UBIR)
#define UART_UBMR_REG(base)                      ((base)->UBMR)
#define UART_UBRC_REG(base)                      ((base)->UBRC)
#define UART_ONEMS_REG(base)                     ((base)->ONEMS)
#define UART_UTS_REG(base)                       ((base)->UTS)
#define UART_UMCR_REG(base)                      ((base)->UMCR)

/*!
 * @}
 */ /* end of group UART_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- UART Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup UART_Register_Masks UART Register Masks
 * @{
 */

/*! @name URXD - UART Receiver Register */
#define UART_URXD_RX_DATA_MASK                   (0xFFU)
#define UART_URXD_RX_DATA_SHIFT                  (0U)
#define UART_URXD_RX_DATA(x)                     (((uint32_t)(((uint32_t)(x)) << UART_URXD_RX_DATA_SHIFT)) & UART_URXD_RX_DATA_MASK)
#define UART_URXD_PRERR_MASK                     (0x400U)
#define UART_URXD_PRERR_SHIFT                    (10U)
#define UART_URXD_BRK_MASK                       (0x800U)
#define UART_URXD_BRK_SHIFT                      (11U)
#define UART_URXD_FRMERR_MASK                    (0x1000U)
#define UART_URXD_FRMERR_SHIFT                   (12U)
#define UART_URXD_OVRRUN_MASK                    (0x2000U)
#define UART_URXD_OVRRUN_SHIFT                   (13U)
#define UART_URXD_ERR_MASK                       (0x4000U)
#define UART_URXD_ERR_SHIFT                      (14U)
#define UART_URXD_CHARRDY_MASK                   (0x8000U)
#define UART_URXD_CHARRDY_SHIFT                  (15U)

/*! @name UTXD - UART Transmitter Register */
#define UART_UTXD_TX_DATA_MASK                   (0xFFU)
#define UART_UTXD_TX_DATA_SHIFT                  (0U)
#define UART_UTXD_TX_DATA(x)                     (((uint32_t)(((uint32_t)(x)) << UART_UTXD_TX_DATA_SHIFT)) & UART_UTXD_TX_DATA_MASK)

/*! @name UCR1 - UART Control Register 1 */
#define UART_UCR1_UARTEN_MASK                    (0x1U)
#define UART_UCR1_UARTEN_SHIFT                   (0U)
#define UART_UCR1_DOZE_MASK                      (0x2U)
#define UART_UCR1_DOZE_SHIFT                     (1U)
#define UART_UCR1_ATDMAEN_MASK                   (0x4U)
#define UART_UCR1_ATDMAEN_SHIFT                  (2U)
#define UART_UCR1_TXDMAEN_MASK                   (0x8U)
#define UART_UCR1_TXDMAEN_SHIFT                  (3U)
#define UART_UCR1_SNDBRK_MASK                    (0x10U)
#define UART_UCR1_SNDBRK_SHIFT                   (4U)
#define UART_UCR1_RTSDEN_MASK                    (0x20U)
#define UART_UCR1_RTSDEN_SHIFT                   (5U)
#define UART_UCR1_TXMPTYEN_MASK                  (0x40U)
#define UART_UCR1_TXMPTYEN_SHIFT                 (6U)
#define UART_UCR1_IREN_MASK                      (0x80U)
#define UART_UCR1_IREN_SHIFT                     (7U)
#define UART_UCR1_RXDMAEN_MASK                   (0x100U)
#define UART_UCR1_RXDMAEN_SHIFT                  (8U)
#define UART_UCR1_RRDYEN_MASK                    (0x200U)
#define UART_UCR1_RRDYEN_SHIFT                   (9U)
#define UART_UCR1_ICD_MASK                       (0xC00U)
#define UART_UCR1_ICD_SHIFT                      (10U)
#define UART_UCR1_ICD(x)                         (((uint32_t)(((uint32_t)(x)) << UART_UCR1_ICD_SHIFT)) & UART_UCR1_ICD_MASK)
#define UART_UCR1_IDEN_MASK                      (0x1000U)
#define UART_UCR1_IDEN_SHIFT                     (12U)
#define UART_UCR1_TRDYEN_MASK                    (0x2000U)
#define UART_UCR1_TRDYEN_SHIFT                   (13U)
#define UART_UCR1_ADBR_MASK                      (0x4000U)
#define UART_UCR1_ADBR_SHIFT                     (14U)
#define UART_UCR1_ADEN_MASK                      (0x8000U)
#define UART_UCR1_ADEN_SHIFT                     (15U)

/*! @name UCR2 - UART Control Register 2 */
#define UART_UCR2_SRST_MASK                      (0x1U)
#define UART_UCR2_SRST_SHIFT                     (0U)
#define UART_UCR2_RXEN_MASK                      (0x2U)
#define UART_UCR2_RXEN_SHIFT                     (1U)
#define UART_UCR2_TXEN_MASK                      (0x4U)
#define UART_UCR2_TXEN_SHIFT                     (2U)
#define UART_UCR2_ATEN_MASK                      (0x8U)
#define UART_UCR2_ATEN_SHIFT                     (3U)
#define UART_UCR2_RTSEN_MASK                     (0x10U)
#define UART_UCR2_RTSEN_SHIFT                    (4U)
#define UART_UCR2_WS_MASK                        (0x20U)
#define UART_UCR2_WS_SHIFT                       (5U)
#define UART_UCR2_STPB_MASK                      (0x40U)
#define UART_UCR2_STPB_SHIFT                     (6U)
#define UART_UCR2_PROE_MASK                      (0x80U)
#define UART_UCR2_PROE_SHIFT                     (7U)
#define UART_UCR2_PREN_MASK                      (0x100U)
#define UART_UCR2_PREN_SHIFT                     (8U)
#define UART_UCR2_RTEC_MASK                      (0x600U)
#define UART_UCR2_RTEC_SHIFT                     (9U)
#define UART_UCR2_RTEC(x)                        (((uint32_t)(((uint32_t)(x)) << UART_UCR2_RTEC_SHIFT)) & UART_UCR2_RTEC_MASK)
#define UART_UCR2_ESCEN_MASK                     (0x800U)
#define UART_UCR2_ESCEN_SHIFT                    (11U)
#define UART_UCR2_CTS_MASK                       (0x1000U)
#define UART_UCR2_CTS_SHIFT                      (12U)
#define UART_UCR2_CTSC_MASK                      (0x2000U)
#define UART_UCR2_CTSC_SHIFT                     (13U)
#define UART_UCR2_IRTS_MASK                      (0x4000U)
#define UART_UCR2_IRTS_SHIFT                     (14U)
#define UART_UCR2_ESCI_MASK                      (0x8000U)
#define UART_UCR2_ESCI_SHIFT                     (15U)

/*! @name UCR3 - UART Control Register 3 */
#define UART_UCR3_ACIEN_MASK                     (0x1U)
#define UART_UCR3_ACIEN_SHIFT                    (0U)
#define UART_UCR3_INVT_MASK                      (0x2U)
#define UART_UCR3_INVT_SHIFT                     (1U)
#define UART_UCR3_RXDMUXSEL_MASK                 (0x4U)
#define UART_UCR3_RXDMUXSEL_SHIFT                (2U)
#define UART_UCR3_DTRDEN_MASK                    (0x8U)
#define UART_UCR3_DTRDEN_SHIFT                   (3U)
#define UART_UCR3_AWAKEN_MASK                    (0x10U)
#define UART_UCR3_AWAKEN_SHIFT                   (4U)
#define UART_UCR3_AIRINTEN_MASK                  (0x20U)
#define UART_UCR3_AIRINTEN_SHIFT                 (5U)
#define UART_UCR3_RXDSEN_MASK                    (0x40U)
#define UART_UCR3_RXDSEN_SHIFT                   (6U)
#define UART_UCR3_ADNIMP_MASK                    (0x80U)
#define UART_UCR3_ADNIMP_SHIFT                   (7U)
#define UART_UCR3_RI_MASK                        (0x100U)
#define UART_UCR3_RI_SHIFT                       (8U)
#define UART_UCR3_DCD_MASK                       (0x200U)
#define UART_UCR3_DCD_SHIFT                      (9U)
#define UART_UCR3_DSR_MASK                       (0x400U)
#define UART_UCR3_DSR_SHIFT                      (10U)
#define UART_UCR3_FRAERREN_MASK                  (0x800U)
#define UART_UCR3_FRAERREN_SHIFT                 (11U)
#define UART_UCR3_PARERREN_MASK                  (0x1000U)
#define UART_UCR3_PARERREN_SHIFT                 (12U)
#define UART_UCR3_DTREN_MASK                     (0x2000U)
#define UART_UCR3_DTREN_SHIFT                    (13U)
#define UART_UCR3_DPEC_MASK                      (0xC000U)
#define UART_UCR3_DPEC_SHIFT                     (14U)
#define UART_UCR3_DPEC(x)                        (((uint32_t)(((uint32_t)(x)) << UART_UCR3_DPEC_SHIFT)) & UART_UCR3_DPEC_MASK)

/*! @name UCR4 - UART Control Register 4 */
#define UART_UCR4_DREN_MASK                      (0x1U)
#define UART_UCR4_DREN_SHIFT                     (0U)
#define UART_UCR4_OREN_MASK                      (0x2U)
#define UART_UCR4_OREN_SHIFT                     (1U)
#define UART_UCR4_BKEN_MASK                      (0x4U)
#define UART_UCR4_BKEN_SHIFT                     (2U)
#define UART_UCR4_TCEN_MASK                      (0x8U)
#define UART_UCR4_TCEN_SHIFT                     (3U)
#define UART_UCR4_LPBYP_MASK                     (0x10U)
#define UART_UCR4_LPBYP_SHIFT                    (4U)
#define UART_UCR4_IRSC_MASK                      (0x20U)
#define UART_UCR4_IRSC_SHIFT                     (5U)
#define UART_UCR4_IDDMAEN_MASK                   (0x40U)
#define UART_UCR4_IDDMAEN_SHIFT                  (6U)
#define UART_UCR4_WKEN_MASK                      (0x80U)
#define UART_UCR4_WKEN_SHIFT                     (7U)
#define UART_UCR4_ENIRI_MASK                     (0x100U)
#define UART_UCR4_ENIRI_SHIFT                    (8U)
#define UART_UCR4_INVR_MASK                      (0x200U)
#define UART_UCR4_INVR_SHIFT                     (9U)
#define UART_UCR4_CTSTL_MASK                     (0xFC00U)
#define UART_UCR4_CTSTL_SHIFT                    (10U)
#define UART_UCR4_CTSTL(x)                       (((uint32_t)(((uint32_t)(x)) << UART_UCR4_CTSTL_SHIFT)) & UART_UCR4_CTSTL_MASK)

/*! @name UFCR - UART FIFO Control Register */
#define UART_UFCR_RXTL_MASK                      (0x3FU)
#define UART_UFCR_RXTL_SHIFT                     (0U)
#define UART_UFCR_RXTL(x)                        (((uint32_t)(((uint32_t)(x)) << UART_UFCR_RXTL_SHIFT)) & UART_UFCR_RXTL_MASK)
#define UART_UFCR_DCEDTE_MASK                    (0x40U)
#define UART_UFCR_DCEDTE_SHIFT                   (6U)
#define UART_UFCR_RFDIV_MASK                     (0x380U)
#define UART_UFCR_RFDIV_SHIFT                    (7U)
#define UART_UFCR_RFDIV(x)                       (((uint32_t)(((uint32_t)(x)) << UART_UFCR_RFDIV_SHIFT)) & UART_UFCR_RFDIV_MASK)
#define UART_UFCR_TXTL_MASK                      (0xFC00U)
#define UART_UFCR_TXTL_SHIFT                     (10U)
#define UART_UFCR_TXTL(x)                        (((uint32_t)(((uint32_t)(x)) << UART_UFCR_TXTL_SHIFT)) & UART_UFCR_TXTL_MASK)

/*! @name USR1 - UART Status Register 1 */
#define UART_USR1_SAD_MASK                       (0x8U)
#define UART_USR1_SAD_SHIFT                      (3U)
#define UART_USR1_AWAKE_MASK                     (0x10U)
#define UART_USR1_AWAKE_SHIFT                    (4U)
#define UART_USR1_AIRINT_MASK                    (0x20U)
#define UART_USR1_AIRINT_SHIFT                   (5U)
#define UART_USR1_RXDS_MASK                      (0x40U)
#define UART_USR1_RXDS_SHIFT                     (6U)
#define UART_USR1_DTRD_MASK                      (0x80U)
#define UART_USR1_DTRD_SHIFT                     (7U)
#define UART_USR1_AGTIM_MASK                     (0x100U)
#define UART_USR1_AGTIM_SHIFT                    (8U)
#define UART_USR1_RRDY_MASK                      (0x200U)
#define UART_USR1_RRDY_SHIFT                     (9U)
#define UART_USR1_FRAMERR_MASK                   (0x400U)
#define UART_USR1_FRAMERR_SHIFT                  (10U)
#define UART_USR1_ESCF_MASK                      (0x800U)
#define UART_USR1_ESCF_SHIFT                     (11U)
#define UART_USR1_RTSD_MASK                      (0x1000U)
#define UART_USR1_RTSD_SHIFT                     (12U)
#define UART_USR1_TRDY_MASK                      (0x2000U)
#define UART_USR1_TRDY_SHIFT                     (13U)
#define UART_USR1_RTSS_MASK                      (0x4000U)
#define UART_USR1_RTSS_SHIFT                     (14U)
#define UART_USR1_PARITYERR_MASK                 (0x8000U)
#define UART_USR1_PARITYERR_SHIFT                (15U)

/*! @name USR2 - UART Status Register 2 */
#define UART_USR2_RDR_MASK                       (0x1U)
#define UART_USR2_RDR_SHIFT                      (0U)
#define UART_USR2_ORE_MASK                       (0x2U)
#define UART_USR2_ORE_SHIFT                      (1U)
#define UART_USR2_BRCD_MASK                      (0x4U)
#define UART_USR2_BRCD_SHIFT                     (2U)
#define UART_USR2_TXDC_MASK                      (0x8U)
#define UART_USR2_TXDC_SHIFT                     (3U)
#define UART_USR2_RTSF_MASK                      (0x10U)
#define UART_USR2_RTSF_SHIFT                     (4U)
#define UART_USR2_DCDIN_MASK                     (0x20U)
#define UART_USR2_DCDIN_SHIFT                    (5U)
#define UART_USR2_DCDDELT_MASK                   (0x40U)
#define UART_USR2_DCDDELT_SHIFT                  (6U)
#define UART_USR2_WAKE_MASK                      (0x80U)
#define UART_USR2_WAKE_SHIFT                     (7U)
#define UART_USR2_IRINT_MASK                     (0x100U)
#define UART_USR2_IRINT_SHIFT                    (8U)
#define UART_USR2_RIIN_MASK                      (0x200U)
#define UART_USR2_RIIN_SHIFT                     (9U)
#define UART_USR2_RIDELT_MASK                    (0x400U)
#define UART_USR2_RIDELT_SHIFT                   (10U)
#define UART_USR2_ACST_MASK                      (0x800U)
#define UART_USR2_ACST_SHIFT                     (11U)
#define UART_USR2_IDLE_MASK                      (0x1000U)
#define UART_USR2_IDLE_SHIFT                     (12U)
#define UART_USR2_DTRF_MASK                      (0x2000U)
#define UART_USR2_DTRF_SHIFT                     (13U)
#define UART_USR2_TXFE_MASK                      (0x4000U)
#define UART_USR2_TXFE_SHIFT                     (14U)
#define UART_USR2_ADET_MASK                      (0x8000U)
#define UART_USR2_ADET_SHIFT                     (15U)

/*! @name UESC - UART Escape Character Register */
#define UART_UESC_ESC_CHAR_MASK                  (0xFFU)
#define UART_UESC_ESC_CHAR_SHIFT                 (0U)
#define UART_UESC_ESC_CHAR(x)                    (((uint32_t)(((uint32_t)(x)) << UART_UESC_ESC_CHAR_SHIFT)) & UART_UESC_ESC_CHAR_MASK)

/*! @name UTIM - UART Escape Timer Register */
#define UART_UTIM_TIM_MASK                       (0xFFFU)
#define UART_UTIM_TIM_SHIFT                      (0U)
#define UART_UTIM_TIM(x)                         (((uint32_t)(((uint32_t)(x)) << UART_UTIM_TIM_SHIFT)) & UART_UTIM_TIM_MASK)

/*! @name UBIR - UART BRM Incremental Register */
#define UART_UBIR_INC_MASK                       (0xFFFFU)
#define UART_UBIR_INC_SHIFT                      (0U)
#define UART_UBIR_INC(x)                         (((uint32_t)(((uint32_t)(x)) << UART_UBIR_INC_SHIFT)) & UART_UBIR_INC_MASK)

/*! @name UBMR - UART BRM Modulator Register */
#define UART_UBMR_MOD_MASK                       (0xFFFFU)
#define UART_UBMR_MOD_SHIFT                      (0U)
#define UART_UBMR_MOD(x)                         (((uint32_t)(((uint32_t)(x)) << UART_UBMR_MOD_SHIFT)) & UART_UBMR_MOD_MASK)

/*! @name UBRC - UART Baud Rate Count Register */
#define UART_UBRC_BCNT_MASK                      (0xFFFFU)
#define UART_UBRC_BCNT_SHIFT                     (0U)
#define UART_UBRC_BCNT(x)                        (((uint32_t)(((uint32_t)(x)) << UART_UBRC_BCNT_SHIFT)) & UART_UBRC_BCNT_MASK)

/*! @name ONEMS - UART One Millisecond Register */
#define UART_ONEMS_ONEMS_MASK                    (0xFFFFFFU)
#define UART_ONEMS_ONEMS_SHIFT                   (0U)
#define UART_ONEMS_ONEMS(x)                      (((uint32_t)(((uint32_t)(x)) << UART_ONEMS_ONEMS_SHIFT)) & UART_ONEMS_ONEMS_MASK)

/*! @name UTS - UART Test Register */
#define UART_UTS_SOFTRST_MASK                    (0x1U)
#define UART_UTS_SOFTRST_SHIFT                   (0U)
#define UART_UTS_RXFULL_MASK                     (0x8U)
#define UART_UTS_RXFULL_SHIFT                    (3U)
#define UART_UTS_TXFULL_MASK                     (0x10U)
#define UART_UTS_TXFULL_SHIFT                    (4U)
#define UART_UTS_RXEMPTY_MASK                    (0x20U)
#define UART_UTS_RXEMPTY_SHIFT                   (5U)
#define UART_UTS_TXEMPTY_MASK                    (0x40U)
#define UART_UTS_TXEMPTY_SHIFT                   (6U)
#define UART_UTS_RXDBG_MASK                      (0x200U)
#define UART_UTS_RXDBG_SHIFT                     (9U)
#define UART_UTS_LOOPIR_MASK                     (0x400U)
#define UART_UTS_LOOPIR_SHIFT                    (10U)
#define UART_UTS_DBGEN_MASK                      (0x800U)
#define UART_UTS_DBGEN_SHIFT                     (11U)
#define UART_UTS_LOOP_MASK                       (0x1000U)
#define UART_UTS_LOOP_SHIFT                      (12U)
#define UART_UTS_FRCPERR_MASK                    (0x2000U)
#define UART_UTS_FRCPERR_SHIFT                   (13U)

/*! @name UMCR - UART RS-485 Mode Control Register */
#define UART_UMCR_MDEN_MASK                      (0x1U)
#define UART_UMCR_MDEN_SHIFT                     (0U)
#define UART_UMCR_SLAM_MASK                      (0x2U)
#define UART_UMCR_SLAM_SHIFT                     (1U)
#define UART_UMCR_TXB8_MASK                      (0x4U)
#define UART_UMCR_TXB8_SHIFT                     (2U)
#define UART_UMCR_SADEN_MASK                     (0x8U)
#define UART_UMCR_SADEN_SHIFT                    (3U)
#define UART_UMCR_SLADDR_MASK                    (0xFF00U)
#define UART_UMCR_SLADDR_SHIFT                   (8U)
#define UART_UMCR_SLADDR(x)                      (((uint32_t)(((uint32_t)(x)) << UART_UMCR_SLADDR_SHIFT)) & UART_UMCR_SLADDR_MASK)


/*!
 * @}
 */ /* end of group UART_Register_Masks */


/* UART - Peripheral instance base addresses */
/** Peripheral UART1 base pointer */
#define UART1_BASE_PTR                           ((UART_MemMapPtr)0x30860000u)
/** Peripheral UART2 base pointer */
#define UART2_BASE_PTR                           ((UART_MemMapPtr)0x30890000u)
/** Peripheral UART3 base pointer */
#define UART3_BASE_PTR                           ((UART_MemMapPtr)0x30880000u)
/** Peripheral UART4 base pointer */
#define UART4_BASE_PTR                           ((UART_MemMapPtr)0x30A60000u)
/** Peripheral UART5 base pointer */
#define UART5_BASE_PTR                           ((UART_MemMapPtr)0x30A70000u)
/** Peripheral UART6 base pointer */
#define UART6_BASE_PTR                           ((UART_MemMapPtr)0x30A80000u)
/** Peripheral UART7 base pointer */
#define UART7_BASE_PTR                           ((UART_MemMapPtr)0x30A90000u)
/** Array initializer of UART peripheral base pointers */
#define UART_BASE_PTRS                           { UART1_BASE_PTR, UART2_BASE_PTR, UART3_BASE_PTR, UART4_BASE_PTR, UART5_BASE_PTR, UART6_BASE_PTR, UART7_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- UART - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup UART_Register_Accessor_Macros UART - Register accessor macros
 * @{
 */


/* UART - Register instance definitions */
/* UART1 */
#define UART1_URXD                               UART_URXD_REG(UART1_BASE_PTR)
#define UART1_UTXD                               UART_UTXD_REG(UART1_BASE_PTR)
#define UART1_UCR1                               UART_UCR1_REG(UART1_BASE_PTR)
#define UART1_UCR2                               UART_UCR2_REG(UART1_BASE_PTR)
#define UART1_UCR3                               UART_UCR3_REG(UART1_BASE_PTR)
#define UART1_UCR4                               UART_UCR4_REG(UART1_BASE_PTR)
#define UART1_UFCR                               UART_UFCR_REG(UART1_BASE_PTR)
#define UART1_USR1                               UART_USR1_REG(UART1_BASE_PTR)
#define UART1_USR2                               UART_USR2_REG(UART1_BASE_PTR)
#define UART1_UESC                               UART_UESC_REG(UART1_BASE_PTR)
#define UART1_UTIM                               UART_UTIM_REG(UART1_BASE_PTR)
#define UART1_UBIR                               UART_UBIR_REG(UART1_BASE_PTR)
#define UART1_UBMR                               UART_UBMR_REG(UART1_BASE_PTR)
#define UART1_UBRC                               UART_UBRC_REG(UART1_BASE_PTR)
#define UART1_ONEMS                              UART_ONEMS_REG(UART1_BASE_PTR)
#define UART1_UTS                                UART_UTS_REG(UART1_BASE_PTR)
#define UART1_UMCR                               UART_UMCR_REG(UART1_BASE_PTR)
/* UART2 */
#define UART2_URXD                               UART_URXD_REG(UART2_BASE_PTR)
#define UART2_UTXD                               UART_UTXD_REG(UART2_BASE_PTR)
#define UART2_UCR1                               UART_UCR1_REG(UART2_BASE_PTR)
#define UART2_UCR2                               UART_UCR2_REG(UART2_BASE_PTR)
#define UART2_UCR3                               UART_UCR3_REG(UART2_BASE_PTR)
#define UART2_UCR4                               UART_UCR4_REG(UART2_BASE_PTR)
#define UART2_UFCR                               UART_UFCR_REG(UART2_BASE_PTR)
#define UART2_USR1                               UART_USR1_REG(UART2_BASE_PTR)
#define UART2_USR2                               UART_USR2_REG(UART2_BASE_PTR)
#define UART2_UESC                               UART_UESC_REG(UART2_BASE_PTR)
#define UART2_UTIM                               UART_UTIM_REG(UART2_BASE_PTR)
#define UART2_UBIR                               UART_UBIR_REG(UART2_BASE_PTR)
#define UART2_UBMR                               UART_UBMR_REG(UART2_BASE_PTR)
#define UART2_UBRC                               UART_UBRC_REG(UART2_BASE_PTR)
#define UART2_ONEMS                              UART_ONEMS_REG(UART2_BASE_PTR)
#define UART2_UTS                                UART_UTS_REG(UART2_BASE_PTR)
#define UART2_UMCR                               UART_UMCR_REG(UART2_BASE_PTR)
/* UART3 */
#define UART3_URXD                               UART_URXD_REG(UART3_BASE_PTR)
#define UART3_UTXD                               UART_UTXD_REG(UART3_BASE_PTR)
#define UART3_UCR1                               UART_UCR1_REG(UART3_BASE_PTR)
#define UART3_UCR2                               UART_UCR2_REG(UART3_BASE_PTR)
#define UART3_UCR3                               UART_UCR3_REG(UART3_BASE_PTR)
#define UART3_UCR4                               UART_UCR4_REG(UART3_BASE_PTR)
#define UART3_UFCR                               UART_UFCR_REG(UART3_BASE_PTR)
#define UART3_USR1                               UART_USR1_REG(UART3_BASE_PTR)
#define UART3_USR2                               UART_USR2_REG(UART3_BASE_PTR)
#define UART3_UESC                               UART_UESC_REG(UART3_BASE_PTR)
#define UART3_UTIM                               UART_UTIM_REG(UART3_BASE_PTR)
#define UART3_UBIR                               UART_UBIR_REG(UART3_BASE_PTR)
#define UART3_UBMR                               UART_UBMR_REG(UART3_BASE_PTR)
#define UART3_UBRC                               UART_UBRC_REG(UART3_BASE_PTR)
#define UART3_ONEMS                              UART_ONEMS_REG(UART3_BASE_PTR)
#define UART3_UTS                                UART_UTS_REG(UART3_BASE_PTR)
#define UART3_UMCR                               UART_UMCR_REG(UART3_BASE_PTR)
/* UART4 */
#define UART4_URXD                               UART_URXD_REG(UART4_BASE_PTR)
#define UART4_UTXD                               UART_UTXD_REG(UART4_BASE_PTR)
#define UART4_UCR1                               UART_UCR1_REG(UART4_BASE_PTR)
#define UART4_UCR2                               UART_UCR2_REG(UART4_BASE_PTR)
#define UART4_UCR3                               UART_UCR3_REG(UART4_BASE_PTR)
#define UART4_UCR4                               UART_UCR4_REG(UART4_BASE_PTR)
#define UART4_UFCR                               UART_UFCR_REG(UART4_BASE_PTR)
#define UART4_USR1                               UART_USR1_REG(UART4_BASE_PTR)
#define UART4_USR2                               UART_USR2_REG(UART4_BASE_PTR)
#define UART4_UESC                               UART_UESC_REG(UART4_BASE_PTR)
#define UART4_UTIM                               UART_UTIM_REG(UART4_BASE_PTR)
#define UART4_UBIR                               UART_UBIR_REG(UART4_BASE_PTR)
#define UART4_UBMR                               UART_UBMR_REG(UART4_BASE_PTR)
#define UART4_UBRC                               UART_UBRC_REG(UART4_BASE_PTR)
#define UART4_ONEMS                              UART_ONEMS_REG(UART4_BASE_PTR)
#define UART4_UTS                                UART_UTS_REG(UART4_BASE_PTR)
#define UART4_UMCR                               UART_UMCR_REG(UART4_BASE_PTR)
/* UART5 */
#define UART5_URXD                               UART_URXD_REG(UART5_BASE_PTR)
#define UART5_UTXD                               UART_UTXD_REG(UART5_BASE_PTR)
#define UART5_UCR1                               UART_UCR1_REG(UART5_BASE_PTR)
#define UART5_UCR2                               UART_UCR2_REG(UART5_BASE_PTR)
#define UART5_UCR3                               UART_UCR3_REG(UART5_BASE_PTR)
#define UART5_UCR4                               UART_UCR4_REG(UART5_BASE_PTR)
#define UART5_UFCR                               UART_UFCR_REG(UART5_BASE_PTR)
#define UART5_USR1                               UART_USR1_REG(UART5_BASE_PTR)
#define UART5_USR2                               UART_USR2_REG(UART5_BASE_PTR)
#define UART5_UESC                               UART_UESC_REG(UART5_BASE_PTR)
#define UART5_UTIM                               UART_UTIM_REG(UART5_BASE_PTR)
#define UART5_UBIR                               UART_UBIR_REG(UART5_BASE_PTR)
#define UART5_UBMR                               UART_UBMR_REG(UART5_BASE_PTR)
#define UART5_UBRC                               UART_UBRC_REG(UART5_BASE_PTR)
#define UART5_ONEMS                              UART_ONEMS_REG(UART5_BASE_PTR)
#define UART5_UTS                                UART_UTS_REG(UART5_BASE_PTR)
#define UART5_UMCR                               UART_UMCR_REG(UART5_BASE_PTR)
/* UART6 */
#define UART6_URXD                               UART_URXD_REG(UART6_BASE_PTR)
#define UART6_UTXD                               UART_UTXD_REG(UART6_BASE_PTR)
#define UART6_UCR1                               UART_UCR1_REG(UART6_BASE_PTR)
#define UART6_UCR2                               UART_UCR2_REG(UART6_BASE_PTR)
#define UART6_UCR3                               UART_UCR3_REG(UART6_BASE_PTR)
#define UART6_UCR4                               UART_UCR4_REG(UART6_BASE_PTR)
#define UART6_UFCR                               UART_UFCR_REG(UART6_BASE_PTR)
#define UART6_USR1                               UART_USR1_REG(UART6_BASE_PTR)
#define UART6_USR2                               UART_USR2_REG(UART6_BASE_PTR)
#define UART6_UESC                               UART_UESC_REG(UART6_BASE_PTR)
#define UART6_UTIM                               UART_UTIM_REG(UART6_BASE_PTR)
#define UART6_UBIR                               UART_UBIR_REG(UART6_BASE_PTR)
#define UART6_UBMR                               UART_UBMR_REG(UART6_BASE_PTR)
#define UART6_UBRC                               UART_UBRC_REG(UART6_BASE_PTR)
#define UART6_ONEMS                              UART_ONEMS_REG(UART6_BASE_PTR)
#define UART6_UTS                                UART_UTS_REG(UART6_BASE_PTR)
#define UART6_UMCR                               UART_UMCR_REG(UART6_BASE_PTR)
/* UART7 */
#define UART7_URXD                               UART_URXD_REG(UART7_BASE_PTR)
#define UART7_UTXD                               UART_UTXD_REG(UART7_BASE_PTR)
#define UART7_UCR1                               UART_UCR1_REG(UART7_BASE_PTR)
#define UART7_UCR2                               UART_UCR2_REG(UART7_BASE_PTR)
#define UART7_UCR3                               UART_UCR3_REG(UART7_BASE_PTR)
#define UART7_UCR4                               UART_UCR4_REG(UART7_BASE_PTR)
#define UART7_UFCR                               UART_UFCR_REG(UART7_BASE_PTR)
#define UART7_USR1                               UART_USR1_REG(UART7_BASE_PTR)
#define UART7_USR2                               UART_USR2_REG(UART7_BASE_PTR)
#define UART7_UESC                               UART_UESC_REG(UART7_BASE_PTR)
#define UART7_UTIM                               UART_UTIM_REG(UART7_BASE_PTR)
#define UART7_UBIR                               UART_UBIR_REG(UART7_BASE_PTR)
#define UART7_UBMR                               UART_UBMR_REG(UART7_BASE_PTR)
#define UART7_UBRC                               UART_UBRC_REG(UART7_BASE_PTR)
#define UART7_ONEMS                              UART_ONEMS_REG(UART7_BASE_PTR)
#define UART7_UTS                                UART_UTS_REG(UART7_BASE_PTR)
#define UART7_UMCR                               UART_UMCR_REG(UART7_BASE_PTR)

/*!
 * @}
 */ /* end of group UART_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group UART_Peripheral */


/* ----------------------------------------------------------------------------
   -- USB
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USB_Peripheral USB
 * @{
 */

/** USB - Peripheral register structure */
typedef struct USB_MemMap {
  uint32_t ID;                                     /**< Identification register, offset: 0x0 */
  uint32_t HWGENERAL;                              /**< Hardware General, offset: 0x4 */
  uint32_t HWHOST;                                 /**< Host Hardware Parameters, offset: 0x8 */
  uint32_t HWDEVICE;                               /**< Device Hardware Parameters, offset: 0xC */
  uint32_t HWTXBUF;                                /**< TX Buffer Hardware Parameters, offset: 0x10 */
  uint32_t HWRXBUF;                                /**< RX Buffer Hardware Parameters, offset: 0x14 */
  uint8_t RESERVED_0[104];
  uint32_t GPTIMER0LD;                             /**< General Purpose Timer #0 Load, offset: 0x80 */
  uint32_t GPTIMER0CTRL;                           /**< General Purpose Timer #0 Controller, offset: 0x84 */
  uint32_t GPTIMER1LD;                             /**< General Purpose Timer #1 Load, offset: 0x88 */
  uint32_t GPTIMER1CTRL;                           /**< General Purpose Timer #1 Controller, offset: 0x8C */
  uint32_t SBUSCFG;                                /**< System Bus Config, offset: 0x90 */
  uint8_t RESERVED_1[108];
  uint8_t CAPLENGTH;                               /**< Capability Registers Length, offset: 0x100 */
  uint8_t RESERVED_2[1];
  uint16_t HCIVERSION;                             /**< Host Controller Interface Version, offset: 0x102 */
  uint32_t HCSPARAMS;                              /**< Host Controller Structural Parameters, offset: 0x104 */
  uint32_t HCCPARAMS;                              /**< Host Controller Capability Parameters, offset: 0x108 */
  uint8_t RESERVED_3[20];
  uint16_t DCIVERSION;                             /**< Device Controller Interface Version, offset: 0x120 */
  uint8_t RESERVED_4[2];
  uint32_t DCCPARAMS;                              /**< Device Controller Capability Parameters, offset: 0x124 */
  uint8_t RESERVED_5[24];
  uint32_t USBCMD;                                 /**< USB Command Register, offset: 0x140 */
  uint32_t USBSTS;                                 /**< USB Status Register, offset: 0x144 */
  uint32_t USBINTR;                                /**< Interrupt Enable Register, offset: 0x148 */
  uint32_t FRINDEX;                                /**< USB Frame Index, offset: 0x14C */
  uint8_t RESERVED_6[4];
  union {                                          /* offset: 0x154 */
    uint32_t DEVICEADDR;                             /**< Device Address, offset: 0x154 */
    uint32_t PERIODICLISTBASE;                       /**< Frame List Base Address, offset: 0x154 */
  };
  union {                                          /* offset: 0x158 */
    uint32_t ASYNCLISTADDR;                          /**< Next Asynch. Address, offset: 0x158 */
    uint32_t ENDPTLISTADDR;                          /**< Endpoint List Address, offset: 0x158 */
  };
  uint8_t RESERVED_7[4];
  uint32_t BURSTSIZE;                              /**< Programmable Burst Size, offset: 0x160 */
  uint32_t TXFILLTUNING;                           /**< TX FIFO Fill Tuning, offset: 0x164 */
  uint8_t RESERVED_8[16];
  uint32_t ENDPTNAK;                               /**< Endpoint NAK, offset: 0x178 */
  uint32_t ENDPTNAKEN;                             /**< Endpoint NAK Enable, offset: 0x17C */
  uint32_t CONFIGFLAG;                             /**< Configure Flag Register, offset: 0x180 */
  uint32_t PORTSC1;                                /**< Port Status & Control, offset: 0x184 */
  uint8_t RESERVED_9[28];
  uint32_t OTGSC;                                  /**< On-The-Go Status & control, offset: 0x1A4 */
  uint32_t USBMODE;                                /**< USB Device Mode, offset: 0x1A8 */
  uint32_t ENDPTSETUPSTAT;                         /**< Endpoint Setup Status, offset: 0x1AC */
  uint32_t ENDPTPRIME;                             /**< Endpoint Prime, offset: 0x1B0 */
  uint32_t ENDPTFLUSH;                             /**< Endpoint Flush, offset: 0x1B4 */
  uint32_t ENDPTSTAT;                              /**< Endpoint Status, offset: 0x1B8 */
  uint32_t ENDPTCOMPLETE;                          /**< Endpoint Complete, offset: 0x1BC */
  uint32_t ENDPTCTRL0;                             /**< Endpoint Control0, offset: 0x1C0 */
  uint32_t ENDPTCTRL[7];                           /**< Endpoint Control 1..Endpoint Control 7, array offset: 0x1C4, array step: 0x4 */
} volatile *USB_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- USB - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USB_Register_Accessor_Macros USB - Register accessor macros
 * @{
 */


/* USB - Register accessors */
#define USB_ID_REG(base)                         ((base)->ID)
#define USB_HWGENERAL_REG(base)                  ((base)->HWGENERAL)
#define USB_HWHOST_REG(base)                     ((base)->HWHOST)
#define USB_HWDEVICE_REG(base)                   ((base)->HWDEVICE)
#define USB_HWTXBUF_REG(base)                    ((base)->HWTXBUF)
#define USB_HWRXBUF_REG(base)                    ((base)->HWRXBUF)
#define USB_GPTIMER0LD_REG(base)                 ((base)->GPTIMER0LD)
#define USB_GPTIMER0CTRL_REG(base)               ((base)->GPTIMER0CTRL)
#define USB_GPTIMER1LD_REG(base)                 ((base)->GPTIMER1LD)
#define USB_GPTIMER1CTRL_REG(base)               ((base)->GPTIMER1CTRL)
#define USB_SBUSCFG_REG(base)                    ((base)->SBUSCFG)
#define USB_CAPLENGTH_REG(base)                  ((base)->CAPLENGTH)
#define USB_HCIVERSION_REG(base)                 ((base)->HCIVERSION)
#define USB_HCSPARAMS_REG(base)                  ((base)->HCSPARAMS)
#define USB_HCCPARAMS_REG(base)                  ((base)->HCCPARAMS)
#define USB_DCIVERSION_REG(base)                 ((base)->DCIVERSION)
#define USB_DCCPARAMS_REG(base)                  ((base)->DCCPARAMS)
#define USB_USBCMD_REG(base)                     ((base)->USBCMD)
#define USB_USBSTS_REG(base)                     ((base)->USBSTS)
#define USB_USBINTR_REG(base)                    ((base)->USBINTR)
#define USB_FRINDEX_REG(base)                    ((base)->FRINDEX)
#define USB_DEVICEADDR_REG(base)                 ((base)->DEVICEADDR)
#define USB_PERIODICLISTBASE_REG(base)           ((base)->PERIODICLISTBASE)
#define USB_ASYNCLISTADDR_REG(base)              ((base)->ASYNCLISTADDR)
#define USB_ENDPTLISTADDR_REG(base)              ((base)->ENDPTLISTADDR)
#define USB_BURSTSIZE_REG(base)                  ((base)->BURSTSIZE)
#define USB_TXFILLTUNING_REG(base)               ((base)->TXFILLTUNING)
#define USB_ENDPTNAK_REG(base)                   ((base)->ENDPTNAK)
#define USB_ENDPTNAKEN_REG(base)                 ((base)->ENDPTNAKEN)
#define USB_CONFIGFLAG_REG(base)                 ((base)->CONFIGFLAG)
#define USB_PORTSC1_REG(base)                    ((base)->PORTSC1)
#define USB_OTGSC_REG(base)                      ((base)->OTGSC)
#define USB_USBMODE_REG(base)                    ((base)->USBMODE)
#define USB_ENDPTSETUPSTAT_REG(base)             ((base)->ENDPTSETUPSTAT)
#define USB_ENDPTPRIME_REG(base)                 ((base)->ENDPTPRIME)
#define USB_ENDPTFLUSH_REG(base)                 ((base)->ENDPTFLUSH)
#define USB_ENDPTSTAT_REG(base)                  ((base)->ENDPTSTAT)
#define USB_ENDPTCOMPLETE_REG(base)              ((base)->ENDPTCOMPLETE)
#define USB_ENDPTCTRL0_REG(base)                 ((base)->ENDPTCTRL0)
#define USB_ENDPTCTRL_REG(base,index)            ((base)->ENDPTCTRL[index])

/*!
 * @}
 */ /* end of group USB_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- USB Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USB_Register_Masks USB Register Masks
 * @{
 */

/*! @name ID - Identification register */
#define USB_ID_ID_MASK                           (0x3FU)
#define USB_ID_ID_SHIFT                          (0U)
#define USB_ID_ID(x)                             (((uint32_t)(((uint32_t)(x)) << USB_ID_ID_SHIFT)) & USB_ID_ID_MASK)
#define USB_ID_NID_MASK                          (0x3F00U)
#define USB_ID_NID_SHIFT                         (8U)
#define USB_ID_NID(x)                            (((uint32_t)(((uint32_t)(x)) << USB_ID_NID_SHIFT)) & USB_ID_NID_MASK)
#define USB_ID_REVISION_MASK                     (0xFF0000U)
#define USB_ID_REVISION_SHIFT                    (16U)
#define USB_ID_REVISION(x)                       (((uint32_t)(((uint32_t)(x)) << USB_ID_REVISION_SHIFT)) & USB_ID_REVISION_MASK)

/*! @name HWGENERAL - Hardware General */
#define USB_HWGENERAL_PHYW_MASK                  (0x30U)
#define USB_HWGENERAL_PHYW_SHIFT                 (4U)
#define USB_HWGENERAL_PHYW(x)                    (((uint32_t)(((uint32_t)(x)) << USB_HWGENERAL_PHYW_SHIFT)) & USB_HWGENERAL_PHYW_MASK)
#define USB_HWGENERAL_PHYM_MASK                  (0x3C0U)
#define USB_HWGENERAL_PHYM_SHIFT                 (6U)
#define USB_HWGENERAL_PHYM(x)                    (((uint32_t)(((uint32_t)(x)) << USB_HWGENERAL_PHYM_SHIFT)) & USB_HWGENERAL_PHYM_MASK)
#define USB_HWGENERAL_SM_MASK                    (0xC00U)
#define USB_HWGENERAL_SM_SHIFT                   (10U)
#define USB_HWGENERAL_SM(x)                      (((uint32_t)(((uint32_t)(x)) << USB_HWGENERAL_SM_SHIFT)) & USB_HWGENERAL_SM_MASK)

/*! @name HWHOST - Host Hardware Parameters */
#define USB_HWHOST_HC_MASK                       (0x1U)
#define USB_HWHOST_HC_SHIFT                      (0U)
#define USB_HWHOST_NPORT_MASK                    (0xEU)
#define USB_HWHOST_NPORT_SHIFT                   (1U)
#define USB_HWHOST_NPORT(x)                      (((uint32_t)(((uint32_t)(x)) << USB_HWHOST_NPORT_SHIFT)) & USB_HWHOST_NPORT_MASK)

/*! @name HWDEVICE - Device Hardware Parameters */
#define USB_HWDEVICE_DC_MASK                     (0x1U)
#define USB_HWDEVICE_DC_SHIFT                    (0U)
#define USB_HWDEVICE_DEVEP_MASK                  (0x3EU)
#define USB_HWDEVICE_DEVEP_SHIFT                 (1U)
#define USB_HWDEVICE_DEVEP(x)                    (((uint32_t)(((uint32_t)(x)) << USB_HWDEVICE_DEVEP_SHIFT)) & USB_HWDEVICE_DEVEP_MASK)

/*! @name HWTXBUF - TX Buffer Hardware Parameters */
#define USB_HWTXBUF_TXBURST_MASK                 (0xFFU)
#define USB_HWTXBUF_TXBURST_SHIFT                (0U)
#define USB_HWTXBUF_TXBURST(x)                   (((uint32_t)(((uint32_t)(x)) << USB_HWTXBUF_TXBURST_SHIFT)) & USB_HWTXBUF_TXBURST_MASK)
#define USB_HWTXBUF_TXCHANADD_MASK               (0xFF0000U)
#define USB_HWTXBUF_TXCHANADD_SHIFT              (16U)
#define USB_HWTXBUF_TXCHANADD(x)                 (((uint32_t)(((uint32_t)(x)) << USB_HWTXBUF_TXCHANADD_SHIFT)) & USB_HWTXBUF_TXCHANADD_MASK)

/*! @name HWRXBUF - RX Buffer Hardware Parameters */
#define USB_HWRXBUF_RXBURST_MASK                 (0xFFU)
#define USB_HWRXBUF_RXBURST_SHIFT                (0U)
#define USB_HWRXBUF_RXBURST(x)                   (((uint32_t)(((uint32_t)(x)) << USB_HWRXBUF_RXBURST_SHIFT)) & USB_HWRXBUF_RXBURST_MASK)
#define USB_HWRXBUF_RXADD_MASK                   (0xFF00U)
#define USB_HWRXBUF_RXADD_SHIFT                  (8U)
#define USB_HWRXBUF_RXADD(x)                     (((uint32_t)(((uint32_t)(x)) << USB_HWRXBUF_RXADD_SHIFT)) & USB_HWRXBUF_RXADD_MASK)

/*! @name GPTIMER0LD - General Purpose Timer #0 Load */
#define USB_GPTIMER0LD_GPTLD_MASK                (0xFFFFFFU)
#define USB_GPTIMER0LD_GPTLD_SHIFT               (0U)
#define USB_GPTIMER0LD_GPTLD(x)                  (((uint32_t)(((uint32_t)(x)) << USB_GPTIMER0LD_GPTLD_SHIFT)) & USB_GPTIMER0LD_GPTLD_MASK)

/*! @name GPTIMER0CTRL - General Purpose Timer #0 Controller */
#define USB_GPTIMER0CTRL_GPTCNT_MASK             (0xFFFFFFU)
#define USB_GPTIMER0CTRL_GPTCNT_SHIFT            (0U)
#define USB_GPTIMER0CTRL_GPTCNT(x)               (((uint32_t)(((uint32_t)(x)) << USB_GPTIMER0CTRL_GPTCNT_SHIFT)) & USB_GPTIMER0CTRL_GPTCNT_MASK)
#define USB_GPTIMER0CTRL_GPTMODE_MASK            (0x1000000U)
#define USB_GPTIMER0CTRL_GPTMODE_SHIFT           (24U)
#define USB_GPTIMER0CTRL_GPTRST_MASK             (0x40000000U)
#define USB_GPTIMER0CTRL_GPTRST_SHIFT            (30U)
#define USB_GPTIMER0CTRL_GPTRUN_MASK             (0x80000000U)
#define USB_GPTIMER0CTRL_GPTRUN_SHIFT            (31U)

/*! @name GPTIMER1LD - General Purpose Timer #1 Load */
#define USB_GPTIMER1LD_GPTLD_MASK                (0xFFFFFFU)
#define USB_GPTIMER1LD_GPTLD_SHIFT               (0U)
#define USB_GPTIMER1LD_GPTLD(x)                  (((uint32_t)(((uint32_t)(x)) << USB_GPTIMER1LD_GPTLD_SHIFT)) & USB_GPTIMER1LD_GPTLD_MASK)

/*! @name GPTIMER1CTRL - General Purpose Timer #1 Controller */
#define USB_GPTIMER1CTRL_GPTCNT_MASK             (0xFFFFFFU)
#define USB_GPTIMER1CTRL_GPTCNT_SHIFT            (0U)
#define USB_GPTIMER1CTRL_GPTCNT(x)               (((uint32_t)(((uint32_t)(x)) << USB_GPTIMER1CTRL_GPTCNT_SHIFT)) & USB_GPTIMER1CTRL_GPTCNT_MASK)
#define USB_GPTIMER1CTRL_GPTMODE_MASK            (0x1000000U)
#define USB_GPTIMER1CTRL_GPTMODE_SHIFT           (24U)
#define USB_GPTIMER1CTRL_GPTRST_MASK             (0x40000000U)
#define USB_GPTIMER1CTRL_GPTRST_SHIFT            (30U)
#define USB_GPTIMER1CTRL_GPTRUN_MASK             (0x80000000U)
#define USB_GPTIMER1CTRL_GPTRUN_SHIFT            (31U)

/*! @name SBUSCFG - System Bus Config */
#define USB_SBUSCFG_AHBBRST_MASK                 (0x7U)
#define USB_SBUSCFG_AHBBRST_SHIFT                (0U)
#define USB_SBUSCFG_AHBBRST(x)                   (((uint32_t)(((uint32_t)(x)) << USB_SBUSCFG_AHBBRST_SHIFT)) & USB_SBUSCFG_AHBBRST_MASK)

/*! @name CAPLENGTH - Capability Registers Length */
#define USB_CAPLENGTH_CAPLENGTH_MASK             (0xFFU)
#define USB_CAPLENGTH_CAPLENGTH_SHIFT            (0U)
#define USB_CAPLENGTH_CAPLENGTH(x)               (((uint8_t)(((uint8_t)(x)) << USB_CAPLENGTH_CAPLENGTH_SHIFT)) & USB_CAPLENGTH_CAPLENGTH_MASK)

/*! @name HCIVERSION - Host Controller Interface Version */
#define USB_HCIVERSION_HCIVERSION_MASK           (0xFFFFU)
#define USB_HCIVERSION_HCIVERSION_SHIFT          (0U)
#define USB_HCIVERSION_HCIVERSION(x)             (((uint16_t)(((uint16_t)(x)) << USB_HCIVERSION_HCIVERSION_SHIFT)) & USB_HCIVERSION_HCIVERSION_MASK)

/*! @name HCSPARAMS - Host Controller Structural Parameters */
#define USB_HCSPARAMS_N_PORTS_MASK               (0xFU)
#define USB_HCSPARAMS_N_PORTS_SHIFT              (0U)
#define USB_HCSPARAMS_N_PORTS(x)                 (((uint32_t)(((uint32_t)(x)) << USB_HCSPARAMS_N_PORTS_SHIFT)) & USB_HCSPARAMS_N_PORTS_MASK)
#define USB_HCSPARAMS_PPC_MASK                   (0x10U)
#define USB_HCSPARAMS_PPC_SHIFT                  (4U)
#define USB_HCSPARAMS_N_PCC_MASK                 (0xF00U)
#define USB_HCSPARAMS_N_PCC_SHIFT                (8U)
#define USB_HCSPARAMS_N_PCC(x)                   (((uint32_t)(((uint32_t)(x)) << USB_HCSPARAMS_N_PCC_SHIFT)) & USB_HCSPARAMS_N_PCC_MASK)
#define USB_HCSPARAMS_N_CC_MASK                  (0xF000U)
#define USB_HCSPARAMS_N_CC_SHIFT                 (12U)
#define USB_HCSPARAMS_N_CC(x)                    (((uint32_t)(((uint32_t)(x)) << USB_HCSPARAMS_N_CC_SHIFT)) & USB_HCSPARAMS_N_CC_MASK)
#define USB_HCSPARAMS_PI_MASK                    (0x10000U)
#define USB_HCSPARAMS_PI_SHIFT                   (16U)
#define USB_HCSPARAMS_N_PTT_MASK                 (0xF00000U)
#define USB_HCSPARAMS_N_PTT_SHIFT                (20U)
#define USB_HCSPARAMS_N_PTT(x)                   (((uint32_t)(((uint32_t)(x)) << USB_HCSPARAMS_N_PTT_SHIFT)) & USB_HCSPARAMS_N_PTT_MASK)
#define USB_HCSPARAMS_N_TT_MASK                  (0xF000000U)
#define USB_HCSPARAMS_N_TT_SHIFT                 (24U)
#define USB_HCSPARAMS_N_TT(x)                    (((uint32_t)(((uint32_t)(x)) << USB_HCSPARAMS_N_TT_SHIFT)) & USB_HCSPARAMS_N_TT_MASK)

/*! @name HCCPARAMS - Host Controller Capability Parameters */
#define USB_HCCPARAMS_ADC_MASK                   (0x1U)
#define USB_HCCPARAMS_ADC_SHIFT                  (0U)
#define USB_HCCPARAMS_PFL_MASK                   (0x2U)
#define USB_HCCPARAMS_PFL_SHIFT                  (1U)
#define USB_HCCPARAMS_ASP_MASK                   (0x4U)
#define USB_HCCPARAMS_ASP_SHIFT                  (2U)
#define USB_HCCPARAMS_IST_MASK                   (0xF0U)
#define USB_HCCPARAMS_IST_SHIFT                  (4U)
#define USB_HCCPARAMS_IST(x)                     (((uint32_t)(((uint32_t)(x)) << USB_HCCPARAMS_IST_SHIFT)) & USB_HCCPARAMS_IST_MASK)
#define USB_HCCPARAMS_EECP_MASK                  (0xFF00U)
#define USB_HCCPARAMS_EECP_SHIFT                 (8U)
#define USB_HCCPARAMS_EECP(x)                    (((uint32_t)(((uint32_t)(x)) << USB_HCCPARAMS_EECP_SHIFT)) & USB_HCCPARAMS_EECP_MASK)

/*! @name DCIVERSION - Device Controller Interface Version */
#define USB_DCIVERSION_DCIVERSION_MASK           (0xFFFFU)
#define USB_DCIVERSION_DCIVERSION_SHIFT          (0U)
#define USB_DCIVERSION_DCIVERSION(x)             (((uint16_t)(((uint16_t)(x)) << USB_DCIVERSION_DCIVERSION_SHIFT)) & USB_DCIVERSION_DCIVERSION_MASK)

/*! @name DCCPARAMS - Device Controller Capability Parameters */
#define USB_DCCPARAMS_DEN_MASK                   (0x1FU)
#define USB_DCCPARAMS_DEN_SHIFT                  (0U)
#define USB_DCCPARAMS_DEN(x)                     (((uint32_t)(((uint32_t)(x)) << USB_DCCPARAMS_DEN_SHIFT)) & USB_DCCPARAMS_DEN_MASK)
#define USB_DCCPARAMS_DC_MASK                    (0x80U)
#define USB_DCCPARAMS_DC_SHIFT                   (7U)
#define USB_DCCPARAMS_HC_MASK                    (0x100U)
#define USB_DCCPARAMS_HC_SHIFT                   (8U)

/*! @name USBCMD - USB Command Register */
#define USB_USBCMD_RS_MASK                       (0x1U)
#define USB_USBCMD_RS_SHIFT                      (0U)
#define USB_USBCMD_RST_MASK                      (0x2U)
#define USB_USBCMD_RST_SHIFT                     (1U)
#define USB_USBCMD_FS_1_MASK                     (0xCU)
#define USB_USBCMD_FS_1_SHIFT                    (2U)
#define USB_USBCMD_FS_1(x)                       (((uint32_t)(((uint32_t)(x)) << USB_USBCMD_FS_1_SHIFT)) & USB_USBCMD_FS_1_MASK)
#define USB_USBCMD_PSE_MASK                      (0x10U)
#define USB_USBCMD_PSE_SHIFT                     (4U)
#define USB_USBCMD_ASE_MASK                      (0x20U)
#define USB_USBCMD_ASE_SHIFT                     (5U)
#define USB_USBCMD_IAA_MASK                      (0x40U)
#define USB_USBCMD_IAA_SHIFT                     (6U)
#define USB_USBCMD_ASP_MASK                      (0x300U)
#define USB_USBCMD_ASP_SHIFT                     (8U)
#define USB_USBCMD_ASP(x)                        (((uint32_t)(((uint32_t)(x)) << USB_USBCMD_ASP_SHIFT)) & USB_USBCMD_ASP_MASK)
#define USB_USBCMD_ASPE_MASK                     (0x800U)
#define USB_USBCMD_ASPE_SHIFT                    (11U)
#define USB_USBCMD_ATDTW_MASK                    (0x1000U)
#define USB_USBCMD_ATDTW_SHIFT                   (12U)
#define USB_USBCMD_SUTW_MASK                     (0x2000U)
#define USB_USBCMD_SUTW_SHIFT                    (13U)
#define USB_USBCMD_FS_2_MASK                     (0x8000U)
#define USB_USBCMD_FS_2_SHIFT                    (15U)
#define USB_USBCMD_ITC_MASK                      (0xFF0000U)
#define USB_USBCMD_ITC_SHIFT                     (16U)
#define USB_USBCMD_ITC(x)                        (((uint32_t)(((uint32_t)(x)) << USB_USBCMD_ITC_SHIFT)) & USB_USBCMD_ITC_MASK)

/*! @name USBSTS - USB Status Register */
#define USB_USBSTS_UI_MASK                       (0x1U)
#define USB_USBSTS_UI_SHIFT                      (0U)
#define USB_USBSTS_UEI_MASK                      (0x2U)
#define USB_USBSTS_UEI_SHIFT                     (1U)
#define USB_USBSTS_PCI_MASK                      (0x4U)
#define USB_USBSTS_PCI_SHIFT                     (2U)
#define USB_USBSTS_FRI_MASK                      (0x8U)
#define USB_USBSTS_FRI_SHIFT                     (3U)
#define USB_USBSTS_SEI_MASK                      (0x10U)
#define USB_USBSTS_SEI_SHIFT                     (4U)
#define USB_USBSTS_AAI_MASK                      (0x20U)
#define USB_USBSTS_AAI_SHIFT                     (5U)
#define USB_USBSTS_URI_MASK                      (0x40U)
#define USB_USBSTS_URI_SHIFT                     (6U)
#define USB_USBSTS_SRI_MASK                      (0x80U)
#define USB_USBSTS_SRI_SHIFT                     (7U)
#define USB_USBSTS_SLI_MASK                      (0x100U)
#define USB_USBSTS_SLI_SHIFT                     (8U)
#define USB_USBSTS_ULPII_MASK                    (0x400U)
#define USB_USBSTS_ULPII_SHIFT                   (10U)
#define USB_USBSTS_HCH_MASK                      (0x1000U)
#define USB_USBSTS_HCH_SHIFT                     (12U)
#define USB_USBSTS_RCL_MASK                      (0x2000U)
#define USB_USBSTS_RCL_SHIFT                     (13U)
#define USB_USBSTS_PS_MASK                       (0x4000U)
#define USB_USBSTS_PS_SHIFT                      (14U)
#define USB_USBSTS_AS_MASK                       (0x8000U)
#define USB_USBSTS_AS_SHIFT                      (15U)
#define USB_USBSTS_NAKI_MASK                     (0x10000U)
#define USB_USBSTS_NAKI_SHIFT                    (16U)
#define USB_USBSTS_TI0_MASK                      (0x1000000U)
#define USB_USBSTS_TI0_SHIFT                     (24U)
#define USB_USBSTS_TI1_MASK                      (0x2000000U)
#define USB_USBSTS_TI1_SHIFT                     (25U)

/*! @name USBINTR - Interrupt Enable Register */
#define USB_USBINTR_UE_MASK                      (0x1U)
#define USB_USBINTR_UE_SHIFT                     (0U)
#define USB_USBINTR_UEE_MASK                     (0x2U)
#define USB_USBINTR_UEE_SHIFT                    (1U)
#define USB_USBINTR_PCE_MASK                     (0x4U)
#define USB_USBINTR_PCE_SHIFT                    (2U)
#define USB_USBINTR_FRE_MASK                     (0x8U)
#define USB_USBINTR_FRE_SHIFT                    (3U)
#define USB_USBINTR_SEE_MASK                     (0x10U)
#define USB_USBINTR_SEE_SHIFT                    (4U)
#define USB_USBINTR_AAE_MASK                     (0x20U)
#define USB_USBINTR_AAE_SHIFT                    (5U)
#define USB_USBINTR_URE_MASK                     (0x40U)
#define USB_USBINTR_URE_SHIFT                    (6U)
#define USB_USBINTR_SRE_MASK                     (0x80U)
#define USB_USBINTR_SRE_SHIFT                    (7U)
#define USB_USBINTR_SLE_MASK                     (0x100U)
#define USB_USBINTR_SLE_SHIFT                    (8U)
#define USB_USBINTR_ULPIE_MASK                   (0x400U)
#define USB_USBINTR_ULPIE_SHIFT                  (10U)
#define USB_USBINTR_NAKE_MASK                    (0x10000U)
#define USB_USBINTR_NAKE_SHIFT                   (16U)
#define USB_USBINTR_UAIE_MASK                    (0x40000U)
#define USB_USBINTR_UAIE_SHIFT                   (18U)
#define USB_USBINTR_UPIE_MASK                    (0x80000U)
#define USB_USBINTR_UPIE_SHIFT                   (19U)
#define USB_USBINTR_TIE0_MASK                    (0x1000000U)
#define USB_USBINTR_TIE0_SHIFT                   (24U)
#define USB_USBINTR_TIE1_MASK                    (0x2000000U)
#define USB_USBINTR_TIE1_SHIFT                   (25U)

/*! @name FRINDEX - USB Frame Index */
#define USB_FRINDEX_FRINDEX_MASK                 (0x3FFFU)
#define USB_FRINDEX_FRINDEX_SHIFT                (0U)
#define USB_FRINDEX_FRINDEX(x)                   (((uint32_t)(((uint32_t)(x)) << USB_FRINDEX_FRINDEX_SHIFT)) & USB_FRINDEX_FRINDEX_MASK)

/*! @name DEVICEADDR - Device Address */
#define USB_DEVICEADDR_USBADRA_MASK              (0x1000000U)
#define USB_DEVICEADDR_USBADRA_SHIFT             (24U)
#define USB_DEVICEADDR_USBADR_MASK               (0xFE000000U)
#define USB_DEVICEADDR_USBADR_SHIFT              (25U)
#define USB_DEVICEADDR_USBADR(x)                 (((uint32_t)(((uint32_t)(x)) << USB_DEVICEADDR_USBADR_SHIFT)) & USB_DEVICEADDR_USBADR_MASK)

/*! @name PERIODICLISTBASE - Frame List Base Address */
#define USB_PERIODICLISTBASE_BASEADR_MASK        (0xFFFFF000U)
#define USB_PERIODICLISTBASE_BASEADR_SHIFT       (12U)
#define USB_PERIODICLISTBASE_BASEADR(x)          (((uint32_t)(((uint32_t)(x)) << USB_PERIODICLISTBASE_BASEADR_SHIFT)) & USB_PERIODICLISTBASE_BASEADR_MASK)

/*! @name ASYNCLISTADDR - Next Asynch. Address */
#define USB_ASYNCLISTADDR_ASYBASE_MASK           (0xFFFFFFE0U)
#define USB_ASYNCLISTADDR_ASYBASE_SHIFT          (5U)
#define USB_ASYNCLISTADDR_ASYBASE(x)             (((uint32_t)(((uint32_t)(x)) << USB_ASYNCLISTADDR_ASYBASE_SHIFT)) & USB_ASYNCLISTADDR_ASYBASE_MASK)

/*! @name ENDPTLISTADDR - Endpoint List Address */
#define USB_ENDPTLISTADDR_EPBASE_MASK            (0xFFFFF800U)
#define USB_ENDPTLISTADDR_EPBASE_SHIFT           (11U)
#define USB_ENDPTLISTADDR_EPBASE(x)              (((uint32_t)(((uint32_t)(x)) << USB_ENDPTLISTADDR_EPBASE_SHIFT)) & USB_ENDPTLISTADDR_EPBASE_MASK)

/*! @name BURSTSIZE - Programmable Burst Size */
#define USB_BURSTSIZE_RXPBURST_MASK              (0xFFU)
#define USB_BURSTSIZE_RXPBURST_SHIFT             (0U)
#define USB_BURSTSIZE_RXPBURST(x)                (((uint32_t)(((uint32_t)(x)) << USB_BURSTSIZE_RXPBURST_SHIFT)) & USB_BURSTSIZE_RXPBURST_MASK)
#define USB_BURSTSIZE_TXPBURST_MASK              (0x1FF00U)
#define USB_BURSTSIZE_TXPBURST_SHIFT             (8U)
#define USB_BURSTSIZE_TXPBURST(x)                (((uint32_t)(((uint32_t)(x)) << USB_BURSTSIZE_TXPBURST_SHIFT)) & USB_BURSTSIZE_TXPBURST_MASK)

/*! @name TXFILLTUNING - TX FIFO Fill Tuning */
#define USB_TXFILLTUNING_TXSCHOH_MASK            (0xFFU)
#define USB_TXFILLTUNING_TXSCHOH_SHIFT           (0U)
#define USB_TXFILLTUNING_TXSCHOH(x)              (((uint32_t)(((uint32_t)(x)) << USB_TXFILLTUNING_TXSCHOH_SHIFT)) & USB_TXFILLTUNING_TXSCHOH_MASK)
#define USB_TXFILLTUNING_TXSCHHEALTH_MASK        (0x1F00U)
#define USB_TXFILLTUNING_TXSCHHEALTH_SHIFT       (8U)
#define USB_TXFILLTUNING_TXSCHHEALTH(x)          (((uint32_t)(((uint32_t)(x)) << USB_TXFILLTUNING_TXSCHHEALTH_SHIFT)) & USB_TXFILLTUNING_TXSCHHEALTH_MASK)
#define USB_TXFILLTUNING_TXFIFOTHRES_MASK        (0x3F0000U)
#define USB_TXFILLTUNING_TXFIFOTHRES_SHIFT       (16U)
#define USB_TXFILLTUNING_TXFIFOTHRES(x)          (((uint32_t)(((uint32_t)(x)) << USB_TXFILLTUNING_TXFIFOTHRES_SHIFT)) & USB_TXFILLTUNING_TXFIFOTHRES_MASK)

/*! @name ENDPTNAK - Endpoint NAK */
#define USB_ENDPTNAK_EPRN_MASK                   (0xFFU)
#define USB_ENDPTNAK_EPRN_SHIFT                  (0U)
#define USB_ENDPTNAK_EPRN(x)                     (((uint32_t)(((uint32_t)(x)) << USB_ENDPTNAK_EPRN_SHIFT)) & USB_ENDPTNAK_EPRN_MASK)
#define USB_ENDPTNAK_EPTN_MASK                   (0xFF0000U)
#define USB_ENDPTNAK_EPTN_SHIFT                  (16U)
#define USB_ENDPTNAK_EPTN(x)                     (((uint32_t)(((uint32_t)(x)) << USB_ENDPTNAK_EPTN_SHIFT)) & USB_ENDPTNAK_EPTN_MASK)

/*! @name ENDPTNAKEN - Endpoint NAK Enable */
#define USB_ENDPTNAKEN_EPRNE_MASK                (0xFFU)
#define USB_ENDPTNAKEN_EPRNE_SHIFT               (0U)
#define USB_ENDPTNAKEN_EPRNE(x)                  (((uint32_t)(((uint32_t)(x)) << USB_ENDPTNAKEN_EPRNE_SHIFT)) & USB_ENDPTNAKEN_EPRNE_MASK)
#define USB_ENDPTNAKEN_EPTNE_MASK                (0xFF0000U)
#define USB_ENDPTNAKEN_EPTNE_SHIFT               (16U)
#define USB_ENDPTNAKEN_EPTNE(x)                  (((uint32_t)(((uint32_t)(x)) << USB_ENDPTNAKEN_EPTNE_SHIFT)) & USB_ENDPTNAKEN_EPTNE_MASK)

/*! @name CONFIGFLAG - Configure Flag Register */
#define USB_CONFIGFLAG_CF_MASK                   (0x1U)
#define USB_CONFIGFLAG_CF_SHIFT                  (0U)

/*! @name PORTSC1 - Port Status & Control */
#define USB_PORTSC1_CCS_MASK                     (0x1U)
#define USB_PORTSC1_CCS_SHIFT                    (0U)
#define USB_PORTSC1_CSC_MASK                     (0x2U)
#define USB_PORTSC1_CSC_SHIFT                    (1U)
#define USB_PORTSC1_PE_MASK                      (0x4U)
#define USB_PORTSC1_PE_SHIFT                     (2U)
#define USB_PORTSC1_PEC_MASK                     (0x8U)
#define USB_PORTSC1_PEC_SHIFT                    (3U)
#define USB_PORTSC1_OCA_MASK                     (0x10U)
#define USB_PORTSC1_OCA_SHIFT                    (4U)
#define USB_PORTSC1_OCC_MASK                     (0x20U)
#define USB_PORTSC1_OCC_SHIFT                    (5U)
#define USB_PORTSC1_FPR_MASK                     (0x40U)
#define USB_PORTSC1_FPR_SHIFT                    (6U)
#define USB_PORTSC1_SUSP_MASK                    (0x80U)
#define USB_PORTSC1_SUSP_SHIFT                   (7U)
#define USB_PORTSC1_PR_MASK                      (0x100U)
#define USB_PORTSC1_PR_SHIFT                     (8U)
#define USB_PORTSC1_HSP_MASK                     (0x200U)
#define USB_PORTSC1_HSP_SHIFT                    (9U)
#define USB_PORTSC1_LS_MASK                      (0xC00U)
#define USB_PORTSC1_LS_SHIFT                     (10U)
#define USB_PORTSC1_LS(x)                        (((uint32_t)(((uint32_t)(x)) << USB_PORTSC1_LS_SHIFT)) & USB_PORTSC1_LS_MASK)
#define USB_PORTSC1_PP_MASK                      (0x1000U)
#define USB_PORTSC1_PP_SHIFT                     (12U)
#define USB_PORTSC1_PO_MASK                      (0x2000U)
#define USB_PORTSC1_PO_SHIFT                     (13U)
#define USB_PORTSC1_PIC_MASK                     (0xC000U)
#define USB_PORTSC1_PIC_SHIFT                    (14U)
#define USB_PORTSC1_PIC(x)                       (((uint32_t)(((uint32_t)(x)) << USB_PORTSC1_PIC_SHIFT)) & USB_PORTSC1_PIC_MASK)
#define USB_PORTSC1_PTC_MASK                     (0xF0000U)
#define USB_PORTSC1_PTC_SHIFT                    (16U)
#define USB_PORTSC1_PTC(x)                       (((uint32_t)(((uint32_t)(x)) << USB_PORTSC1_PTC_SHIFT)) & USB_PORTSC1_PTC_MASK)
#define USB_PORTSC1_WKCN_MASK                    (0x100000U)
#define USB_PORTSC1_WKCN_SHIFT                   (20U)
#define USB_PORTSC1_WKDC_MASK                    (0x200000U)
#define USB_PORTSC1_WKDC_SHIFT                   (21U)
#define USB_PORTSC1_WKOC_MASK                    (0x400000U)
#define USB_PORTSC1_WKOC_SHIFT                   (22U)
#define USB_PORTSC1_PHCD_MASK                    (0x800000U)
#define USB_PORTSC1_PHCD_SHIFT                   (23U)
#define USB_PORTSC1_PFSC_MASK                    (0x1000000U)
#define USB_PORTSC1_PFSC_SHIFT                   (24U)
#define USB_PORTSC1_PTS_2_MASK                   (0x2000000U)
#define USB_PORTSC1_PTS_2_SHIFT                  (25U)
#define USB_PORTSC1_PSPD_MASK                    (0xC000000U)
#define USB_PORTSC1_PSPD_SHIFT                   (26U)
#define USB_PORTSC1_PSPD(x)                      (((uint32_t)(((uint32_t)(x)) << USB_PORTSC1_PSPD_SHIFT)) & USB_PORTSC1_PSPD_MASK)
#define USB_PORTSC1_PTW_MASK                     (0x10000000U)
#define USB_PORTSC1_PTW_SHIFT                    (28U)
#define USB_PORTSC1_STS_MASK                     (0x20000000U)
#define USB_PORTSC1_STS_SHIFT                    (29U)
#define USB_PORTSC1_PTS_1_MASK                   (0xC0000000U)
#define USB_PORTSC1_PTS_1_SHIFT                  (30U)
#define USB_PORTSC1_PTS_1(x)                     (((uint32_t)(((uint32_t)(x)) << USB_PORTSC1_PTS_1_SHIFT)) & USB_PORTSC1_PTS_1_MASK)

/*! @name OTGSC - On-The-Go Status & control */
#define USB_OTGSC_VD_MASK                        (0x1U)
#define USB_OTGSC_VD_SHIFT                       (0U)
#define USB_OTGSC_VC_MASK                        (0x2U)
#define USB_OTGSC_VC_SHIFT                       (1U)
#define USB_OTGSC_OT_MASK                        (0x8U)
#define USB_OTGSC_OT_SHIFT                       (3U)
#define USB_OTGSC_DP_MASK                        (0x10U)
#define USB_OTGSC_DP_SHIFT                       (4U)
#define USB_OTGSC_IDPU_MASK                      (0x20U)
#define USB_OTGSC_IDPU_SHIFT                     (5U)
#define USB_OTGSC_ID_MASK                        (0x100U)
#define USB_OTGSC_ID_SHIFT                       (8U)
#define USB_OTGSC_AVV_MASK                       (0x200U)
#define USB_OTGSC_AVV_SHIFT                      (9U)
#define USB_OTGSC_ASV_MASK                       (0x400U)
#define USB_OTGSC_ASV_SHIFT                      (10U)
#define USB_OTGSC_BSV_MASK                       (0x800U)
#define USB_OTGSC_BSV_SHIFT                      (11U)
#define USB_OTGSC_BSE_MASK                       (0x1000U)
#define USB_OTGSC_BSE_SHIFT                      (12U)
#define USB_OTGSC_TOG_1MS_MASK                   (0x2000U)
#define USB_OTGSC_TOG_1MS_SHIFT                  (13U)
#define USB_OTGSC_DPS_MASK                       (0x4000U)
#define USB_OTGSC_DPS_SHIFT                      (14U)
#define USB_OTGSC_IDIS_MASK                      (0x10000U)
#define USB_OTGSC_IDIS_SHIFT                     (16U)
#define USB_OTGSC_AVVIS_MASK                     (0x20000U)
#define USB_OTGSC_AVVIS_SHIFT                    (17U)
#define USB_OTGSC_ASVIS_MASK                     (0x40000U)
#define USB_OTGSC_ASVIS_SHIFT                    (18U)
#define USB_OTGSC_BSVIS_MASK                     (0x80000U)
#define USB_OTGSC_BSVIS_SHIFT                    (19U)
#define USB_OTGSC_BSEIS_MASK                     (0x100000U)
#define USB_OTGSC_BSEIS_SHIFT                    (20U)
#define USB_OTGSC_STATUS_1MS_MASK                (0x200000U)
#define USB_OTGSC_STATUS_1MS_SHIFT               (21U)
#define USB_OTGSC_DPIS_MASK                      (0x400000U)
#define USB_OTGSC_DPIS_SHIFT                     (22U)
#define USB_OTGSC_IDIE_MASK                      (0x1000000U)
#define USB_OTGSC_IDIE_SHIFT                     (24U)
#define USB_OTGSC_AVVIE_MASK                     (0x2000000U)
#define USB_OTGSC_AVVIE_SHIFT                    (25U)
#define USB_OTGSC_ASVIE_MASK                     (0x4000000U)
#define USB_OTGSC_ASVIE_SHIFT                    (26U)
#define USB_OTGSC_BSVIE_MASK                     (0x8000000U)
#define USB_OTGSC_BSVIE_SHIFT                    (27U)
#define USB_OTGSC_BSEIE_MASK                     (0x10000000U)
#define USB_OTGSC_BSEIE_SHIFT                    (28U)
#define USB_OTGSC_EN_1MS_MASK                    (0x20000000U)
#define USB_OTGSC_EN_1MS_SHIFT                   (29U)
#define USB_OTGSC_DPIE_MASK                      (0x40000000U)
#define USB_OTGSC_DPIE_SHIFT                     (30U)

/*! @name USBMODE - USB Device Mode */
#define USB_USBMODE_CM_MASK                      (0x3U)
#define USB_USBMODE_CM_SHIFT                     (0U)
#define USB_USBMODE_CM(x)                        (((uint32_t)(((uint32_t)(x)) << USB_USBMODE_CM_SHIFT)) & USB_USBMODE_CM_MASK)
#define USB_USBMODE_ES_MASK                      (0x4U)
#define USB_USBMODE_ES_SHIFT                     (2U)
#define USB_USBMODE_SLOM_MASK                    (0x8U)
#define USB_USBMODE_SLOM_SHIFT                   (3U)
#define USB_USBMODE_SDIS_MASK                    (0x10U)
#define USB_USBMODE_SDIS_SHIFT                   (4U)

/*! @name ENDPTSETUPSTAT - Endpoint Setup Status */
#define USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT_MASK   (0xFFFFU)
#define USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT_SHIFT  (0U)
#define USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT(x)     (((uint32_t)(((uint32_t)(x)) << USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT_SHIFT)) & USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT_MASK)

/*! @name ENDPTPRIME - Endpoint Prime */
#define USB_ENDPTPRIME_PERB_MASK                 (0xFFU)
#define USB_ENDPTPRIME_PERB_SHIFT                (0U)
#define USB_ENDPTPRIME_PERB(x)                   (((uint32_t)(((uint32_t)(x)) << USB_ENDPTPRIME_PERB_SHIFT)) & USB_ENDPTPRIME_PERB_MASK)
#define USB_ENDPTPRIME_PETB_MASK                 (0xFF0000U)
#define USB_ENDPTPRIME_PETB_SHIFT                (16U)
#define USB_ENDPTPRIME_PETB(x)                   (((uint32_t)(((uint32_t)(x)) << USB_ENDPTPRIME_PETB_SHIFT)) & USB_ENDPTPRIME_PETB_MASK)

/*! @name ENDPTFLUSH - Endpoint Flush */
#define USB_ENDPTFLUSH_FERB_MASK                 (0xFFU)
#define USB_ENDPTFLUSH_FERB_SHIFT                (0U)
#define USB_ENDPTFLUSH_FERB(x)                   (((uint32_t)(((uint32_t)(x)) << USB_ENDPTFLUSH_FERB_SHIFT)) & USB_ENDPTFLUSH_FERB_MASK)
#define USB_ENDPTFLUSH_FETB_MASK                 (0xFF0000U)
#define USB_ENDPTFLUSH_FETB_SHIFT                (16U)
#define USB_ENDPTFLUSH_FETB(x)                   (((uint32_t)(((uint32_t)(x)) << USB_ENDPTFLUSH_FETB_SHIFT)) & USB_ENDPTFLUSH_FETB_MASK)

/*! @name ENDPTSTAT - Endpoint Status */
#define USB_ENDPTSTAT_ERBR_MASK                  (0xFFU)
#define USB_ENDPTSTAT_ERBR_SHIFT                 (0U)
#define USB_ENDPTSTAT_ERBR(x)                    (((uint32_t)(((uint32_t)(x)) << USB_ENDPTSTAT_ERBR_SHIFT)) & USB_ENDPTSTAT_ERBR_MASK)
#define USB_ENDPTSTAT_ETBR_MASK                  (0xFF0000U)
#define USB_ENDPTSTAT_ETBR_SHIFT                 (16U)
#define USB_ENDPTSTAT_ETBR(x)                    (((uint32_t)(((uint32_t)(x)) << USB_ENDPTSTAT_ETBR_SHIFT)) & USB_ENDPTSTAT_ETBR_MASK)

/*! @name ENDPTCOMPLETE - Endpoint Complete */
#define USB_ENDPTCOMPLETE_ERCE_MASK              (0xFFU)
#define USB_ENDPTCOMPLETE_ERCE_SHIFT             (0U)
#define USB_ENDPTCOMPLETE_ERCE(x)                (((uint32_t)(((uint32_t)(x)) << USB_ENDPTCOMPLETE_ERCE_SHIFT)) & USB_ENDPTCOMPLETE_ERCE_MASK)
#define USB_ENDPTCOMPLETE_ETCE_MASK              (0xFF0000U)
#define USB_ENDPTCOMPLETE_ETCE_SHIFT             (16U)
#define USB_ENDPTCOMPLETE_ETCE(x)                (((uint32_t)(((uint32_t)(x)) << USB_ENDPTCOMPLETE_ETCE_SHIFT)) & USB_ENDPTCOMPLETE_ETCE_MASK)

/*! @name ENDPTCTRL0 - Endpoint Control0 */
#define USB_ENDPTCTRL0_RXS_MASK                  (0x1U)
#define USB_ENDPTCTRL0_RXS_SHIFT                 (0U)
#define USB_ENDPTCTRL0_RXT_MASK                  (0xCU)
#define USB_ENDPTCTRL0_RXT_SHIFT                 (2U)
#define USB_ENDPTCTRL0_RXT(x)                    (((uint32_t)(((uint32_t)(x)) << USB_ENDPTCTRL0_RXT_SHIFT)) & USB_ENDPTCTRL0_RXT_MASK)
#define USB_ENDPTCTRL0_RXE_MASK                  (0x80U)
#define USB_ENDPTCTRL0_RXE_SHIFT                 (7U)
#define USB_ENDPTCTRL0_TXS_MASK                  (0x10000U)
#define USB_ENDPTCTRL0_TXS_SHIFT                 (16U)
#define USB_ENDPTCTRL0_TXT_MASK                  (0xC0000U)
#define USB_ENDPTCTRL0_TXT_SHIFT                 (18U)
#define USB_ENDPTCTRL0_TXT(x)                    (((uint32_t)(((uint32_t)(x)) << USB_ENDPTCTRL0_TXT_SHIFT)) & USB_ENDPTCTRL0_TXT_MASK)
#define USB_ENDPTCTRL0_TXE_MASK                  (0x800000U)
#define USB_ENDPTCTRL0_TXE_SHIFT                 (23U)

/*! @name ENDPTCTRL - Endpoint Control 1..Endpoint Control 7 */
#define USB_ENDPTCTRL_RXS_MASK                   (0x1U)
#define USB_ENDPTCTRL_RXS_SHIFT                  (0U)
#define USB_ENDPTCTRL_RXD_MASK                   (0x2U)
#define USB_ENDPTCTRL_RXD_SHIFT                  (1U)
#define USB_ENDPTCTRL_RXT_MASK                   (0xCU)
#define USB_ENDPTCTRL_RXT_SHIFT                  (2U)
#define USB_ENDPTCTRL_RXT(x)                     (((uint32_t)(((uint32_t)(x)) << USB_ENDPTCTRL_RXT_SHIFT)) & USB_ENDPTCTRL_RXT_MASK)
#define USB_ENDPTCTRL_RXI_MASK                   (0x20U)
#define USB_ENDPTCTRL_RXI_SHIFT                  (5U)
#define USB_ENDPTCTRL_RXR_MASK                   (0x40U)
#define USB_ENDPTCTRL_RXR_SHIFT                  (6U)
#define USB_ENDPTCTRL_RXE_MASK                   (0x80U)
#define USB_ENDPTCTRL_RXE_SHIFT                  (7U)
#define USB_ENDPTCTRL_TXS_MASK                   (0x10000U)
#define USB_ENDPTCTRL_TXS_SHIFT                  (16U)
#define USB_ENDPTCTRL_TXD_MASK                   (0x20000U)
#define USB_ENDPTCTRL_TXD_SHIFT                  (17U)
#define USB_ENDPTCTRL_TXT_MASK                   (0xC0000U)
#define USB_ENDPTCTRL_TXT_SHIFT                  (18U)
#define USB_ENDPTCTRL_TXT(x)                     (((uint32_t)(((uint32_t)(x)) << USB_ENDPTCTRL_TXT_SHIFT)) & USB_ENDPTCTRL_TXT_MASK)
#define USB_ENDPTCTRL_TXI_MASK                   (0x200000U)
#define USB_ENDPTCTRL_TXI_SHIFT                  (21U)
#define USB_ENDPTCTRL_TXR_MASK                   (0x400000U)
#define USB_ENDPTCTRL_TXR_SHIFT                  (22U)
#define USB_ENDPTCTRL_TXE_MASK                   (0x800000U)
#define USB_ENDPTCTRL_TXE_SHIFT                  (23U)

/* The count of USB_ENDPTCTRL */
#define USB_ENDPTCTRL_COUNT                      (7U)


/*!
 * @}
 */ /* end of group USB_Register_Masks */


/* USB - Peripheral instance base addresses */
/** Peripheral USB1 base pointer */
#define USB1_BASE_PTR                            ((USB_MemMapPtr)0x30B10000u)
/** Peripheral USB2 base pointer */
#define USB2_BASE_PTR                            ((USB_MemMapPtr)0x30B20000u)
/** Peripheral USB_HSIC base pointer */
#define USB_HSIC_BASE_PTR                        ((USB_MemMapPtr)0x30B30000u)
/** Array initializer of USB peripheral base pointers */
#define USB_BASE_PTRS                            { USB1_BASE_PTR, USB2_BASE_PTR, USB_HSIC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- USB - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USB_Register_Accessor_Macros USB - Register accessor macros
 * @{
 */


/* USB - Register instance definitions */
/* USB1 */
#define USB1_ID                                  USB_ID_REG(USB1_BASE_PTR)
#define USB1_HWGENERAL                           USB_HWGENERAL_REG(USB1_BASE_PTR)
#define USB1_HWHOST                              USB_HWHOST_REG(USB1_BASE_PTR)
#define USB1_HWDEVICE                            USB_HWDEVICE_REG(USB1_BASE_PTR)
#define USB1_HWTXBUF                             USB_HWTXBUF_REG(USB1_BASE_PTR)
#define USB1_HWRXBUF                             USB_HWRXBUF_REG(USB1_BASE_PTR)
#define USB1_GPTIMER0LD                          USB_GPTIMER0LD_REG(USB1_BASE_PTR)
#define USB1_GPTIMER0CTRL                        USB_GPTIMER0CTRL_REG(USB1_BASE_PTR)
#define USB1_GPTIMER1LD                          USB_GPTIMER1LD_REG(USB1_BASE_PTR)
#define USB1_GPTIMER1CTRL                        USB_GPTIMER1CTRL_REG(USB1_BASE_PTR)
#define USB1_SBUSCFG                             USB_SBUSCFG_REG(USB1_BASE_PTR)
#define USB1_CAPLENGTH                           USB_CAPLENGTH_REG(USB1_BASE_PTR)
#define USB1_HCIVERSION                          USB_HCIVERSION_REG(USB1_BASE_PTR)
#define USB1_HCSPARAMS                           USB_HCSPARAMS_REG(USB1_BASE_PTR)
#define USB1_HCCPARAMS                           USB_HCCPARAMS_REG(USB1_BASE_PTR)
#define USB1_DCIVERSION                          USB_DCIVERSION_REG(USB1_BASE_PTR)
#define USB1_DCCPARAMS                           USB_DCCPARAMS_REG(USB1_BASE_PTR)
#define USB1_USBCMD                              USB_USBCMD_REG(USB1_BASE_PTR)
#define USB1_USBSTS                              USB_USBSTS_REG(USB1_BASE_PTR)
#define USB1_USBINTR                             USB_USBINTR_REG(USB1_BASE_PTR)
#define USB1_FRINDEX                             USB_FRINDEX_REG(USB1_BASE_PTR)
#define USB1_DEVICEADDR                          USB_DEVICEADDR_REG(USB1_BASE_PTR)
#define USB1_PERIODICLISTBASE                    USB_PERIODICLISTBASE_REG(USB1_BASE_PTR)
#define USB1_ASYNCLISTADDR                       USB_ASYNCLISTADDR_REG(USB1_BASE_PTR)
#define USB1_ENDPTLISTADDR                       USB_ENDPTLISTADDR_REG(USB1_BASE_PTR)
#define USB1_BURSTSIZE                           USB_BURSTSIZE_REG(USB1_BASE_PTR)
#define USB1_TXFILLTUNING                        USB_TXFILLTUNING_REG(USB1_BASE_PTR)
#define USB1_ENDPTNAK                            USB_ENDPTNAK_REG(USB1_BASE_PTR)
#define USB1_ENDPTNAKEN                          USB_ENDPTNAKEN_REG(USB1_BASE_PTR)
#define USB1_CONFIGFLAG                          USB_CONFIGFLAG_REG(USB1_BASE_PTR)
#define USB1_PORTSC1                             USB_PORTSC1_REG(USB1_BASE_PTR)
#define USB1_USBMODE                             USB_USBMODE_REG(USB1_BASE_PTR)
#define USB1_ENDPTSETUPSTAT                      USB_ENDPTSETUPSTAT_REG(USB1_BASE_PTR)
#define USB1_ENDPTPRIME                          USB_ENDPTPRIME_REG(USB1_BASE_PTR)
#define USB1_ENDPTFLUSH                          USB_ENDPTFLUSH_REG(USB1_BASE_PTR)
#define USB1_ENDPTSTAT                           USB_ENDPTSTAT_REG(USB1_BASE_PTR)
#define USB1_ENDPTCOMPLETE                       USB_ENDPTCOMPLETE_REG(USB1_BASE_PTR)
#define USB1_ENDPTCTRL0                          USB_ENDPTCTRL0_REG(USB1_BASE_PTR)
#define USB1_ENDPTCTRL1                          USB_ENDPTCTRL_REG(USB1_BASE_PTR,0)
#define USB1_ENDPTCTRL2                          USB_ENDPTCTRL_REG(USB1_BASE_PTR,1)
#define USB1_ENDPTCTRL3                          USB_ENDPTCTRL_REG(USB1_BASE_PTR,2)
#define USB1_ENDPTCTRL4                          USB_ENDPTCTRL_REG(USB1_BASE_PTR,3)
#define USB1_ENDPTCTRL5                          USB_ENDPTCTRL_REG(USB1_BASE_PTR,4)
#define USB1_ENDPTCTRL6                          USB_ENDPTCTRL_REG(USB1_BASE_PTR,5)
#define USB1_ENDPTCTRL7                          USB_ENDPTCTRL_REG(USB1_BASE_PTR,6)
/* USB2 */
#define USB2_ID                                  USB_ID_REG(USB2_BASE_PTR)
#define USB2_HWGENERAL                           USB_HWGENERAL_REG(USB2_BASE_PTR)
#define USB2_HWHOST                              USB_HWHOST_REG(USB2_BASE_PTR)
#define USB2_HWDEVICE                            USB_HWDEVICE_REG(USB2_BASE_PTR)
#define USB2_HWTXBUF                             USB_HWTXBUF_REG(USB2_BASE_PTR)
#define USB2_HWRXBUF                             USB_HWRXBUF_REG(USB2_BASE_PTR)
#define USB2_GPTIMER0LD                          USB_GPTIMER0LD_REG(USB2_BASE_PTR)
#define USB2_GPTIMER0CTRL                        USB_GPTIMER0CTRL_REG(USB2_BASE_PTR)
#define USB2_GPTIMER1LD                          USB_GPTIMER1LD_REG(USB2_BASE_PTR)
#define USB2_GPTIMER1CTRL                        USB_GPTIMER1CTRL_REG(USB2_BASE_PTR)
#define USB2_SBUSCFG                             USB_SBUSCFG_REG(USB2_BASE_PTR)
#define USB2_CAPLENGTH                           USB_CAPLENGTH_REG(USB2_BASE_PTR)
#define USB2_HCIVERSION                          USB_HCIVERSION_REG(USB2_BASE_PTR)
#define USB2_HCSPARAMS                           USB_HCSPARAMS_REG(USB2_BASE_PTR)
#define USB2_HCCPARAMS                           USB_HCCPARAMS_REG(USB2_BASE_PTR)
#define USB2_DCIVERSION                          USB_DCIVERSION_REG(USB2_BASE_PTR)
#define USB2_DCCPARAMS                           USB_DCCPARAMS_REG(USB2_BASE_PTR)
#define USB2_USBCMD                              USB_USBCMD_REG(USB2_BASE_PTR)
#define USB2_USBSTS                              USB_USBSTS_REG(USB2_BASE_PTR)
#define USB2_USBINTR                             USB_USBINTR_REG(USB2_BASE_PTR)
#define USB2_FRINDEX                             USB_FRINDEX_REG(USB2_BASE_PTR)
#define USB2_DEVICEADDR                          USB_DEVICEADDR_REG(USB2_BASE_PTR)
#define USB2_PERIODICLISTBASE                    USB_PERIODICLISTBASE_REG(USB2_BASE_PTR)
#define USB2_ASYNCLISTADDR                       USB_ASYNCLISTADDR_REG(USB2_BASE_PTR)
#define USB2_ENDPTLISTADDR                       USB_ENDPTLISTADDR_REG(USB2_BASE_PTR)
#define USB2_BURSTSIZE                           USB_BURSTSIZE_REG(USB2_BASE_PTR)
#define USB2_TXFILLTUNING                        USB_TXFILLTUNING_REG(USB2_BASE_PTR)
#define USB2_ENDPTNAK                            USB_ENDPTNAK_REG(USB2_BASE_PTR)
#define USB2_ENDPTNAKEN                          USB_ENDPTNAKEN_REG(USB2_BASE_PTR)
#define USB2_CONFIGFLAG                          USB_CONFIGFLAG_REG(USB2_BASE_PTR)
#define USB2_PORTSC1                             USB_PORTSC1_REG(USB2_BASE_PTR)
#define USB2_USBMODE                             USB_USBMODE_REG(USB2_BASE_PTR)
#define USB2_ENDPTSETUPSTAT                      USB_ENDPTSETUPSTAT_REG(USB2_BASE_PTR)
#define USB2_ENDPTPRIME                          USB_ENDPTPRIME_REG(USB2_BASE_PTR)
#define USB2_ENDPTFLUSH                          USB_ENDPTFLUSH_REG(USB2_BASE_PTR)
#define USB2_ENDPTSTAT                           USB_ENDPTSTAT_REG(USB2_BASE_PTR)
#define USB2_ENDPTCOMPLETE                       USB_ENDPTCOMPLETE_REG(USB2_BASE_PTR)
#define USB2_ENDPTCTRL0                          USB_ENDPTCTRL0_REG(USB2_BASE_PTR)
#define USB2_ENDPTCTRL1                          USB_ENDPTCTRL_REG(USB2_BASE_PTR,0)
#define USB2_ENDPTCTRL2                          USB_ENDPTCTRL_REG(USB2_BASE_PTR,1)
#define USB2_ENDPTCTRL3                          USB_ENDPTCTRL_REG(USB2_BASE_PTR,2)
#define USB2_ENDPTCTRL4                          USB_ENDPTCTRL_REG(USB2_BASE_PTR,3)
#define USB2_ENDPTCTRL5                          USB_ENDPTCTRL_REG(USB2_BASE_PTR,4)
#define USB2_ENDPTCTRL6                          USB_ENDPTCTRL_REG(USB2_BASE_PTR,5)
#define USB2_ENDPTCTRL7                          USB_ENDPTCTRL_REG(USB2_BASE_PTR,6)
/* USB_HSIC */
#define USB_HSIC_ID                              USB_ID_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_HWGENERAL                       USB_HWGENERAL_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_HWHOST                          USB_HWHOST_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_HWDEVICE                        USB_HWDEVICE_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_HWTXBUF                         USB_HWTXBUF_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_HWRXBUF                         USB_HWRXBUF_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_GPTIMER0LD                      USB_GPTIMER0LD_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_GPTIMER0CTRL                    USB_GPTIMER0CTRL_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_GPTIMER1LD                      USB_GPTIMER1LD_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_GPTIMER1CTRL                    USB_GPTIMER1CTRL_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_SBUSCFG                         USB_SBUSCFG_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_CAPLENGTH                       USB_CAPLENGTH_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_HCIVERSION                      USB_HCIVERSION_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_HCSPARAMS                       USB_HCSPARAMS_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_HCCPARAMS                       USB_HCCPARAMS_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_DCIVERSION                      USB_DCIVERSION_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_DCCPARAMS                       USB_DCCPARAMS_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_USBCMD                          USB_USBCMD_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_USBSTS                          USB_USBSTS_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_USBINTR                         USB_USBINTR_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_FRINDEX                         USB_FRINDEX_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_DEVICEADDR                      USB_DEVICEADDR_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_PERIODICLISTBASE                USB_PERIODICLISTBASE_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ASYNCLISTADDR                   USB_ASYNCLISTADDR_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTLISTADDR                   USB_ENDPTLISTADDR_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_BURSTSIZE                       USB_BURSTSIZE_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_TXFILLTUNING                    USB_TXFILLTUNING_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTNAK                        USB_ENDPTNAK_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTNAKEN                      USB_ENDPTNAKEN_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_CONFIGFLAG                      USB_CONFIGFLAG_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_PORTSC1                         USB_PORTSC1_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_OTGSC                           USB_OTGSC_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_USBMODE                         USB_USBMODE_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTSETUPSTAT                  USB_ENDPTSETUPSTAT_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTPRIME                      USB_ENDPTPRIME_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTFLUSH                      USB_ENDPTFLUSH_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTSTAT                       USB_ENDPTSTAT_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTCOMPLETE                   USB_ENDPTCOMPLETE_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTCTRL0                      USB_ENDPTCTRL0_REG(USB_HSIC_BASE_PTR)
#define USB_HSIC_ENDPTCTRL1                      USB_ENDPTCTRL_REG(USB_HSIC_BASE_PTR,0)
#define USB_HSIC_ENDPTCTRL2                      USB_ENDPTCTRL_REG(USB_HSIC_BASE_PTR,1)
#define USB_HSIC_ENDPTCTRL3                      USB_ENDPTCTRL_REG(USB_HSIC_BASE_PTR,2)
#define USB_HSIC_ENDPTCTRL4                      USB_ENDPTCTRL_REG(USB_HSIC_BASE_PTR,3)
#define USB_HSIC_ENDPTCTRL5                      USB_ENDPTCTRL_REG(USB_HSIC_BASE_PTR,4)
#define USB_HSIC_ENDPTCTRL6                      USB_ENDPTCTRL_REG(USB_HSIC_BASE_PTR,5)
#define USB_HSIC_ENDPTCTRL7                      USB_ENDPTCTRL_REG(USB_HSIC_BASE_PTR,6)

/* USB - Register array accessors */
#define USB1_ENDPTCTRL(index)                    USB_ENDPTCTRL_REG(USB1_BASE_PTR,index)
#define USB2_ENDPTCTRL(index)                    USB_ENDPTCTRL_REG(USB2_BASE_PTR,index)
#define USB_HSIC_ENDPTCTRL(index)                USB_ENDPTCTRL_REG(USB_HSIC_BASE_PTR,index)

/*!
 * @}
 */ /* end of group USB_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group USB_Peripheral */


/* ----------------------------------------------------------------------------
   -- USBNC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNC_Peripheral USBNC
 * @{
 */

/** USBNC - Peripheral register structure */
typedef struct USBNC_MemMap {
  uint32_t OTGn_CTRL1;                             /**< , offset: 0x0 */
  uint32_t OTGn_CTRL2;                             /**< , offset: 0x4 */
  uint8_t RESERVED_0[40];
  uint32_t OTGn_PHY_CFG1;                          /**< USB OTG PHY Configuration Register 1, offset: 0x30 */
  uint32_t OTGn_PHY_CFG2;                          /**< USB OTG PHY Configuration Register 2, offset: 0x34 */
  uint8_t RESERVED_1[4];
  uint32_t OTGn_PHY_STATUS;                        /**< USB OTG PHY Status Register, offset: 0x3C */
} volatile *USBNC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- USBNC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNC_Register_Accessor_Macros USBNC - Register accessor macros
 * @{
 */


/* USBNC - Register accessors */
#define USBNC_OTGn_CTRL1_REG(base)               ((base)->OTGn_CTRL1)
#define USBNC_OTGn_CTRL2_REG(base)               ((base)->OTGn_CTRL2)
#define USBNC_OTGn_PHY_CFG1_REG(base)            ((base)->OTGn_PHY_CFG1)
#define USBNC_OTGn_PHY_CFG2_REG(base)            ((base)->OTGn_PHY_CFG2)
#define USBNC_OTGn_PHY_STATUS_REG(base)          ((base)->OTGn_PHY_STATUS)

/*!
 * @}
 */ /* end of group USBNC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- USBNC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNC_Register_Masks USBNC Register Masks
 * @{
 */

/*! @name OTGn_CTRL1 -  */
#define USBNC_OTGn_CTRL1_OVER_CUR_DIS_MASK       (0x80U)
#define USBNC_OTGn_CTRL1_OVER_CUR_DIS_SHIFT      (7U)
#define USBNC_OTGn_CTRL1_OVER_CUR_POL_MASK       (0x100U)
#define USBNC_OTGn_CTRL1_OVER_CUR_POL_SHIFT      (8U)
#define USBNC_OTGn_CTRL1_PWR_POL_MASK            (0x200U)
#define USBNC_OTGn_CTRL1_PWR_POL_SHIFT           (9U)
#define USBNC_OTGn_CTRL1_WIE_MASK                (0x400U)
#define USBNC_OTGn_CTRL1_WIE_SHIFT               (10U)
#define USBNC_OTGn_CTRL1_WKUP_SW_EN_MASK         (0x4000U)
#define USBNC_OTGn_CTRL1_WKUP_SW_EN_SHIFT        (14U)
#define USBNC_OTGn_CTRL1_WKUP_SW_MASK            (0x8000U)
#define USBNC_OTGn_CTRL1_WKUP_SW_SHIFT           (15U)
#define USBNC_OTGn_CTRL1_WKUP_ID_EN_MASK         (0x10000U)
#define USBNC_OTGn_CTRL1_WKUP_ID_EN_SHIFT        (16U)
#define USBNC_OTGn_CTRL1_WKUP_VBUS_EN_MASK       (0x20000U)
#define USBNC_OTGn_CTRL1_WKUP_VBUS_EN_SHIFT      (17U)
#define USBNC_OTGn_CTRL1_WKUP_DPDM_EN_MASK       (0x20000000U)
#define USBNC_OTGn_CTRL1_WKUP_DPDM_EN_SHIFT      (29U)
#define USBNC_OTGn_CTRL1_WIR_MASK                (0x80000000U)
#define USBNC_OTGn_CTRL1_WIR_SHIFT               (31U)

/*! @name OTGn_CTRL2 -  */
#define USBNC_OTGn_CTRL2_VBUS_SOURCE_SEL_MASK    (0x3U)
#define USBNC_OTGn_CTRL2_VBUS_SOURCE_SEL_SHIFT   (0U)
#define USBNC_OTGn_CTRL2_VBUS_SOURCE_SEL(x)      (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_CTRL2_VBUS_SOURCE_SEL_SHIFT)) & USBNC_OTGn_CTRL2_VBUS_SOURCE_SEL_MASK)
#define USBNC_OTGn_CTRL2_AUTURESUME_EN_MASK      (0x4U)
#define USBNC_OTGn_CTRL2_AUTURESUME_EN_SHIFT     (2U)
#define USBNC_OTGn_CTRL2_LOWSPEED_EN_MASK        (0x8U)
#define USBNC_OTGn_CTRL2_LOWSPEED_EN_SHIFT       (3U)
#define USBNC_OTGn_CTRL2_TERMSEL_OVERRIDE_MASK   (0x10U)
#define USBNC_OTGn_CTRL2_TERMSEL_OVERRIDE_SHIFT  (4U)
#define USBNC_OTGn_CTRL2_TERMSEL_OVERRIDEEN_MASK (0x20U)
#define USBNC_OTGn_CTRL2_TERMSEL_OVERRIDEEN_SHIFT (5U)
#define USBNC_OTGn_CTRL2_OPMODE_OVERRIDE_MASK    (0xC0U)
#define USBNC_OTGn_CTRL2_OPMODE_OVERRIDE_SHIFT   (6U)
#define USBNC_OTGn_CTRL2_OPMODE_OVERRIDE(x)      (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_CTRL2_OPMODE_OVERRIDE_SHIFT)) & USBNC_OTGn_CTRL2_OPMODE_OVERRIDE_MASK)
#define USBNC_OTGn_CTRL2_OPMODE_OVERRIDEEN_MASK  (0x100U)
#define USBNC_OTGn_CTRL2_OPMODE_OVERRIDEEN_SHIFT (8U)
#define USBNC_OTGn_CTRL2_XCVRSEL_OVERRIDE_MASK   (0x600U)
#define USBNC_OTGn_CTRL2_XCVRSEL_OVERRIDE_SHIFT  (9U)
#define USBNC_OTGn_CTRL2_XCVRSEL_OVERRIDE(x)     (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_CTRL2_XCVRSEL_OVERRIDE_SHIFT)) & USBNC_OTGn_CTRL2_XCVRSEL_OVERRIDE_MASK)
#define USBNC_OTGn_CTRL2_XCVRSEL_OVERRIDEEN_MASK (0x800U)
#define USBNC_OTGn_CTRL2_XCVRSEL_OVERRIDEEN_SHIFT (11U)
#define USBNC_OTGn_CTRL2_DPPULLDOWN_OVERRIDE_MASK (0x1000U)
#define USBNC_OTGn_CTRL2_DPPULLDOWN_OVERRIDE_SHIFT (12U)
#define USBNC_OTGn_CTRL2_DPPULLDOWN_OVERRIDEEN_MASK (0x2000U)
#define USBNC_OTGn_CTRL2_DPPULLDOWN_OVERRIDEEN_SHIFT (13U)
#define USBNC_OTGn_CTRL2_DMPULLDOWN_OVERRIDE_MASK (0x4000U)
#define USBNC_OTGn_CTRL2_DMPULLDOWN_OVERRIDE_SHIFT (14U)
#define USBNC_OTGn_CTRL2_DMPULLDOWN_OVERRIDEEN_MASK (0x8000U)
#define USBNC_OTGn_CTRL2_DMPULLDOWN_OVERRIDEEN_SHIFT (15U)
#define USBNC_OTGn_CTRL2_DIG_ID_SEL_MASK         (0x100000U)
#define USBNC_OTGn_CTRL2_DIG_ID_SEL_SHIFT        (20U)
#define USBNC_OTGn_CTRL2_UTMI_CLK_VLD_MASK       (0x80000000U)
#define USBNC_OTGn_CTRL2_UTMI_CLK_VLD_SHIFT      (31U)

/*! @name OTGn_PHY_CFG1 - USB OTG PHY Configuration Register 1 */
#define USBNC_OTGn_PHY_CFG1_COMMONONN_MASK       (0x1U)
#define USBNC_OTGn_PHY_CFG1_COMMONONN_SHIFT      (0U)
#define USBNC_OTGn_PHY_CFG1_FSEL_MASK            (0xEU)
#define USBNC_OTGn_PHY_CFG1_FSEL_SHIFT           (1U)
#define USBNC_OTGn_PHY_CFG1_FSEL(x)              (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_FSEL_SHIFT)) & USBNC_OTGn_PHY_CFG1_FSEL_MASK)
#define USBNC_OTGn_PHY_CFG1_COMPDISTUNE0_MASK    (0x70U)
#define USBNC_OTGn_PHY_CFG1_COMPDISTUNE0_SHIFT   (4U)
#define USBNC_OTGn_PHY_CFG1_COMPDISTUNE0(x)      (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_COMPDISTUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_COMPDISTUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_SQRXTUNE0_MASK       (0x380U)
#define USBNC_OTGn_PHY_CFG1_SQRXTUNE0_SHIFT      (7U)
#define USBNC_OTGn_PHY_CFG1_SQRXTUNE0(x)         (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_SQRXTUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_SQRXTUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_OTGTUNE0_MASK        (0x1C00U)
#define USBNC_OTGn_PHY_CFG1_OTGTUNE0_SHIFT       (10U)
#define USBNC_OTGn_PHY_CFG1_OTGTUNE0(x)          (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_OTGTUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_OTGTUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_TXHSXVTUNE0_MASK     (0x6000U)
#define USBNC_OTGn_PHY_CFG1_TXHSXVTUNE0_SHIFT    (13U)
#define USBNC_OTGn_PHY_CFG1_TXHSXVTUNE0(x)       (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_TXHSXVTUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_TXHSXVTUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_TXFSLSTUNE0_MASK     (0xF0000U)
#define USBNC_OTGn_PHY_CFG1_TXFSLSTUNE0_SHIFT    (16U)
#define USBNC_OTGn_PHY_CFG1_TXFSLSTUNE0(x)       (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_TXFSLSTUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_TXFSLSTUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_TXVREFTUNE0_MASK     (0xF00000U)
#define USBNC_OTGn_PHY_CFG1_TXVREFTUNE0_SHIFT    (20U)
#define USBNC_OTGn_PHY_CFG1_TXVREFTUNE0(x)       (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_TXVREFTUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_TXVREFTUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_TXRISETUNE0_MASK     (0x3000000U)
#define USBNC_OTGn_PHY_CFG1_TXRISETUNE0_SHIFT    (24U)
#define USBNC_OTGn_PHY_CFG1_TXRISETUNE0(x)       (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_TXRISETUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_TXRISETUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_TXRESTUNE0_MASK      (0xC000000U)
#define USBNC_OTGn_PHY_CFG1_TXRESTUNE0_SHIFT     (26U)
#define USBNC_OTGn_PHY_CFG1_TXRESTUNE0(x)        (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_TXRESTUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_TXRESTUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_TXPREEMPAMPTUNE0_MASK (0x30000000U)
#define USBNC_OTGn_PHY_CFG1_TXPREEMPAMPTUNE0_SHIFT (28U)
#define USBNC_OTGn_PHY_CFG1_TXPREEMPAMPTUNE0(x)  (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_CFG1_TXPREEMPAMPTUNE0_SHIFT)) & USBNC_OTGn_PHY_CFG1_TXPREEMPAMPTUNE0_MASK)
#define USBNC_OTGn_PHY_CFG1_TXPREEMPPULSETUNE0_MASK (0x40000000U)
#define USBNC_OTGn_PHY_CFG1_TXPREEMPPULSETUNE0_SHIFT (30U)
#define USBNC_OTGn_PHY_CFG1_CHRGDET_Megamix_MASK (0x80000000U)
#define USBNC_OTGn_PHY_CFG1_CHRGDET_Megamix_SHIFT (31U)

/*! @name OTGn_PHY_CFG2 - USB OTG PHY Configuration Register 2 */
#define USBNC_OTGn_PHY_CFG2_CHRGSEL_MASK         (0x1U)
#define USBNC_OTGn_PHY_CFG2_CHRGSEL_SHIFT        (0U)
#define USBNC_OTGn_PHY_CFG2_VDATDETENB0_MASK     (0x2U)
#define USBNC_OTGn_PHY_CFG2_VDATDETENB0_SHIFT    (1U)
#define USBNC_OTGn_PHY_CFG2_VDATSRCENB0_MASK     (0x4U)
#define USBNC_OTGn_PHY_CFG2_VDATSRCENB0_SHIFT    (2U)
#define USBNC_OTGn_PHY_CFG2_DCDENB_MASK          (0x8U)
#define USBNC_OTGn_PHY_CFG2_DCDENB_SHIFT         (3U)
#define USBNC_OTGn_PHY_CFG2_ACAENB0_MASK         (0x10U)
#define USBNC_OTGn_PHY_CFG2_ACAENB0_SHIFT        (4U)
#define USBNC_OTGn_PHY_CFG2_SLEEPM0_MASK         (0x20U)
#define USBNC_OTGn_PHY_CFG2_SLEEPM0_SHIFT        (5U)
#define USBNC_OTGn_PHY_CFG2_LOOPBACKENB0_MASK    (0x40U)
#define USBNC_OTGn_PHY_CFG2_LOOPBACKENB0_SHIFT   (6U)
#define USBNC_OTGn_PHY_CFG2_TXBITSTUFFEN0_MASK   (0x100U)
#define USBNC_OTGn_PHY_CFG2_TXBITSTUFFEN0_SHIFT  (8U)
#define USBNC_OTGn_PHY_CFG2_TXBITSTUFFENH0_MASK  (0x200U)
#define USBNC_OTGn_PHY_CFG2_TXBITSTUFFENH0_SHIFT (9U)
#define USBNC_OTGn_PHY_CFG2_OTGDISABLE0_MASK     (0x400U)
#define USBNC_OTGn_PHY_CFG2_OTGDISABLE0_SHIFT    (10U)
#define USBNC_OTGn_PHY_CFG2_ADPCHRG0_MASK        (0x800U)
#define USBNC_OTGn_PHY_CFG2_ADPCHRG0_SHIFT       (11U)
#define USBNC_OTGn_PHY_CFG2_ADPDISCHRG0_MASK     (0x1000U)
#define USBNC_OTGn_PHY_CFG2_ADPDISCHRG0_SHIFT    (12U)
#define USBNC_OTGn_PHY_CFG2_ADPPRBENB0_MASK      (0x2000U)
#define USBNC_OTGn_PHY_CFG2_ADPPRBENB0_SHIFT     (13U)
#define USBNC_OTGn_PHY_CFG2_VBUSVLDEXTSEL0_MASK  (0x4000U)
#define USBNC_OTGn_PHY_CFG2_VBUSVLDEXTSEL0_SHIFT (14U)
#define USBNC_OTGn_PHY_CFG2_VBUSVLDEXT_MASK      (0x8000U)
#define USBNC_OTGn_PHY_CFG2_VBUSVLDEXT_SHIFT     (15U)
#define USBNC_OTGn_PHY_CFG2_DRVVBUS0_MASK        (0x10000U)
#define USBNC_OTGn_PHY_CFG2_DRVVBUS0_SHIFT       (16U)

/*! @name OTGn_PHY_STATUS - USB OTG PHY Status Register */
#define USBNC_OTGn_PHY_STATUS_LINE_STATE_MASK    (0x3U)
#define USBNC_OTGn_PHY_STATUS_LINE_STATE_SHIFT   (0U)
#define USBNC_OTGn_PHY_STATUS_LINE_STATE(x)      (((uint32_t)(((uint32_t)(x)) << USBNC_OTGn_PHY_STATUS_LINE_STATE_SHIFT)) & USBNC_OTGn_PHY_STATUS_LINE_STATE_MASK)
#define USBNC_OTGn_PHY_STATUS_SESS_VLD_MASK      (0x4U)
#define USBNC_OTGn_PHY_STATUS_SESS_VLD_SHIFT     (2U)
#define USBNC_OTGn_PHY_STATUS_VBUS_VLD_MASK      (0x8U)
#define USBNC_OTGn_PHY_STATUS_VBUS_VLD_SHIFT     (3U)
#define USBNC_OTGn_PHY_STATUS_ID_DIG_MASK        (0x10U)
#define USBNC_OTGn_PHY_STATUS_ID_DIG_SHIFT       (4U)
#define USBNC_OTGn_PHY_STATUS_HOST_DISCONNECT_MASK (0x20U)
#define USBNC_OTGn_PHY_STATUS_HOST_DISCONNECT_SHIFT (5U)
#define USBNC_OTGn_PHY_STATUS_RIDC0_MASK         (0x1000000U)
#define USBNC_OTGn_PHY_STATUS_RIDC0_SHIFT        (24U)
#define USBNC_OTGn_PHY_STATUS_RIDB0_MASK         (0x2000000U)
#define USBNC_OTGn_PHY_STATUS_RIDB0_SHIFT        (25U)
#define USBNC_OTGn_PHY_STATUS_RIDA0_MASK         (0x4000000U)
#define USBNC_OTGn_PHY_STATUS_RIDA0_SHIFT        (26U)
#define USBNC_OTGn_PHY_STATUS_RIDGND0_MASK       (0x8000000U)
#define USBNC_OTGn_PHY_STATUS_RIDGND0_SHIFT      (27U)
#define USBNC_OTGn_PHY_STATUS_RIDFLOAT0_MASK     (0x10000000U)
#define USBNC_OTGn_PHY_STATUS_RIDFLOAT0_SHIFT    (28U)
#define USBNC_OTGn_PHY_STATUS_CHRGDET_MASK       (0x20000000U)
#define USBNC_OTGn_PHY_STATUS_CHRGDET_SHIFT      (29U)
#define USBNC_OTGn_PHY_STATUS_ADPPRB0_MASK       (0x40000000U)
#define USBNC_OTGn_PHY_STATUS_ADPPRB0_SHIFT      (30U)
#define USBNC_OTGn_PHY_STATUS_ADPSNS0_MASK       (0x80000000U)
#define USBNC_OTGn_PHY_STATUS_ADPSNS0_SHIFT      (31U)


/*!
 * @}
 */ /* end of group USBNC_Register_Masks */


/* USBNC - Peripheral instance base addresses */
/** Peripheral USBNC1 base pointer */
#define USBNC1_BASE_PTR                          ((USBNC_MemMapPtr)0x30B10200u)
/** Peripheral USBNC2 base pointer */
#define USBNC2_BASE_PTR                          ((USBNC_MemMapPtr)0x30B20200u)
/** Array initializer of USBNC peripheral base pointers */
#define USBNC_BASE_PTRS                          { USBNC1_BASE_PTR, USBNC2_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- USBNC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNC_Register_Accessor_Macros USBNC - Register accessor macros
 * @{
 */


/* USBNC - Register instance definitions */
/* USBNC1 */
#define USBNC1_OTGn_CTRL1                        USBNC_OTGn_CTRL1_REG(USBNC1_BASE_PTR)
#define USBNC1_OTGn_CTRL2                        USBNC_OTGn_CTRL2_REG(USBNC1_BASE_PTR)
#define USBNC1_OTGn_PHY_CFG1                     USBNC_OTGn_PHY_CFG1_REG(USBNC1_BASE_PTR)
#define USBNC1_OTGn_PHY_CFG2                     USBNC_OTGn_PHY_CFG2_REG(USBNC1_BASE_PTR)
#define USBNC1_OTGn_PHY_STATUS                   USBNC_OTGn_PHY_STATUS_REG(USBNC1_BASE_PTR)
/* USBNC2 */
#define USBNC2_OTGn_CTRL1                        USBNC_OTGn_CTRL1_REG(USBNC2_BASE_PTR)
#define USBNC2_OTGn_CTRL2                        USBNC_OTGn_CTRL2_REG(USBNC2_BASE_PTR)
#define USBNC2_OTGn_PHY_CFG1                     USBNC_OTGn_PHY_CFG1_REG(USBNC2_BASE_PTR)
#define USBNC2_OTGn_PHY_CFG2                     USBNC_OTGn_PHY_CFG2_REG(USBNC2_BASE_PTR)
#define USBNC2_OTGn_PHY_STATUS                   USBNC_OTGn_PHY_STATUS_REG(USBNC2_BASE_PTR)

/*!
 * @}
 */ /* end of group USBNC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group USBNC_Peripheral */


/* ----------------------------------------------------------------------------
   -- USBNCADP
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNCADP_Peripheral USBNCADP
 * @{
 */

/** USBNCADP - Peripheral register structure */
typedef struct USBNCADP_MemMap {
  uint32_t ADP_CFG1;                               /**< , offset: 0x0 */
  uint32_t ADP_CFG2;                               /**< , offset: 0x4 */
  uint32_t ADP_STATUS;                             /**< , offset: 0x8 */
} volatile *USBNCADP_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- USBNCADP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNCADP_Register_Accessor_Macros USBNCADP - Register accessor macros
 * @{
 */


/* USBNCADP - Register accessors */
#define USBNCADP_ADP_CFG1_REG(base)              ((base)->ADP_CFG1)
#define USBNCADP_ADP_CFG2_REG(base)              ((base)->ADP_CFG2)
#define USBNCADP_ADP_STATUS_REG(base)            ((base)->ADP_STATUS)

/*!
 * @}
 */ /* end of group USBNCADP_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- USBNCADP Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNCADP_Register_Masks USBNCADP Register Masks
 * @{
 */

/*! @name ADP_CFG1 -  */
#define USBNCADP_ADP_CFG1_ADP_WAIT_MASK          (0x3FFFFU)
#define USBNCADP_ADP_CFG1_ADP_WAIT_SHIFT         (0U)
#define USBNCADP_ADP_CFG1_ADP_WAIT(x)            (((uint32_t)(((uint32_t)(x)) << USBNCADP_ADP_CFG1_ADP_WAIT_SHIFT)) & USBNCADP_ADP_CFG1_ADP_WAIT_MASK)
#define USBNCADP_ADP_CFG1_TIMER_EN_MASK          (0x100000U)
#define USBNCADP_ADP_CFG1_TIMER_EN_SHIFT         (20U)
#define USBNCADP_ADP_CFG1_ADP_SNS_INT_EN_MASK    (0x200000U)
#define USBNCADP_ADP_CFG1_ADP_SNS_INT_EN_SHIFT   (21U)
#define USBNCADP_ADP_CFG1_ADP_PRB_INT_EN_MASK    (0x400000U)
#define USBNCADP_ADP_CFG1_ADP_PRB_INT_EN_SHIFT   (22U)
#define USBNCADP_ADP_CFG1_ADP_PRB_EN_MASK        (0x800000U)
#define USBNCADP_ADP_CFG1_ADP_PRB_EN_SHIFT       (23U)

/*! @name ADP_CFG2 -  */
#define USBNCADP_ADP_CFG2_ADP_CHRG_DELTA_MASK    (0x7FU)
#define USBNCADP_ADP_CFG2_ADP_CHRG_DELTA_SHIFT   (0U)
#define USBNCADP_ADP_CFG2_ADP_CHRG_DELTA(x)      (((uint32_t)(((uint32_t)(x)) << USBNCADP_ADP_CFG2_ADP_CHRG_DELTA_SHIFT)) & USBNCADP_ADP_CFG2_ADP_CHRG_DELTA_MASK)
#define USBNCADP_ADP_CFG2_ADP_CHRG_SWCMP_MASK    (0x80U)
#define USBNCADP_ADP_CFG2_ADP_CHRG_SWCMP_SHIFT   (7U)
#define USBNCADP_ADP_CFG2_ADP_CHRG_SWTIME_MASK   (0xFF00U)
#define USBNCADP_ADP_CFG2_ADP_CHRG_SWTIME_SHIFT  (8U)
#define USBNCADP_ADP_CFG2_ADP_CHRG_SWTIME(x)     (((uint32_t)(((uint32_t)(x)) << USBNCADP_ADP_CFG2_ADP_CHRG_SWTIME_SHIFT)) & USBNCADP_ADP_CFG2_ADP_CHRG_SWTIME_MASK)
#define USBNCADP_ADP_CFG2_ADP_DISCHG_TIME_MASK   (0xFF0000U)
#define USBNCADP_ADP_CFG2_ADP_DISCHG_TIME_SHIFT  (16U)
#define USBNCADP_ADP_CFG2_ADP_DISCHG_TIME(x)     (((uint32_t)(((uint32_t)(x)) << USBNCADP_ADP_CFG2_ADP_DISCHG_TIME_SHIFT)) & USBNCADP_ADP_CFG2_ADP_DISCHG_TIME_MASK)

/*! @name ADP_STATUS -  */
#define USBNCADP_ADP_STATUS_ADP_PRB_TIMR_MASK    (0xFFU)
#define USBNCADP_ADP_STATUS_ADP_PRB_TIMR_SHIFT   (0U)
#define USBNCADP_ADP_STATUS_ADP_PRB_TIMR(x)      (((uint32_t)(((uint32_t)(x)) << USBNCADP_ADP_STATUS_ADP_PRB_TIMR_SHIFT)) & USBNCADP_ADP_STATUS_ADP_PRB_TIMR_MASK)
#define USBNCADP_ADP_STATUS_ADP_CNT_MASK         (0x3FFFF00U)
#define USBNCADP_ADP_STATUS_ADP_CNT_SHIFT        (8U)
#define USBNCADP_ADP_STATUS_ADP_CNT(x)           (((uint32_t)(((uint32_t)(x)) << USBNCADP_ADP_STATUS_ADP_CNT_SHIFT)) & USBNCADP_ADP_STATUS_ADP_CNT_MASK)
#define USBNCADP_ADP_STATUS_ADP_SNS_INT_MASK     (0x4000000U)
#define USBNCADP_ADP_STATUS_ADP_SNS_INT_SHIFT    (26U)
#define USBNCADP_ADP_STATUS_ADP_PRB_INT_MASK     (0x8000000U)
#define USBNCADP_ADP_STATUS_ADP_PRB_INT_SHIFT    (27U)


/*!
 * @}
 */ /* end of group USBNCADP_Register_Masks */


/* USBNCADP - Peripheral instance base addresses */
/** Peripheral USBNCADP base pointer */
#define USBNCADP_BASE_PTR                        ((USBNCADP_MemMapPtr)0x30B10250u)
/** Array initializer of USBNCADP peripheral base pointers */
#define USBNCADP_BASE_PTRS                       { USBNCADP_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- USBNCADP - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNCADP_Register_Accessor_Macros USBNCADP - Register accessor macros
 * @{
 */


/* USBNCADP - Register instance definitions */
/* USBNCADP */
#define USBNCADP_ADP_CFG1                        USBNCADP_ADP_CFG1_REG(USBNCADP_BASE_PTR)
#define USBNCADP_ADP_CFG2                        USBNCADP_ADP_CFG2_REG(USBNCADP_BASE_PTR)
#define USBNCADP_ADP_STATUS                      USBNCADP_ADP_STATUS_REG(USBNCADP_BASE_PTR)

/*!
 * @}
 */ /* end of group USBNCADP_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group USBNCADP_Peripheral */


/* ----------------------------------------------------------------------------
   -- USBNCHSIC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNCHSIC_Peripheral USBNCHSIC
 * @{
 */

/** USBNCHSIC - Peripheral register structure */
typedef struct USBNCHSIC_MemMap {
  uint32_t HSIC_CTRL1;                             /**< , offset: 0x0 */
  uint32_t HSIC_CTRL2;                             /**< , offset: 0x4 */
  uint8_t RESERVED_0[56];
  uint32_t UH_HSICPHY_CFG1;                        /**< USB Host HSIC PHY Configuration Register, offset: 0x40 */
} volatile *USBNCHSIC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- USBNCHSIC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNCHSIC_Register_Accessor_Macros USBNCHSIC - Register accessor macros
 * @{
 */


/* USBNCHSIC - Register accessors */
#define USBNCHSIC_HSIC_CTRL1_REG(base)           ((base)->HSIC_CTRL1)
#define USBNCHSIC_HSIC_CTRL2_REG(base)           ((base)->HSIC_CTRL2)
#define USBNCHSIC_UH_HSICPHY_CFG1_REG(base)      ((base)->UH_HSICPHY_CFG1)

/*!
 * @}
 */ /* end of group USBNCHSIC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- USBNCHSIC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNCHSIC_Register_Masks USBNCHSIC Register Masks
 * @{
 */

/*! @name HSIC_CTRL1 -  */
#define USBNCHSIC_HSIC_CTRL1_OVER_CUR_DIS_MASK   (0x80U)
#define USBNCHSIC_HSIC_CTRL1_OVER_CUR_DIS_SHIFT  (7U)
#define USBNCHSIC_HSIC_CTRL1_OVER_CUR_POL_MASK   (0x100U)
#define USBNCHSIC_HSIC_CTRL1_OVER_CUR_POL_SHIFT  (8U)
#define USBNCHSIC_HSIC_CTRL1_PWR_POL_MASK        (0x200U)
#define USBNCHSIC_HSIC_CTRL1_PWR_POL_SHIFT       (9U)
#define USBNCHSIC_HSIC_CTRL1_WIE_MASK            (0x400U)
#define USBNCHSIC_HSIC_CTRL1_WIE_SHIFT           (10U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_SW_EN_MASK     (0x4000U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_SW_EN_SHIFT    (14U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_SW_MASK        (0x8000U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_SW_SHIFT       (15U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_ID_EN_MASK     (0x10000U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_ID_EN_SHIFT    (16U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_VBUS_EN_MASK   (0x20000U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_VBUS_EN_SHIFT  (17U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_DPDM_EN_MASK   (0x20000000U)
#define USBNCHSIC_HSIC_CTRL1_WKUP_DPDM_EN_SHIFT  (29U)
#define USBNCHSIC_HSIC_CTRL1_WIR_MASK            (0x80000000U)
#define USBNCHSIC_HSIC_CTRL1_WIR_SHIFT           (31U)

/*! @name HSIC_CTRL2 -  */
#define USBNCHSIC_HSIC_CTRL2_VBUS_SOURCE_SEL_MASK (0x3U)
#define USBNCHSIC_HSIC_CTRL2_VBUS_SOURCE_SEL_SHIFT (0U)
#define USBNCHSIC_HSIC_CTRL2_VBUS_SOURCE_SEL(x)  (((uint32_t)(((uint32_t)(x)) << USBNCHSIC_HSIC_CTRL2_VBUS_SOURCE_SEL_SHIFT)) & USBNCHSIC_HSIC_CTRL2_VBUS_SOURCE_SEL_MASK)
#define USBNCHSIC_HSIC_CTRL2_AUTURESUME_EN_MASK  (0x4U)
#define USBNCHSIC_HSIC_CTRL2_AUTURESUME_EN_SHIFT (2U)
#define USBNCHSIC_HSIC_CTRL2_LOWSPEED_EN_MASK    (0x8U)
#define USBNCHSIC_HSIC_CTRL2_LOWSPEED_EN_SHIFT   (3U)
#define USBNCHSIC_HSIC_CTRL2_TERMSEL_OVERRIDE_MASK (0x10U)
#define USBNCHSIC_HSIC_CTRL2_TERMSEL_OVERRIDE_SHIFT (4U)
#define USBNCHSIC_HSIC_CTRL2_TERMSEL_OVERRIDEEN_MASK (0x20U)
#define USBNCHSIC_HSIC_CTRL2_TERMSEL_OVERRIDEEN_SHIFT (5U)
#define USBNCHSIC_HSIC_CTRL2_OPMODE_OVERRIDE_MASK (0xC0U)
#define USBNCHSIC_HSIC_CTRL2_OPMODE_OVERRIDE_SHIFT (6U)
#define USBNCHSIC_HSIC_CTRL2_OPMODE_OVERRIDE(x)  (((uint32_t)(((uint32_t)(x)) << USBNCHSIC_HSIC_CTRL2_OPMODE_OVERRIDE_SHIFT)) & USBNCHSIC_HSIC_CTRL2_OPMODE_OVERRIDE_MASK)
#define USBNCHSIC_HSIC_CTRL2_OPMODE_OVERRIDEEN_MASK (0x100U)
#define USBNCHSIC_HSIC_CTRL2_OPMODE_OVERRIDEEN_SHIFT (8U)
#define USBNCHSIC_HSIC_CTRL2_XCVRSEL_OVERRIDE_MASK (0x600U)
#define USBNCHSIC_HSIC_CTRL2_XCVRSEL_OVERRIDE_SHIFT (9U)
#define USBNCHSIC_HSIC_CTRL2_XCVRSEL_OVERRIDE(x) (((uint32_t)(((uint32_t)(x)) << USBNCHSIC_HSIC_CTRL2_XCVRSEL_OVERRIDE_SHIFT)) & USBNCHSIC_HSIC_CTRL2_XCVRSEL_OVERRIDE_MASK)
#define USBNCHSIC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN_MASK (0x800U)
#define USBNCHSIC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN_SHIFT (11U)
#define USBNCHSIC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE_MASK (0x1000U)
#define USBNCHSIC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE_SHIFT (12U)
#define USBNCHSIC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN_MASK (0x2000U)
#define USBNCHSIC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN_SHIFT (13U)
#define USBNCHSIC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE_MASK (0x4000U)
#define USBNCHSIC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE_SHIFT (14U)
#define USBNCHSIC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN_MASK (0x8000U)
#define USBNCHSIC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN_SHIFT (15U)
#define USBNCHSIC_HSIC_CTRL2_DIG_ID_SEL_MASK     (0x100000U)
#define USBNCHSIC_HSIC_CTRL2_DIG_ID_SEL_SHIFT    (20U)
#define USBNCHSIC_HSIC_CTRL2_UTMI_CLK_VLD_MASK   (0x80000000U)
#define USBNCHSIC_HSIC_CTRL2_UTMI_CLK_VLD_SHIFT  (31U)

/*! @name UH_HSICPHY_CFG1 - USB Host HSIC PHY Configuration Register */
#define USBNCHSIC_UH_HSICPHY_CFG1_COMMONONN_MASK (0x1U)
#define USBNCHSIC_UH_HSICPHY_CFG1_COMMONONN_SHIFT (0U)
#define USBNCHSIC_UH_HSICPHY_CFG1_LOOPBACKENB_MASK (0x2U)
#define USBNCHSIC_UH_HSICPHY_CFG1_LOOPBACKENB_SHIFT (1U)
#define USBNCHSIC_UH_HSICPHY_CFG1_DPPULLDOWN_MASK (0x4U)
#define USBNCHSIC_UH_HSICPHY_CFG1_DPPULLDOWN_SHIFT (2U)
#define USBNCHSIC_UH_HSICPHY_CFG1_DMPULLDOWN_MASK (0x8U)
#define USBNCHSIC_UH_HSICPHY_CFG1_DMPULLDOWN_SHIFT (3U)
#define USBNCHSIC_UH_HSICPHY_CFG1_SLEEPM_MASK    (0x10U)
#define USBNCHSIC_UH_HSICPHY_CFG1_SLEEPM_SHIFT   (4U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXBITSTUFFEN_MASK (0x20U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXBITSTUFFEN_SHIFT (5U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXBITSTUFFENH_MASK (0x40U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXBITSTUFFENH_SHIFT (6U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXRPUTUNE_MASK (0x300U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXRPUTUNE_SHIFT (8U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXRPUTUNE(x)   (((uint32_t)(((uint32_t)(x)) << USBNCHSIC_UH_HSICPHY_CFG1_TXRPUTUNE_SHIFT)) & USBNCHSIC_UH_HSICPHY_CFG1_TXRPUTUNE_MASK)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXRPDTUNE_MASK (0xC00U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXRPDTUNE_SHIFT (10U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXRPDTUNE(x)   (((uint32_t)(((uint32_t)(x)) << USBNCHSIC_UH_HSICPHY_CFG1_TXRPDTUNE_SHIFT)) & USBNCHSIC_UH_HSICPHY_CFG1_TXRPDTUNE_MASK)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXSRTUNE_MASK  (0xF000U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXSRTUNE_SHIFT (12U)
#define USBNCHSIC_UH_HSICPHY_CFG1_TXSRTUNE(x)    (((uint32_t)(((uint32_t)(x)) << USBNCHSIC_UH_HSICPHY_CFG1_TXSRTUNE_SHIFT)) & USBNCHSIC_UH_HSICPHY_CFG1_TXSRTUNE_MASK)
#define USBNCHSIC_UH_HSICPHY_CFG1_REFCLKDIV_MASK (0x7F0000U)
#define USBNCHSIC_UH_HSICPHY_CFG1_REFCLKDIV_SHIFT (16U)
#define USBNCHSIC_UH_HSICPHY_CFG1_REFCLKDIV(x)   (((uint32_t)(((uint32_t)(x)) << USBNCHSIC_UH_HSICPHY_CFG1_REFCLKDIV_SHIFT)) & USBNCHSIC_UH_HSICPHY_CFG1_REFCLKDIV_MASK)
#define USBNCHSIC_UH_HSICPHY_CFG1_REFCLKSEL_MASK (0x3000000U)
#define USBNCHSIC_UH_HSICPHY_CFG1_REFCLKSEL_SHIFT (24U)
#define USBNCHSIC_UH_HSICPHY_CFG1_REFCLKSEL(x)   (((uint32_t)(((uint32_t)(x)) << USBNCHSIC_UH_HSICPHY_CFG1_REFCLKSEL_SHIFT)) & USBNCHSIC_UH_HSICPHY_CFG1_REFCLKSEL_MASK)


/*!
 * @}
 */ /* end of group USBNCHSIC_Register_Masks */


/* USBNCHSIC - Peripheral instance base addresses */
/** Peripheral USBNCHSIC base pointer */
#define USBNCHSIC_BASE_PTR                       ((USBNCHSIC_MemMapPtr)0x30B30200u)
/** Array initializer of USBNCHSIC peripheral base pointers */
#define USBNCHSIC_BASE_PTRS                      { USBNCHSIC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- USBNCHSIC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USBNCHSIC_Register_Accessor_Macros USBNCHSIC - Register accessor macros
 * @{
 */


/* USBNCHSIC - Register instance definitions */
/* USBNCHSIC */
#define USBNCHSIC_HSIC_CTRL1                     USBNCHSIC_HSIC_CTRL1_REG(USBNCHSIC_BASE_PTR)
#define USBNCHSIC_HSIC_CTRL2                     USBNCHSIC_HSIC_CTRL2_REG(USBNCHSIC_BASE_PTR)
#define USBNCHSIC_UH_HSICPHY_CFG1                USBNCHSIC_UH_HSICPHY_CFG1_REG(USBNCHSIC_BASE_PTR)

/*!
 * @}
 */ /* end of group USBNCHSIC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group USBNCHSIC_Peripheral */


/* ----------------------------------------------------------------------------
   -- USDHC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USDHC_Peripheral USDHC
 * @{
 */

/** USDHC - Peripheral register structure */
typedef struct USDHC_MemMap {
  uint32_t DS_ADDR;                                /**< DMA System Address, offset: 0x0 */
  uint32_t BLK_ATT;                                /**< Block Attributes, offset: 0x4 */
  uint32_t CMD_ARG;                                /**< Command Argument, offset: 0x8 */
  uint32_t CMD_XFR_TYP;                            /**< Command Transfer Type, offset: 0xC */
  uint32_t CMD_RSP0;                               /**< Command Response0, offset: 0x10 */
  uint32_t CMD_RSP1;                               /**< Command Response1, offset: 0x14 */
  uint32_t CMD_RSP2;                               /**< Command Response2, offset: 0x18 */
  uint32_t CMD_RSP3;                               /**< Command Response3, offset: 0x1C */
  uint32_t DATA_BUFF_ACC_PORT;                     /**< Data Buffer Access Port, offset: 0x20 */
  uint32_t PRES_STATE;                             /**< Present State, offset: 0x24 */
  uint32_t PROT_CTRL;                              /**< Protocol Control, offset: 0x28 */
  uint32_t SYS_CTRL;                               /**< System Control, offset: 0x2C */
  uint32_t INT_STATUS;                             /**< Interrupt Status, offset: 0x30 */
  uint32_t INT_STATUS_EN;                          /**< Interrupt Status Enable, offset: 0x34 */
  uint32_t INT_SIGNAL_EN;                          /**< Interrupt Signal Enable, offset: 0x38 */
  uint32_t AUTOCMD12_ERR_STATUS;                   /**< Auto CMD12 Error Status, offset: 0x3C */
  uint32_t HOST_CTRL_CAP;                          /**< Host Controller Capabilities, offset: 0x40 */
  uint32_t WTMK_LVL;                               /**< Watermark Level, offset: 0x44 */
  uint32_t MIX_CTRL;                               /**< Mixer Control, offset: 0x48 */
  uint8_t RESERVED_0[4];
  uint32_t FORCE_EVENT;                            /**< Force Event, offset: 0x50 */
  uint32_t ADMA_ERR_STATUS;                        /**< ADMA Error Status Register, offset: 0x54 */
  uint32_t ADMA_SYS_ADDR;                          /**< ADMA System Address, offset: 0x58 */
  uint8_t RESERVED_1[4];
  uint32_t DLL_CTRL;                               /**< DLL (Delay Line) Control, offset: 0x60 */
  uint32_t DLL_STATUS;                             /**< DLL Status, offset: 0x64 */
  uint32_t CLK_TUNE_CTRL_STATUS;                   /**< CLK Tuning Control and Status, offset: 0x68 */
  uint8_t RESERVED_2[4];
  uint32_t STROBE_DLL_CTRL;                        /**< Strobe DLL Control, offset: 0x70 */
  uint32_t STROBE_DLL_STATUS;                      /**< Strobe DLL Status, offset: 0x74 */
  uint8_t RESERVED_3[72];
  uint32_t VEND_SPEC;                              /**< Vendor Specific Register, offset: 0xC0 */
  uint32_t MMC_BOOT;                               /**< MMC Boot Register, offset: 0xC4 */
  uint32_t VEND_SPEC2;                             /**< Vendor Specific 2 Register, offset: 0xC8 */
  uint32_t TUNING_CTRL;                            /**< Tuning Control Register, offset: 0xCC */
} volatile *USDHC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- USDHC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USDHC_Register_Accessor_Macros USDHC - Register accessor macros
 * @{
 */


/* USDHC - Register accessors */
#define USDHC_DS_ADDR_REG(base)                  ((base)->DS_ADDR)
#define USDHC_BLK_ATT_REG(base)                  ((base)->BLK_ATT)
#define USDHC_CMD_ARG_REG(base)                  ((base)->CMD_ARG)
#define USDHC_CMD_XFR_TYP_REG(base)              ((base)->CMD_XFR_TYP)
#define USDHC_CMD_RSP0_REG(base)                 ((base)->CMD_RSP0)
#define USDHC_CMD_RSP1_REG(base)                 ((base)->CMD_RSP1)
#define USDHC_CMD_RSP2_REG(base)                 ((base)->CMD_RSP2)
#define USDHC_CMD_RSP3_REG(base)                 ((base)->CMD_RSP3)
#define USDHC_DATA_BUFF_ACC_PORT_REG(base)       ((base)->DATA_BUFF_ACC_PORT)
#define USDHC_PRES_STATE_REG(base)               ((base)->PRES_STATE)
#define USDHC_PROT_CTRL_REG(base)                ((base)->PROT_CTRL)
#define USDHC_SYS_CTRL_REG(base)                 ((base)->SYS_CTRL)
#define USDHC_INT_STATUS_REG(base)               ((base)->INT_STATUS)
#define USDHC_INT_STATUS_EN_REG(base)            ((base)->INT_STATUS_EN)
#define USDHC_INT_SIGNAL_EN_REG(base)            ((base)->INT_SIGNAL_EN)
#define USDHC_AUTOCMD12_ERR_STATUS_REG(base)     ((base)->AUTOCMD12_ERR_STATUS)
#define USDHC_HOST_CTRL_CAP_REG(base)            ((base)->HOST_CTRL_CAP)
#define USDHC_WTMK_LVL_REG(base)                 ((base)->WTMK_LVL)
#define USDHC_MIX_CTRL_REG(base)                 ((base)->MIX_CTRL)
#define USDHC_FORCE_EVENT_REG(base)              ((base)->FORCE_EVENT)
#define USDHC_ADMA_ERR_STATUS_REG(base)          ((base)->ADMA_ERR_STATUS)
#define USDHC_ADMA_SYS_ADDR_REG(base)            ((base)->ADMA_SYS_ADDR)
#define USDHC_DLL_CTRL_REG(base)                 ((base)->DLL_CTRL)
#define USDHC_DLL_STATUS_REG(base)               ((base)->DLL_STATUS)
#define USDHC_CLK_TUNE_CTRL_STATUS_REG(base)     ((base)->CLK_TUNE_CTRL_STATUS)
#define USDHC_STROBE_DLL_CTRL_REG(base)          ((base)->STROBE_DLL_CTRL)
#define USDHC_STROBE_DLL_STATUS_REG(base)        ((base)->STROBE_DLL_STATUS)
#define USDHC_VEND_SPEC_REG(base)                ((base)->VEND_SPEC)
#define USDHC_MMC_BOOT_REG(base)                 ((base)->MMC_BOOT)
#define USDHC_VEND_SPEC2_REG(base)               ((base)->VEND_SPEC2)
#define USDHC_TUNING_CTRL_REG(base)              ((base)->TUNING_CTRL)

/*!
 * @}
 */ /* end of group USDHC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- USDHC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USDHC_Register_Masks USDHC Register Masks
 * @{
 */

/*! @name DS_ADDR - DMA System Address */
#define USDHC_DS_ADDR_DS_ADDR_MASK               (0xFFFFFFFCU)
#define USDHC_DS_ADDR_DS_ADDR_SHIFT              (2U)
#define USDHC_DS_ADDR_DS_ADDR(x)                 (((uint32_t)(((uint32_t)(x)) << USDHC_DS_ADDR_DS_ADDR_SHIFT)) & USDHC_DS_ADDR_DS_ADDR_MASK)

/*! @name BLK_ATT - Block Attributes */
#define USDHC_BLK_ATT_BLKSIZE_MASK               (0x1FFFU)
#define USDHC_BLK_ATT_BLKSIZE_SHIFT              (0U)
#define USDHC_BLK_ATT_BLKSIZE(x)                 (((uint32_t)(((uint32_t)(x)) << USDHC_BLK_ATT_BLKSIZE_SHIFT)) & USDHC_BLK_ATT_BLKSIZE_MASK)
#define USDHC_BLK_ATT_BLKCNT_MASK                (0xFFFF0000U)
#define USDHC_BLK_ATT_BLKCNT_SHIFT               (16U)
#define USDHC_BLK_ATT_BLKCNT(x)                  (((uint32_t)(((uint32_t)(x)) << USDHC_BLK_ATT_BLKCNT_SHIFT)) & USDHC_BLK_ATT_BLKCNT_MASK)

/*! @name CMD_ARG - Command Argument */
#define USDHC_CMD_ARG_CMDARG_MASK                (0xFFFFFFFFU)
#define USDHC_CMD_ARG_CMDARG_SHIFT               (0U)
#define USDHC_CMD_ARG_CMDARG(x)                  (((uint32_t)(((uint32_t)(x)) << USDHC_CMD_ARG_CMDARG_SHIFT)) & USDHC_CMD_ARG_CMDARG_MASK)

/*! @name CMD_XFR_TYP - Command Transfer Type */
#define USDHC_CMD_XFR_TYP_RSPTYP_MASK            (0x30000U)
#define USDHC_CMD_XFR_TYP_RSPTYP_SHIFT           (16U)
#define USDHC_CMD_XFR_TYP_RSPTYP(x)              (((uint32_t)(((uint32_t)(x)) << USDHC_CMD_XFR_TYP_RSPTYP_SHIFT)) & USDHC_CMD_XFR_TYP_RSPTYP_MASK)
#define USDHC_CMD_XFR_TYP_CCCEN_MASK             (0x80000U)
#define USDHC_CMD_XFR_TYP_CCCEN_SHIFT            (19U)
#define USDHC_CMD_XFR_TYP_CICEN_MASK             (0x100000U)
#define USDHC_CMD_XFR_TYP_CICEN_SHIFT            (20U)
#define USDHC_CMD_XFR_TYP_DPSEL_MASK             (0x200000U)
#define USDHC_CMD_XFR_TYP_DPSEL_SHIFT            (21U)
#define USDHC_CMD_XFR_TYP_CMDTYP_MASK            (0xC00000U)
#define USDHC_CMD_XFR_TYP_CMDTYP_SHIFT           (22U)
#define USDHC_CMD_XFR_TYP_CMDTYP(x)              (((uint32_t)(((uint32_t)(x)) << USDHC_CMD_XFR_TYP_CMDTYP_SHIFT)) & USDHC_CMD_XFR_TYP_CMDTYP_MASK)
#define USDHC_CMD_XFR_TYP_CMDINX_MASK            (0x3F000000U)
#define USDHC_CMD_XFR_TYP_CMDINX_SHIFT           (24U)
#define USDHC_CMD_XFR_TYP_CMDINX(x)              (((uint32_t)(((uint32_t)(x)) << USDHC_CMD_XFR_TYP_CMDINX_SHIFT)) & USDHC_CMD_XFR_TYP_CMDINX_MASK)

/*! @name CMD_RSP0 - Command Response0 */
#define USDHC_CMD_RSP0_CMDRSP0_MASK              (0xFFFFFFFFU)
#define USDHC_CMD_RSP0_CMDRSP0_SHIFT             (0U)
#define USDHC_CMD_RSP0_CMDRSP0(x)                (((uint32_t)(((uint32_t)(x)) << USDHC_CMD_RSP0_CMDRSP0_SHIFT)) & USDHC_CMD_RSP0_CMDRSP0_MASK)

/*! @name CMD_RSP1 - Command Response1 */
#define USDHC_CMD_RSP1_CMDRSP1_MASK              (0xFFFFFFFFU)
#define USDHC_CMD_RSP1_CMDRSP1_SHIFT             (0U)
#define USDHC_CMD_RSP1_CMDRSP1(x)                (((uint32_t)(((uint32_t)(x)) << USDHC_CMD_RSP1_CMDRSP1_SHIFT)) & USDHC_CMD_RSP1_CMDRSP1_MASK)

/*! @name CMD_RSP2 - Command Response2 */
#define USDHC_CMD_RSP2_CMDRSP2_MASK              (0xFFFFFFFFU)
#define USDHC_CMD_RSP2_CMDRSP2_SHIFT             (0U)
#define USDHC_CMD_RSP2_CMDRSP2(x)                (((uint32_t)(((uint32_t)(x)) << USDHC_CMD_RSP2_CMDRSP2_SHIFT)) & USDHC_CMD_RSP2_CMDRSP2_MASK)

/*! @name CMD_RSP3 - Command Response3 */
#define USDHC_CMD_RSP3_CMDRSP3_MASK              (0xFFFFFFFFU)
#define USDHC_CMD_RSP3_CMDRSP3_SHIFT             (0U)
#define USDHC_CMD_RSP3_CMDRSP3(x)                (((uint32_t)(((uint32_t)(x)) << USDHC_CMD_RSP3_CMDRSP3_SHIFT)) & USDHC_CMD_RSP3_CMDRSP3_MASK)

/*! @name DATA_BUFF_ACC_PORT - Data Buffer Access Port */
#define USDHC_DATA_BUFF_ACC_PORT_DATCONT_MASK    (0xFFFFFFFFU)
#define USDHC_DATA_BUFF_ACC_PORT_DATCONT_SHIFT   (0U)
#define USDHC_DATA_BUFF_ACC_PORT_DATCONT(x)      (((uint32_t)(((uint32_t)(x)) << USDHC_DATA_BUFF_ACC_PORT_DATCONT_SHIFT)) & USDHC_DATA_BUFF_ACC_PORT_DATCONT_MASK)

/*! @name PRES_STATE - Present State */
#define USDHC_PRES_STATE_CIHB_MASK               (0x1U)
#define USDHC_PRES_STATE_CIHB_SHIFT              (0U)
#define USDHC_PRES_STATE_CDIHB_MASK              (0x2U)
#define USDHC_PRES_STATE_CDIHB_SHIFT             (1U)
#define USDHC_PRES_STATE_DLA_MASK                (0x4U)
#define USDHC_PRES_STATE_DLA_SHIFT               (2U)
#define USDHC_PRES_STATE_SDSTB_MASK              (0x8U)
#define USDHC_PRES_STATE_SDSTB_SHIFT             (3U)
#define USDHC_PRES_STATE_IPGOFF_MASK             (0x10U)
#define USDHC_PRES_STATE_IPGOFF_SHIFT            (4U)
#define USDHC_PRES_STATE_HCKOFF_MASK             (0x20U)
#define USDHC_PRES_STATE_HCKOFF_SHIFT            (5U)
#define USDHC_PRES_STATE_PEROFF_MASK             (0x40U)
#define USDHC_PRES_STATE_PEROFF_SHIFT            (6U)
#define USDHC_PRES_STATE_SDOFF_MASK              (0x80U)
#define USDHC_PRES_STATE_SDOFF_SHIFT             (7U)
#define USDHC_PRES_STATE_WTA_MASK                (0x100U)
#define USDHC_PRES_STATE_WTA_SHIFT               (8U)
#define USDHC_PRES_STATE_RTA_MASK                (0x200U)
#define USDHC_PRES_STATE_RTA_SHIFT               (9U)
#define USDHC_PRES_STATE_BWEN_MASK               (0x400U)
#define USDHC_PRES_STATE_BWEN_SHIFT              (10U)
#define USDHC_PRES_STATE_BREN_MASK               (0x800U)
#define USDHC_PRES_STATE_BREN_SHIFT              (11U)
#define USDHC_PRES_STATE_RTR_MASK                (0x1000U)
#define USDHC_PRES_STATE_RTR_SHIFT               (12U)
#define USDHC_PRES_STATE_TSCD_MASK               (0x8000U)
#define USDHC_PRES_STATE_TSCD_SHIFT              (15U)
#define USDHC_PRES_STATE_CINST_MASK              (0x10000U)
#define USDHC_PRES_STATE_CINST_SHIFT             (16U)
#define USDHC_PRES_STATE_CDPL_MASK               (0x40000U)
#define USDHC_PRES_STATE_CDPL_SHIFT              (18U)
#define USDHC_PRES_STATE_WPSPL_MASK              (0x80000U)
#define USDHC_PRES_STATE_WPSPL_SHIFT             (19U)
#define USDHC_PRES_STATE_CLSL_MASK               (0x800000U)
#define USDHC_PRES_STATE_CLSL_SHIFT              (23U)
#define USDHC_PRES_STATE_DLSL_MASK               (0xFF000000U)
#define USDHC_PRES_STATE_DLSL_SHIFT              (24U)
#define USDHC_PRES_STATE_DLSL(x)                 (((uint32_t)(((uint32_t)(x)) << USDHC_PRES_STATE_DLSL_SHIFT)) & USDHC_PRES_STATE_DLSL_MASK)

/*! @name PROT_CTRL - Protocol Control */
#define USDHC_PROT_CTRL_LCTL_MASK                (0x1U)
#define USDHC_PROT_CTRL_LCTL_SHIFT               (0U)
#define USDHC_PROT_CTRL_DTW_MASK                 (0x6U)
#define USDHC_PROT_CTRL_DTW_SHIFT                (1U)
#define USDHC_PROT_CTRL_DTW(x)                   (((uint32_t)(((uint32_t)(x)) << USDHC_PROT_CTRL_DTW_SHIFT)) & USDHC_PROT_CTRL_DTW_MASK)
#define USDHC_PROT_CTRL_D3CD_MASK                (0x8U)
#define USDHC_PROT_CTRL_D3CD_SHIFT               (3U)
#define USDHC_PROT_CTRL_EMODE_MASK               (0x30U)
#define USDHC_PROT_CTRL_EMODE_SHIFT              (4U)
#define USDHC_PROT_CTRL_EMODE(x)                 (((uint32_t)(((uint32_t)(x)) << USDHC_PROT_CTRL_EMODE_SHIFT)) & USDHC_PROT_CTRL_EMODE_MASK)
#define USDHC_PROT_CTRL_CDTL_MASK                (0x40U)
#define USDHC_PROT_CTRL_CDTL_SHIFT               (6U)
#define USDHC_PROT_CTRL_CDSS_MASK                (0x80U)
#define USDHC_PROT_CTRL_CDSS_SHIFT               (7U)
#define USDHC_PROT_CTRL_DMASEL_MASK              (0x300U)
#define USDHC_PROT_CTRL_DMASEL_SHIFT             (8U)
#define USDHC_PROT_CTRL_DMASEL(x)                (((uint32_t)(((uint32_t)(x)) << USDHC_PROT_CTRL_DMASEL_SHIFT)) & USDHC_PROT_CTRL_DMASEL_MASK)
#define USDHC_PROT_CTRL_SABGREQ_MASK             (0x10000U)
#define USDHC_PROT_CTRL_SABGREQ_SHIFT            (16U)
#define USDHC_PROT_CTRL_CREQ_MASK                (0x20000U)
#define USDHC_PROT_CTRL_CREQ_SHIFT               (17U)
#define USDHC_PROT_CTRL_RWCTL_MASK               (0x40000U)
#define USDHC_PROT_CTRL_RWCTL_SHIFT              (18U)
#define USDHC_PROT_CTRL_IABG_MASK                (0x80000U)
#define USDHC_PROT_CTRL_IABG_SHIFT               (19U)
#define USDHC_PROT_CTRL_RD_DONE_NO_8CLK_MASK     (0x100000U)
#define USDHC_PROT_CTRL_RD_DONE_NO_8CLK_SHIFT    (20U)
#define USDHC_PROT_CTRL_WECINT_MASK              (0x1000000U)
#define USDHC_PROT_CTRL_WECINT_SHIFT             (24U)
#define USDHC_PROT_CTRL_WECINS_MASK              (0x2000000U)
#define USDHC_PROT_CTRL_WECINS_SHIFT             (25U)
#define USDHC_PROT_CTRL_WECRM_MASK               (0x4000000U)
#define USDHC_PROT_CTRL_WECRM_SHIFT              (26U)
#define USDHC_PROT_CTRL_BURST_LEN_EN_MASK        (0x38000000U)
#define USDHC_PROT_CTRL_BURST_LEN_EN_SHIFT       (27U)
#define USDHC_PROT_CTRL_BURST_LEN_EN(x)          (((uint32_t)(((uint32_t)(x)) << USDHC_PROT_CTRL_BURST_LEN_EN_SHIFT)) & USDHC_PROT_CTRL_BURST_LEN_EN_MASK)
#define USDHC_PROT_CTRL_NON_EXACT_BLK_RD_MASK    (0x40000000U)
#define USDHC_PROT_CTRL_NON_EXACT_BLK_RD_SHIFT   (30U)

/*! @name SYS_CTRL - System Control */
#define USDHC_SYS_CTRL_DVS_MASK                  (0xF0U)
#define USDHC_SYS_CTRL_DVS_SHIFT                 (4U)
#define USDHC_SYS_CTRL_DVS(x)                    (((uint32_t)(((uint32_t)(x)) << USDHC_SYS_CTRL_DVS_SHIFT)) & USDHC_SYS_CTRL_DVS_MASK)
#define USDHC_SYS_CTRL_SDCLKFS_MASK              (0xFF00U)
#define USDHC_SYS_CTRL_SDCLKFS_SHIFT             (8U)
#define USDHC_SYS_CTRL_SDCLKFS(x)                (((uint32_t)(((uint32_t)(x)) << USDHC_SYS_CTRL_SDCLKFS_SHIFT)) & USDHC_SYS_CTRL_SDCLKFS_MASK)
#define USDHC_SYS_CTRL_DTOCV_MASK                (0xF0000U)
#define USDHC_SYS_CTRL_DTOCV_SHIFT               (16U)
#define USDHC_SYS_CTRL_DTOCV(x)                  (((uint32_t)(((uint32_t)(x)) << USDHC_SYS_CTRL_DTOCV_SHIFT)) & USDHC_SYS_CTRL_DTOCV_MASK)
#define USDHC_SYS_CTRL_IPP_RST_N_MASK            (0x800000U)
#define USDHC_SYS_CTRL_IPP_RST_N_SHIFT           (23U)
#define USDHC_SYS_CTRL_RSTA_MASK                 (0x1000000U)
#define USDHC_SYS_CTRL_RSTA_SHIFT                (24U)
#define USDHC_SYS_CTRL_RSTC_MASK                 (0x2000000U)
#define USDHC_SYS_CTRL_RSTC_SHIFT                (25U)
#define USDHC_SYS_CTRL_RSTD_MASK                 (0x4000000U)
#define USDHC_SYS_CTRL_RSTD_SHIFT                (26U)
#define USDHC_SYS_CTRL_INITA_MASK                (0x8000000U)
#define USDHC_SYS_CTRL_INITA_SHIFT               (27U)
#define USDHC_SYS_CTRL_RSTT_MASK                 (0x10000000U)
#define USDHC_SYS_CTRL_RSTT_SHIFT                (28U)

/*! @name INT_STATUS - Interrupt Status */
#define USDHC_INT_STATUS_CC_MASK                 (0x1U)
#define USDHC_INT_STATUS_CC_SHIFT                (0U)
#define USDHC_INT_STATUS_TC_MASK                 (0x2U)
#define USDHC_INT_STATUS_TC_SHIFT                (1U)
#define USDHC_INT_STATUS_BGE_MASK                (0x4U)
#define USDHC_INT_STATUS_BGE_SHIFT               (2U)
#define USDHC_INT_STATUS_DINT_MASK               (0x8U)
#define USDHC_INT_STATUS_DINT_SHIFT              (3U)
#define USDHC_INT_STATUS_BWR_MASK                (0x10U)
#define USDHC_INT_STATUS_BWR_SHIFT               (4U)
#define USDHC_INT_STATUS_BRR_MASK                (0x20U)
#define USDHC_INT_STATUS_BRR_SHIFT               (5U)
#define USDHC_INT_STATUS_CINS_MASK               (0x40U)
#define USDHC_INT_STATUS_CINS_SHIFT              (6U)
#define USDHC_INT_STATUS_CRM_MASK                (0x80U)
#define USDHC_INT_STATUS_CRM_SHIFT               (7U)
#define USDHC_INT_STATUS_CINT_MASK               (0x100U)
#define USDHC_INT_STATUS_CINT_SHIFT              (8U)
#define USDHC_INT_STATUS_RTE_MASK                (0x1000U)
#define USDHC_INT_STATUS_RTE_SHIFT               (12U)
#define USDHC_INT_STATUS_TP_MASK                 (0x4000U)
#define USDHC_INT_STATUS_TP_SHIFT                (14U)
#define USDHC_INT_STATUS_CTOE_MASK               (0x10000U)
#define USDHC_INT_STATUS_CTOE_SHIFT              (16U)
#define USDHC_INT_STATUS_CCE_MASK                (0x20000U)
#define USDHC_INT_STATUS_CCE_SHIFT               (17U)
#define USDHC_INT_STATUS_CEBE_MASK               (0x40000U)
#define USDHC_INT_STATUS_CEBE_SHIFT              (18U)
#define USDHC_INT_STATUS_CIE_MASK                (0x80000U)
#define USDHC_INT_STATUS_CIE_SHIFT               (19U)
#define USDHC_INT_STATUS_DTOE_MASK               (0x100000U)
#define USDHC_INT_STATUS_DTOE_SHIFT              (20U)
#define USDHC_INT_STATUS_DCE_MASK                (0x200000U)
#define USDHC_INT_STATUS_DCE_SHIFT               (21U)
#define USDHC_INT_STATUS_DEBE_MASK               (0x400000U)
#define USDHC_INT_STATUS_DEBE_SHIFT              (22U)
#define USDHC_INT_STATUS_AC12E_MASK              (0x1000000U)
#define USDHC_INT_STATUS_AC12E_SHIFT             (24U)
#define USDHC_INT_STATUS_TNE_MASK                (0x4000000U)
#define USDHC_INT_STATUS_TNE_SHIFT               (26U)
#define USDHC_INT_STATUS_DMAE_MASK               (0x10000000U)
#define USDHC_INT_STATUS_DMAE_SHIFT              (28U)

/*! @name INT_STATUS_EN - Interrupt Status Enable */
#define USDHC_INT_STATUS_EN_CCSEN_MASK           (0x1U)
#define USDHC_INT_STATUS_EN_CCSEN_SHIFT          (0U)
#define USDHC_INT_STATUS_EN_TCSEN_MASK           (0x2U)
#define USDHC_INT_STATUS_EN_TCSEN_SHIFT          (1U)
#define USDHC_INT_STATUS_EN_BGESEN_MASK          (0x4U)
#define USDHC_INT_STATUS_EN_BGESEN_SHIFT         (2U)
#define USDHC_INT_STATUS_EN_DINTSEN_MASK         (0x8U)
#define USDHC_INT_STATUS_EN_DINTSEN_SHIFT        (3U)
#define USDHC_INT_STATUS_EN_BWRSEN_MASK          (0x10U)
#define USDHC_INT_STATUS_EN_BWRSEN_SHIFT         (4U)
#define USDHC_INT_STATUS_EN_BRRSEN_MASK          (0x20U)
#define USDHC_INT_STATUS_EN_BRRSEN_SHIFT         (5U)
#define USDHC_INT_STATUS_EN_CINSSEN_MASK         (0x40U)
#define USDHC_INT_STATUS_EN_CINSSEN_SHIFT        (6U)
#define USDHC_INT_STATUS_EN_CRMSEN_MASK          (0x80U)
#define USDHC_INT_STATUS_EN_CRMSEN_SHIFT         (7U)
#define USDHC_INT_STATUS_EN_CINTSEN_MASK         (0x100U)
#define USDHC_INT_STATUS_EN_CINTSEN_SHIFT        (8U)
#define USDHC_INT_STATUS_EN_RTESEN_MASK          (0x1000U)
#define USDHC_INT_STATUS_EN_RTESEN_SHIFT         (12U)
#define USDHC_INT_STATUS_EN_TPSEN_MASK           (0x4000U)
#define USDHC_INT_STATUS_EN_TPSEN_SHIFT          (14U)
#define USDHC_INT_STATUS_EN_CTOESEN_MASK         (0x10000U)
#define USDHC_INT_STATUS_EN_CTOESEN_SHIFT        (16U)
#define USDHC_INT_STATUS_EN_CCESEN_MASK          (0x20000U)
#define USDHC_INT_STATUS_EN_CCESEN_SHIFT         (17U)
#define USDHC_INT_STATUS_EN_CEBESEN_MASK         (0x40000U)
#define USDHC_INT_STATUS_EN_CEBESEN_SHIFT        (18U)
#define USDHC_INT_STATUS_EN_CIESEN_MASK          (0x80000U)
#define USDHC_INT_STATUS_EN_CIESEN_SHIFT         (19U)
#define USDHC_INT_STATUS_EN_DTOESEN_MASK         (0x100000U)
#define USDHC_INT_STATUS_EN_DTOESEN_SHIFT        (20U)
#define USDHC_INT_STATUS_EN_DCESEN_MASK          (0x200000U)
#define USDHC_INT_STATUS_EN_DCESEN_SHIFT         (21U)
#define USDHC_INT_STATUS_EN_DEBESEN_MASK         (0x400000U)
#define USDHC_INT_STATUS_EN_DEBESEN_SHIFT        (22U)
#define USDHC_INT_STATUS_EN_AC12ESEN_MASK        (0x1000000U)
#define USDHC_INT_STATUS_EN_AC12ESEN_SHIFT       (24U)
#define USDHC_INT_STATUS_EN_TNESEN_MASK          (0x4000000U)
#define USDHC_INT_STATUS_EN_TNESEN_SHIFT         (26U)
#define USDHC_INT_STATUS_EN_DMAESEN_MASK         (0x10000000U)
#define USDHC_INT_STATUS_EN_DMAESEN_SHIFT        (28U)

/*! @name INT_SIGNAL_EN - Interrupt Signal Enable */
#define USDHC_INT_SIGNAL_EN_CCIEN_MASK           (0x1U)
#define USDHC_INT_SIGNAL_EN_CCIEN_SHIFT          (0U)
#define USDHC_INT_SIGNAL_EN_TCIEN_MASK           (0x2U)
#define USDHC_INT_SIGNAL_EN_TCIEN_SHIFT          (1U)
#define USDHC_INT_SIGNAL_EN_BGEIEN_MASK          (0x4U)
#define USDHC_INT_SIGNAL_EN_BGEIEN_SHIFT         (2U)
#define USDHC_INT_SIGNAL_EN_DINTIEN_MASK         (0x8U)
#define USDHC_INT_SIGNAL_EN_DINTIEN_SHIFT        (3U)
#define USDHC_INT_SIGNAL_EN_BWRIEN_MASK          (0x10U)
#define USDHC_INT_SIGNAL_EN_BWRIEN_SHIFT         (4U)
#define USDHC_INT_SIGNAL_EN_BRRIEN_MASK          (0x20U)
#define USDHC_INT_SIGNAL_EN_BRRIEN_SHIFT         (5U)
#define USDHC_INT_SIGNAL_EN_CINSIEN_MASK         (0x40U)
#define USDHC_INT_SIGNAL_EN_CINSIEN_SHIFT        (6U)
#define USDHC_INT_SIGNAL_EN_CRMIEN_MASK          (0x80U)
#define USDHC_INT_SIGNAL_EN_CRMIEN_SHIFT         (7U)
#define USDHC_INT_SIGNAL_EN_CINTIEN_MASK         (0x100U)
#define USDHC_INT_SIGNAL_EN_CINTIEN_SHIFT        (8U)
#define USDHC_INT_SIGNAL_EN_RTEIEN_MASK          (0x1000U)
#define USDHC_INT_SIGNAL_EN_RTEIEN_SHIFT         (12U)
#define USDHC_INT_SIGNAL_EN_TPIEN_MASK           (0x4000U)
#define USDHC_INT_SIGNAL_EN_TPIEN_SHIFT          (14U)
#define USDHC_INT_SIGNAL_EN_CTOEIEN_MASK         (0x10000U)
#define USDHC_INT_SIGNAL_EN_CTOEIEN_SHIFT        (16U)
#define USDHC_INT_SIGNAL_EN_CCEIEN_MASK          (0x20000U)
#define USDHC_INT_SIGNAL_EN_CCEIEN_SHIFT         (17U)
#define USDHC_INT_SIGNAL_EN_CEBEIEN_MASK         (0x40000U)
#define USDHC_INT_SIGNAL_EN_CEBEIEN_SHIFT        (18U)
#define USDHC_INT_SIGNAL_EN_CIEIEN_MASK          (0x80000U)
#define USDHC_INT_SIGNAL_EN_CIEIEN_SHIFT         (19U)
#define USDHC_INT_SIGNAL_EN_DTOEIEN_MASK         (0x100000U)
#define USDHC_INT_SIGNAL_EN_DTOEIEN_SHIFT        (20U)
#define USDHC_INT_SIGNAL_EN_DCEIEN_MASK          (0x200000U)
#define USDHC_INT_SIGNAL_EN_DCEIEN_SHIFT         (21U)
#define USDHC_INT_SIGNAL_EN_DEBEIEN_MASK         (0x400000U)
#define USDHC_INT_SIGNAL_EN_DEBEIEN_SHIFT        (22U)
#define USDHC_INT_SIGNAL_EN_AC12EIEN_MASK        (0x1000000U)
#define USDHC_INT_SIGNAL_EN_AC12EIEN_SHIFT       (24U)
#define USDHC_INT_SIGNAL_EN_TNEIEN_MASK          (0x4000000U)
#define USDHC_INT_SIGNAL_EN_TNEIEN_SHIFT         (26U)
#define USDHC_INT_SIGNAL_EN_DMAEIEN_MASK         (0x10000000U)
#define USDHC_INT_SIGNAL_EN_DMAEIEN_SHIFT        (28U)

/*! @name AUTOCMD12_ERR_STATUS - Auto CMD12 Error Status */
#define USDHC_AUTOCMD12_ERR_STATUS_AC12NE_MASK   (0x1U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12NE_SHIFT  (0U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12TOE_MASK  (0x2U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12TOE_SHIFT (1U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12EBE_MASK  (0x4U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12EBE_SHIFT (2U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12CE_MASK   (0x8U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12CE_SHIFT  (3U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12IE_MASK   (0x10U)
#define USDHC_AUTOCMD12_ERR_STATUS_AC12IE_SHIFT  (4U)
#define USDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E_MASK (0x80U)
#define USDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E_SHIFT (7U)
#define USDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING_MASK (0x400000U)
#define USDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING_SHIFT (22U)
#define USDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL_MASK (0x800000U)
#define USDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL_SHIFT (23U)

/*! @name HOST_CTRL_CAP - Host Controller Capabilities */
#define USDHC_HOST_CTRL_CAP_SDR50_SUPPORT_MASK   (0x1U)
#define USDHC_HOST_CTRL_CAP_SDR50_SUPPORT_SHIFT  (0U)
#define USDHC_HOST_CTRL_CAP_SDR104_SUPPORT_MASK  (0x2U)
#define USDHC_HOST_CTRL_CAP_SDR104_SUPPORT_SHIFT (1U)
#define USDHC_HOST_CTRL_CAP_DDR50_SUPPORT_MASK   (0x4U)
#define USDHC_HOST_CTRL_CAP_DDR50_SUPPORT_SHIFT  (2U)
#define USDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING_MASK (0xF00U)
#define USDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING_SHIFT (8U)
#define USDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(x) (((uint32_t)(((uint32_t)(x)) << USDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING_SHIFT)) & USDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING_MASK)
#define USDHC_HOST_CTRL_CAP_USE_TUNING_SDR50_MASK (0x2000U)
#define USDHC_HOST_CTRL_CAP_USE_TUNING_SDR50_SHIFT (13U)
#define USDHC_HOST_CTRL_CAP_RETUNING_MODE_MASK   (0xC000U)
#define USDHC_HOST_CTRL_CAP_RETUNING_MODE_SHIFT  (14U)
#define USDHC_HOST_CTRL_CAP_RETUNING_MODE(x)     (((uint32_t)(((uint32_t)(x)) << USDHC_HOST_CTRL_CAP_RETUNING_MODE_SHIFT)) & USDHC_HOST_CTRL_CAP_RETUNING_MODE_MASK)
#define USDHC_HOST_CTRL_CAP_MBL_MASK             (0x70000U)
#define USDHC_HOST_CTRL_CAP_MBL_SHIFT            (16U)
#define USDHC_HOST_CTRL_CAP_MBL(x)               (((uint32_t)(((uint32_t)(x)) << USDHC_HOST_CTRL_CAP_MBL_SHIFT)) & USDHC_HOST_CTRL_CAP_MBL_MASK)
#define USDHC_HOST_CTRL_CAP_ADMAS_MASK           (0x100000U)
#define USDHC_HOST_CTRL_CAP_ADMAS_SHIFT          (20U)
#define USDHC_HOST_CTRL_CAP_HSS_MASK             (0x200000U)
#define USDHC_HOST_CTRL_CAP_HSS_SHIFT            (21U)
#define USDHC_HOST_CTRL_CAP_DMAS_MASK            (0x400000U)
#define USDHC_HOST_CTRL_CAP_DMAS_SHIFT           (22U)
#define USDHC_HOST_CTRL_CAP_SRS_MASK             (0x800000U)
#define USDHC_HOST_CTRL_CAP_SRS_SHIFT            (23U)
#define USDHC_HOST_CTRL_CAP_VS33_MASK            (0x1000000U)
#define USDHC_HOST_CTRL_CAP_VS33_SHIFT           (24U)
#define USDHC_HOST_CTRL_CAP_VS30_MASK            (0x2000000U)
#define USDHC_HOST_CTRL_CAP_VS30_SHIFT           (25U)
#define USDHC_HOST_CTRL_CAP_VS18_MASK            (0x4000000U)
#define USDHC_HOST_CTRL_CAP_VS18_SHIFT           (26U)

/*! @name WTMK_LVL - Watermark Level */
#define USDHC_WTMK_LVL_RD_WML_MASK               (0xFFU)
#define USDHC_WTMK_LVL_RD_WML_SHIFT              (0U)
#define USDHC_WTMK_LVL_RD_WML(x)                 (((uint32_t)(((uint32_t)(x)) << USDHC_WTMK_LVL_RD_WML_SHIFT)) & USDHC_WTMK_LVL_RD_WML_MASK)
#define USDHC_WTMK_LVL_RD_BRST_LEN_MASK          (0x1F00U)
#define USDHC_WTMK_LVL_RD_BRST_LEN_SHIFT         (8U)
#define USDHC_WTMK_LVL_RD_BRST_LEN(x)            (((uint32_t)(((uint32_t)(x)) << USDHC_WTMK_LVL_RD_BRST_LEN_SHIFT)) & USDHC_WTMK_LVL_RD_BRST_LEN_MASK)
#define USDHC_WTMK_LVL_WR_WML_MASK               (0xFF0000U)
#define USDHC_WTMK_LVL_WR_WML_SHIFT              (16U)
#define USDHC_WTMK_LVL_WR_WML(x)                 (((uint32_t)(((uint32_t)(x)) << USDHC_WTMK_LVL_WR_WML_SHIFT)) & USDHC_WTMK_LVL_WR_WML_MASK)
#define USDHC_WTMK_LVL_WR_BRST_LEN_MASK          (0x1F000000U)
#define USDHC_WTMK_LVL_WR_BRST_LEN_SHIFT         (24U)
#define USDHC_WTMK_LVL_WR_BRST_LEN(x)            (((uint32_t)(((uint32_t)(x)) << USDHC_WTMK_LVL_WR_BRST_LEN_SHIFT)) & USDHC_WTMK_LVL_WR_BRST_LEN_MASK)

/*! @name MIX_CTRL - Mixer Control */
#define USDHC_MIX_CTRL_DMAEN_MASK                (0x1U)
#define USDHC_MIX_CTRL_DMAEN_SHIFT               (0U)
#define USDHC_MIX_CTRL_BCEN_MASK                 (0x2U)
#define USDHC_MIX_CTRL_BCEN_SHIFT                (1U)
#define USDHC_MIX_CTRL_AC12EN_MASK               (0x4U)
#define USDHC_MIX_CTRL_AC12EN_SHIFT              (2U)
#define USDHC_MIX_CTRL_DDR_EN_MASK               (0x8U)
#define USDHC_MIX_CTRL_DDR_EN_SHIFT              (3U)
#define USDHC_MIX_CTRL_DTDSEL_MASK               (0x10U)
#define USDHC_MIX_CTRL_DTDSEL_SHIFT              (4U)
#define USDHC_MIX_CTRL_MSBSEL_MASK               (0x20U)
#define USDHC_MIX_CTRL_MSBSEL_SHIFT              (5U)
#define USDHC_MIX_CTRL_NIBBLE_POS_MASK           (0x40U)
#define USDHC_MIX_CTRL_NIBBLE_POS_SHIFT          (6U)
#define USDHC_MIX_CTRL_AC23EN_MASK               (0x80U)
#define USDHC_MIX_CTRL_AC23EN_SHIFT              (7U)
#define USDHC_MIX_CTRL_EXE_TUNE_MASK             (0x400000U)
#define USDHC_MIX_CTRL_EXE_TUNE_SHIFT            (22U)
#define USDHC_MIX_CTRL_SMP_CLK_SEL_MASK          (0x800000U)
#define USDHC_MIX_CTRL_SMP_CLK_SEL_SHIFT         (23U)
#define USDHC_MIX_CTRL_AUTO_TUNE_EN_MASK         (0x1000000U)
#define USDHC_MIX_CTRL_AUTO_TUNE_EN_SHIFT        (24U)
#define USDHC_MIX_CTRL_FBCLK_SEL_MASK            (0x2000000U)
#define USDHC_MIX_CTRL_FBCLK_SEL_SHIFT           (25U)
#define USDHC_MIX_CTRL_HS400_MODE_MASK           (0x4000000U)
#define USDHC_MIX_CTRL_HS400_MODE_SHIFT          (26U)

/*! @name FORCE_EVENT - Force Event */
#define USDHC_FORCE_EVENT_FEVTAC12NE_MASK        (0x1U)
#define USDHC_FORCE_EVENT_FEVTAC12NE_SHIFT       (0U)
#define USDHC_FORCE_EVENT_FEVTAC12TOE_MASK       (0x2U)
#define USDHC_FORCE_EVENT_FEVTAC12TOE_SHIFT      (1U)
#define USDHC_FORCE_EVENT_FEVTAC12CE_MASK        (0x4U)
#define USDHC_FORCE_EVENT_FEVTAC12CE_SHIFT       (2U)
#define USDHC_FORCE_EVENT_FEVTAC12EBE_MASK       (0x8U)
#define USDHC_FORCE_EVENT_FEVTAC12EBE_SHIFT      (3U)
#define USDHC_FORCE_EVENT_FEVTAC12IE_MASK        (0x10U)
#define USDHC_FORCE_EVENT_FEVTAC12IE_SHIFT       (4U)
#define USDHC_FORCE_EVENT_FEVTCNIBAC12E_MASK     (0x80U)
#define USDHC_FORCE_EVENT_FEVTCNIBAC12E_SHIFT    (7U)
#define USDHC_FORCE_EVENT_FEVTCTOE_MASK          (0x10000U)
#define USDHC_FORCE_EVENT_FEVTCTOE_SHIFT         (16U)
#define USDHC_FORCE_EVENT_FEVTCCE_MASK           (0x20000U)
#define USDHC_FORCE_EVENT_FEVTCCE_SHIFT          (17U)
#define USDHC_FORCE_EVENT_FEVTCEBE_MASK          (0x40000U)
#define USDHC_FORCE_EVENT_FEVTCEBE_SHIFT         (18U)
#define USDHC_FORCE_EVENT_FEVTCIE_MASK           (0x80000U)
#define USDHC_FORCE_EVENT_FEVTCIE_SHIFT          (19U)
#define USDHC_FORCE_EVENT_FEVTDTOE_MASK          (0x100000U)
#define USDHC_FORCE_EVENT_FEVTDTOE_SHIFT         (20U)
#define USDHC_FORCE_EVENT_FEVTDCE_MASK           (0x200000U)
#define USDHC_FORCE_EVENT_FEVTDCE_SHIFT          (21U)
#define USDHC_FORCE_EVENT_FEVTDEBE_MASK          (0x400000U)
#define USDHC_FORCE_EVENT_FEVTDEBE_SHIFT         (22U)
#define USDHC_FORCE_EVENT_FEVTAC12E_MASK         (0x1000000U)
#define USDHC_FORCE_EVENT_FEVTAC12E_SHIFT        (24U)
#define USDHC_FORCE_EVENT_FEVTTNE_MASK           (0x4000000U)
#define USDHC_FORCE_EVENT_FEVTTNE_SHIFT          (26U)
#define USDHC_FORCE_EVENT_FEVTDMAE_MASK          (0x10000000U)
#define USDHC_FORCE_EVENT_FEVTDMAE_SHIFT         (28U)
#define USDHC_FORCE_EVENT_FEVTCINT_MASK          (0x80000000U)
#define USDHC_FORCE_EVENT_FEVTCINT_SHIFT         (31U)

/*! @name ADMA_ERR_STATUS - ADMA Error Status Register */
#define USDHC_ADMA_ERR_STATUS_ADMAES_MASK        (0x3U)
#define USDHC_ADMA_ERR_STATUS_ADMAES_SHIFT       (0U)
#define USDHC_ADMA_ERR_STATUS_ADMAES(x)          (((uint32_t)(((uint32_t)(x)) << USDHC_ADMA_ERR_STATUS_ADMAES_SHIFT)) & USDHC_ADMA_ERR_STATUS_ADMAES_MASK)
#define USDHC_ADMA_ERR_STATUS_ADMALME_MASK       (0x4U)
#define USDHC_ADMA_ERR_STATUS_ADMALME_SHIFT      (2U)
#define USDHC_ADMA_ERR_STATUS_ADMADCE_MASK       (0x8U)
#define USDHC_ADMA_ERR_STATUS_ADMADCE_SHIFT      (3U)

/*! @name ADMA_SYS_ADDR - ADMA System Address */
#define USDHC_ADMA_SYS_ADDR_ADS_ADDR_MASK        (0xFFFFFFFCU)
#define USDHC_ADMA_SYS_ADDR_ADS_ADDR_SHIFT       (2U)
#define USDHC_ADMA_SYS_ADDR_ADS_ADDR(x)          (((uint32_t)(((uint32_t)(x)) << USDHC_ADMA_SYS_ADDR_ADS_ADDR_SHIFT)) & USDHC_ADMA_SYS_ADDR_ADS_ADDR_MASK)

/*! @name DLL_CTRL - DLL (Delay Line) Control */
#define USDHC_DLL_CTRL_DLL_CTRL_ENABLE_MASK      (0x1U)
#define USDHC_DLL_CTRL_DLL_CTRL_ENABLE_SHIFT     (0U)
#define USDHC_DLL_CTRL_DLL_CTRL_RESET_MASK       (0x2U)
#define USDHC_DLL_CTRL_DLL_CTRL_RESET_SHIFT      (1U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD_MASK (0x4U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD_SHIFT (2U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0_MASK (0x78U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0_SHIFT (3U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(x) (((uint32_t)(((uint32_t)(x)) << USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0_SHIFT)) & USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0_MASK)
#define USDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE_MASK (0x80U)
#define USDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE_SHIFT (7U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_MASK (0x100U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_SHIFT (8U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL_MASK (0xFE00U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT (9U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(x) (((uint32_t)(((uint32_t)(x)) << USDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT)) & USDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL_MASK)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1_MASK (0x70000U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1_SHIFT (16U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(x) (((uint32_t)(((uint32_t)(x)) << USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1_SHIFT)) & USDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1_MASK)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT_MASK (0xFF00000U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT_SHIFT (20U)
#define USDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(x) (((uint32_t)(((uint32_t)(x)) << USDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT_SHIFT)) & USDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT_MASK)
#define USDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT_MASK (0xF0000000U)
#define USDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT_SHIFT (28U)
#define USDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(x) (((uint32_t)(((uint32_t)(x)) << USDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT_SHIFT)) & USDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT_MASK)

/*! @name DLL_STATUS - DLL Status */
#define USDHC_DLL_STATUS_DLL_STS_SLV_LOCK_MASK   (0x1U)
#define USDHC_DLL_STATUS_DLL_STS_SLV_LOCK_SHIFT  (0U)
#define USDHC_DLL_STATUS_DLL_STS_REF_LOCK_MASK   (0x2U)
#define USDHC_DLL_STATUS_DLL_STS_REF_LOCK_SHIFT  (1U)
#define USDHC_DLL_STATUS_DLL_STS_SLV_SEL_MASK    (0x1FCU)
#define USDHC_DLL_STATUS_DLL_STS_SLV_SEL_SHIFT   (2U)
#define USDHC_DLL_STATUS_DLL_STS_SLV_SEL(x)      (((uint32_t)(((uint32_t)(x)) << USDHC_DLL_STATUS_DLL_STS_SLV_SEL_SHIFT)) & USDHC_DLL_STATUS_DLL_STS_SLV_SEL_MASK)
#define USDHC_DLL_STATUS_DLL_STS_REF_SEL_MASK    (0xFE00U)
#define USDHC_DLL_STATUS_DLL_STS_REF_SEL_SHIFT   (9U)
#define USDHC_DLL_STATUS_DLL_STS_REF_SEL(x)      (((uint32_t)(((uint32_t)(x)) << USDHC_DLL_STATUS_DLL_STS_REF_SEL_SHIFT)) & USDHC_DLL_STATUS_DLL_STS_REF_SEL_MASK)

/*! @name CLK_TUNE_CTRL_STATUS - CLK Tuning Control and Status */
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST_MASK (0xFU)
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST_SHIFT (0U)
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(x) (((uint32_t)(((uint32_t)(x)) << USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST_SHIFT)) & USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST_MASK)
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT_MASK (0xF0U)
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT_SHIFT (4U)
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(x) (((uint32_t)(((uint32_t)(x)) << USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT_SHIFT)) & USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT_MASK)
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE_MASK (0x7F00U)
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE_SHIFT (8U)
#define USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(x) (((uint32_t)(((uint32_t)(x)) << USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE_SHIFT)) & USDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE_MASK)
#define USDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR_MASK  (0x8000U)
#define USDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR_SHIFT (15U)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST_MASK (0xF0000U)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST_SHIFT (16U)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST(x) (((uint32_t)(((uint32_t)(x)) << USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST_SHIFT)) & USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST_MASK)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT_MASK (0xF00000U)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT_SHIFT (20U)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT(x) (((uint32_t)(((uint32_t)(x)) << USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT_SHIFT)) & USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT_MASK)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE_MASK (0x7F000000U)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE_SHIFT (24U)
#define USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE(x) (((uint32_t)(((uint32_t)(x)) << USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE_SHIFT)) & USDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE_MASK)
#define USDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR_MASK  (0x80000000U)
#define USDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR_SHIFT (31U)

/*! @name STROBE_DLL_CTRL - Strobe DLL Control */
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE_MASK (0x1U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE_SHIFT (0U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET_MASK (0x2U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET_SHIFT (1U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD_MASK (0x4U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD_SHIFT (2U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET_MASK (0x38U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET_SHIFT (3U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET(x) (((uint32_t)(((uint32_t)(x)) << USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET_SHIFT)) & USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET_MASK)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0_MASK (0x40U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0_SHIFT (6U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1_MASK (0x80U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1_SHIFT (7U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_MASK (0x100U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_SHIFT (8U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL_MASK (0xFE00U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT (9U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL(x) (((uint32_t)(((uint32_t)(x)) << USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL_SHIFT)) & USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL_MASK)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT_MASK (0xFF00000U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT_SHIFT (20U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT(x) (((uint32_t)(((uint32_t)(x)) << USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT_SHIFT)) & USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT_MASK)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT_MASK (0xF0000000U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT_SHIFT (28U)
#define USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT(x) (((uint32_t)(((uint32_t)(x)) << USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT_SHIFT)) & USDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT_MASK)

/*! @name STROBE_DLL_STATUS - Strobe DLL Status */
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK_MASK (0x1U)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK_SHIFT (0U)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK_MASK (0x2U)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK_SHIFT (1U)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL_MASK (0x1FCU)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL_SHIFT (2U)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL(x) (((uint32_t)(((uint32_t)(x)) << USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL_SHIFT)) & USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL_MASK)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL_MASK (0xFE00U)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL_SHIFT (9U)
#define USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL(x) (((uint32_t)(((uint32_t)(x)) << USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL_SHIFT)) & USDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL_MASK)

/*! @name VEND_SPEC - Vendor Specific Register */
#define USDHC_VEND_SPEC_EXT_DMA_EN_MASK          (0x1U)
#define USDHC_VEND_SPEC_EXT_DMA_EN_SHIFT         (0U)
#define USDHC_VEND_SPEC_VSELECT_MASK             (0x2U)
#define USDHC_VEND_SPEC_VSELECT_SHIFT            (1U)
#define USDHC_VEND_SPEC_CONFLICT_CHK_EN_MASK     (0x4U)
#define USDHC_VEND_SPEC_CONFLICT_CHK_EN_SHIFT    (2U)
#define USDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN_MASK  (0x8U)
#define USDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN_SHIFT (3U)
#define USDHC_VEND_SPEC_DAT3_CD_POL_MASK         (0x10U)
#define USDHC_VEND_SPEC_DAT3_CD_POL_SHIFT        (4U)
#define USDHC_VEND_SPEC_CD_POL_MASK              (0x20U)
#define USDHC_VEND_SPEC_CD_POL_SHIFT             (5U)
#define USDHC_VEND_SPEC_WP_POL_MASK              (0x40U)
#define USDHC_VEND_SPEC_WP_POL_SHIFT             (6U)
#define USDHC_VEND_SPEC_CLKONJ_IN_ABORT_MASK     (0x80U)
#define USDHC_VEND_SPEC_CLKONJ_IN_ABORT_SHIFT    (7U)
#define USDHC_VEND_SPEC_FRC_SDCLK_ON_MASK        (0x100U)
#define USDHC_VEND_SPEC_FRC_SDCLK_ON_SHIFT       (8U)
#define USDHC_VEND_SPEC_IPG_CLK_SOFT_EN_MASK     (0x800U)
#define USDHC_VEND_SPEC_IPG_CLK_SOFT_EN_SHIFT    (11U)
#define USDHC_VEND_SPEC_HCLK_SOFT_EN_MASK        (0x1000U)
#define USDHC_VEND_SPEC_HCLK_SOFT_EN_SHIFT       (12U)
#define USDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN_MASK  (0x2000U)
#define USDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN_SHIFT (13U)
#define USDHC_VEND_SPEC_CARD_CLK_SOFT_EN_MASK    (0x4000U)
#define USDHC_VEND_SPEC_CARD_CLK_SOFT_EN_SHIFT   (14U)
#define USDHC_VEND_SPEC_CRC_CHK_DIS_MASK         (0x8000U)
#define USDHC_VEND_SPEC_CRC_CHK_DIS_SHIFT        (15U)
#define USDHC_VEND_SPEC_INT_ST_VAL_MASK          (0xFF0000U)
#define USDHC_VEND_SPEC_INT_ST_VAL_SHIFT         (16U)
#define USDHC_VEND_SPEC_INT_ST_VAL(x)            (((uint32_t)(((uint32_t)(x)) << USDHC_VEND_SPEC_INT_ST_VAL_SHIFT)) & USDHC_VEND_SPEC_INT_ST_VAL_MASK)
#define USDHC_VEND_SPEC_CMD_BYTE_EN_MASK         (0x80000000U)
#define USDHC_VEND_SPEC_CMD_BYTE_EN_SHIFT        (31U)

/*! @name MMC_BOOT - MMC Boot Register */
#define USDHC_MMC_BOOT_DTOCV_ACK_MASK            (0xFU)
#define USDHC_MMC_BOOT_DTOCV_ACK_SHIFT           (0U)
#define USDHC_MMC_BOOT_DTOCV_ACK(x)              (((uint32_t)(((uint32_t)(x)) << USDHC_MMC_BOOT_DTOCV_ACK_SHIFT)) & USDHC_MMC_BOOT_DTOCV_ACK_MASK)
#define USDHC_MMC_BOOT_BOOT_ACK_MASK             (0x10U)
#define USDHC_MMC_BOOT_BOOT_ACK_SHIFT            (4U)
#define USDHC_MMC_BOOT_BOOT_MODE_MASK            (0x20U)
#define USDHC_MMC_BOOT_BOOT_MODE_SHIFT           (5U)
#define USDHC_MMC_BOOT_BOOT_EN_MASK              (0x40U)
#define USDHC_MMC_BOOT_BOOT_EN_SHIFT             (6U)
#define USDHC_MMC_BOOT_AUTO_SABG_EN_MASK         (0x80U)
#define USDHC_MMC_BOOT_AUTO_SABG_EN_SHIFT        (7U)
#define USDHC_MMC_BOOT_DISABLE_TIME_OUT_MASK     (0x100U)
#define USDHC_MMC_BOOT_DISABLE_TIME_OUT_SHIFT    (8U)
#define USDHC_MMC_BOOT_BOOT_BLK_CNT_MASK         (0xFFFF0000U)
#define USDHC_MMC_BOOT_BOOT_BLK_CNT_SHIFT        (16U)
#define USDHC_MMC_BOOT_BOOT_BLK_CNT(x)           (((uint32_t)(((uint32_t)(x)) << USDHC_MMC_BOOT_BOOT_BLK_CNT_SHIFT)) & USDHC_MMC_BOOT_BOOT_BLK_CNT_MASK)

/*! @name VEND_SPEC2 - Vendor Specific 2 Register */
#define USDHC_VEND_SPEC2_SDR104_TIMING_DIS_MASK  (0x1U)
#define USDHC_VEND_SPEC2_SDR104_TIMING_DIS_SHIFT (0U)
#define USDHC_VEND_SPEC2_SDR104_OE_DIS_MASK      (0x2U)
#define USDHC_VEND_SPEC2_SDR104_OE_DIS_SHIFT     (1U)
#define USDHC_VEND_SPEC2_SDR104_NSD_DIS_MASK     (0x4U)
#define USDHC_VEND_SPEC2_SDR104_NSD_DIS_SHIFT    (2U)
#define USDHC_VEND_SPEC2_CARD_INT_D3_TEST_MASK   (0x8U)
#define USDHC_VEND_SPEC2_CARD_INT_D3_TEST_SHIFT  (3U)
#define USDHC_VEND_SPEC2_TUNING_8bit_EN_MASK     (0x10U)
#define USDHC_VEND_SPEC2_TUNING_8bit_EN_SHIFT    (4U)
#define USDHC_VEND_SPEC2_TUNING_1bit_EN_MASK     (0x20U)
#define USDHC_VEND_SPEC2_TUNING_1bit_EN_SHIFT    (5U)
#define USDHC_VEND_SPEC2_TUNING_CMD_EN_MASK      (0x40U)
#define USDHC_VEND_SPEC2_TUNING_CMD_EN_SHIFT     (6U)
#define USDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS_MASK (0x80U)
#define USDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS_SHIFT (7U)
#define USDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN_MASK (0x400U)
#define USDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN_SHIFT (10U)
#define USDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN_MASK (0x800U)
#define USDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN_SHIFT (11U)

/*! @name TUNING_CTRL - Tuning Control Register */
#define USDHC_TUNING_CTRL_TUNING_START_TAP_MASK  (0xFFU)
#define USDHC_TUNING_CTRL_TUNING_START_TAP_SHIFT (0U)
#define USDHC_TUNING_CTRL_TUNING_START_TAP(x)    (((uint32_t)(((uint32_t)(x)) << USDHC_TUNING_CTRL_TUNING_START_TAP_SHIFT)) & USDHC_TUNING_CTRL_TUNING_START_TAP_MASK)
#define USDHC_TUNING_CTRL_TUNING_COUNTER_MASK    (0xFF00U)
#define USDHC_TUNING_CTRL_TUNING_COUNTER_SHIFT   (8U)
#define USDHC_TUNING_CTRL_TUNING_COUNTER(x)      (((uint32_t)(((uint32_t)(x)) << USDHC_TUNING_CTRL_TUNING_COUNTER_SHIFT)) & USDHC_TUNING_CTRL_TUNING_COUNTER_MASK)
#define USDHC_TUNING_CTRL_TUNING_STEP_MASK       (0x70000U)
#define USDHC_TUNING_CTRL_TUNING_STEP_SHIFT      (16U)
#define USDHC_TUNING_CTRL_TUNING_STEP(x)         (((uint32_t)(((uint32_t)(x)) << USDHC_TUNING_CTRL_TUNING_STEP_SHIFT)) & USDHC_TUNING_CTRL_TUNING_STEP_MASK)
#define USDHC_TUNING_CTRL_TUNING_WINDOW_MASK     (0x700000U)
#define USDHC_TUNING_CTRL_TUNING_WINDOW_SHIFT    (20U)
#define USDHC_TUNING_CTRL_TUNING_WINDOW(x)       (((uint32_t)(((uint32_t)(x)) << USDHC_TUNING_CTRL_TUNING_WINDOW_SHIFT)) & USDHC_TUNING_CTRL_TUNING_WINDOW_MASK)
#define USDHC_TUNING_CTRL_STD_TUNING_EN_MASK     (0x1000000U)
#define USDHC_TUNING_CTRL_STD_TUNING_EN_SHIFT    (24U)


/*!
 * @}
 */ /* end of group USDHC_Register_Masks */


/* USDHC - Peripheral instance base addresses */
/** Peripheral USDHC1 base pointer */
#define USDHC1_BASE_PTR                          ((USDHC_MemMapPtr)0x30B40000u)
/** Peripheral USDHC2 base pointer */
#define USDHC2_BASE_PTR                          ((USDHC_MemMapPtr)0x30B50000u)
/** Peripheral USDHC3 base pointer */
#define USDHC3_BASE_PTR                          ((USDHC_MemMapPtr)0x30B60000u)
/** Array initializer of USDHC peripheral base pointers */
#define USDHC_BASE_PTRS                          { USDHC1_BASE_PTR, USDHC2_BASE_PTR, USDHC3_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- USDHC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USDHC_Register_Accessor_Macros USDHC - Register accessor macros
 * @{
 */


/* USDHC - Register instance definitions */
/* USDHC1 */
#define USDHC1_DS_ADDR                           USDHC_DS_ADDR_REG(USDHC1_BASE_PTR)
#define USDHC1_BLK_ATT                           USDHC_BLK_ATT_REG(USDHC1_BASE_PTR)
#define USDHC1_CMD_ARG                           USDHC_CMD_ARG_REG(USDHC1_BASE_PTR)
#define USDHC1_CMD_XFR_TYP                       USDHC_CMD_XFR_TYP_REG(USDHC1_BASE_PTR)
#define USDHC1_CMD_RSP0                          USDHC_CMD_RSP0_REG(USDHC1_BASE_PTR)
#define USDHC1_CMD_RSP1                          USDHC_CMD_RSP1_REG(USDHC1_BASE_PTR)
#define USDHC1_CMD_RSP2                          USDHC_CMD_RSP2_REG(USDHC1_BASE_PTR)
#define USDHC1_CMD_RSP3                          USDHC_CMD_RSP3_REG(USDHC1_BASE_PTR)
#define USDHC1_DATA_BUFF_ACC_PORT                USDHC_DATA_BUFF_ACC_PORT_REG(USDHC1_BASE_PTR)
#define USDHC1_PRES_STATE                        USDHC_PRES_STATE_REG(USDHC1_BASE_PTR)
#define USDHC1_PROT_CTRL                         USDHC_PROT_CTRL_REG(USDHC1_BASE_PTR)
#define USDHC1_SYS_CTRL                          USDHC_SYS_CTRL_REG(USDHC1_BASE_PTR)
#define USDHC1_INT_STATUS                        USDHC_INT_STATUS_REG(USDHC1_BASE_PTR)
#define USDHC1_INT_STATUS_EN                     USDHC_INT_STATUS_EN_REG(USDHC1_BASE_PTR)
#define USDHC1_INT_SIGNAL_EN                     USDHC_INT_SIGNAL_EN_REG(USDHC1_BASE_PTR)
#define USDHC1_AUTOCMD12_ERR_STATUS              USDHC_AUTOCMD12_ERR_STATUS_REG(USDHC1_BASE_PTR)
#define USDHC1_HOST_CTRL_CAP                     USDHC_HOST_CTRL_CAP_REG(USDHC1_BASE_PTR)
#define USDHC1_WTMK_LVL                          USDHC_WTMK_LVL_REG(USDHC1_BASE_PTR)
#define USDHC1_MIX_CTRL                          USDHC_MIX_CTRL_REG(USDHC1_BASE_PTR)
#define USDHC1_FORCE_EVENT                       USDHC_FORCE_EVENT_REG(USDHC1_BASE_PTR)
#define USDHC1_ADMA_ERR_STATUS                   USDHC_ADMA_ERR_STATUS_REG(USDHC1_BASE_PTR)
#define USDHC1_ADMA_SYS_ADDR                     USDHC_ADMA_SYS_ADDR_REG(USDHC1_BASE_PTR)
#define USDHC1_DLL_CTRL                          USDHC_DLL_CTRL_REG(USDHC1_BASE_PTR)
#define USDHC1_DLL_STATUS                        USDHC_DLL_STATUS_REG(USDHC1_BASE_PTR)
#define USDHC1_CLK_TUNE_CTRL_STATUS              USDHC_CLK_TUNE_CTRL_STATUS_REG(USDHC1_BASE_PTR)
#define USDHC1_STROBE_DLL_CTRL                   USDHC_STROBE_DLL_CTRL_REG(USDHC1_BASE_PTR)
#define USDHC1_STROBE_DLL_STATUS                 USDHC_STROBE_DLL_STATUS_REG(USDHC1_BASE_PTR)
#define USDHC1_VEND_SPEC                         USDHC_VEND_SPEC_REG(USDHC1_BASE_PTR)
#define USDHC1_MMC_BOOT                          USDHC_MMC_BOOT_REG(USDHC1_BASE_PTR)
#define USDHC1_VEND_SPEC2                        USDHC_VEND_SPEC2_REG(USDHC1_BASE_PTR)
#define USDHC1_TUNING_CTRL                       USDHC_TUNING_CTRL_REG(USDHC1_BASE_PTR)
/* USDHC2 */
#define USDHC2_DS_ADDR                           USDHC_DS_ADDR_REG(USDHC2_BASE_PTR)
#define USDHC2_BLK_ATT                           USDHC_BLK_ATT_REG(USDHC2_BASE_PTR)
#define USDHC2_CMD_ARG                           USDHC_CMD_ARG_REG(USDHC2_BASE_PTR)
#define USDHC2_CMD_XFR_TYP                       USDHC_CMD_XFR_TYP_REG(USDHC2_BASE_PTR)
#define USDHC2_CMD_RSP0                          USDHC_CMD_RSP0_REG(USDHC2_BASE_PTR)
#define USDHC2_CMD_RSP1                          USDHC_CMD_RSP1_REG(USDHC2_BASE_PTR)
#define USDHC2_CMD_RSP2                          USDHC_CMD_RSP2_REG(USDHC2_BASE_PTR)
#define USDHC2_CMD_RSP3                          USDHC_CMD_RSP3_REG(USDHC2_BASE_PTR)
#define USDHC2_DATA_BUFF_ACC_PORT                USDHC_DATA_BUFF_ACC_PORT_REG(USDHC2_BASE_PTR)
#define USDHC2_PRES_STATE                        USDHC_PRES_STATE_REG(USDHC2_BASE_PTR)
#define USDHC2_PROT_CTRL                         USDHC_PROT_CTRL_REG(USDHC2_BASE_PTR)
#define USDHC2_SYS_CTRL                          USDHC_SYS_CTRL_REG(USDHC2_BASE_PTR)
#define USDHC2_INT_STATUS                        USDHC_INT_STATUS_REG(USDHC2_BASE_PTR)
#define USDHC2_INT_STATUS_EN                     USDHC_INT_STATUS_EN_REG(USDHC2_BASE_PTR)
#define USDHC2_INT_SIGNAL_EN                     USDHC_INT_SIGNAL_EN_REG(USDHC2_BASE_PTR)
#define USDHC2_AUTOCMD12_ERR_STATUS              USDHC_AUTOCMD12_ERR_STATUS_REG(USDHC2_BASE_PTR)
#define USDHC2_HOST_CTRL_CAP                     USDHC_HOST_CTRL_CAP_REG(USDHC2_BASE_PTR)
#define USDHC2_WTMK_LVL                          USDHC_WTMK_LVL_REG(USDHC2_BASE_PTR)
#define USDHC2_MIX_CTRL                          USDHC_MIX_CTRL_REG(USDHC2_BASE_PTR)
#define USDHC2_FORCE_EVENT                       USDHC_FORCE_EVENT_REG(USDHC2_BASE_PTR)
#define USDHC2_ADMA_ERR_STATUS                   USDHC_ADMA_ERR_STATUS_REG(USDHC2_BASE_PTR)
#define USDHC2_ADMA_SYS_ADDR                     USDHC_ADMA_SYS_ADDR_REG(USDHC2_BASE_PTR)
#define USDHC2_DLL_CTRL                          USDHC_DLL_CTRL_REG(USDHC2_BASE_PTR)
#define USDHC2_DLL_STATUS                        USDHC_DLL_STATUS_REG(USDHC2_BASE_PTR)
#define USDHC2_CLK_TUNE_CTRL_STATUS              USDHC_CLK_TUNE_CTRL_STATUS_REG(USDHC2_BASE_PTR)
#define USDHC2_STROBE_DLL_CTRL                   USDHC_STROBE_DLL_CTRL_REG(USDHC2_BASE_PTR)
#define USDHC2_STROBE_DLL_STATUS                 USDHC_STROBE_DLL_STATUS_REG(USDHC2_BASE_PTR)
#define USDHC2_VEND_SPEC                         USDHC_VEND_SPEC_REG(USDHC2_BASE_PTR)
#define USDHC2_MMC_BOOT                          USDHC_MMC_BOOT_REG(USDHC2_BASE_PTR)
#define USDHC2_VEND_SPEC2                        USDHC_VEND_SPEC2_REG(USDHC2_BASE_PTR)
#define USDHC2_TUNING_CTRL                       USDHC_TUNING_CTRL_REG(USDHC2_BASE_PTR)
/* USDHC3 */
#define USDHC3_DS_ADDR                           USDHC_DS_ADDR_REG(USDHC3_BASE_PTR)
#define USDHC3_BLK_ATT                           USDHC_BLK_ATT_REG(USDHC3_BASE_PTR)
#define USDHC3_CMD_ARG                           USDHC_CMD_ARG_REG(USDHC3_BASE_PTR)
#define USDHC3_CMD_XFR_TYP                       USDHC_CMD_XFR_TYP_REG(USDHC3_BASE_PTR)
#define USDHC3_CMD_RSP0                          USDHC_CMD_RSP0_REG(USDHC3_BASE_PTR)
#define USDHC3_CMD_RSP1                          USDHC_CMD_RSP1_REG(USDHC3_BASE_PTR)
#define USDHC3_CMD_RSP2                          USDHC_CMD_RSP2_REG(USDHC3_BASE_PTR)
#define USDHC3_CMD_RSP3                          USDHC_CMD_RSP3_REG(USDHC3_BASE_PTR)
#define USDHC3_DATA_BUFF_ACC_PORT                USDHC_DATA_BUFF_ACC_PORT_REG(USDHC3_BASE_PTR)
#define USDHC3_PRES_STATE                        USDHC_PRES_STATE_REG(USDHC3_BASE_PTR)
#define USDHC3_PROT_CTRL                         USDHC_PROT_CTRL_REG(USDHC3_BASE_PTR)
#define USDHC3_SYS_CTRL                          USDHC_SYS_CTRL_REG(USDHC3_BASE_PTR)
#define USDHC3_INT_STATUS                        USDHC_INT_STATUS_REG(USDHC3_BASE_PTR)
#define USDHC3_INT_STATUS_EN                     USDHC_INT_STATUS_EN_REG(USDHC3_BASE_PTR)
#define USDHC3_INT_SIGNAL_EN                     USDHC_INT_SIGNAL_EN_REG(USDHC3_BASE_PTR)
#define USDHC3_AUTOCMD12_ERR_STATUS              USDHC_AUTOCMD12_ERR_STATUS_REG(USDHC3_BASE_PTR)
#define USDHC3_HOST_CTRL_CAP                     USDHC_HOST_CTRL_CAP_REG(USDHC3_BASE_PTR)
#define USDHC3_WTMK_LVL                          USDHC_WTMK_LVL_REG(USDHC3_BASE_PTR)
#define USDHC3_MIX_CTRL                          USDHC_MIX_CTRL_REG(USDHC3_BASE_PTR)
#define USDHC3_FORCE_EVENT                       USDHC_FORCE_EVENT_REG(USDHC3_BASE_PTR)
#define USDHC3_ADMA_ERR_STATUS                   USDHC_ADMA_ERR_STATUS_REG(USDHC3_BASE_PTR)
#define USDHC3_ADMA_SYS_ADDR                     USDHC_ADMA_SYS_ADDR_REG(USDHC3_BASE_PTR)
#define USDHC3_DLL_CTRL                          USDHC_DLL_CTRL_REG(USDHC3_BASE_PTR)
#define USDHC3_DLL_STATUS                        USDHC_DLL_STATUS_REG(USDHC3_BASE_PTR)
#define USDHC3_CLK_TUNE_CTRL_STATUS              USDHC_CLK_TUNE_CTRL_STATUS_REG(USDHC3_BASE_PTR)
#define USDHC3_STROBE_DLL_CTRL                   USDHC_STROBE_DLL_CTRL_REG(USDHC3_BASE_PTR)
#define USDHC3_STROBE_DLL_STATUS                 USDHC_STROBE_DLL_STATUS_REG(USDHC3_BASE_PTR)
#define USDHC3_VEND_SPEC                         USDHC_VEND_SPEC_REG(USDHC3_BASE_PTR)
#define USDHC3_MMC_BOOT                          USDHC_MMC_BOOT_REG(USDHC3_BASE_PTR)
#define USDHC3_VEND_SPEC2                        USDHC_VEND_SPEC2_REG(USDHC3_BASE_PTR)
#define USDHC3_TUNING_CTRL                       USDHC_TUNING_CTRL_REG(USDHC3_BASE_PTR)

/*!
 * @}
 */ /* end of group USDHC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group USDHC_Peripheral */


/* ----------------------------------------------------------------------------
   -- WDOG
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup WDOG_Peripheral WDOG
 * @{
 */

/** WDOG - Peripheral register structure */
typedef struct WDOG_MemMap {
  uint16_t WCR;                                    /**< Watchdog Control Register, offset: 0x0 */
  uint16_t WSR;                                    /**< Watchdog Service Register, offset: 0x2 */
  uint16_t WRSR;                                   /**< Watchdog Reset Status Register, offset: 0x4 */
  uint16_t WICR;                                   /**< Watchdog Interrupt Control Register, offset: 0x6 */
  uint16_t WMCR;                                   /**< Watchdog Miscellaneous Control Register, offset: 0x8 */
} volatile *WDOG_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- WDOG - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup WDOG_Register_Accessor_Macros WDOG - Register accessor macros
 * @{
 */


/* WDOG - Register accessors */
#define WDOG_WCR_REG(base)                       ((base)->WCR)
#define WDOG_WSR_REG(base)                       ((base)->WSR)
#define WDOG_WRSR_REG(base)                      ((base)->WRSR)
#define WDOG_WICR_REG(base)                      ((base)->WICR)
#define WDOG_WMCR_REG(base)                      ((base)->WMCR)

/*!
 * @}
 */ /* end of group WDOG_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- WDOG Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup WDOG_Register_Masks WDOG Register Masks
 * @{
 */

/*! @name WCR - Watchdog Control Register */
#define WDOG_WCR_WDZST_MASK                      (0x1U)
#define WDOG_WCR_WDZST_SHIFT                     (0U)
#define WDOG_WCR_WDBG_MASK                       (0x2U)
#define WDOG_WCR_WDBG_SHIFT                      (1U)
#define WDOG_WCR_WDE_MASK                        (0x4U)
#define WDOG_WCR_WDE_SHIFT                       (2U)
#define WDOG_WCR_WDT_MASK                        (0x8U)
#define WDOG_WCR_WDT_SHIFT                       (3U)
#define WDOG_WCR_SRS_MASK                        (0x10U)
#define WDOG_WCR_SRS_SHIFT                       (4U)
#define WDOG_WCR_WDA_MASK                        (0x20U)
#define WDOG_WCR_WDA_SHIFT                       (5U)
#define WDOG_WCR_SRE_MASK                        (0x40U)
#define WDOG_WCR_SRE_SHIFT                       (6U)
#define WDOG_WCR_WDW_MASK                        (0x80U)
#define WDOG_WCR_WDW_SHIFT                       (7U)
#define WDOG_WCR_WT_MASK                         (0xFF00U)
#define WDOG_WCR_WT_SHIFT                        (8U)
#define WDOG_WCR_WT(x)                           (((uint16_t)(((uint16_t)(x)) << WDOG_WCR_WT_SHIFT)) & WDOG_WCR_WT_MASK)

/*! @name WSR - Watchdog Service Register */
#define WDOG_WSR_WSR_MASK                        (0xFFFFU)
#define WDOG_WSR_WSR_SHIFT                       (0U)
#define WDOG_WSR_WSR(x)                          (((uint16_t)(((uint16_t)(x)) << WDOG_WSR_WSR_SHIFT)) & WDOG_WSR_WSR_MASK)

/*! @name WRSR - Watchdog Reset Status Register */
#define WDOG_WRSR_SFTW_MASK                      (0x1U)
#define WDOG_WRSR_SFTW_SHIFT                     (0U)
#define WDOG_WRSR_TOUT_MASK                      (0x2U)
#define WDOG_WRSR_TOUT_SHIFT                     (1U)
#define WDOG_WRSR_POR_MASK                       (0x10U)
#define WDOG_WRSR_POR_SHIFT                      (4U)

/*! @name WICR - Watchdog Interrupt Control Register */
#define WDOG_WICR_WICT_MASK                      (0xFFU)
#define WDOG_WICR_WICT_SHIFT                     (0U)
#define WDOG_WICR_WICT(x)                        (((uint16_t)(((uint16_t)(x)) << WDOG_WICR_WICT_SHIFT)) & WDOG_WICR_WICT_MASK)
#define WDOG_WICR_WTIS_MASK                      (0x4000U)
#define WDOG_WICR_WTIS_SHIFT                     (14U)
#define WDOG_WICR_WIE_MASK                       (0x8000U)
#define WDOG_WICR_WIE_SHIFT                      (15U)

/*! @name WMCR - Watchdog Miscellaneous Control Register */
#define WDOG_WMCR_PDE_MASK                       (0x1U)
#define WDOG_WMCR_PDE_SHIFT                      (0U)


/*!
 * @}
 */ /* end of group WDOG_Register_Masks */


/* WDOG - Peripheral instance base addresses */
/** Peripheral WDOG1 base pointer */
#define WDOG1_BASE_PTR                           ((WDOG_MemMapPtr)0x30280000u)
/** Peripheral WDOG2 base pointer */
#define WDOG2_BASE_PTR                           ((WDOG_MemMapPtr)0x30290000u)
/** Peripheral WDOG3 base pointer */
#define WDOG3_BASE_PTR                           ((WDOG_MemMapPtr)0x302A0000u)
/** Peripheral WDOG4 base pointer */
#define WDOG4_BASE_PTR                           ((WDOG_MemMapPtr)0x302B0000u)
/** Array initializer of WDOG peripheral base pointers */
#define WDOG_BASE_PTRS                           { WDOG1_BASE_PTR, WDOG2_BASE_PTR, WDOG3_BASE_PTR, WDOG4_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- WDOG - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup WDOG_Register_Accessor_Macros WDOG - Register accessor macros
 * @{
 */


/* WDOG - Register instance definitions */
/* WDOG1 */
#define WDOG1_WCR                                WDOG_WCR_REG(WDOG1_BASE_PTR)
#define WDOG1_WSR                                WDOG_WSR_REG(WDOG1_BASE_PTR)
#define WDOG1_WRSR                               WDOG_WRSR_REG(WDOG1_BASE_PTR)
#define WDOG1_WICR                               WDOG_WICR_REG(WDOG1_BASE_PTR)
#define WDOG1_WMCR                               WDOG_WMCR_REG(WDOG1_BASE_PTR)
/* WDOG2 */
#define WDOG2_WCR                                WDOG_WCR_REG(WDOG2_BASE_PTR)
#define WDOG2_WSR                                WDOG_WSR_REG(WDOG2_BASE_PTR)
#define WDOG2_WRSR                               WDOG_WRSR_REG(WDOG2_BASE_PTR)
#define WDOG2_WICR                               WDOG_WICR_REG(WDOG2_BASE_PTR)
#define WDOG2_WMCR                               WDOG_WMCR_REG(WDOG2_BASE_PTR)
/* WDOG3 */
#define WDOG3_WCR                                WDOG_WCR_REG(WDOG3_BASE_PTR)
#define WDOG3_WSR                                WDOG_WSR_REG(WDOG3_BASE_PTR)
#define WDOG3_WRSR                               WDOG_WRSR_REG(WDOG3_BASE_PTR)
#define WDOG3_WICR                               WDOG_WICR_REG(WDOG3_BASE_PTR)
#define WDOG3_WMCR                               WDOG_WMCR_REG(WDOG3_BASE_PTR)
/* WDOG4 */
#define WDOG4_WCR                                WDOG_WCR_REG(WDOG4_BASE_PTR)
#define WDOG4_WSR                                WDOG_WSR_REG(WDOG4_BASE_PTR)
#define WDOG4_WRSR                               WDOG_WRSR_REG(WDOG4_BASE_PTR)
#define WDOG4_WICR                               WDOG_WICR_REG(WDOG4_BASE_PTR)
#define WDOG4_WMCR                               WDOG_WMCR_REG(WDOG4_BASE_PTR)

/*!
 * @}
 */ /* end of group WDOG_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group WDOG_Peripheral */


/* ----------------------------------------------------------------------------
   -- XTALOSC
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup XTALOSC_Peripheral XTALOSC
 * @{
 */

/** XTALOSC - Peripheral register structure */
typedef struct XTALOSC_MemMap {
  uint32_t CTRL_24M;                               /**< Anadig 24M Oscillator Control Register, offset: 0x0 */
  uint32_t CTRL_24M_SET;                           /**< Anadig 24M Oscillator Control Register, offset: 0x4 */
  uint32_t CTRL_24M_CLR;                           /**< Anadig 24M Oscillator Control Register, offset: 0x8 */
  uint32_t CTRL_24M_TOG;                           /**< Anadig 24M Oscillator Control Register, offset: 0xC */
  uint32_t RCOSC_CONFIG0;                          /**< Anadig 24MHz RC Osc. config0 Register, offset: 0x10 */
  uint32_t RCOSC_CONFIG0_SET;                      /**< Anadig 24MHz RC Osc. config0 Register, offset: 0x14 */
  uint32_t RCOSC_CONFIG0_CLR;                      /**< Anadig 24MHz RC Osc. config0 Register, offset: 0x18 */
  uint32_t RCOSC_CONFIG0_TOG;                      /**< Anadig 24MHz RC Osc. config0 Register, offset: 0x1C */
  uint32_t RCOSC_CONFIG1;                          /**< Anadig 24MHz RC Osc. config1 Register, offset: 0x20 */
  uint32_t RCOSC_CONFIG1_SET;                      /**< Anadig 24MHz RC Osc. config1 Register, offset: 0x24 */
  uint32_t RCOSC_CONFIG1_CLR;                      /**< Anadig 24MHz RC Osc. config1 Register, offset: 0x28 */
  uint32_t RCOSC_CONFIG1_TOG;                      /**< Anadig 24MHz RC Osc. config1 Register, offset: 0x2C */
  uint32_t RCOSC_CONFIG2;                          /**< Anadig 24MHz RC Osc. config2 Register, offset: 0x30 */
  uint32_t RCOSC_CONFIG2_SET;                      /**< Anadig 24MHz RC Osc. config2 Register, offset: 0x34 */
  uint32_t RCOSC_CONFIG2_CLR;                      /**< Anadig 24MHz RC Osc. config2 Register, offset: 0x38 */
  uint32_t RCOSC_CONFIG2_TOG;                      /**< Anadig 24MHz RC Osc. config2 Register, offset: 0x3C */
  uint8_t RESERVED_0[16];
  uint32_t OSC_32K;                                /**< 32K Oscillator Control Register, offset: 0x50 */
  uint32_t OSC_32K_SET;                            /**< 32K Oscillator Control Register, offset: 0x54 */
  uint32_t OSC_32K_CLR;                            /**< 32K Oscillator Control Register, offset: 0x58 */
  uint32_t OSC_32K_TOG;                            /**< 32K Oscillator Control Register, offset: 0x5C */
} volatile *XTALOSC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- XTALOSC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup XTALOSC_Register_Accessor_Macros XTALOSC - Register accessor macros
 * @{
 */


/* XTALOSC - Register accessors */
#define XTALOSC_CTRL_24M_REG(base)               ((base)->CTRL_24M)
#define XTALOSC_CTRL_24M_SET_REG(base)           ((base)->CTRL_24M_SET)
#define XTALOSC_CTRL_24M_CLR_REG(base)           ((base)->CTRL_24M_CLR)
#define XTALOSC_CTRL_24M_TOG_REG(base)           ((base)->CTRL_24M_TOG)
#define XTALOSC_RCOSC_CONFIG0_REG(base)          ((base)->RCOSC_CONFIG0)
#define XTALOSC_RCOSC_CONFIG0_SET_REG(base)      ((base)->RCOSC_CONFIG0_SET)
#define XTALOSC_RCOSC_CONFIG0_CLR_REG(base)      ((base)->RCOSC_CONFIG0_CLR)
#define XTALOSC_RCOSC_CONFIG0_TOG_REG(base)      ((base)->RCOSC_CONFIG0_TOG)
#define XTALOSC_RCOSC_CONFIG1_REG(base)          ((base)->RCOSC_CONFIG1)
#define XTALOSC_RCOSC_CONFIG1_SET_REG(base)      ((base)->RCOSC_CONFIG1_SET)
#define XTALOSC_RCOSC_CONFIG1_CLR_REG(base)      ((base)->RCOSC_CONFIG1_CLR)
#define XTALOSC_RCOSC_CONFIG1_TOG_REG(base)      ((base)->RCOSC_CONFIG1_TOG)
#define XTALOSC_RCOSC_CONFIG2_REG(base)          ((base)->RCOSC_CONFIG2)
#define XTALOSC_RCOSC_CONFIG2_SET_REG(base)      ((base)->RCOSC_CONFIG2_SET)
#define XTALOSC_RCOSC_CONFIG2_CLR_REG(base)      ((base)->RCOSC_CONFIG2_CLR)
#define XTALOSC_RCOSC_CONFIG2_TOG_REG(base)      ((base)->RCOSC_CONFIG2_TOG)
#define XTALOSC_OSC_32K_REG(base)                ((base)->OSC_32K)
#define XTALOSC_OSC_32K_SET_REG(base)            ((base)->OSC_32K_SET)
#define XTALOSC_OSC_32K_CLR_REG(base)            ((base)->OSC_32K_CLR)
#define XTALOSC_OSC_32K_TOG_REG(base)            ((base)->OSC_32K_TOG)

/*!
 * @}
 */ /* end of group XTALOSC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- XTALOSC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup XTALOSC_Register_Masks XTALOSC Register Masks
 * @{
 */

/*! @name CTRL_24M - Anadig 24M Oscillator Control Register */
#define XTALOSC_CTRL_24M_XTAL_24M_PWD_MASK       (0x1U)
#define XTALOSC_CTRL_24M_XTAL_24M_PWD_SHIFT      (0U)
#define XTALOSC_CTRL_24M_XTAL_24M_EN_MASK        (0x2U)
#define XTALOSC_CTRL_24M_XTAL_24M_EN_SHIFT       (1U)
#define XTALOSC_CTRL_24M_OSC_XTALOK_MASK         (0x4U)
#define XTALOSC_CTRL_24M_OSC_XTALOK_SHIFT        (2U)
#define XTALOSC_CTRL_24M_OSC_XTALOK_EN_MASK      (0x8U)
#define XTALOSC_CTRL_24M_OSC_XTALOK_EN_SHIFT     (3U)
#define XTALOSC_CTRL_24M_CLKGATE_CTRL_MASK       (0x10U)
#define XTALOSC_CTRL_24M_CLKGATE_CTRL_SHIFT      (4U)
#define XTALOSC_CTRL_24M_CLKGATE_DELAY_MASK      (0xE0U)
#define XTALOSC_CTRL_24M_CLKGATE_DELAY_SHIFT     (5U)
#define XTALOSC_CTRL_24M_CLKGATE_DELAY(x)        (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_CLKGATE_DELAY_SHIFT)) & XTALOSC_CTRL_24M_CLKGATE_DELAY_MASK)
#define XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE_MASK  (0x100U)
#define XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE_SHIFT (8U)
#define XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY_MASK (0x600U)
#define XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY_SHIFT (9U)
#define XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY(x)  (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY_SHIFT)) & XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY_MASK)
#define XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT_MASK (0x800U)
#define XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT_SHIFT (11U)
#define XTALOSC_CTRL_24M_OSC_SEL_MASK            (0x1000U)
#define XTALOSC_CTRL_24M_OSC_SEL_SHIFT           (12U)
#define XTALOSC_CTRL_24M_RC_OSC_EN_MASK          (0x2000U)
#define XTALOSC_CTRL_24M_RC_OSC_EN_SHIFT         (13U)
#define XTALOSC_CTRL_24M_XTAL_MISC_MASK          (0x7FFF8000U)
#define XTALOSC_CTRL_24M_XTAL_MISC_SHIFT         (15U)
#define XTALOSC_CTRL_24M_XTAL_MISC(x)            (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_XTAL_MISC_SHIFT)) & XTALOSC_CTRL_24M_XTAL_MISC_MASK)

/*! @name CTRL_24M_SET - Anadig 24M Oscillator Control Register */
#define XTALOSC_CTRL_24M_SET_XTAL_24M_PWD_MASK   (0x1U)
#define XTALOSC_CTRL_24M_SET_XTAL_24M_PWD_SHIFT  (0U)
#define XTALOSC_CTRL_24M_SET_XTAL_24M_EN_MASK    (0x2U)
#define XTALOSC_CTRL_24M_SET_XTAL_24M_EN_SHIFT   (1U)
#define XTALOSC_CTRL_24M_SET_OSC_XTALOK_MASK     (0x4U)
#define XTALOSC_CTRL_24M_SET_OSC_XTALOK_SHIFT    (2U)
#define XTALOSC_CTRL_24M_SET_OSC_XTALOK_EN_MASK  (0x8U)
#define XTALOSC_CTRL_24M_SET_OSC_XTALOK_EN_SHIFT (3U)
#define XTALOSC_CTRL_24M_SET_CLKGATE_CTRL_MASK   (0x10U)
#define XTALOSC_CTRL_24M_SET_CLKGATE_CTRL_SHIFT  (4U)
#define XTALOSC_CTRL_24M_SET_CLKGATE_DELAY_MASK  (0xE0U)
#define XTALOSC_CTRL_24M_SET_CLKGATE_DELAY_SHIFT (5U)
#define XTALOSC_CTRL_24M_SET_CLKGATE_DELAY(x)    (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_SET_CLKGATE_DELAY_SHIFT)) & XTALOSC_CTRL_24M_SET_CLKGATE_DELAY_MASK)
#define XTALOSC_CTRL_24M_SET_RCOSC_CG_OVERRIDE_MASK (0x100U)
#define XTALOSC_CTRL_24M_SET_RCOSC_CG_OVERRIDE_SHIFT (8U)
#define XTALOSC_CTRL_24M_SET_XTALOSC_PWRUP_DELAY_MASK (0x600U)
#define XTALOSC_CTRL_24M_SET_XTALOSC_PWRUP_DELAY_SHIFT (9U)
#define XTALOSC_CTRL_24M_SET_XTALOSC_PWRUP_DELAY(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_SET_XTALOSC_PWRUP_DELAY_SHIFT)) & XTALOSC_CTRL_24M_SET_XTALOSC_PWRUP_DELAY_MASK)
#define XTALOSC_CTRL_24M_SET_XTALOSC_PWRUP_STAT_MASK (0x800U)
#define XTALOSC_CTRL_24M_SET_XTALOSC_PWRUP_STAT_SHIFT (11U)
#define XTALOSC_CTRL_24M_SET_OSC_SEL_MASK        (0x1000U)
#define XTALOSC_CTRL_24M_SET_OSC_SEL_SHIFT       (12U)
#define XTALOSC_CTRL_24M_SET_RC_OSC_EN_MASK      (0x2000U)
#define XTALOSC_CTRL_24M_SET_RC_OSC_EN_SHIFT     (13U)
#define XTALOSC_CTRL_24M_SET_XTAL_MISC_MASK      (0x7FFF8000U)
#define XTALOSC_CTRL_24M_SET_XTAL_MISC_SHIFT     (15U)
#define XTALOSC_CTRL_24M_SET_XTAL_MISC(x)        (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_SET_XTAL_MISC_SHIFT)) & XTALOSC_CTRL_24M_SET_XTAL_MISC_MASK)

/*! @name CTRL_24M_CLR - Anadig 24M Oscillator Control Register */
#define XTALOSC_CTRL_24M_CLR_XTAL_24M_PWD_MASK   (0x1U)
#define XTALOSC_CTRL_24M_CLR_XTAL_24M_PWD_SHIFT  (0U)
#define XTALOSC_CTRL_24M_CLR_XTAL_24M_EN_MASK    (0x2U)
#define XTALOSC_CTRL_24M_CLR_XTAL_24M_EN_SHIFT   (1U)
#define XTALOSC_CTRL_24M_CLR_OSC_XTALOK_MASK     (0x4U)
#define XTALOSC_CTRL_24M_CLR_OSC_XTALOK_SHIFT    (2U)
#define XTALOSC_CTRL_24M_CLR_OSC_XTALOK_EN_MASK  (0x8U)
#define XTALOSC_CTRL_24M_CLR_OSC_XTALOK_EN_SHIFT (3U)
#define XTALOSC_CTRL_24M_CLR_CLKGATE_CTRL_MASK   (0x10U)
#define XTALOSC_CTRL_24M_CLR_CLKGATE_CTRL_SHIFT  (4U)
#define XTALOSC_CTRL_24M_CLR_CLKGATE_DELAY_MASK  (0xE0U)
#define XTALOSC_CTRL_24M_CLR_CLKGATE_DELAY_SHIFT (5U)
#define XTALOSC_CTRL_24M_CLR_CLKGATE_DELAY(x)    (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_CLR_CLKGATE_DELAY_SHIFT)) & XTALOSC_CTRL_24M_CLR_CLKGATE_DELAY_MASK)
#define XTALOSC_CTRL_24M_CLR_RCOSC_CG_OVERRIDE_MASK (0x100U)
#define XTALOSC_CTRL_24M_CLR_RCOSC_CG_OVERRIDE_SHIFT (8U)
#define XTALOSC_CTRL_24M_CLR_XTALOSC_PWRUP_DELAY_MASK (0x600U)
#define XTALOSC_CTRL_24M_CLR_XTALOSC_PWRUP_DELAY_SHIFT (9U)
#define XTALOSC_CTRL_24M_CLR_XTALOSC_PWRUP_DELAY(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_CLR_XTALOSC_PWRUP_DELAY_SHIFT)) & XTALOSC_CTRL_24M_CLR_XTALOSC_PWRUP_DELAY_MASK)
#define XTALOSC_CTRL_24M_CLR_XTALOSC_PWRUP_STAT_MASK (0x800U)
#define XTALOSC_CTRL_24M_CLR_XTALOSC_PWRUP_STAT_SHIFT (11U)
#define XTALOSC_CTRL_24M_CLR_OSC_SEL_MASK        (0x1000U)
#define XTALOSC_CTRL_24M_CLR_OSC_SEL_SHIFT       (12U)
#define XTALOSC_CTRL_24M_CLR_RC_OSC_EN_MASK      (0x2000U)
#define XTALOSC_CTRL_24M_CLR_RC_OSC_EN_SHIFT     (13U)
#define XTALOSC_CTRL_24M_CLR_XTAL_MISC_MASK      (0x7FFF8000U)
#define XTALOSC_CTRL_24M_CLR_XTAL_MISC_SHIFT     (15U)
#define XTALOSC_CTRL_24M_CLR_XTAL_MISC(x)        (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_CLR_XTAL_MISC_SHIFT)) & XTALOSC_CTRL_24M_CLR_XTAL_MISC_MASK)

/*! @name CTRL_24M_TOG - Anadig 24M Oscillator Control Register */
#define XTALOSC_CTRL_24M_TOG_XTAL_24M_PWD_MASK   (0x1U)
#define XTALOSC_CTRL_24M_TOG_XTAL_24M_PWD_SHIFT  (0U)
#define XTALOSC_CTRL_24M_TOG_XTAL_24M_EN_MASK    (0x2U)
#define XTALOSC_CTRL_24M_TOG_XTAL_24M_EN_SHIFT   (1U)
#define XTALOSC_CTRL_24M_TOG_OSC_XTALOK_MASK     (0x4U)
#define XTALOSC_CTRL_24M_TOG_OSC_XTALOK_SHIFT    (2U)
#define XTALOSC_CTRL_24M_TOG_OSC_XTALOK_EN_MASK  (0x8U)
#define XTALOSC_CTRL_24M_TOG_OSC_XTALOK_EN_SHIFT (3U)
#define XTALOSC_CTRL_24M_TOG_CLKGATE_CTRL_MASK   (0x10U)
#define XTALOSC_CTRL_24M_TOG_CLKGATE_CTRL_SHIFT  (4U)
#define XTALOSC_CTRL_24M_TOG_CLKGATE_DELAY_MASK  (0xE0U)
#define XTALOSC_CTRL_24M_TOG_CLKGATE_DELAY_SHIFT (5U)
#define XTALOSC_CTRL_24M_TOG_CLKGATE_DELAY(x)    (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_TOG_CLKGATE_DELAY_SHIFT)) & XTALOSC_CTRL_24M_TOG_CLKGATE_DELAY_MASK)
#define XTALOSC_CTRL_24M_TOG_RCOSC_CG_OVERRIDE_MASK (0x100U)
#define XTALOSC_CTRL_24M_TOG_RCOSC_CG_OVERRIDE_SHIFT (8U)
#define XTALOSC_CTRL_24M_TOG_XTALOSC_PWRUP_DELAY_MASK (0x600U)
#define XTALOSC_CTRL_24M_TOG_XTALOSC_PWRUP_DELAY_SHIFT (9U)
#define XTALOSC_CTRL_24M_TOG_XTALOSC_PWRUP_DELAY(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_TOG_XTALOSC_PWRUP_DELAY_SHIFT)) & XTALOSC_CTRL_24M_TOG_XTALOSC_PWRUP_DELAY_MASK)
#define XTALOSC_CTRL_24M_TOG_XTALOSC_PWRUP_STAT_MASK (0x800U)
#define XTALOSC_CTRL_24M_TOG_XTALOSC_PWRUP_STAT_SHIFT (11U)
#define XTALOSC_CTRL_24M_TOG_OSC_SEL_MASK        (0x1000U)
#define XTALOSC_CTRL_24M_TOG_OSC_SEL_SHIFT       (12U)
#define XTALOSC_CTRL_24M_TOG_RC_OSC_EN_MASK      (0x2000U)
#define XTALOSC_CTRL_24M_TOG_RC_OSC_EN_SHIFT     (13U)
#define XTALOSC_CTRL_24M_TOG_XTAL_MISC_MASK      (0x7FFF8000U)
#define XTALOSC_CTRL_24M_TOG_XTAL_MISC_SHIFT     (15U)
#define XTALOSC_CTRL_24M_TOG_XTAL_MISC(x)        (((uint32_t)(((uint32_t)(x)) << XTALOSC_CTRL_24M_TOG_XTAL_MISC_SHIFT)) & XTALOSC_CTRL_24M_TOG_XTAL_MISC_MASK)

/*! @name RCOSC_CONFIG0 - Anadig 24MHz RC Osc. config0 Register */
#define XTALOSC_RCOSC_CONFIG0_TUNE_START_MASK    (0x1U)
#define XTALOSC_RCOSC_CONFIG0_TUNE_START_SHIFT   (0U)
#define XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE_MASK   (0x2U)
#define XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE_SHIFT  (1U)
#define XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS_MASK   (0x4U)
#define XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS_SHIFT  (2U)
#define XTALOSC_RCOSC_CONFIG0_TUNE_INVERT_MASK   (0x8U)
#define XTALOSC_RCOSC_CONFIG0_TUNE_INVERT_SHIFT  (3U)
#define XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_MASK   (0xFF0U)
#define XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_SHIFT  (4U)
#define XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG(x)     (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_SHIFT)) & XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_MASK)
#define XTALOSC_RCOSC_CONFIG0_HYST_PLUS_MASK     (0xF000U)
#define XTALOSC_RCOSC_CONFIG0_HYST_PLUS_SHIFT    (12U)
#define XTALOSC_RCOSC_CONFIG0_HYST_PLUS(x)       (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_HYST_PLUS_SHIFT)) & XTALOSC_RCOSC_CONFIG0_HYST_PLUS_MASK)
#define XTALOSC_RCOSC_CONFIG0_HYST_MINUS_MASK    (0xF0000U)
#define XTALOSC_RCOSC_CONFIG0_HYST_MINUS_SHIFT   (16U)
#define XTALOSC_RCOSC_CONFIG0_HYST_MINUS(x)      (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_HYST_MINUS_SHIFT)) & XTALOSC_RCOSC_CONFIG0_HYST_MINUS_MASK)
#define XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR_MASK (0xFF000000U)
#define XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR_SHIFT (24U)
#define XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR_SHIFT)) & XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR_MASK)

/*! @name RCOSC_CONFIG0_SET - Anadig 24MHz RC Osc. config0 Register */
#define XTALOSC_RCOSC_CONFIG0_SET_TUNE_START_MASK (0x1U)
#define XTALOSC_RCOSC_CONFIG0_SET_TUNE_START_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG0_SET_TUNE_ENABLE_MASK (0x2U)
#define XTALOSC_RCOSC_CONFIG0_SET_TUNE_ENABLE_SHIFT (1U)
#define XTALOSC_RCOSC_CONFIG0_SET_TUNE_BYPASS_MASK (0x4U)
#define XTALOSC_RCOSC_CONFIG0_SET_TUNE_BYPASS_SHIFT (2U)
#define XTALOSC_RCOSC_CONFIG0_SET_TUNE_INVERT_MASK (0x8U)
#define XTALOSC_RCOSC_CONFIG0_SET_TUNE_INVERT_SHIFT (3U)
#define XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_MASK (0xFF0U)
#define XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_SHIFT (4U)
#define XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_SHIFT)) & XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_MASK)
#define XTALOSC_RCOSC_CONFIG0_SET_HYST_PLUS_MASK (0xF000U)
#define XTALOSC_RCOSC_CONFIG0_SET_HYST_PLUS_SHIFT (12U)
#define XTALOSC_RCOSC_CONFIG0_SET_HYST_PLUS(x)   (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_SET_HYST_PLUS_SHIFT)) & XTALOSC_RCOSC_CONFIG0_SET_HYST_PLUS_MASK)
#define XTALOSC_RCOSC_CONFIG0_SET_HYST_MINUS_MASK (0xF0000U)
#define XTALOSC_RCOSC_CONFIG0_SET_HYST_MINUS_SHIFT (16U)
#define XTALOSC_RCOSC_CONFIG0_SET_HYST_MINUS(x)  (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_SET_HYST_MINUS_SHIFT)) & XTALOSC_RCOSC_CONFIG0_SET_HYST_MINUS_MASK)
#define XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_CUR_MASK (0xFF000000U)
#define XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_CUR_SHIFT (24U)
#define XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_CUR(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_CUR_SHIFT)) & XTALOSC_RCOSC_CONFIG0_SET_RC_OSC_PROG_CUR_MASK)

/*! @name RCOSC_CONFIG0_CLR - Anadig 24MHz RC Osc. config0 Register */
#define XTALOSC_RCOSC_CONFIG0_CLR_TUNE_START_MASK (0x1U)
#define XTALOSC_RCOSC_CONFIG0_CLR_TUNE_START_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG0_CLR_TUNE_ENABLE_MASK (0x2U)
#define XTALOSC_RCOSC_CONFIG0_CLR_TUNE_ENABLE_SHIFT (1U)
#define XTALOSC_RCOSC_CONFIG0_CLR_TUNE_BYPASS_MASK (0x4U)
#define XTALOSC_RCOSC_CONFIG0_CLR_TUNE_BYPASS_SHIFT (2U)
#define XTALOSC_RCOSC_CONFIG0_CLR_TUNE_INVERT_MASK (0x8U)
#define XTALOSC_RCOSC_CONFIG0_CLR_TUNE_INVERT_SHIFT (3U)
#define XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_MASK (0xFF0U)
#define XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_SHIFT (4U)
#define XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_SHIFT)) & XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_MASK)
#define XTALOSC_RCOSC_CONFIG0_CLR_HYST_PLUS_MASK (0xF000U)
#define XTALOSC_RCOSC_CONFIG0_CLR_HYST_PLUS_SHIFT (12U)
#define XTALOSC_RCOSC_CONFIG0_CLR_HYST_PLUS(x)   (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_CLR_HYST_PLUS_SHIFT)) & XTALOSC_RCOSC_CONFIG0_CLR_HYST_PLUS_MASK)
#define XTALOSC_RCOSC_CONFIG0_CLR_HYST_MINUS_MASK (0xF0000U)
#define XTALOSC_RCOSC_CONFIG0_CLR_HYST_MINUS_SHIFT (16U)
#define XTALOSC_RCOSC_CONFIG0_CLR_HYST_MINUS(x)  (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_CLR_HYST_MINUS_SHIFT)) & XTALOSC_RCOSC_CONFIG0_CLR_HYST_MINUS_MASK)
#define XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_CUR_MASK (0xFF000000U)
#define XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_CUR_SHIFT (24U)
#define XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_CUR(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_CUR_SHIFT)) & XTALOSC_RCOSC_CONFIG0_CLR_RC_OSC_PROG_CUR_MASK)

/*! @name RCOSC_CONFIG0_TOG - Anadig 24MHz RC Osc. config0 Register */
#define XTALOSC_RCOSC_CONFIG0_TOG_TUNE_START_MASK (0x1U)
#define XTALOSC_RCOSC_CONFIG0_TOG_TUNE_START_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG0_TOG_TUNE_ENABLE_MASK (0x2U)
#define XTALOSC_RCOSC_CONFIG0_TOG_TUNE_ENABLE_SHIFT (1U)
#define XTALOSC_RCOSC_CONFIG0_TOG_TUNE_BYPASS_MASK (0x4U)
#define XTALOSC_RCOSC_CONFIG0_TOG_TUNE_BYPASS_SHIFT (2U)
#define XTALOSC_RCOSC_CONFIG0_TOG_TUNE_INVERT_MASK (0x8U)
#define XTALOSC_RCOSC_CONFIG0_TOG_TUNE_INVERT_SHIFT (3U)
#define XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_MASK (0xFF0U)
#define XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_SHIFT (4U)
#define XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_SHIFT)) & XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_MASK)
#define XTALOSC_RCOSC_CONFIG0_TOG_HYST_PLUS_MASK (0xF000U)
#define XTALOSC_RCOSC_CONFIG0_TOG_HYST_PLUS_SHIFT (12U)
#define XTALOSC_RCOSC_CONFIG0_TOG_HYST_PLUS(x)   (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_TOG_HYST_PLUS_SHIFT)) & XTALOSC_RCOSC_CONFIG0_TOG_HYST_PLUS_MASK)
#define XTALOSC_RCOSC_CONFIG0_TOG_HYST_MINUS_MASK (0xF0000U)
#define XTALOSC_RCOSC_CONFIG0_TOG_HYST_MINUS_SHIFT (16U)
#define XTALOSC_RCOSC_CONFIG0_TOG_HYST_MINUS(x)  (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_TOG_HYST_MINUS_SHIFT)) & XTALOSC_RCOSC_CONFIG0_TOG_HYST_MINUS_MASK)
#define XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_CUR_MASK (0xFF000000U)
#define XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_CUR_SHIFT (24U)
#define XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_CUR(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_CUR_SHIFT)) & XTALOSC_RCOSC_CONFIG0_TOG_RC_OSC_PROG_CUR_MASK)

/*! @name RCOSC_CONFIG1 - Anadig 24MHz RC Osc. config1 Register */
#define XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG_MASK  (0xFFFU)
#define XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG(x)    (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG_SHIFT)) & XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG_MASK)
#define XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR_MASK  (0xFFF00000U)
#define XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR_SHIFT (20U)
#define XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR(x)    (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR_SHIFT)) & XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR_MASK)

/*! @name RCOSC_CONFIG1_SET - Anadig 24MHz RC Osc. config1 Register */
#define XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_TRG_MASK (0xFFFU)
#define XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_TRG_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_TRG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_TRG_SHIFT)) & XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_TRG_MASK)
#define XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_CUR_MASK (0xFFF00000U)
#define XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_CUR_SHIFT (20U)
#define XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_CUR(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_CUR_SHIFT)) & XTALOSC_RCOSC_CONFIG1_SET_COUNT_RC_CUR_MASK)

/*! @name RCOSC_CONFIG1_CLR - Anadig 24MHz RC Osc. config1 Register */
#define XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_TRG_MASK (0xFFFU)
#define XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_TRG_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_TRG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_TRG_SHIFT)) & XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_TRG_MASK)
#define XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_CUR_MASK (0xFFF00000U)
#define XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_CUR_SHIFT (20U)
#define XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_CUR(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_CUR_SHIFT)) & XTALOSC_RCOSC_CONFIG1_CLR_COUNT_RC_CUR_MASK)

/*! @name RCOSC_CONFIG1_TOG - Anadig 24MHz RC Osc. config1 Register */
#define XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_TRG_MASK (0xFFFU)
#define XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_TRG_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_TRG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_TRG_SHIFT)) & XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_TRG_MASK)
#define XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_CUR_MASK (0xFFF00000U)
#define XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_CUR_SHIFT (20U)
#define XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_CUR(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_CUR_SHIFT)) & XTALOSC_RCOSC_CONFIG1_TOG_COUNT_RC_CUR_MASK)

/*! @name RCOSC_CONFIG2 - Anadig 24MHz RC Osc. config2 Register */
#define XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG_MASK  (0xFFFU)
#define XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG(x)    (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG_SHIFT)) & XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG_MASK)
#define XTALOSC_RCOSC_CONFIG2_ENABLE_1M_MASK     (0x10000U)
#define XTALOSC_RCOSC_CONFIG2_ENABLE_1M_SHIFT    (16U)
#define XTALOSC_RCOSC_CONFIG2_MUX_1M_MASK        (0x20000U)
#define XTALOSC_RCOSC_CONFIG2_MUX_1M_SHIFT       (17U)
#define XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL_MASK (0x80000000U)
#define XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL_SHIFT (31U)

/*! @name RCOSC_CONFIG2_SET - Anadig 24MHz RC Osc. config2 Register */
#define XTALOSC_RCOSC_CONFIG2_SET_COUNT_1M_TRG_MASK (0xFFFU)
#define XTALOSC_RCOSC_CONFIG2_SET_COUNT_1M_TRG_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG2_SET_COUNT_1M_TRG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG2_SET_COUNT_1M_TRG_SHIFT)) & XTALOSC_RCOSC_CONFIG2_SET_COUNT_1M_TRG_MASK)
#define XTALOSC_RCOSC_CONFIG2_SET_ENABLE_1M_MASK (0x10000U)
#define XTALOSC_RCOSC_CONFIG2_SET_ENABLE_1M_SHIFT (16U)
#define XTALOSC_RCOSC_CONFIG2_SET_MUX_1M_MASK    (0x20000U)
#define XTALOSC_RCOSC_CONFIG2_SET_MUX_1M_SHIFT   (17U)
#define XTALOSC_RCOSC_CONFIG2_SET_CLK_1M_ERR_FL_MASK (0x80000000U)
#define XTALOSC_RCOSC_CONFIG2_SET_CLK_1M_ERR_FL_SHIFT (31U)

/*! @name RCOSC_CONFIG2_CLR - Anadig 24MHz RC Osc. config2 Register */
#define XTALOSC_RCOSC_CONFIG2_CLR_COUNT_1M_TRG_MASK (0xFFFU)
#define XTALOSC_RCOSC_CONFIG2_CLR_COUNT_1M_TRG_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG2_CLR_COUNT_1M_TRG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG2_CLR_COUNT_1M_TRG_SHIFT)) & XTALOSC_RCOSC_CONFIG2_CLR_COUNT_1M_TRG_MASK)
#define XTALOSC_RCOSC_CONFIG2_CLR_ENABLE_1M_MASK (0x10000U)
#define XTALOSC_RCOSC_CONFIG2_CLR_ENABLE_1M_SHIFT (16U)
#define XTALOSC_RCOSC_CONFIG2_CLR_MUX_1M_MASK    (0x20000U)
#define XTALOSC_RCOSC_CONFIG2_CLR_MUX_1M_SHIFT   (17U)
#define XTALOSC_RCOSC_CONFIG2_CLR_CLK_1M_ERR_FL_MASK (0x80000000U)
#define XTALOSC_RCOSC_CONFIG2_CLR_CLK_1M_ERR_FL_SHIFT (31U)

/*! @name RCOSC_CONFIG2_TOG - Anadig 24MHz RC Osc. config2 Register */
#define XTALOSC_RCOSC_CONFIG2_TOG_COUNT_1M_TRG_MASK (0xFFFU)
#define XTALOSC_RCOSC_CONFIG2_TOG_COUNT_1M_TRG_SHIFT (0U)
#define XTALOSC_RCOSC_CONFIG2_TOG_COUNT_1M_TRG(x) (((uint32_t)(((uint32_t)(x)) << XTALOSC_RCOSC_CONFIG2_TOG_COUNT_1M_TRG_SHIFT)) & XTALOSC_RCOSC_CONFIG2_TOG_COUNT_1M_TRG_MASK)
#define XTALOSC_RCOSC_CONFIG2_TOG_ENABLE_1M_MASK (0x10000U)
#define XTALOSC_RCOSC_CONFIG2_TOG_ENABLE_1M_SHIFT (16U)
#define XTALOSC_RCOSC_CONFIG2_TOG_MUX_1M_MASK    (0x20000U)
#define XTALOSC_RCOSC_CONFIG2_TOG_MUX_1M_SHIFT   (17U)
#define XTALOSC_RCOSC_CONFIG2_TOG_CLK_1M_ERR_FL_MASK (0x80000000U)
#define XTALOSC_RCOSC_CONFIG2_TOG_CLK_1M_ERR_FL_SHIFT (31U)

/*! @name OSC_32K - 32K Oscillator Control Register */
#define XTALOSC_OSC_32K_RTC_XTAL_SOURCE_MASK     (0x1U)
#define XTALOSC_OSC_32K_RTC_XTAL_SOURCE_SHIFT    (0U)

/*! @name OSC_32K_SET - 32K Oscillator Control Register */
#define XTALOSC_OSC_32K_SET_RTC_XTAL_SOURCE_MASK (0x1U)
#define XTALOSC_OSC_32K_SET_RTC_XTAL_SOURCE_SHIFT (0U)

/*! @name OSC_32K_CLR - 32K Oscillator Control Register */
#define XTALOSC_OSC_32K_CLR_RTC_XTAL_SOURCE_MASK (0x1U)
#define XTALOSC_OSC_32K_CLR_RTC_XTAL_SOURCE_SHIFT (0U)

/*! @name OSC_32K_TOG - 32K Oscillator Control Register */
#define XTALOSC_OSC_32K_TOG_RTC_XTAL_SOURCE_MASK (0x1U)
#define XTALOSC_OSC_32K_TOG_RTC_XTAL_SOURCE_SHIFT (0U)


/*!
 * @}
 */ /* end of group XTALOSC_Register_Masks */


/* XTALOSC - Peripheral instance base addresses */
/** Peripheral XTALOSC base pointer */
#define XTALOSC_BASE_PTR                         ((XTALOSC_MemMapPtr)0x30360000u)
/** Array initializer of XTALOSC peripheral base pointers */
#define XTALOSC_BASE_PTRS                        { XTALOSC_BASE_PTR }

/* ----------------------------------------------------------------------------
   -- XTALOSC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup XTALOSC_Register_Accessor_Macros XTALOSC - Register accessor macros
 * @{
 */


/* XTALOSC - Register instance definitions */
/* XTALOSC */
#define XTALOSC_CTRL_24M                         XTALOSC_CTRL_24M_REG(XTALOSC_BASE_PTR)
#define XTALOSC_CTRL_24M_SET                     XTALOSC_CTRL_24M_SET_REG(XTALOSC_BASE_PTR)
#define XTALOSC_CTRL_24M_CLR                     XTALOSC_CTRL_24M_CLR_REG(XTALOSC_BASE_PTR)
#define XTALOSC_CTRL_24M_TOG                     XTALOSC_CTRL_24M_TOG_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG0                    XTALOSC_RCOSC_CONFIG0_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG0_SET                XTALOSC_RCOSC_CONFIG0_SET_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG0_CLR                XTALOSC_RCOSC_CONFIG0_CLR_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG0_TOG                XTALOSC_RCOSC_CONFIG0_TOG_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG1                    XTALOSC_RCOSC_CONFIG1_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG1_SET                XTALOSC_RCOSC_CONFIG1_SET_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG1_CLR                XTALOSC_RCOSC_CONFIG1_CLR_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG1_TOG                XTALOSC_RCOSC_CONFIG1_TOG_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG2                    XTALOSC_RCOSC_CONFIG2_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG2_SET                XTALOSC_RCOSC_CONFIG2_SET_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG2_CLR                XTALOSC_RCOSC_CONFIG2_CLR_REG(XTALOSC_BASE_PTR)
#define XTALOSC_RCOSC_CONFIG2_TOG                XTALOSC_RCOSC_CONFIG2_TOG_REG(XTALOSC_BASE_PTR)
#define XTALOSC_OSC_32K                          XTALOSC_OSC_32K_REG(XTALOSC_BASE_PTR)
#define XTALOSC_OSC_32K_SET                      XTALOSC_OSC_32K_SET_REG(XTALOSC_BASE_PTR)
#define XTALOSC_OSC_32K_CLR                      XTALOSC_OSC_32K_CLR_REG(XTALOSC_BASE_PTR)
#define XTALOSC_OSC_32K_TOG                      XTALOSC_OSC_32K_TOG_REG(XTALOSC_BASE_PTR)

/*!
 * @}
 */ /* end of group XTALOSC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group XTALOSC_Peripheral */


/*
** End of section using anonymous unions
*/

#if defined (__CC_ARM)
  #pragma pop
#elif defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
  #pragma clang diagnostic pop
#elif defined(__GNUC__)
  /* leave anonymous unions enabled */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=default
#else
  #error Not supported compiler type
#endif

/*!
 * @}
 */ /* end of group Peripheral_defines */


/* ----------------------------------------------------------------------------
   -- SDK Compatibility
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SDK_Compatibility_Symbols SDK Compatibility
 * @{
 */

/* No SDK compatibility issues. */

/*!
 * @}
 */ /* end of group SDK_Compatibility_Symbols */


#else /* #if !defined(MCU_MCIMX7D7_A7) */
  /* There is already included the same memory map. Check if it is compatible (has the same major version) */
  #if (MCU_MEM_MAP_VERSION != 0x0100U)
    #if (!defined(MCU_MEM_MAP_SUPPRESS_VERSION_WARNING))
      #warning There are included two not compatible versions of memory maps. Please check possible differences.
    #endif /* (!defined(MCU_MEM_MAP_SUPPRESS_VERSION_WARNING)) */
  #endif /* (MCU_MEM_MAP_VERSION != 0x0100U) */
#endif  /* #if !defined(MCU_MCIMX7D7_A7) */

